# coding: utf8
from __future__ import unicode_literals


ADJECTIVES_IRREG = {
    "aalénien": ("aalénien",),
    "aalénienne": ("aalénien",),
    "aaléniennes": ("aalénien",),
    "aaléniens": ("aalénien",),
    "abactérien": ("abactérien",),
    "abactérienne": ("abactérien",),
    "abactériennes": ("abactérien",),
    "abactériens": ("abactérien",),
    "abaissable": ("abaissable",),
    "abaissables": ("abaissable",),
    "abaisseur": ("abaisseur",),
    "abaisseurs": ("abaisseur",),
    "abandonnique": ("abandonnique",),
    "abandonniques": ("abandonnique",),
    "abarticulaire": ("abarticulaire",),
    "abarticulaires": ("abarticulaire",),
    "abattable": ("abattable",),
    "abattables": ("abattable",),
    "abaza": ("abaza",),
    "abazas": ("abaza",),
    "abbasside": ("abbasside",),
    "abbassides": ("abbasside",),
    "abbatiale": ("abbatial",),
    "abbatiales": ("abbatial",),
    "abbatial": ("abbatial",),
    "abbatiaux": ("abbatial",),
    "abbevillien": ("abbevillien",),
    "abbevillienne": ("abbevillien",),
    "abbevilliennes": ("abbevillien",),
    "abbevilliens": ("abbevillien",),
    "abdicataire": ("abdicataire",),
    "abdicataires": ("abdicataire",),
    "abdicatif": ("abdicatif",),
    "abdicatifs": ("abdicatif",),
    "abdicative": ("abdicatif",),
    "abdicatives": ("abdicatif",),
    "abdominale": ("abdominal",),
    "abdominales": ("abdominal",),
    "abdominal": ("abdominal",),
    "abdominaux": ("abdominal",),
    "abdomino-génital": ("abdomino-génital",),
    "abdomino-génitaux": ("abdomino-génital",),
    "abdomino-thoracique": ("abdomino-thoracique",),
    "abducteur": ("abducteur",),
    "abducteurs": ("abducteur",),
    "abductrice": ("abducteur",),
    "abductrices": ("abducteur",),
    "abécédaire": ("abécédaire",),
    "abécédaires": ("abécédaire",),
    "abeillère": ("abeiller",),
    "abeillères": ("abeiller",),
    "abeiller": ("abeiller",),
    "abeillers": ("abeiller",),
    "abélien": ("abélien",),
    "abélienne": ("abélien",),
    "abéliennes": ("abélien",),
    "abéliens": ("abélien",),
    "abgal": ("abgal",),
    "abgals": ("abgal",),
    "abiétique": ("abiétique",),
    "abiétiques": ("abiétique",),
    "abiétoformophénolique": ("abiétoformophénolique",),
    "abiétoformophénoliques": ("abiétoformophénolique",),
    "abiétoglycérophtalique": ("abiétoglycérophtalique",),
    "abiétoglycérophtaliques": ("abiétoglycérophtalique",),
    "abiétomaléique": ("abiétomaléique",),
    "abiétomaléiques": ("abiétomaléique",),
    "abiotique": ("abiotique",),
    "abiotiques": ("abiotique",),
    "abjuratoire": ("abjuratoire",),
    "abjuratoires": ("abjuratoire",),
    "abkhaze": ("abkhaze",),
    "abkhazes": ("abkhaze",),
    "ablatif": ("ablatif",),
    "ablatifs": ("ablatif",),
    "ablative": ("ablatif",),
    "ablatives": ("ablatif",),
    "abolitionniste": ("abolitionniste",),
    "abolitionnistes": ("abolitionniste",),
    "abominable": ("abominable",),
    "abominables": ("abominable",),
    "abondanciste": ("abondanciste",),
    "abondancistes": ("abondanciste",),
    "abonnable": ("abonnable",),
    "abonnables": ("abonnable",),
    "abonnataire": ("abonnataire",),
    "abonnataires": ("abonnataire",),
    "abordable": ("abordable",),
    "abordables": ("abordable",),
    "aborigène": ("aborigène",),
    "aborigènes": ("aborigène",),
    "abortif": ("abortif",),
    "abortifs": ("abortif",),
    "abortive": ("abortif",),
    "abortives": ("abortif",),
    "aboulique": ("aboulique",),
    "abouliques": ("aboulique",),
    "abranche": ("abranche",),
    "abranches": ("abranche",),
    "abrasif": ("abrasif",),
    "abrasifs": ("abrasif",),
    "abrasive": ("abrasif",),
    "abrasives": ("abrasif",),
    "abrégeable": ("abrégeable",),
    "abrégeables": ("abrégeable",),
    "abréviateur": ("abréviateur",),
    "abréviateurs": ("abréviateur",),
    "abréviatrice": ("abréviateur",),
    "abréviatrices": ("abréviateur",),
    "abréviatif": ("abréviatif",),
    "abréviatifs": ("abréviatif",),
    "abréviative": ("abréviatif",),
    "abréviatives": ("abréviatif",),
    "abricot": ("abricot",),
    "abrogatif": ("abrogatif",),
    "abrogatifs": ("abrogatif",),
    "abrogative": ("abrogatif",),
    "abrogatives": ("abrogatif",),
    "abrogatoire": ("abrogatoire",),
    "abrogatoires": ("abrogatoire",),
    "abrogeable": ("abrogeable",),
    "abrogeables": ("abrogeable",),
    "abrutisseur": ("abrutisseur",),
    "abrutisseurs": ("abrutisseur",),
    "abrutisseuse": ("abrutisseur",),
    "abrutisseuses": ("abrutisseur",),
    "abruzzaise": ("abruzzais",),
    "abruzzaises": ("abruzzais",),
    "abruzzais": ("abruzzais",),
    "abscissique": ("abscissique",),
    "abscissiques": ("abscissique",),
    "absconse": ("abscons",),
    "absconses": ("abscons",),
    "abscons": ("abscons",),
    "absentéiste": ("absentéiste",),
    "absentéistes": ("absentéiste",),
    "absidale": ("absidal",),
    "absidales": ("absidal",),
    "absidal": ("absidal",),
    "absidaux": ("absidal",),
    "absidiale": ("absidial",),
    "absidiales": ("absidial",),
    "absidial": ("absidial",),
    "absidiaux": ("absidial",),
    "absoluteur": ("absoluteur",),
    "absoluteurs": ("absoluteur",),
    "absolutrice": ("absoluteur",),
    "absolutrices": ("absoluteur",),
    "absolutif": ("absolutif",),
    "absolutifs": ("absolutif",),
    "absolutive": ("absolutif",),
    "absolutives": ("absolutif",),
    "absolutiste": ("absolutiste",),
    "absolutistes": ("absolutiste",),
    "absolutoire": ("absolutoire",),
    "absolutoires": ("absolutoire",),
    "absorbable": ("absorbable",),
    "absorbables": ("absorbable",),
    "absorptif": ("absorptif",),
    "absorptifs": ("absorptif",),
    "absorptive": ("absorptif",),
    "absorptives": ("absorptif",),
    "abstème": ("abstème",),
    "abstèmes": ("abstème",),
    "abstentionniste": ("abstentionniste",),
    "abstentionnistes": ("abstentionniste",),
    "abstracteur": ("abstracteur",),
    "abstracteurs": ("abstracteur",),
    "abstractrice": ("abstracteur",),
    "abstractrices": ("abstracteur",),
    "abstractif": ("abstractif",),
    "abstractifs": ("abstractif",),
    "abstractive": ("abstractif",),
    "abstractives": ("abstractif",),
    "abstractionniste": ("abstractionniste",),
    "abstractionnistes": ("abstractionniste",),
    "abstruse": ("abstrus",),
    "abstruses": ("abstrus",),
    "abstrus": ("abstrus",),
    "absurde": ("absurde",),
    "absurdes": ("absurde",),
    "absurdiste": ("absurdiste",),
    "absurdistes": ("absurdiste",),
    "abusif": ("abusif",),
    "abusifs": ("abusif",),
    "abusive": ("abusif",),
    "abusives": ("abusif",),
    "abyssale": ("abyssal",),
    "abyssales": ("abyssal",),
    "abyssal": ("abyssal",),
    "abyssaux": ("abyssal",),
    "abyssinien": ("abyssinien",),
    "abyssinienne": ("abyssinien",),
    "abyssiniennes": ("abyssinien",),
    "abyssiniens": ("abyssinien",),
    "acacien": ("acacien",),
    "acaciens": ("acacien",),
    "academicus": ("academicus",),
    "académique": ("académique",),
    "académiques": ("académique",),
    "académisable": ("académisable",),
    "académisables": ("académisable",),
    "acadien": ("acadien",),
    "acadienne": ("acadien",),
    "acadiennes": ("acadien",),
    "acadiens": ("acadien",),
    "acajou": ("acajou",),
    "acalculique": ("acalculique",),
    "acalculiques": ("acalculique",),
    "acalorique": ("acalorique",),
    "acaloriques": ("acalorique",),
    "acardiaque": ("acardiaque",),
    "acardiaques": ("acardiaque",),
    "acariâtre": ("acariâtre",),
    "acariâtres": ("acariâtre",),
    "acaricide": ("acaricide",),
    "acaricides": ("acaricide",),
    "acarpe": ("acarpe",),
    "acarpes": ("acarpe",),
    "acatalecte": ("acatalecte",),
    "acatalectes": ("acatalecte",),
    "acatalectique": ("acatalectique",),
    "acatalectiques": ("acatalectique",),
    "acataleptique": ("acataleptique",),
    "acataleptiques": ("acataleptique",),
    "acatène": ("acatène",),
    "acatènes": ("acatène",),
    "acaule": ("acaule",),
    "acaules": ("acaule",),
    "accapareur": ("accapareur",),
    "accapareurs": ("accapareur",),
    "accapareuse": ("accapareur",),
    "accapareuses": ("accapareur",),
    "accélérateur": ("accélérateur",),
    "accélérateurs": ("accélérateur",),
    "accélératrice": ("accélérateur",),
    "accélératrices": ("accélérateur",),
    "accentuable": ("accentuable",),
    "accentuables": ("accentuable",),
    "accentuelle": ("accentuel",),
    "accentuelles": ("accentuel",),
    "accentuel": ("accentuel",),
    "accentuels": ("accentuel",),
    "acceptable": ("acceptable",),
    "acceptables": ("acceptable",),
    "accepteur": ("accepteur",),
    "accepteurs": ("accepteur",),
    "accessible": ("accessible",),
    "accessibles": ("accessible",),
    "accessoire": ("accessoire",),
    "accessoires": ("accessoire",),
    "accidentelle": ("accidentel",),
    "accidentelles": ("accidentel",),
    "accidentel": ("accidentel",),
    "accidentels": ("accidentel",),
    "accidentogène": ("accidentogène",),
    "accidentogènes": ("accidentogène",),
    "accidentologique": ("accidentologique",),
    "accidentologiques": ("accidentologique",),
    "acclimatable": ("acclimatable",),
    "acclimatables": ("acclimatable",),
    "accommodable": ("accommodable",),
    "accommodables": ("accommodable",),
    "accommodateur": ("accommodateur",),
    "accommodateurs": ("accommodateur",),
    "accommodatrice": ("accommodateur",),
    "accommodatrices": ("accommodateur",),
    "accommodatice": ("accommodatice",),
    "accommodatices": ("accommodatice",),
    "accompagnateur": ("accompagnateur",),
    "accompagnateurs": ("accompagnateur",),
    "accompagnatrice": ("accompagnateur",),
    "accompagnatrices": ("accompagnateur",),
    "accordable": ("accordable",),
    "accordables": ("accordable",),
    "accore": ("accore",),
    "accores": ("accore",),
    "accostable": ("accostable",),
    "accostables": ("accostable",),
    "accréditaire": ("accréditaire",),
    "accréditaires": ("accréditaire",),
    "accréditif": ("accréditif",),
    "accréditifs": ("accréditif",),
    "accréditive": ("accréditif",),
    "accréditives": ("accréditif",),
    "accro": ("accro",),
    "accros": ("accro",),
    "accrocheur": ("accrocheur",),
    "accrocheurs": ("accrocheur",),
    "accrocheuse": ("accrocheur",),
    "accrocheuses": ("accrocheur",),
    "acculturatif": ("acculturatif",),
    "acculturatifs": ("acculturatif",),
    "acculturative": ("acculturatif",),
    "acculturatives": ("acculturatif",),
    "accumulateur": ("accumulateur",),
    "accumulateurs": ("accumulateur",),
    "accumulatrice": ("accumulateur",),
    "accumulatrices": ("accumulateur",),
    "accumulatif": ("accumulatif",),
    "accumulatifs": ("accumulatif",),
    "accumulative": ("accumulatif",),
    "accumulatives": ("accumulatif",),
    "accusable": ("accusable",),
    "accusables": ("accusable",),
    "accusateur": ("accusateur",),
    "accusateurs": ("accusateur",),
    "accusatrice": ("accusateur",),
    "accusatrices": ("accusateur",),
    "accusatif": ("accusatif",),
    "accusatifs": ("accusatif",),
    "accusative": ("accusatif",),
    "accusatives": ("accusatif",),
    "accusatoire": ("accusatoire",),
    "accusatoires": ("accusatoire",),
    "acellulaire": ("acellulaire",),
    "acellulaires": ("acellulaire",),
    "acéphale": ("acéphale",),
    "acéphales": ("acéphale",),
    "acerbe": ("acerbe",),
    "acerbes": ("acerbe",),
    "acérée": ("acéré",),
    "acérées": ("acéré",),
    "acéré": ("acéré",),
    "acère": ("acère",),
    "acérés": ("acéré",),
    "acères": ("acère",),
    "acétabulaire": ("acétabulaire",),
    "acétabulaires": ("acétabulaire",),
    "acéteuse": ("acéteux",),
    "acéteuses": ("acéteux",),
    "acéteux": ("acéteux",),
    "acétimétrique": ("acétimétrique",),
    "acétimétriques": ("acétimétrique",),
    "acétique": ("acétique",),
    "acétiques": ("acétique",),
    "acétonémique": ("acétonémique",),
    "acétonémiques": ("acétonémique",),
    "acétonique": ("acétonique",),
    "acétoniques": ("acétonique",),
    "acétonurique": ("acétonurique",),
    "acétonuriques": ("acétonurique",),
    "acétylacétique": ("acétylacétique",),
    "acétylacétiques": ("acétylacétique",),
    "acétylcholinolytique": ("acétylcholinolytique",),
    "acétylcholinolytiques": ("acétylcholinolytique",),
    "acétylcholinomimétique": ("acétylcholinomimétique",),
    "acétylcholinomimétiques": ("acétylcholinomimétique",),
    "acétylénique": ("acétylénique",),
    "acétyléniques": ("acétylénique",),
    "acétylique": ("acétylique",),
    "acétyliques": ("acétylique",),
    "acétylsalicylique": ("acétylsalicylique",),
    "acétylsalicyliques": ("acétylsalicylique",),
    "acharite": ("acharite",),
    "acharites": ("acharite",),
    "achéen": ("achéen",),
    "achéenne": ("achéen",),
    "achéennes": ("achéen",),
    "achéens": ("achéen",),
    "achéménide": ("achéménide",),
    "achéménides": ("achéménide",),
    "acheminable": ("acheminable",),
    "acheminables": ("acheminable",),
    "achérontique": ("achérontique",),
    "achérontiques": ("achérontique",),
    "achetable": ("achetable",),
    "achetables": ("achetable",),
    "acheuléen": ("acheuléen",),
    "acheuléenne": ("acheuléen",),
    "acheuléennes": ("acheuléen",),
    "acheuléens": ("acheuléen",),
    "achevable": ("achevable",),
    "achevables": ("achevable",),
    "achilléen": ("achilléen",),
    "achilléenne": ("achilléen",),
    "achilléennes": ("achilléen",),
    "achilléens": ("achilléen",),
    "acholurique": ("acholurique",),
    "acholuriques": ("acholurique",),
    "achondroplasique": ("achondroplasique",),
    "achondroplasiques": ("achondroplasique",),
    "achromateuse": ("achromateux",),
    "achromateuses": ("achromateux",),
    "achromateux": ("achromateux",),
    "achromatique": ("achromatique",),
    "achromatiques": ("achromatique",),
    "achromatope": ("achromatope",),
    "achromatopes": ("achromatope",),
    "achromatopsique": ("achromatopsique",),
    "achromatopsiques": ("achromatopsique",),
    "achrome": ("achrome",),
    "achromes": ("achrome",),
    "achromique": ("achromique",),
    "achromiques": ("achromique",),
    "aciculaire": ("aciculaire",),
    "aciculaires": ("aciculaire",),
    "acide": ("acide",),
    "acides": ("acide",),
    "acidifiable": ("acidifiable",),
    "acidifiables": ("acidifiable",),
    "acidimétrique": ("acidimétrique",),
    "acidimétriques": ("acidimétrique",),
    "acidiphile": ("acidiphile",),
    "acidiphiles": ("acidiphile",),
    "acido-basique": ("acido-basique",),
    "acidocétosique": ("acidocétosique",),
    "acidocétosiques": ("acidocétosique",),
    "acidophile": ("acidophile",),
    "acidophiles": ("acidophile",),
    "acido-résistant": ("acido-résistant",),
    "aciéreuse": ("aciéreux",),
    "aciéreuses": ("aciéreux",),
    "aciéreux": ("aciéreux",),
    "acinétique": ("acinétique",),
    "acinétiques": ("acinétique",),
    "acineuse": ("acineux",),
    "acineuses": ("acineux",),
    "acineux": ("acineux",),
    "aciniforme": ("aciniforme",),
    "aciniformes": ("aciniforme",),
    "acléidien": ("acléidien",),
    "acléidienne": ("acléidien",),
    "acléidiennes": ("acléidien",),
    "acléidiens": ("acléidien",),
    "aclinale": ("aclinal",),
    "aclinales": ("aclinal",),
    "aclinal": ("aclinal",),
    "aclinaux": ("aclinal",),
    "aclinique": ("aclinique",),
    "acliniques": ("aclinique",),
    "acméiste": ("acméiste",),
    "acméistes": ("acméiste",),
    "acnéique": ("acnéique",),
    "acnéiques": ("acnéique",),
    "acnodale": ("acnodal",),
    "acnodales": ("acnodal",),
    "acnodal": ("acnodal",),
    "acnodaux": ("acnodal",),
    "acône": ("acône",),
    "acônes": ("acône",),
    "aconitique": ("aconitique",),
    "aconitiques": ("aconitique",),
    "acosmique": ("acosmique",),
    "acosmiques": ("acosmique",),
    "acotylédonée": ("acotylédoné",),
    "acotylédonées": ("acotylédoné",),
    "acotylédoné": ("acotylédoné",),
    "acotylédone": ("acotylédone",),
    "acotylédonés": ("acotylédoné",),
    "acotylédones": ("acotylédone",),
    "acoumétrique": ("acoumétrique",),
    "acoumétriques": ("acoumétrique",),
    "acousmatique": ("acousmatique",),
    "acousmatiques": ("acousmatique",),
    "acoustique": ("acoustique",),
    "acoustiques": ("acoustique",),
    "acquise": ("acquis",),
    "acquises": ("acquis",),
    "acquis": ("acquis",),
    "acquisitif": ("acquisitif",),
    "acquisitifs": ("acquisitif",),
    "acquisitive": ("acquisitif",),
    "acquisitives": ("acquisitif",),
    "acquittable": ("acquittable",),
    "acquittables": ("acquittable",),
    "acraspède": ("acraspède",),
    "acraspèdes": ("acraspède",),
    "âcre": ("âcre",),
    "âcres": ("âcre",),
    "acridien": ("acridien",),
    "acridienne": ("acridien",),
    "acridiennes": ("acridien",),
    "acridiens": ("acridien",),
    "acridinique": ("acridinique",),
    "acridiniques": ("acridinique",),
    "acrimonieuse": ("acrimonieux",),
    "acrimonieuses": ("acrimonieux",),
    "acrimonieux": ("acrimonieux",),
    "acritique": ("acritique",),
    "acritiques": ("acritique",),
    "acroamatique": ("acroamatique",),
    "acroamatiques": ("acroamatique",),
    "acroatique": ("acroatique",),
    "acroatiques": ("acroatique",),
    "acrobatique": ("acrobatique",),
    "acrobatiques": ("acrobatique",),
    "acrocarpe": ("acrocarpe",),
    "acrocarpes": ("acrocarpe",),
    "acrocentrique": ("acrocentrique",),
    "acrocentriques": ("acrocentrique",),
    "acrocéphale": ("acrocéphale",),
    "acrocéphales": ("acrocéphale",),
    "acrocéphalique": ("acrocéphalique",),
    "acrocéphaliques": ("acrocéphalique",),
    "acrodonte": ("acrodonte",),
    "acrodontes": ("acrodonte",),
    "acrofaciale": ("acrofacial",),
    "acrofaciales": ("acrofacial",),
    "acrofacial": ("acrofacial",),
    "acrofaciaux": ("acrofacial",),
    "acrolithe": ("acrolithe",),
    "acrolithes": ("acrolithe",),
    "acromégale": ("acromégale",),
    "acromégales": ("acromégale",),
    "acromégalique": ("acromégalique",),
    "acromégaliques": ("acromégalique",),
    "acromésomélique": ("acromésomélique",),
    "acromésoméliques": ("acromésomélique",),
    "acromiale": ("acromial",),
    "acromiales": ("acromial",),
    "acromial": ("acromial",),
    "acromiaux": ("acromial",),
    "acronale": ("acronal",),
    "acronales": ("acronal",),
    "acronal": ("acronal",),
    "acronaux": ("acronal",),
    "acronymique": ("acronymique",),
    "acronymiques": ("acronymique",),
    "acropète": ("acropète",),
    "acropètes": ("acropète",),
    "acrostiche": ("acrostiche",),
    "acrostiches": ("acrostiche",),
    "acrotone": ("acrotone",),
    "acrotones": ("acrotone",),
    "acrylique": ("acrylique",),
    "acryliques": ("acrylique",),
    "actancielle": ("actanciel",),
    "actancielles": ("actanciel",),
    "actanciel": ("actanciel",),
    "actanciels": ("actanciel",),
    "actantielle": ("actantiel",),
    "actantielles": ("actantiel",),
    "actantiel": ("actantiel",),
    "actantiels": ("actantiel",),
    "actiaque": ("actiaque",),
    "actiaques": ("actiaque",),
    "actif": ("actif",),
    "actifs": ("actif",),
    "active": ("actif",),
    "actives": ("actif",),
    "actinifère": ("actinifère",),
    "actinifères": ("actinifère",),
    "actinique": ("actinique",),
    "actiniques": ("actinique",),
    "actinologique": ("actinologique",),
    "actinologiques": ("actinologique",),
    "actinométrique": ("actinométrique",),
    "actinométriques": ("actinométrique",),
    "actinomorphe": ("actinomorphe",),
    "actinomorphes": ("actinomorphe",),
    "actinomycosique": ("actinomycosique",),
    "actinomycosiques": ("actinomycosique",),
    "actinorhizien": ("actinorhizien",),
    "actinorhizienne": ("actinorhizien",),
    "actinorhiziennes": ("actinorhizien",),
    "actinorhiziens": ("actinorhizien",),
    "actionnable": ("actionnable",),
    "actionnables": ("actionnable",),
    "actionnaliste": ("actionnaliste",),
    "actionnalistes": ("actionnaliste",),
    "activable": ("activable",),
    "activables": ("activable",),
    "activateur": ("activateur",),
    "activateurs": ("activateur",),
    "activatrice": ("activateur",),
    "activatrices": ("activateur",),
    "activiste": ("activiste",),
    "activistes": ("activiste",),
    "actualisateur": ("actualisateur",),
    "actualisateurs": ("actualisateur",),
    "actualisatrice": ("actualisateur",),
    "actualisatrices": ("actualisateur",),
    "actuarielle": ("actuariel",),
    "actuarielles": ("actuariel",),
    "actuariel": ("actuariel",),
    "actuariels": ("actuariel",),
    "actuelle": ("actuel",),
    "actuelles": ("actuel",),
    "actuel": ("actuel",),
    "actuels": ("actuel",),
    "aculéate": ("aculéate",),
    "aculéates": ("aculéate",),
    "aculéiforme": ("aculéiforme",),
    "aculéiformes": ("aculéiforme",),
    "acuminifère": ("acuminifère",),
    "acuminifères": ("acuminifère",),
    "acupuncturale": ("acupunctural",),
    "acupuncturales": ("acupunctural",),
    "acupunctural": ("acupunctural",),
    "acupuncturaux": ("acupunctural",),
    "acutangle": ("acutangle",),
    "acutangles": ("acutangle",),
    "acutirostre": ("acutirostre",),
    "acutirostres": ("acutirostre",),
    "acyclique": ("acyclique",),
    "acycliques": ("acyclique",),
    "acyloïnique": ("acyloïnique",),
    "acyloïniques": ("acyloïnique",),
    "adamien": ("adamien",),
    "adamienne": ("adamien",),
    "adamiennes": ("adamien",),
    "adamiens": ("adamien",),
    "adamique": ("adamique",),
    "adamiques": ("adamique",),
    "adamite": ("adamite",),
    "adamites": ("adamite",),
    "adaptable": ("adaptable",),
    "adaptables": ("adaptable",),
    "adaptatif": ("adaptatif",),
    "adaptatifs": ("adaptatif",),
    "adaptative": ("adaptatif",),
    "adaptatives": ("adaptatif",),
    "addictif": ("addictif",),
    "addictifs": ("addictif",),
    "addictive": ("addictif",),
    "addictives": ("addictif",),
    "additif": ("additif",),
    "additifs": ("additif",),
    "additive": ("additif",),
    "additives": ("additif",),
    "additionnable": ("additionnable",),
    "additionnables": ("additionnable",),
    "additionnelle": ("additionnel",),
    "additionnelles": ("additionnel",),
    "additionnel": ("additionnel",),
    "additionnels": ("additionnel",),
    "adducteur": ("adducteur",),
    "adducteurs": ("adducteur",),
    "adductrice": ("adducteur",),
    "adductrices": ("adducteur",),
    "adénoïde": ("adénoïde",),
    "adénoïdes": ("adénoïde",),
    "adénoïdien": ("adénoïdien",),
    "adénoïdienne": ("adénoïdien",),
    "adénoïdiennes": ("adénoïdien",),
    "adénoïdiens": ("adénoïdien",),
    "adénomateuse": ("adénomateux",),
    "adénomateuses": ("adénomateux",),
    "adénomateux": ("adénomateux",),
    "adénovirale": ("adénoviral",),
    "adénovirales": ("adénoviral",),
    "adénoviral": ("adénoviral",),
    "adénoviraux": ("adénoviral",),
    "adénylique": ("adénylique",),
    "adényliques": ("adénylique",),
    "adéphage": ("adéphage",),
    "adéphages": ("adéphage",),
    "adhésif": ("adhésif",),
    "adhésifs": ("adhésif",),
    "adhésive": ("adhésif",),
    "adhésives": ("adhésif",),
    "adiabatique": ("adiabatique",),
    "adiabatiques": ("adiabatique",),
    "adiaphorétique": ("adiaphorétique",),
    "adiaphorétiques": ("adiaphorétique",),
    "adiaphoriste": ("adiaphoriste",),
    "adiaphoristes": ("adiaphoriste",),
    "adimensionnelle": ("adimensionnel",),
    "adimensionnelles": ("adimensionnel",),
    "adimensionnel": ("adimensionnel",),
    "adimensionnels": ("adimensionnel",),
    "adipeuse": ("adipeux",),
    "adipeuses": ("adipeux",),
    "adipeux": ("adipeux",),
    "adipique": ("adipique",),
    "adipiques": ("adipique",),
    "adipokinétique": ("adipokinétique",),
    "adipokinétiques": ("adipokinétique",),
    "adjectif": ("adjectif",),
    "adjectifs": ("adjectif",),
    "adjective": ("adjectif",),
    "adjectives": ("adjectif",),
    "adjectivale": ("adjectival",),
    "adjectivales": ("adjectival",),
    "adjectival": ("adjectival",),
    "adjectivaux": ("adjectival",),
    "adjudicatif": ("adjudicatif",),
    "adjudicatifs": ("adjudicatif",),
    "adjudicative": ("adjudicatif",),
    "adjudicatives": ("adjudicatif",),
    "adlérien": ("adlérien",),
    "adlérienne": ("adlérien",),
    "adlériennes": ("adlérien",),
    "adlériens": ("adlérien",),
    "administrable": ("administrable",),
    "administrables": ("administrable",),
    "administratif": ("administratif",),
    "administratifs": ("administratif",),
    "administrative": ("administratif",),
    "administratives": ("administratif",),
    "admirable": ("admirable",),
    "admirables": ("admirable",),
    "admirateur": ("admirateur",),
    "admirateurs": ("admirateur",),
    "admiratrice": ("admirateur",),
    "admiratrices": ("admirateur",),
    "admiratif": ("admiratif",),
    "admiratifs": ("admiratif",),
    "admirative": ("admiratif",),
    "admiratives": ("admiratif",),
    "admissible": ("admissible",),
    "admissibles": ("admissible",),
    "adnominale": ("adnominal",),
    "adnominales": ("adnominal",),
    "adnominal": ("adnominal",),
    "adnominaux": ("adnominal",),
    "adogmatique": ("adogmatique",),
    "adogmatiques": ("adogmatique",),
    "adonien": ("adonien",),
    "adonienne": ("adonien",),
    "adoniennes": ("adonien",),
    "adoniens": ("adonien",),
    "adonique": ("adonique",),
    "adoniques": ("adonique",),
    "adoptable": ("adoptable",),
    "adoptables": ("adoptable",),
    "adoptianiste": ("adoptianiste",),
    "adoptianistes": ("adoptianiste",),
    "adoptif": ("adoptif",),
    "adoptifs": ("adoptif",),
    "adoptive": ("adoptif",),
    "adoptives": ("adoptif",),
    "adorable": ("adorable",),
    "adorables": ("adorable",),
    "adorale": ("adoral",),
    "adorales": ("adoral",),
    "adoral": ("adoral",),
    "adoraux": ("adoral",),
    "adragante": ("adragante",),
    "adragantes": ("adragante",),
    "adrénalinique": ("adrénalinique",),
    "adrénaliniques": ("adrénalinique",),
    "adrénergique": ("adrénergique",),
    "adrénergiques": ("adrénergique",),
    "adrénolytique": ("adrénolytique",),
    "adrénolytiques": ("adrénolytique",),
    "adressable": ("adressable",),
    "adressables": ("adressable",),
    "adriatique": ("adriatique",),
    "adriatiques": ("adriatique",),
    "adsorbable": ("adsorbable",),
    "adsorbables": ("adsorbable",),
    "adulaire": ("adulaire",),
    "adulaires": ("adulaire",),
    "adulateur": ("adulateur",),
    "adulateurs": ("adulateur",),
    "adulatrice": ("adulateur",),
    "adulatrices": ("adulateur",),
    "adulte": ("adulte",),
    "adultes": ("adulte",),
    "adultère": ("adultère",),
    "adultères": ("adultère",),
    "adventice": ("adventice",),
    "adventices": ("adventice",),
    "adventif": ("adventif",),
    "adventifs": ("adventif",),
    "adventive": ("adventif",),
    "adventives": ("adventif",),
    "adventiste": ("adventiste",),
    "adventistes": ("adventiste",),
    "adverbale": ("adverbal",),
    "adverbales": ("adverbal",),
    "adverbal": ("adverbal",),
    "adverbaux": ("adverbal",),
    "adverbiale": ("adverbial",),
    "adverbiales": ("adverbial",),
    "adverbial": ("adverbial",),
    "adverbiaux": ("adverbial",),
    "adverbialisateur": ("adverbialisateur",),
    "adverbialisateurs": ("adverbialisateur",),
    "adverbialisatrice": ("adverbialisateur",),
    "adverbialisatrices": ("adverbialisateur",),
    "adversatif": ("adversatif",),
    "adversatifs": ("adversatif",),
    "adversative": ("adversatif",),
    "adversatives": ("adversatif",),
    "adverse": ("adverse",),
    "adverses": ("adverse",),
    "adversif": ("adversif",),
    "adversifs": ("adversif",),
    "adversive": ("adversif",),
    "adversives": ("adversif",),
    "adynamique": ("adynamique",),
    "adynamiques": ("adynamique",),
    "aegyrinique": ("aegyrinique",),
    "aegyriniques": ("aegyrinique",),
    "aérateur": ("aérateur",),
    "aérateurs": ("aérateur",),
    "aératrice": ("aérateur",),
    "aératrices": ("aérateur",),
    "aéraulique": ("aéraulique",),
    "aérauliques": ("aéraulique",),
    "aérianiste": ("aérianiste",),
    "aérianistes": ("aérianiste",),
    "aéricole": ("aéricole",),
    "aéricoles": ("aéricole",),
    "aérien": ("aérien",),
    "aérienne": ("aérien",),
    "aériennes": ("aérien",),
    "aériens": ("aérien",),
    "aérifère": ("aérifère",),
    "aérifères": ("aérifère",),
    "aériforme": ("aériforme",),
    "aériformes": ("aériforme",),
    "aérivore": ("aérivore",),
    "aérivores": ("aérivore",),
    "aéroacétylénique": ("aéroacétylénique",),
    "aéroacétyléniques": ("aéroacétylénique",),
    "aérobie": ("aérobie",),
    "aérobies": ("aérobie",),
    "aérobique": ("aérobique",),
    "aérobiques": ("aérobique",),
    "aérodigestif": ("aérodigestif",),
    "aérodigestifs": ("aérodigestif",),
    "aérodigestive": ("aérodigestif",),
    "aérodigestives": ("aérodigestif",),
    "aérodynamique": ("aérodynamique",),
    "aérodynamiques": ("aérodynamique",),
    "aéroélastique": ("aéroélastique",),
    "aéroélastiques": ("aéroélastique",),
    "aérogène": ("aérogène",),
    "aérogènes": ("aérogène",),
    "aérolithique": ("aérolithique",),
    "aérolithiques": ("aérolithique",),
    "aérologique": ("aérologique",),
    "aérologiques": ("aérologique",),
    "aéromaritime": ("aéromaritime",),
    "aéromaritimes": ("aéromaritime",),
    "aéromobile": ("aéromobile",),
    "aéromobiles": ("aéromobile",),
    "aéronautique": ("aéronautique",),
    "aéronautiques": ("aéronautique",),
    "aéronomique": ("aéronomique",),
    "aéronomiques": ("aéronomique",),
    "aérophotogrammétrique": ("aérophotogrammétrique",),
    "aérophotogrammétriques": ("aérophotogrammétrique",),
    "aéroportable": ("aéroportable",),
    "aéroportables": ("aéroportable",),
    "aéroportuaire": ("aéroportuaire",),
    "aéroportuaires": ("aéroportuaire",),
    "aéropostale": ("aéropostal",),
    "aéropostales": ("aéropostal",),
    "aéropostal": ("aéropostal",),
    "aéropostaux": ("aéropostal",),
    "aérospatiale": ("aérospatial",),
    "aérospatiales": ("aérospatial",),
    "aérospatial": ("aérospatial",),
    "aérospatiaux": ("aérospatial",),
    "aérostatique": ("aérostatique",),
    "aérostatiques": ("aérostatique",),
    "aérosynchrone": ("aérosynchrone",),
    "aérosynchrones": ("aérosynchrone",),
    "aérotechnique": ("aérotechnique",),
    "aérotechniques": ("aérotechnique",),
    "aéroterrestre": ("aéroterrestre",),
    "aéroterrestres": ("aéroterrestre",),
    "aérothermique": ("aérothermique",),
    "aérothermiques": ("aérothermique",),
    "aérotransportable": ("aérotransportable",),
    "aérotransportables": ("aérotransportable",),
    "aérotympanique": ("aérotympanique",),
    "aérotympaniques": ("aérotympanique",),
    "aethésiogène": ("aethésiogène",),
    "aethésiogènes": ("aethésiogène",),
    "afar": ("afar",),
    "afars": ("afar",),
    "affable": ("affable",),
    "affables": ("affable",),
    "affabulateur": ("affabulateur",),
    "affabulateurs": ("affabulateur",),
    "affabulatrice": ("affabulateur",),
    "affabulatrices": ("affabulateur",),
    "affaiblisseur": ("affaiblisseur",),
    "affaiblisseurs": ("affaiblisseur",),
    "affaiblisseuse": ("affaiblisseur",),
    "affaiblisseuses": ("affaiblisseur",),
    "affairiste": ("affairiste",),
    "affairistes": ("affairiste",),
    "affectable": ("affectable",),
    "affectables": ("affectable",),
    "affectataire": ("affectataire",),
    "affectataires": ("affectataire",),
    "affectif": ("affectif",),
    "affectifs": ("affectif",),
    "affective": ("affectif",),
    "affectives": ("affectif",),
    "affectueuse": ("affectueux",),
    "affectueuses": ("affectueux",),
    "affectueux": ("affectueux",),
    "affermable": ("affermable",),
    "affermables": ("affermable",),
    "affichable": ("affichable",),
    "affichables": ("affichable",),
    "affinée": ("affiné",),
    "affinées": ("affiné",),
    "affiné": ("affiné",),
    "affine": ("affine",),
    "affinés": ("affiné",),
    "affines": ("affine",),
    "affinitaire": ("affinitaire",),
    "affinitaires": ("affinitaire",),
    "affirmatif": ("affirmatif",),
    "affirmatifs": ("affirmatif",),
    "affirmative": ("affirmatif",),
    "affirmatives": ("affirmatif",),
    "affixale": ("affixal",),
    "affixales": ("affixal",),
    "affixal": ("affixal",),
    "affixaux": ("affixal",),
    "affixée": ("affixé",),
    "affixées": ("affixé",),
    "affixé": ("affixé",),
    "affixe": ("affixe",),
    "affixés": ("affixé",),
    "affixes": ("affixe",),
    "afflictif": ("afflictif",),
    "afflictifs": ("afflictif",),
    "afflictive": ("afflictif",),
    "afflictives": ("afflictif",),
    "affouagère": ("affouager",),
    "affouagères": ("affouager",),
    "affouager": ("affouager",),
    "affouagers": ("affouager",),
    "affouillable": ("affouillable",),
    "affouillables": ("affouillable",),
    "affranchissable": ("affranchissable",),
    "affranchissables": ("affranchissable",),
    "affranchisseur": ("affranchisseur",),
    "affranchisseurs": ("affranchisseur",),
    "affranchisseuse": ("affranchisseur",),
    "affranchisseuses": ("affranchisseur",),
    "affreuse": ("affreux",),
    "affreuses": ("affreux",),
    "affreux": ("affreux",),
    "affriquée": ("affriquée",),
    "affriquées": ("affriquée",),
    "afocale": ("afocal",),
    "afocales": ("afocal",),
    "afocal": ("afocal",),
    "afocaux": ("afocal",),
    "africaniste": ("africaniste",),
    "africanistes": ("africaniste",),
    "afrikaander": ("afrikaander",),
    "afrikaanders": ("afrikaander",),
    "afrikander": ("afrikander",),
    "afrikanders": ("afrikander",),
    "afrikaner": ("afrikaner",),
    "afrikaners": ("afrikaner",),
    "afro": ("afro",),
    "afro-américaine": ("afro-américain",),
    "afroaméricaine": ("afroaméricain",),
    "afro-américaines": ("afro-américain",),
    "afroaméricaines": ("afroaméricain",),
    "afro-américain": ("afro-américain",),
    "afroaméricain": ("afroaméricain",),
    "afro-américains": ("afro-américain",),
    "afroaméricains": ("afroaméricain",),
    "afro-asiatique": ("afro-asiatique",),
    "afroasiatique": ("afroasiatique",),
    "afroasiatiques": ("afroasiatique",),
    "afro-brésilien": ("afro-brésilien",),
    "afro-brésiliens": ("afro-brésilien",),
    "afrocentriste": ("afrocentriste",),
    "afrocentristes": ("afrocentriste",),
    "afro-cubaines": ("afro-cubain",),
    "afro-cubain": ("afro-cubain",),
    "afro-cubains": ("afro-cubain",),
    "agame": ("agame",),
    "agames": ("agame",),
    "agenaise": ("agenais",),
    "agenaises": ("agenais",),
    "agenais": ("agenais",),
    "agénésique": ("agénésique",),
    "agénésiques": ("agénésique",),
    "agentif": ("agentif",),
    "agentifs": ("agentif",),
    "agentive": ("agentif",),
    "agentives": ("agentif",),
    "aggadique": ("aggadique",),
    "aggadiques": ("aggadique",),
    "agglomératif": ("agglomératif",),
    "agglomératifs": ("agglomératif",),
    "agglomérative": ("agglomératif",),
    "agglomératives": ("agglomératif",),
    "agglutinable": ("agglutinable",),
    "agglutinables": ("agglutinable",),
    "agile": ("agile",),
    "agiles": ("agile",),
    "aglomérulaire": ("aglomérulaire",),
    "aglomérulaires": ("aglomérulaire",),
    "aglosse": ("aglosse",),
    "aglosses": ("aglosse",),
    "aglyphe": ("aglyphe",),
    "aglyphes": ("aglyphe",),
    "agnathe": ("agnathe",),
    "agnathes": ("agnathe",),
    "agnatique": ("agnatique",),
    "agnatiques": ("agnatique",),
    "agneline": ("agneline",),
    "agnelines": ("agneline",),
    "agnosique": ("agnosique",),
    "agnosiques": ("agnosique",),
    "agnostique": ("agnostique",),
    "agnostiques": ("agnostique",),
    "agogique": ("agogique",),
    "agogiques": ("agogique",),
    "agonique": ("agonique",),
    "agoniques": ("agonique",),
    "agoniste": ("agoniste",),
    "agonistes": ("agoniste",),
    "agonistique": ("agonistique",),
    "agonistiques": ("agonistique",),
    "agoraphobe": ("agoraphobe",),
    "agoraphobes": ("agoraphobe",),
    "agrafeur": ("agrafeur",),
    "agrafeurs": ("agrafeur",),
    "agrafeuse": ("agrafeur",),
    "agrafeuses": ("agrafeur",),
    "agraire": ("agraire",),
    "agraires": ("agraire",),
    "agrammaticale": ("agrammatical",),
    "agrammaticales": ("agrammatical",),
    "agrammatical": ("agrammatical",),
    "agrammaticaux": ("agrammatical",),
    "agrammatique": ("agrammatique",),
    "agrammatiques": ("agrammatique",),
    "agranulaire": ("agranulaire",),
    "agranulaires": ("agranulaire",),
    "agraphique": ("agraphique",),
    "agraphiques": ("agraphique",),
    "agrarien": ("agrarien",),
    "agrarienne": ("agrarien",),
    "agrariennes": ("agrarien",),
    "agrariens": ("agrarien",),
    "agréable": ("agréable",),
    "agréables": ("agréable",),
    "agrégatif": ("agrégatif",),
    "agrégatifs": ("agrégatif",),
    "agrégative": ("agrégatif",),
    "agrégatives": ("agrégatif",),
    "agrégeable": ("agrégeable",),
    "agrégeables": ("agrégeable",),
    "agresseur": ("agresseur",),
    "agresseurs": ("agresseur",),
    "agresseuse": ("agresseur",),
    "agresseuses": ("agresseur",),
    "agressif": ("agressif",),
    "agressifs": ("agressif",),
    "agressive": ("agressif",),
    "agressives": ("agressif",),
    "agreste": ("agreste",),
    "agrestes": ("agreste",),
    "agricole": ("agricole",),
    "agricoles": ("agricole",),
    "agro-alimentaire": ("agro-alimentaire",),
    "agroalimentaire": ("agroalimentaire",),
    "agro-alimentaires": ("agro-alimentaire",),
    "agroalimentaires": ("agroalimentaire",),
    "agrobiologique": ("agrobiologique",),
    "agrobiologiques": ("agrobiologique",),
    "agrochimique": ("agrochimique",),
    "agrochimiques": ("agrochimique",),
    "agroclimatologique": ("agroclimatologique",),
    "agroclimatologiques": ("agroclimatologique",),
    "agrogéologique": ("agrogéologique",),
    "agrogéologiques": ("agrogéologique",),
    "agro-industriel": ("agro-industriel",),
    "agro-industriels": ("agro-industriel",),
    "agrologique": ("agrologique",),
    "agrologiques": ("agrologique",),
    "agrométéorologique": ("agrométéorologique",),
    "agrométéorologiques": ("agrométéorologique",),
    "agronomique": ("agronomique",),
    "agronomiques": ("agronomique",),
    "agropastorale": ("agropastoral",),
    "agropastorales": ("agropastoral",),
    "agropastoral": ("agropastoral",),
    "agropastoraux": ("agropastoral",),
    "agrotechnique": ("agrotechnique",),
    "agrotechniques": ("agrotechnique",),
    "aguicheur": ("aguicheur",),
    "aguicheurs": ("aguicheur",),
    "aguicheuse": ("aguicheur",),
    "aguicheuses": ("aguicheur",),
    "ahistorique": ("ahistorique",),
    "ahistoriques": ("ahistorique",),
    "aigre": ("aigre",),
    "aigres": ("aigre",),
    "aigre-douce": ("aigre-doux",),
    "aigre-doux": ("aigre-doux",),
    "aigres-douces": ("aigre-doux",),
    "aigres-doux": ("aigre-doux",),
    "aigrelet": ("aigrelet",),
    "aigrelets": ("aigrelet",),
    "aigrelette": ("aigrelet",),
    "aigrelettes": ("aigrelet",),
    "aiguë": ("aigu",),
    "aiguës": ("aigu",),
    "aigu": ("aigu",),
    "aigus": ("aigu",),
    "aiguisable": ("aiguisable",),
    "aiguisables": ("aiguisable",),
    "aiguiseur": ("aiguiseur",),
    "aiguiseurs": ("aiguiseur",),
    "aiguiseuse": ("aiguiseur",),
    "aiguiseuses": ("aiguiseur",),
    "aimable": ("aimable",),
    "aimables": ("aimable",),
    "aïnou": ("aïnou",),
    "aïnous": ("aïnou",),
    "aisée": ("aisé",),
    "aisées": ("aisé",),
    "aisé": ("aisé",),
    "aise": ("aise",),
    "aisés": ("aisé",),
    "aises": ("aise",),
    "aixoise": ("aixois",),
    "aixoises": ("aixois",),
    "aixois": ("aixois",),
    "ajiste": ("ajiste",),
    "ajistes": ("ajiste",),
    "ajournable": ("ajournable",),
    "ajournables": ("ajournable",),
    "ajustable": ("ajustable",),
    "ajustables": ("ajustable",),
    "akinétique": ("akinétique",),
    "akinétiques": ("akinétique",),
    "akkadien": ("akkadien",),
    "akkadienne": ("akkadien",),
    "akkadiennes": ("akkadien",),
    "akkadiens": ("akkadien",),
    "akritique": ("akritique",),
    "akritiques": ("akritique",),
    "alaire": ("alaire",),
    "alaires": ("alaire",),
    "alaouite": ("alaouite",),
    "alaouites": ("alaouite",),
    "alarmiste": ("alarmiste",),
    "alarmistes": ("alarmiste",),
    "albanaise": ("albanais",),
    "albanaises": ("albanais",),
    "albanais": ("albanais",),
    "albanophone": ("albanophone",),
    "albanophones": ("albanophone",),
    "albien": ("albien",),
    "albienne": ("albien",),
    "albiennes": ("albien",),
    "albiens": ("albien",),
    "albigeoise": ("albigeois",),
    "albigeoises": ("albigeois",),
    "albigeois": ("albigeois",),
    "albinos": ("albinos",),
    "alboche": ("alboche",),
    "alboches": ("alboche",),
    "albumineuse": ("albumineux",),
    "albumineuses": ("albumineux",),
    "albumineux": ("albumineux",),
    "albuminoïde": ("albuminoïde",),
    "albuminoïdes": ("albuminoïde",),
    "albuminorachique": ("albuminorachique",),
    "albuminorachiques": ("albuminorachique",),
    "albuminurique": ("albuminurique",),
    "albuminuriques": ("albuminurique",),
    "albumoïde": ("albumoïde",),
    "albumoïdes": ("albumoïde",),
    "alcaïque": ("alcaïque",),
    "alcaïques": ("alcaïque",),
    "alcalimétrique": ("alcalimétrique",),
    "alcalimétriques": ("alcalimétrique",),
    "alcalinoterreuse": ("alcalinoterreux",),
    "alcalino-terreuses": ("alcalinoterreux",),
    "alcalinoterreuses": ("alcalinoterreux",),
    "alcalinoterreux": ("alcalinoterreux",),
    "alcaloïdique": ("alcaloïdique",),
    "alcaloïdiques": ("alcaloïdique",),
    "alcaloïfère": ("alcaloïfère",),
    "alcaloïfères": ("alcaloïfère",),
    "alchimique": ("alchimique",),
    "alchimiques": ("alchimique",),
    "alcoolémique": ("alcoolémique",),
    "alcoolémiques": ("alcoolémique",),
    "alcoolique": ("alcoolique",),
    "alcooliques": ("alcoolique",),
    "alcoolisable": ("alcoolisable",),
    "alcoolisables": ("alcoolisable",),
    "alcoométrique": ("alcoométrique",),
    "alcoométriques": ("alcoométrique",),
    "alcyonien": ("alcyonien",),
    "alcyonienne": ("alcyonien",),
    "alcyoniennes": ("alcyonien",),
    "alcyoniens": ("alcyonien",),
    "aldéhydique": ("aldéhydique",),
    "aldéhydiques": ("aldéhydique",),
    "aldonique": ("aldonique",),
    "aldoniques": ("aldonique",),
    "aléatoire": ("aléatoire",),
    "aléatoires": ("aléatoire",),
    "alémanique": ("alémanique",),
    "alémaniques": ("alémanique",),
    "alénoise": ("alénois",),
    "alénoises": ("alénois",),
    "alénois": ("alénois",),
    "aléoute": ("aléoute",),
    "aléoutes": ("aléoute",),
    "aléoutien": ("aléoutien",),
    "aléoutienne": ("aléoutien",),
    "aléoutiennes": ("aléoutien",),
    "aléoutiens": ("aléoutien",),
    "alerte": ("alerte",),
    "alertes": ("alerte",),
    "alésable": ("alésable",),
    "alésables": ("alésable",),
    "aléseur": ("aléseur",),
    "aléseurs": ("aléseur",),
    "aléseuse": ("aléseur",),
    "aléseuses": ("aléseur",),
    "aléthique": ("aléthique",),
    "aléthiques": ("aléthique",),
    "aleucémique": ("aleucémique",),
    "aleucémiques": ("aleucémique",),
    "aleurobie": ("aleurobie",),
    "aleurobies": ("aleurobie",),
    "alexique": ("alexique",),
    "alexiques": ("alexique",),
    "alfatière": ("alfatier",),
    "alfatières": ("alfatier",),
    "alfatier": ("alfatier",),
    "alfatiers": ("alfatier",),
    "algale": ("algal",),
    "algales": ("algal",),
    "algal": ("algal",),
    "algaux": ("algal",),
    "algébrique": ("algébrique",),
    "algébriques": ("algébrique",),
    "algérien": ("algérien",),
    "algérienne": ("algérien",),
    "algériennes": ("algérien",),
    "algériens": ("algérien",),
    "algéroise": ("algérois",),
    "algéroises": ("algérois",),
    "algérois": ("algérois",),
    "algésiogène": ("algésiogène",),
    "algésiogènes": ("algésiogène",),
    "algésique": ("algésique",),
    "algésiques": ("algésique",),
    "algide": ("algide",),
    "algides": ("algide",),
    "alginique": ("alginique",),
    "alginiques": ("alginique",),
    "algique": ("algique",),
    "algiques": ("algique",),
    "algogène": ("algogène",),
    "algogènes": ("algogène",),
    "algoïde": ("algoïde",),
    "algoïdes": ("algoïde",),
    "algologique": ("algologique",),
    "algologiques": ("algologique",),
    "algonkien": ("algonkien",),
    "algonkienne": ("algonkien",),
    "algonkiennes": ("algonkien",),
    "algonkiens": ("algonkien",),
    "algonquien": ("algonquien",),
    "algonquienne": ("algonquien",),
    "algonquiennes": ("algonquien",),
    "algonquiens": ("algonquien",),
    "algophile": ("algophile",),
    "algophiles": ("algophile",),
    "algophobe": ("algophobe",),
    "algophobes": ("algophobe",),
    "algorithmique": ("algorithmique",),
    "algorithmiques": ("algorithmique",),
    "alicyclique": ("alicyclique",),
    "alicycliques": ("alicyclique",),
    "aliénable": ("aliénable",),
    "aliénables": ("aliénable",),
    "aliéniste": ("aliéniste",),
    "aliénistes": ("aliéniste",),
    "alifère": ("alifère",),
    "alifères": ("alifère",),
    "aliforme": ("aliforme",),
    "aliformes": ("aliforme",),
    "aliginique": ("aliginique",),
    "aliginiques": ("aliginique",),
    "alimentaire": ("alimentaire",),
    "alimentaires": ("alimentaire",),
    "alimentateur": ("alimentateur",),
    "alimentateurs": ("alimentateur",),
    "alimentatrice": ("alimentateur",),
    "alimentatrices": ("alimentateur",),
    "alinéaire": ("alinéaire",),
    "alinéaires": ("alinéaire",),
    "aliphatique": ("aliphatique",),
    "aliphatiques": ("aliphatique",),
    "aliquante": ("aliquante",),
    "aliquantes": ("aliquante",),
    "aliquote": ("aliquote",),
    "aliquotes": ("aliquote",),
    "alizéen": ("alizéen",),
    "alizéenne": ("alizéen",),
    "alizéennes": ("alizéen",),
    "alizéens": ("alizéen",),
    "allantoïdien": ("allantoïdien",),
    "allantoïdienne": ("allantoïdien",),
    "allantoïdiennes": ("allantoïdien",),
    "allantoïdiens": ("allantoïdien",),
    "allate": ("allate",),
    "allates": ("allate",),
    "allégable": ("allégable",),
    "allégables": ("allégable",),
    "allégeable": ("allégeable",),
    "allégeables": ("allégeable",),
    "allégorique": ("allégorique",),
    "allégoriques": ("allégorique",),
    "allègre": ("allègre",),
    "allègres": ("allègre",),
    "allèle": ("allèle",),
    "allèles": ("allèle",),
    "allélique": ("allélique",),
    "alléliques": ("allélique",),
    "allélogène": ("allélogène",),
    "allélogènes": ("allélogène",),
    "allélomorphe": ("allélomorphe",),
    "allélomorphes": ("allélomorphe",),
    "allélomorphique": ("allélomorphique",),
    "allélomorphiques": ("allélomorphique",),
    "allélotrope": ("allélotrope",),
    "allélotropes": ("allélotrope",),
    "allénique": ("allénique",),
    "alléniques": ("allénique",),
    "allénolique": ("allénolique",),
    "allénoliques": ("allénolique",),
    "allergène": ("allergène",),
    "allergènes": ("allergène",),
    "allergénique": ("allergénique",),
    "allergéniques": ("allergénique",),
    "allergique": ("allergique",),
    "allergiques": ("allergique",),
    "allergologique": ("allergologique",),
    "allergologiques": ("allergologique",),
    "alliable": ("alliable",),
    "alliables": ("alliable",),
    "allitératif": ("allitératif",),
    "allitératifs": ("allitératif",),
    "allitérative": ("allitératif",),
    "allitératives": ("allitératif",),
    "allitique": ("allitique",),
    "allitiques": ("allitique",),
    "allocatif": ("allocatif",),
    "allocatifs": ("allocatif",),
    "allocative": ("allocatif",),
    "allocatives": ("allocatif",),
    "allocentriste": ("allocentriste",),
    "allocentristes": ("allocentriste",),
    "allochtone": ("allochtone",),
    "allochtones": ("allochtone",),
    "allodiale": ("allodial",),
    "allodiales": ("allodial",),
    "allodial": ("allodial",),
    "allodiaux": ("allodial",),
    "allogame": ("allogame",),
    "allogames": ("allogame",),
    "allogène": ("allogène",),
    "allogènes": ("allogène",),
    "allogénique": ("allogénique",),
    "allogéniques": ("allogénique",),
    "alloglotte": ("alloglotte",),
    "alloglottes": ("alloglotte",),
    "allométrique": ("allométrique",),
    "allométriques": ("allométrique",),
    "allongeable": ("allongeable",),
    "allongeables": ("allongeable",),
    "allopathe": ("allopathe",),
    "allopathes": ("allopathe",),
    "allopathique": ("allopathique",),
    "allopathiques": ("allopathique",),
    "allopatrique": ("allopatrique",),
    "allopatriques": ("allopatrique",),
    "allophanique": ("allophanique",),
    "allophaniques": ("allophanique",),
    "allophone": ("allophone",),
    "allophones": ("allophone",),
    "allostérique": ("allostérique",),
    "allostériques": ("allostérique",),
    "allotonique": ("allotonique",),
    "allotoniques": ("allotonique",),
    "allotropique": ("allotropique",),
    "allotropiques": ("allotropique",),
    "allotypique": ("allotypique",),
    "allotypiques": ("allotypique",),
    "allouable": ("allouable",),
    "allouables": ("allouable",),
    "alloxurique": ("alloxurique",),
    "alloxuriques": ("alloxurique",),
    "allumettière": ("allumettier",),
    "allumettières": ("allumettier",),
    "allumettier": ("allumettier",),
    "allumettiers": ("allumettier",),
    "allumeur": ("allumeur",),
    "allumeurs": ("allumeur",),
    "allumeuse": ("allumeur",),
    "allumeuses": ("allumeur",),
    "allusif": ("allusif",),
    "allusifs": ("allusif",),
    "allusive": ("allusif",),
    "allusives": ("allusif",),
    "alluviale": ("alluvial",),
    "alluviales": ("alluvial",),
    "alluvial": ("alluvial",),
    "alluviaux": ("alluvial",),
    "alluvionnaire": ("alluvionnaire",),
    "alluvionnaires": ("alluvionnaire",),
    "allylique": ("allylique",),
    "allyliques": ("allylique",),
    "aloétique": ("aloétique",),
    "aloétiques": ("aloétique",),
    "alogique": ("alogique",),
    "alogiques": ("alogique",),
    "alopécique": ("alopécique",),
    "alopéciques": ("alopécique",),
    "alourdissable": ("alourdissable",),
    "alourdissables": ("alourdissable",),
    "alpestre": ("alpestre",),
    "alpestres": ("alpestre",),
    "alpha": ("alpha",),
    "alphabète": ("alphabète",),
    "alphabètes": ("alphabète",),
    "alphabétique": ("alphabétique",),
    "alphabétiques": ("alphabétique",),
    "alphalinoléique": ("alphalinoléique",),
    "alphalinoléiques": ("alphalinoléique",),
    "alphalytique": ("alphalytique",),
    "alphalytiques": ("alphalytique",),
    "alphamimétique": ("alphamimétique",),
    "alphamimétiques": ("alphamimétique",),
    "alphanumérique": ("alphanumérique",),
    "alphanumériques": ("alphanumérique",),
    "alpharécepteur": ("alpharécepteur",),
    "alpharécepteurs": ("alpharécepteur",),
    "alpharéceptrice": ("alpharécepteur",),
    "alpharéceptrices": ("alpharécepteur",),
    "alphatique": ("alphatique",),
    "alphatiques": ("alphatique",),
    "alpien": ("alpien",),
    "alpienne": ("alpien",),
    "alpiennes": ("alpien",),
    "alpiens": ("alpien",),
    "alsacien": ("alsacien",),
    "alsacienne": ("alsacien",),
    "alsaciennes": ("alsacien",),
    "alsaciens": ("alsacien",),
    "altaïque": ("altaïque",),
    "altaïques": ("altaïque",),
    "altazimutale": ("altazimutal",),
    "altazimutales": ("altazimutal",),
    "altazimutal": ("altazimutal",),
    "altazimutaux": ("altazimutal",),
    "altérable": ("altérable",),
    "altérables": ("altérable",),
    "altéragène": ("altéragène",),
    "altéragènes": ("altéragène",),
    "altératif": ("altératif",),
    "altératifs": ("altératif",),
    "altérative": ("altératif",),
    "altératives": ("altératif",),
    "alternatif": ("alternatif",),
    "alternatifs": ("alternatif",),
    "alternative": ("alternatif",),
    "alternatives": ("alternatif",),
    "alternée": ("alterné",),
    "alternées": ("alterné",),
    "alterné": ("alterné",),
    "alterne": ("alterne",),
    "alternés": ("alterné",),
    "alternes": ("alterne",),
    "altière": ("altier",),
    "altières": ("altier",),
    "altier": ("altier",),
    "altiers": ("altier",),
    "altimétrique": ("altimétrique",),
    "altimétriques": ("altimétrique",),
    "altitudinaire": ("altitudinaire",),
    "altitudinaires": ("altitudinaire",),
    "altitudinale": ("altitudinal",),
    "altitudinales": ("altitudinal",),
    "altitudinal": ("altitudinal",),
    "altitudinaux": ("altitudinal",),
    "altruiste": ("altruiste",),
    "altruistes": ("altruiste",),
    "aluminaire": ("aluminaire",),
    "aluminaires": ("aluminaire",),
    "alumineuse": ("alumineux",),
    "alumineuses": ("alumineux",),
    "alumineux": ("alumineux",),
    "aluminifère": ("aluminifère",),
    "aluminifères": ("aluminifère",),
    "aluminique": ("aluminique",),
    "aluminiques": ("aluminique",),
    "aluné": ("aluné",),
    "alunés": ("aluné",),
    "alunifère": ("alunifère",),
    "alunifères": ("alunifère",),
    "alvéolaire": ("alvéolaire",),
    "alvéolaires": ("alvéolaire",),
    "alvéolo-dentaire": ("alvéolo-dentaire",),
    "alvéolodentaire": ("alvéolodentaire",),
    "alvéolodentaires": ("alvéolodentaire",),
    "alvéopalatale": ("alvéopalatal",),
    "alvéopalatales": ("alvéopalatal",),
    "alvéopalatal": ("alvéopalatal",),
    "alvéopalataux": ("alvéopalatal",),
    "amarante": ("amarante",),
    "amarnien": ("amarnien",),
    "amarnienne": ("amarnien",),
    "amarniennes": ("amarnien",),
    "amarniens": ("amarnien",),
    "amateur": ("amateur",),
    "amateurs": ("amateur",),
    "amaurotique": ("amaurotique",),
    "amaurotiques": ("amaurotique",),
    "amazonien": ("amazonien",),
    "amazonienne": ("amazonien",),
    "amazoniennes": ("amazonien",),
    "amazoniens": ("amazonien",),
    "ambidextre": ("ambidextre",),
    "ambidextres": ("ambidextre",),
    "ambiéquale": ("ambiéqual",),
    "ambiéquales": ("ambiéqual",),
    "ambiéqual": ("ambiéqual",),
    "ambiéquaux": ("ambiéqual",),
    "ambiguë": ("ambigu",),
    "ambiguës": ("ambigu",),
    "ambigu": ("ambigu",),
    "ambigus": ("ambigu",),
    "ambiophonique": ("ambiophonique",),
    "ambiophoniques": ("ambiophonique",),
    "ambipare": ("ambipare",),
    "ambipares": ("ambipare",),
    "ambitieuse": ("ambitieux",),
    "ambitieuses": ("ambitieux",),
    "ambitieux": ("ambitieux",),
    "ambleur": ("ambleur",),
    "ambleurs": ("ambleur",),
    "ambleuse": ("ambleur",),
    "ambleuses": ("ambleur",),
    "amblyope": ("amblyope",),
    "amblyopes": ("amblyope",),
    "ambrée": ("ambré",),
    "ambrées": ("ambré",),
    "ambré": ("ambré",),
    "ambre": ("ambre",),
    "ambrés": ("ambré",),
    "ambroisien": ("ambroisien",),
    "ambroisienne": ("ambroisien",),
    "ambroisiennes": ("ambroisien",),
    "ambroisiens": ("ambroisien",),
    "ambrosiaque": ("ambrosiaque",),
    "ambrosiaques": ("ambrosiaque",),
    "ambrosien": ("ambrosien",),
    "ambrosienne": ("ambrosien",),
    "ambrosiennes": ("ambrosien",),
    "ambrosiens": ("ambrosien",),
    "ambulacraire": ("ambulacraire",),
    "ambulacraires": ("ambulacraire",),
    "ambulacrale": ("ambulacral",),
    "ambulacrales": ("ambulacral",),
    "ambulacral": ("ambulacral",),
    "ambulacraux": ("ambulacral",),
    "ambulancière": ("ambulancier",),
    "ambulancières": ("ambulancier",),
    "ambulancier": ("ambulancier",),
    "ambulanciers": ("ambulancier",),
    "ambulatoire": ("ambulatoire",),
    "ambulatoires": ("ambulatoire",),
    "améliorable": ("améliorable",),
    "améliorables": ("améliorable",),
    "améliorateur": ("améliorateur",),
    "améliorateurs": ("améliorateur",),
    "amélioratrice": ("améliorateur",),
    "amélioratrices": ("améliorateur",),
    "amélioratif": ("amélioratif",),
    "amélioratifs": ("amélioratif",),
    "améliorative": ("amélioratif",),
    "amélioratives": ("amélioratif",),
    "aménageable": ("aménageable",),
    "aménageables": ("aménageable",),
    "amendable": ("amendable",),
    "amendables": ("amendable",),
    "amène": ("amène",),
    "amènes": ("amène",),
    "amensale": ("amensal",),
    "amensales": ("amensal",),
    "amensal": ("amensal",),
    "amensaux": ("amensal",),
    "amentifère": ("amentifère",),
    "amentifères": ("amentifère",),
    "amère": ("amer",),
    "amères": ("amer",),
    "amer": ("amer",),
    "amers": ("amer",),
    "américaniste": ("américaniste",),
    "américanistes": ("américaniste",),
    "américanophile": ("américanophile",),
    "américanophiles": ("américanophile",),
    "américanophobe": ("américanophobe",),
    "américanophobes": ("américanophobe",),
    "amérindien": ("amérindien",),
    "amérindienne": ("amérindien",),
    "amérindiennes": ("amérindien",),
    "amérindiens": ("amérindien",),
    "amétabole": ("amétabole",),
    "amétaboles": ("amétabole",),
    "amétallique": ("amétallique",),
    "amétalliques": ("amétallique",),
    "améthyste": ("améthyste",),
    "amétrope": ("amétrope",),
    "amétropes": ("amétrope",),
    "ameutable": ("ameutable",),
    "ameutables": ("ameutable",),
    "amharique": ("amharique",),
    "amhariques": ("amharique",),
    "amiable": ("amiable",),
    "amiables": ("amiable",),
    "amiantifère": ("amiantifère",),
    "amiantifères": ("amiantifère",),
    "amibien": ("amibien",),
    "amibienne": ("amibien",),
    "amibiennes": ("amibien",),
    "amibiens": ("amibien",),
    "amiboïde": ("amiboïde",),
    "amiboïdes": ("amiboïde",),
    "amicale": ("amical",),
    "amicales": ("amical",),
    "amical": ("amical",),
    "amicaux": ("amical",),
    "amicaliste": ("amicaliste",),
    "amicalistes": ("amicaliste",),
    "amicrobien": ("amicrobien",),
    "amicrobienne": ("amicrobien",),
    "amicrobiennes": ("amicrobien",),
    "amicrobiens": ("amicrobien",),
    "amictique": ("amictique",),
    "amictiques": ("amictique",),
    "amido": ("amido",),
    "amidomercureuse": ("amidomercureux",),
    "amidomercureuses": ("amidomercureux",),
    "amidomercureux": ("amidomercureux",),
    "amidomercurique": ("amidomercurique",),
    "amidomercuriques": ("amidomercurique",),
    "amidonnière": ("amidonnier",),
    "amidonnières": ("amidonnier",),
    "amidonnier": ("amidonnier",),
    "amidonniers": ("amidonnier",),
    "amimique": ("amimique",),
    "amimiques": ("amimique",),
    "aminoazoïque": ("aminoazoïque",),
    "aminoazoïques": ("aminoazoïque",),
    "aminobenzoïque": ("aminobenzoïque",),
    "aminobenzoïques": ("aminobenzoïque",),
    "aminobutyrique": ("aminobutyrique",),
    "aminobutyriques": ("aminobutyrique",),
    "aminocaproïque": ("aminocaproïque",),
    "aminocaproïques": ("aminocaproïque",),
    "aminocéphalosporanique": ("aminocéphalosporanique",),
    "aminocéphalosporaniques": ("aminocéphalosporanique",),
    "aminolévulique": ("aminolévulique",),
    "aminolévuliques": ("aminolévulique",),
    "aminopénicillanique": ("aminopénicillanique",),
    "aminopénicillaniques": ("aminopénicillanique",),
    "aminoptérinique": ("aminoptérinique",),
    "aminoptériniques": ("aminoptérinique",),
    "aminosalicylique": ("aminosalicylique",),
    "aminosalicyliques": ("aminosalicylique",),
    "amirale": ("amiral",),
    "amirales": ("amiral",),
    "amiral": ("amiral",),
    "amiraux": ("amiral",),
    "amissible": ("amissible",),
    "amissibles": ("amissible",),
    "amitotique": ("amitotique",),
    "amitotiques": ("amitotique",),
    "ammoniac": ("ammoniac",),
    "ammoniacs": ("ammoniac",),
    "ammoniaque": ("ammoniac",),
    "ammoniaques": ("ammoniac",),
    "ammoniacale": ("ammoniacal",),
    "ammoniacales": ("ammoniacal",),
    "ammoniacal": ("ammoniacal",),
    "ammoniacaux": ("ammoniacal",),
    "ammonique": ("ammonique",),
    "ammoniques": ("ammonique",),
    "ammonotélique": ("ammonotélique",),
    "ammonotéliques": ("ammonotélique",),
    "ammophile": ("ammophile",),
    "ammophiles": ("ammophile",),
    "amnésique": ("amnésique",),
    "amnésiques": ("amnésique",),
    "amnestique": ("amnestique",),
    "amnestiques": ("amnestique",),
    "amnicole": ("amnicole",),
    "amnicoles": ("amnicole",),
    "amniotique": ("amniotique",),
    "amniotiques": ("amniotique",),
    "amnistiable": ("amnistiable",),
    "amnistiables": ("amnistiable",),
    "amoebicide": ("amoebicide",),
    "amoebicides": ("amoebicide",),
    "amorale": ("amoral",),
    "amorales": ("amoral",),
    "amoral": ("amoral",),
    "amoraux": ("amoral",),
    "amoraliste": ("amoraliste",),
    "amoralistes": ("amoraliste",),
    "amorphe": ("amorphe",),
    "amorphes": ("amorphe",),
    "amortissable": ("amortissable",),
    "amortissables": ("amortissable",),
    "amortisseur": ("amortisseur",),
    "amortisseurs": ("amortisseur",),
    "amortisseuse": ("amortisseur",),
    "amortisseuses": ("amortisseur",),
    "amouillante": ("amouillante",),
    "amouillantes": ("amouillante",),
    "amoureuse": ("amoureux",),
    "amoureuses": ("amoureux",),
    "amoureux": ("amoureux",),
    "amovible": ("amovible",),
    "amovibles": ("amovible",),
    "ampérien": ("ampérien",),
    "ampérienne": ("ampérien",),
    "ampériennes": ("ampérien",),
    "ampériens": ("ampérien",),
    "amphétaminique": ("amphétaminique",),
    "amphétaminiques": ("amphétaminique",),
    "amphibie": ("amphibie",),
    "amphibies": ("amphibie",),
    "amphibien": ("amphibien",),
    "amphibienne": ("amphibien",),
    "amphibiennes": ("amphibien",),
    "amphibiens": ("amphibien",),
    "amphibiotique": ("amphibiotique",),
    "amphibiotiques": ("amphibiotique",),
    "amphibolique": ("amphibolique",),
    "amphiboliques": ("amphibolique",),
    "amphibologique": ("amphibologique",),
    "amphibologiques": ("amphibologique",),
    "amphictyonique": ("amphictyonique",),
    "amphictyoniques": ("amphictyonique",),
    "amphidiploïde": ("amphidiploïde",),
    "amphidiploïdes": ("amphidiploïde",),
    "amphidromique": ("amphidromique",),
    "amphidromiques": ("amphidromique",),
    "amphigourique": ("amphigourique",),
    "amphigouriques": ("amphigourique",),
    "amphipathique": ("amphipathique",),
    "amphipathiques": ("amphipathique",),
    "amphiphile": ("amphiphile",),
    "amphiphiles": ("amphiphile",),
    "amphipode": ("amphipode",),
    "amphipodes": ("amphipode",),
    "amphiprostyle": ("amphiprostyle",),
    "amphiprostyles": ("amphiprostyle",),
    "amphitone": ("amphitone",),
    "amphitones": ("amphitone",),
    "amphophile": ("amphophile",),
    "amphophiles": ("amphophile",),
    "amphorique": ("amphorique",),
    "amphoriques": ("amphorique",),
    "amphotère": ("amphotère",),
    "amphotères": ("amphotère",),
    "ample": ("ample",),
    "amples": ("ample",),
    "amplectif": ("amplectif",),
    "amplectifs": ("amplectif",),
    "amplective": ("amplectif",),
    "amplectives": ("amplectif",),
    "amplexicaule": ("amplexicaule",),
    "amplexicaules": ("amplexicaule",),
    "ampliatif": ("ampliatif",),
    "ampliatifs": ("ampliatif",),
    "ampliative": ("ampliatif",),
    "ampliatives": ("ampliatif",),
    "amplificateur": ("amplificateur",),
    "amplificateurs": ("amplificateur",),
    "amplificatrice": ("amplificateur",),
    "amplificatrices": ("amplificateur",),
    "amplificatif": ("amplificatif",),
    "amplificatifs": ("amplificatif",),
    "amplificative": ("amplificatif",),
    "amplificatives": ("amplificatif",),
    "ampliforme": ("ampliforme",),
    "ampliformes": ("ampliforme",),
    "ampullaire": ("ampullaire",),
    "ampullaires": ("ampullaire",),
    "amusable": ("amusable",),
    "amusables": ("amusable",),
    "amyélinique": ("amyélinique",),
    "amyéliniques": ("amyélinique",),
    "amygdalaire": ("amygdalaire",),
    "amygdalaires": ("amygdalaire",),
    "amygdalien": ("amygdalien",),
    "amygdalienne": ("amygdalien",),
    "amygdaliennes": ("amygdalien",),
    "amygdaliens": ("amygdalien",),
    "amygdaliforme": ("amygdaliforme",),
    "amygdaliformes": ("amygdaliforme",),
    "amygdaloïde": ("amygdaloïde",),
    "amygdaloïdes": ("amygdaloïde",),
    "amylique": ("amylique",),
    "amyliques": ("amylique",),
    "amyloïde": ("amyloïde",),
    "amyloïdes": ("amyloïde",),
    "amylolytique": ("amylolytique",),
    "amylolytiques": ("amylolytique",),
    "amyotonique": ("amyotonique",),
    "amyotoniques": ("amyotonique",),
    "amyotrophique": ("amyotrophique",),
    "amyotrophiques": ("amyotrophique",),
    "anabaptiste": ("anabaptiste",),
    "anabaptistes": ("anabaptiste",),
    "anabatique": ("anabatique",),
    "anabatiques": ("anabatique",),
    "anabiotique": ("anabiotique",),
    "anabiotiques": ("anabiotique",),
    "anabolique": ("anabolique",),
    "anaboliques": ("anabolique",),
    "anacamptique": ("anacamptique",),
    "anacamptiques": ("anacamptique",),
    "anachorétique": ("anachorétique",),
    "anachorétiques": ("anachorétique",),
    "anachronique": ("anachronique",),
    "anachroniques": ("anachronique",),
    "anaclinale": ("anaclinal",),
    "anaclinales": ("anaclinal",),
    "anaclinal": ("anaclinal",),
    "anaclinaux": ("anaclinal",),
    "anaclitique": ("anaclitique",),
    "anaclitiques": ("anaclitique",),
    "anacréontique": ("anacréontique",),
    "anacréontiques": ("anacréontique",),
    "anacrotique": ("anacrotique",),
    "anacrotiques": ("anacrotique",),
    "anacyclique": ("anacyclique",),
    "anacycliques": ("anacyclique",),
    "anadrome": ("anadrome",),
    "anadromes": ("anadrome",),
    "anaérobie": ("anaérobie",),
    "anaérobies": ("anaérobie",),
    "anagapique": ("anagapique",),
    "anagapiques": ("anagapique",),
    "anagène": ("anagène",),
    "anagènes": ("anagène",),
    "anaglyptique": ("anaglyptique",),
    "anaglyptiques": ("anaglyptique",),
    "anagogique": ("anagogique",),
    "anagogiques": ("anagogique",),
    "anagrammatique": ("anagrammatique",),
    "anagrammatiques": ("anagrammatique",),
    "anale": ("anal",),
    "anales": ("anal",),
    "anal": ("anal",),
    "anaux": ("anal",),
    "analeptique": ("analeptique",),
    "analeptiques": ("analeptique",),
    "analgésique": ("analgésique",),
    "analgésiques": ("analgésique",),
    "anallagmatique": ("anallagmatique",),
    "anallagmatiques": ("anallagmatique",),
    "anallatique": ("anallatique",),
    "anallatiques": ("anallatique",),
    "anallatiseur": ("anallatiseur",),
    "anallatiseurs": ("anallatiseur",),
    "anallergique": ("anallergique",),
    "anallergiques": ("anallergique",),
    "analogique": ("analogique",),
    "analogiques": ("analogique",),
    "analogue": ("analogue",),
    "analogues": ("analogue",),
    "analphabète": ("analphabète",),
    "analphabètes": ("analphabète",),
    "analysable": ("analysable",),
    "analysables": ("analysable",),
    "analyseur": ("analyseur",),
    "analyseurs": ("analyseur",),
    "analyseuse": ("analyseur",),
    "analyseuses": ("analyseur",),
    "analytique": ("analytique",),
    "analytiques": ("analytique",),
    "anamnestique": ("anamnestique",),
    "anamnestiques": ("anamnestique",),
    "anamorphe": ("anamorphe",),
    "anamorphes": ("anamorphe",),
    "anamorphoseur": ("anamorphoseur",),
    "anamorphoseurs": ("anamorphoseur",),
    "anamorphotique": ("anamorphotique",),
    "anamorphotiques": ("anamorphotique",),
    "anapeiratique": ("anapeiratique",),
    "anapeiratiques": ("anapeiratique",),
    "anapestique": ("anapestique",),
    "anapestiques": ("anapestique",),
    "anaphasique": ("anaphasique",),
    "anaphasiques": ("anaphasique",),
    "anaphorique": ("anaphorique",),
    "anaphoriques": ("anaphorique",),
    "anaphrodisiaque": ("anaphrodisiaque",),
    "anaphrodisiaques": ("anaphrodisiaque",),
    "anaphylactique": ("anaphylactique",),
    "anaphylactiques": ("anaphylactique",),
    "anaphylactoïde": ("anaphylactoïde",),
    "anaphylactoïdes": ("anaphylactoïde",),
    "anaphylatoxinique": ("anaphylatoxinique",),
    "anaphylatoxiniques": ("anaphylatoxinique",),
    "anaplasique": ("anaplasique",),
    "anaplasiques": ("anaplasique",),
    "anar": ("anar",),
    "anars": ("anar",),
    "anarchique": ("anarchique",),
    "anarchiques": ("anarchique",),
    "anarchiste": ("anarchiste",),
    "anarchistes": ("anarchiste",),
    "anarthrique": ("anarthrique",),
    "anarthriques": ("anarthrique",),
    "anascitique": ("anascitique",),
    "anascitiques": ("anascitique",),
    "anastatique": ("anastatique",),
    "anastatiques": ("anastatique",),
    "anastigmatique": ("anastigmatique",),
    "anastigmatiques": ("anastigmatique",),
    "anastomotique": ("anastomotique",),
    "anastomotiques": ("anastomotique",),
    "anathématique": ("anathématique",),
    "anathématiques": ("anathématique",),
    "anathème": ("anathème",),
    "anathèmes": ("anathème",),
    "anatifère": ("anatifère",),
    "anatifères": ("anatifère",),
    "anatolien": ("anatolien",),
    "anatolienne": ("anatolien",),
    "anatoliennes": ("anatolien",),
    "anatoliens": ("anatolien",),
    "anatomique": ("anatomique",),
    "anatomiques": ("anatomique",),
    "anatomoclinique": ("anatomoclinique",),
    "anatomocliniques": ("anatomoclinique",),
    "anatomopathologique": ("anatomopathologique",),
    "anatomopathologiques": ("anatomopathologique",),
    "anatomophysiologique": ("anatomophysiologique",),
    "anatomophysiologiques": ("anatomophysiologique",),
    "anatoxique": ("anatoxique",),
    "anatoxiques": ("anatoxique",),
    "anatrope": ("anatrope",),
    "anatropes": ("anatrope",),
    "ancestrale": ("ancestral",),
    "ancestrales": ("ancestral",),
    "ancestral": ("ancestral",),
    "ancestraux": ("ancestral",),
    "ancien": ("ancien",),
    "ancienne": ("ancien",),
    "anciennes": ("ancien",),
    "anciens": ("ancien",),
    "ancillaire": ("ancillaire",),
    "ancillaires": ("ancillaire",),
    "andalou": ("andalou",),
    "andalouse": ("andalou",),
    "andalouses": ("andalou",),
    "andalous": ("andalou",),
    "andésitique": ("andésitique",),
    "andésitiques": ("andésitique",),
    "andouille": ("andouille",),
    "androcéphale": ("androcéphale",),
    "androcéphales": ("androcéphale",),
    "androgène": ("androgène",),
    "androgènes": ("androgène",),
    "androgénétique": ("androgénétique",),
    "androgénétiques": ("androgénétique",),
    "androgénique": ("androgénique",),
    "androgéniques": ("androgénique",),
    "androgyne": ("androgyne",),
    "androgynes": ("androgyne",),
    "androgyniflore": ("androgyniflore",),
    "androgyniflores": ("androgyniflore",),
    "androïde": ("androïde",),
    "androïdes": ("androïde",),
    "androlâtre": ("androlâtre",),
    "androlâtres": ("androlâtre",),
    "androphore": ("androphore",),
    "androphores": ("androphore",),
    "anecdotique": ("anecdotique",),
    "anecdotiques": ("anecdotique",),
    "anéchoïde": ("anéchoïde",),
    "anéchoïdes": ("anéchoïde",),
    "anéchoïque": ("anéchoïque",),
    "anéchoïques": ("anéchoïque",),
    "anélastique": ("anélastique",),
    "anélastiques": ("anélastique",),
    "anémique": ("anémique",),
    "anémiques": ("anémique",),
    "anémochore": ("anémochore",),
    "anémochores": ("anémochore",),
    "anémogame": ("anémogame",),
    "anémogames": ("anémogame",),
    "anémométrique": ("anémométrique",),
    "anémométriques": ("anémométrique",),
    "anémophile": ("anémophile",),
    "anémophiles": ("anémophile",),
    "anencéphale": ("anencéphale",),
    "anencéphales": ("anencéphale",),
    "anencéphalique": ("anencéphalique",),
    "anencéphaliques": ("anencéphalique",),
    "anépigraphe": ("anépigraphe",),
    "anépigraphes": ("anépigraphe",),
    "anérète": ("anérète",),
    "anérètes": ("anérète",),
    "anergique": ("anergique",),
    "anergiques": ("anergique",),
    "anéroïde": ("anéroïde",),
    "anéroïdes": ("anéroïde",),
    "anesthésiable": ("anesthésiable",),
    "anesthésiables": ("anesthésiable",),
    "anesthésiologique": ("anesthésiologique",),
    "anesthésiologiques": ("anesthésiologique",),
    "anesthésique": ("anesthésique",),
    "anesthésiques": ("anesthésique",),
    "aneuploïde": ("aneuploïde",),
    "aneuploïdes": ("aneuploïde",),
    "aneurogène": ("aneurogène",),
    "aneurogènes": ("aneurogène",),
    "anévrismale": ("anévrismal",),
    "anévrismales": ("anévrismal",),
    "anévrismal": ("anévrismal",),
    "anévrismaux": ("anévrismal",),
    "anévrysmale": ("anévrysmal",),
    "anévrysmales": ("anévrysmal",),
    "anévrysmal": ("anévrysmal",),
    "anévrysmaux": ("anévrysmal",),
    "angéiographique": ("angéiographique",),
    "angéiographiques": ("angéiographique",),
    "angéiologique": ("angéiologique",),
    "angéiologiques": ("angéiologique",),
    "angélique": ("angélique",),
    "angéliques": ("angélique",),
    "angiectasique": ("angiectasique",),
    "angiectasiques": ("angiectasique",),
    "angineuse": ("angineux",),
    "angineuses": ("angineux",),
    "angineux": ("angineux",),
    "angiocarpe": ("angiocarpe",),
    "angiocarpes": ("angiocarpe",),
    "angiographique": ("angiographique",),
    "angiographiques": ("angiographique",),
    "angiohématique": ("angiohématique",),
    "angiohématiques": ("angiohématique",),
    "angiolithique": ("angiolithique",),
    "angiolithiques": ("angiolithique",),
    "angiologique": ("angiologique",),
    "angiologiques": ("angiologique",),
    "angiomateuse": ("angiomateux",),
    "angiomateuses": ("angiomateux",),
    "angiomateux": ("angiomateux",),
    "angioneurotique": ("angioneurotique",),
    "angioneurotiques": ("angioneurotique",),
    "angiopathique": ("angiopathique",),
    "angiopathiques": ("angiopathique",),
    "angioplastique": ("angioplastique",),
    "angioplastiques": ("angioplastique",),
    "angiospasmodique": ("angiospasmodique",),
    "angiospasmodiques": ("angiospasmodique",),
    "angiospastique": ("angiospastique",),
    "angiospastiques": ("angiospastique",),
    "angiotensinogène": ("angiotensinogène",),
    "angiotensinogènes": ("angiotensinogène",),
    "angkorien": ("angkorien",),
    "angkorienne": ("angkorien",),
    "angkoriennes": ("angkorien",),
    "angkoriens": ("angkorien",),
    "anglaise": ("anglais",),
    "anglaises": ("anglais",),
    "anglais": ("anglais",),
    "anglo-américaine": ("anglo-américain",),
    "anglo-américain": ("anglo-américain",),
    "anglo-américains": ("anglo-américain",),
    "anglo-angevin": ("anglo-angevin",),
    "anglo-angevins": ("anglo-angevin",),
    "anglo-arabe": ("anglo-arabe",),
    "anglo-irlandaise": ("anglo-irlandais",),
    "anglo-irlandais": ("anglo-irlandais",),
    "anglomane": ("anglomane",),
    "anglomanes": ("anglomane",),
    "anglo-normande": ("anglo-normand",),
    "anglo-normand": ("anglo-normand",),
    "anglo-nubiennes": ("anglo-nubienne",),
    "anglophile": ("anglophile",),
    "anglophiles": ("anglophile",),
    "anglophobe": ("anglophobe",),
    "anglophobes": ("anglophobe",),
    "anglophone": ("anglophone",),
    "anglophones": ("anglophone",),
    "anglo-saxon": ("anglo-saxon",),
    "anglo-saxonne": ("anglo-saxon",),
    "anglo-saxonnes": ("anglo-saxon",),
    "anglo-saxons": ("anglo-saxon",),
    "angoisseuse": ("angoisseux",),
    "angoisseuses": ("angoisseux",),
    "angoisseux": ("angoisseux",),
    "angolaise": ("angolais",),
    "angolaises": ("angolais",),
    "angolais": ("angolais",),
    "angora": ("angora",),
    "angoras": ("angora",),
    "anguiforme": ("anguiforme",),
    "anguiformes": ("anguiforme",),
    "anguilliforme": ("anguilliforme",),
    "anguilliformes": ("anguilliforme",),
    "anguilloïde": ("anguilloïde",),
    "anguilloïdes": ("anguilloïde",),
    "angulaire": ("angulaire",),
    "angulaires": ("angulaire",),
    "anguleuse": ("anguleux",),
    "anguleuses": ("anguleux",),
    "anguleux": ("anguleux",),
    "angusticole": ("angusticole",),
    "angusticoles": ("angusticole",),
    "angusticolle": ("angusticolle",),
    "angusticolles": ("angusticolle",),
    "angustirostre": ("angustirostre",),
    "angustirostres": ("angustirostre",),
    "anharmonique": ("anharmonique",),
    "anharmoniques": ("anharmonique",),
    "anhidrotique": ("anhidrotique",),
    "anhidrotiques": ("anhidrotique",),
    "anhiste": ("anhiste",),
    "anhistes": ("anhiste",),
    "anhistorique": ("anhistorique",),
    "anhistoriques": ("anhistorique",),
    "anhydre": ("anhydre",),
    "anhydres": ("anhydre",),
    "anhystérétique": ("anhystérétique",),
    "anhystérétiques": ("anhystérétique",),
    "anictérique": ("anictérique",),
    "anictériques": ("anictérique",),
    "animale": ("animal",),
    "animales": ("animal",),
    "animal": ("animal",),
    "animaux": ("animal",),
    "animalière": ("animalier",),
    "animalières": ("animalier",),
    "animalier": ("animalier",),
    "animaliers": ("animalier",),
    "animateur": ("animateur",),
    "animateurs": ("animateur",),
    "animatrice": ("animateur",),
    "animatrices": ("animateur",),
    "animiste": ("animiste",),
    "animistes": ("animiste",),
    "anionique": ("anionique",),
    "anioniques": ("anionique",),
    "anionotropique": ("anionotropique",),
    "anionotropiques": ("anionotropique",),
    "anisien": ("anisien",),
    "anisienne": ("anisien",),
    "anisiennes": ("anisien",),
    "anisiens": ("anisien",),
    "anisique": ("anisique",),
    "anisiques": ("anisique",),
    "anisochrone": ("anisochrone",),
    "anisochrones": ("anisochrone",),
    "anisodonte": ("anisodonte",),
    "anisodontes": ("anisodonte",),
    "anisométrique": ("anisométrique",),
    "anisométriques": ("anisométrique",),
    "anisomyaire": ("anisomyaire",),
    "anisomyaires": ("anisomyaire",),
    "anisopaque": ("anisopaque",),
    "anisopaques": ("anisopaque",),
    "anisopétale": ("anisopétale",),
    "anisopétales": ("anisopétale",),
    "anisostémone": ("anisostémone",),
    "anisostémones": ("anisostémone",),
    "anisotonique": ("anisotonique",),
    "anisotoniques": ("anisotonique",),
    "anisotrope": ("anisotrope",),
    "anisotropes": ("anisotrope",),
    "anisotropique": ("anisotropique",),
    "anisotropiques": ("anisotropique",),
    "annale": ("annal",),
    "annales": ("annal",),
    "annal": ("annal",),
    "annaux": ("annal",),
    "annamite": ("annamite",),
    "annamites": ("annamite",),
    "annamitique": ("annamitique",),
    "annamitiques": ("annamitique",),
    "annexe": ("annexe",),
    "annexes": ("annexe",),
    "annexielle": ("annexiel",),
    "annexielles": ("annexiel",),
    "annexiel": ("annexiel",),
    "annexiels": ("annexiel",),
    "annexionniste": ("annexionniste",),
    "annexionnistes": ("annexionniste",),
    "anniversaire": ("anniversaire",),
    "anniversaires": ("anniversaire",),
    "annonaire": ("annonaire",),
    "annonaires": ("annonaire",),
    "annonciateur": ("annonciateur",),
    "annonciateurs": ("annonciateur",),
    "annonciatrice": ("annonciateur",),
    "annonciatrices": ("annonciateur",),
    "annuelle": ("annuel",),
    "annuelles": ("annuel",),
    "annuel": ("annuel",),
    "annuels": ("annuel",),
    "annulable": ("annulable",),
    "annulables": ("annulable",),
    "annulaire": ("annulaire",),
    "annulaires": ("annulaire",),
    "annulateur": ("annulateur",),
    "annulateurs": ("annulateur",),
    "annulatrice": ("annulateur",),
    "annulatrices": ("annulateur",),
    "annulatif": ("annulatif",),
    "annulatifs": ("annulatif",),
    "annulative": ("annulatif",),
    "annulatives": ("annulatif",),
    "anobjectale": ("anobjectal",),
    "anobjectales": ("anobjectal",),
    "anobjectal": ("anobjectal",),
    "anobjectaux": ("anobjectal",),
    "anodique": ("anodique",),
    "anodiques": ("anodique",),
    "anodonte": ("anodonte",),
    "anodontes": ("anodonte",),
    "anomale": ("anomal",),
    "anomales": ("anomal",),
    "anomal": ("anomal",),
    "anomaux": ("anomal",),
    "anomalistique": ("anomalistique",),
    "anomalistiques": ("anomalistique",),
    "anomérique": ("anomérique",),
    "anomériques": ("anomérique",),
    "anomique": ("anomique",),
    "anomiques": ("anomique",),
    "anonyme": ("anonyme",),
    "anonymes": ("anonyme",),
    "anopisthographique": ("anopisthographique",),
    "anopisthographiques": ("anopisthographique",),
    "anorexigène": ("anorexigène",),
    "anorexigènes": ("anorexigène",),
    "anorexique": ("anorexique",),
    "anorexiques": ("anorexique",),
    "anorganique": ("anorganique",),
    "anorganiques": ("anorganique",),
    "anorgasmique": ("anorgasmique",),
    "anorgasmiques": ("anorgasmique",),
    "anormale": ("anormal",),
    "anormales": ("anormal",),
    "anormal": ("anormal",),
    "anormaux": ("anormal",),
    "anorogénique": ("anorogénique",),
    "anorogéniques": ("anorogénique",),
    "anosmatique": ("anosmatique",),
    "anosmatiques": ("anosmatique",),
    "anosmique": ("anosmique",),
    "anosmiques": ("anosmique",),
    "anosognosique": ("anosognosique",),
    "anosognosiques": ("anosognosique",),
    "anote": ("anote",),
    "anotes": ("anote",),
    "anoure": ("anoure",),
    "anoures": ("anoure",),
    "anovulatoire": ("anovulatoire",),
    "anovulatoires": ("anovulatoire",),
    "anoxémique": ("anoxémique",),
    "anoxémiques": ("anoxémique",),
    "anoxique": ("anoxique",),
    "anoxiques": ("anoxique",),
    "ansériforme": ("ansériforme",),
    "ansériformes": ("ansériforme",),
    "antagonique": ("antagonique",),
    "antagoniques": ("antagonique",),
    "antagoniste": ("antagoniste",),
    "antagonistes": ("antagoniste",),
    "antalgique": ("antalgique",),
    "antalgiques": ("antalgique",),
    "antarctique": ("antarctique",),
    "antarctiques": ("antarctique",),
    "antébrachiale": ("antébrachial",),
    "antébrachiales": ("antébrachial",),
    "antébrachial": ("antébrachial",),
    "antébrachiaux": ("antébrachial",),
    "antécambrien": ("antécambrien",),
    "antécambrienne": ("antécambrien",),
    "antécambriennes": ("antécambrien",),
    "antécambriens": ("antécambrien",),
    "antéconciliaire": ("antéconciliaire",),
    "antéconciliaires": ("antéconciliaire",),
    "antéconsonantique": ("antéconsonantique",),
    "antéconsonantiques": ("antéconsonantique",),
    "antédiluvien": ("antédiluvien",),
    "antédiluvienne": ("antédiluvien",),
    "antédiluviennes": ("antédiluvien",),
    "antédiluviens": ("antédiluvien",),
    "antéhypophysaire": ("antéhypophysaire",),
    "antéhypophysaires": ("antéhypophysaire",),
    "antéislamique": ("antéislamique",),
    "antéislamiques": ("antéislamique",),
    "antenaise": ("antenais",),
    "antenaises": ("antenais",),
    "antenais": ("antenais",),
    "antennaire": ("antennaire",),
    "antennaires": ("antennaire",),
    "antennifère": ("antennifère",),
    "antennifères": ("antennifère",),
    "antenniforme": ("antenniforme",),
    "antenniformes": ("antenniforme",),
    "anténuptiale": ("anténuptial",),
    "anténuptiales": ("anténuptial",),
    "anténuptial": ("anténuptial",),
    "anténuptiaux": ("anténuptial",),
    "antépénultième": ("antépénultième",),
    "antépénultièmes": ("antépénultième",),
    "antéprédicatif": ("antéprédicatif",),
    "antéprédicatifs": ("antéprédicatif",),
    "antéprédicative": ("antéprédicatif",),
    "antéprédicatives": ("antéprédicatif",),
    "antérograde": ("antérograde",),
    "antérogrades": ("antérograde",),
    "antéro-inférieure": ("antéro-inférieur",),
    "antéro-interne": ("antéro-interne",),
    "antérolatérale": ("antérolatéral",),
    "antérolatérales": ("antérolatéral",),
    "antérolatéral": ("antérolatéral",),
    "antérolatéraux": ("antérolatéral",),
    "antétectonique": ("antétectonique",),
    "antétectoniques": ("antétectonique",),
    "anthelminthique": ("anthelminthique",),
    "anthelminthiques": ("anthelminthique",),
    "anthogénésique": ("anthogénésique",),
    "anthogénésiques": ("anthogénésique",),
    "anthologique": ("anthologique",),
    "anthologiques": ("anthologique",),
    "anthophage": ("anthophage",),
    "anthophages": ("anthophage",),
    "anthophile": ("anthophile",),
    "anthophiles": ("anthophile",),
    "anthracénique": ("anthracénique",),
    "anthracéniques": ("anthracénique",),
    "anthracifère": ("anthracifère",),
    "anthracifères": ("anthracifère",),
    "anthracite": ("anthracite",),
    "anthraciteuse": ("anthraciteux",),
    "anthraciteuses": ("anthraciteux",),
    "anthraciteux": ("anthraciteux",),
    "anthracologique": ("anthracologique",),
    "anthracologiques": ("anthracologique",),
    "anthracosique": ("anthracosique",),
    "anthracosiques": ("anthracosique",),
    "anthraflavique": ("anthraflavique",),
    "anthraflaviques": ("anthraflavique",),
    "anthranilique": ("anthranilique",),
    "anthraniliques": ("anthranilique",),
    "anthraquinonique": ("anthraquinonique",),
    "anthraquinoniques": ("anthraquinonique",),
    "anthropien": ("anthropien",),
    "anthropienne": ("anthropien",),
    "anthropiennes": ("anthropien",),
    "anthropiens": ("anthropien",),
    "anthropique": ("anthropique",),
    "anthropiques": ("anthropique",),
    "anthropobiologique": ("anthropobiologique",),
    "anthropobiologiques": ("anthropobiologique",),
    "anthropocentrique": ("anthropocentrique",),
    "anthropocentriques": ("anthropocentrique",),
    "anthropographique": ("anthropographique",),
    "anthropographiques": ("anthropographique",),
    "anthropoïde": ("anthropoïde",),
    "anthropoïdes": ("anthropoïde",),
    "anthropolâtrique": ("anthropolâtrique",),
    "anthropolâtriques": ("anthropolâtrique",),
    "anthropologique": ("anthropologique",),
    "anthropologiques": ("anthropologique",),
    "anthropométrique": ("anthropométrique",),
    "anthropométriques": ("anthropométrique",),
    "anthropomorphe": ("anthropomorphe",),
    "anthropomorphes": ("anthropomorphe",),
    "anthropomorphique": ("anthropomorphique",),
    "anthropomorphiques": ("anthropomorphique",),
    "anthropomorphiste": ("anthropomorphiste",),
    "anthropomorphistes": ("anthropomorphiste",),
    "anthroponymique": ("anthroponymique",),
    "anthroponymiques": ("anthroponymique",),
    "anthropophage": ("anthropophage",),
    "anthropophages": ("anthropophage",),
    "anthropophagique": ("anthropophagique",),
    "anthropophagiques": ("anthropophagique",),
    "anthropophile": ("anthropophile",),
    "anthropophiles": ("anthropophile",),
    "anthroposomatologique": ("anthroposomatologique",),
    "anthroposomatologiques": ("anthroposomatologique",),
    "anthroposophique": ("anthroposophique",),
    "anthroposophiques": ("anthroposophique",),
    "anthropotechnique": ("anthropotechnique",),
    "anthropotechniques": ("anthropotechnique",),
    "anthropothéiste": ("anthropothéiste",),
    "anthropothéistes": ("anthropothéiste",),
    "anthropozoïque": ("anthropozoïque",),
    "anthropozoïques": ("anthropozoïque",),
    "anthropozoochore": ("anthropozoochore",),
    "anthropozoochores": ("anthropozoochore",),
    "antiabolitionniste": ("antiabolitionniste",),
    "antiabolitionnistes": ("antiabolitionniste",),
    "antiacide": ("antiacide",),
    "antiacnéique": ("antiacnéique",),
    "antiacnéiques": ("antiacnéique",),
    "antiacridien": ("antiacridien",),
    "antiacridienne": ("antiacridien",),
    "antiacridiennes": ("antiacridien",),
    "antiacridiens": ("antiacridien",),
    "antiadhésif": ("antiadhésif",),
    "antiadhésifs": ("antiadhésif",),
    "antiadhésive": ("antiadhésif",),
    "antiadhésives": ("antiadhésif",),
    "antiaérien": ("antiaérien",),
    "antiaérienne": ("antiaérien",),
    "antiaériennes": ("antiaérien",),
    "antiaériens": ("antiaérien",),
    "antialcool": ("antialcool",),
    "antialcoolique": ("antialcoolique",),
    "antialcooliques": ("antialcoolique",),
    "antiallergique": ("antiallergique",),
    "antiallergiques": ("antiallergique",),
    "anti-américaine": ("anti-américain",),
    "antiaméricaine": ("antiaméricain",),
    "anti-américaines": ("anti-américain",),
    "antiaméricaines": ("antiaméricain",),
    "anti-américain": ("anti-américain",),
    "antiaméricain": ("antiaméricain",),
    "anti-américains": ("anti-américain",),
    "antiaméricains": ("antiaméricain",),
    "antianaphylactique": ("antianaphylactique",),
    "antianaphylactiques": ("antianaphylactique",),
    "antiandrogène": ("antiandrogène",),
    "antiandrogénique": ("antiandrogénique",),
    "antiandrogéniques": ("antiandrogénique",),
    "antianémique": ("antianémique",),
    "antianémiques": ("antianémique",),
    "antiangineuse": ("antiangineux",),
    "antiangineuses": ("antiangineux",),
    "antiangineux": ("antiangineux",),
    "antiangoreuse": ("antiangoreux",),
    "antiangoreuses": ("antiangoreux",),
    "antiangoreux": ("antiangoreux",),
    "antiapartheid": ("antiapartheid",),
    "antiarthritique": ("antiarthritique",),
    "antiarthritiques": ("antiarthritique",),
    "antiarythmique": ("antiarythmique",),
    "antiarythmiques": ("antiarythmique",),
    "antiasthmatique": ("antiasthmatique",),
    "antiasthmatiques": ("antiasthmatique",),
    "antiatomique": ("antiatomique",),
    "antiatomiques": ("antiatomique",),
    "antiautoritaire": ("antiautoritaire",),
    "antiautoritaires": ("antiautoritaire",),
    "antibactéricide": ("antibactéricide",),
    "antibactéricides": ("antibactéricide",),
    "antibactérien": ("antibactérien",),
    "antibactérienne": ("antibactérien",),
    "antibactériennes": ("antibactérien",),
    "antibactériens": ("antibactérien",),
    "antibactériologique": ("antibactériologique",),
    "antibactériologiques": ("antibactériologique",),
    "antibalistique": ("antibalistique",),
    "antibalistiques": ("antibalistique",),
    "antibase": ("antibase",),
    "antibelge": ("antibelge",),
    "antibelges": ("antibelge",),
    "antibiotique": ("antibiotique",),
    "antibiotiques": ("antibiotique",),
    "antiblanchiment": ("antiblanchiment",),
    "antiblocage": ("antiblocage",),
    "antibotulique": ("antibotulique",),
    "antibotuliques": ("antibotulique",),
    "antibourgeoise": ("antibourgeois",),
    "antibourgeoises": ("antibourgeois",),
    "antibourgeois": ("antibourgeois",),
    "antiboycott": ("antiboycott",),
    "antibrachiale": ("antibrachial",),
    "antibrachiales": ("antibrachial",),
    "antibrachial": ("antibrachial",),
    "antibrachiaux": ("antibrachial",),
    "antibrouillard": ("antibrouillard",),
    "antibrucellose": ("antibrucellose",),
    "antibruit": ("antibruit",),
    "antibuée": ("antibuée",),
    "antibureaucratique": ("antibureaucratique",),
    "antibureaucratiques": ("antibureaucratique",),
    "anticabreur": ("anticabreur",),
    "anticabreurs": ("anticabreur",),
    "anticalcaire": ("anticalcaire",),
    "anticalcaires": ("anticalcaire",),
    "anticalcique": ("anticalcique",),
    "anticalciques": ("anticalcique",),
    "anticalorique": ("anticalorique",),
    "anticaloriques": ("anticalorique",),
    "anticancéreuse": ("anticancéreux",),
    "anticancéreuses": ("anticancéreux",),
    "anticancéreux": ("anticancéreux",),
    "anticapillaire": ("anticapillaire",),
    "anticapillaires": ("anticapillaire",),
    "anticapitaliste": ("anticapitaliste",),
    "anti-capitalistes": ("anti-capitaliste",),
    "anticapitalistes": ("anticapitaliste",),
    "anticasseur": ("anticasseur",),
    "anticasseurs": ("anticasseur",),
    "anticastriste": ("anticastriste",),
    "anticastristes": ("anticastriste",),
    "anticaustique": ("anticaustique",),
    "anticaustiques": ("anticaustique",),
    "anticellulite": ("anticellulite",),
    "anticernes": ("anticernes",),
    "antichar": ("antichar",),
    "antichars": ("antichar",),
    "antichinoise": ("antichinois",),
    "antichinoises": ("antichinois",),
    "antichinois": ("antichinois",),
    "antichoc": ("antichoc",),
    "anticholérique": ("anticholérique",),
    "anticholériques": ("anticholérique",),
    "anticholinergique": ("anticholinergique",),
    "anticholinergiques": ("anticholinergique",),
    "anticholinestérasique": ("anticholinestérasique",),
    "anticholinestérasiques": ("anticholinestérasique",),
    "antichômage": ("antichômage",),
    "antichrésiste": ("antichrésiste",),
    "antichrésistes": ("antichrésiste",),
    "antichrétien": ("antichrétien",),
    "antichrétienne": ("antichrétien",),
    "antichrétiennes": ("antichrétien",),
    "antichrétiens": ("antichrétien",),
    "antichute": ("antichute",),
    "anticipateur": ("anticipateur",),
    "anticipateurs": ("anticipateur",),
    "anticipatrice": ("anticipateur",),
    "anticipatrices": ("anticipateur",),
    "anticipatif": ("anticipatif",),
    "anticipatifs": ("anticipatif",),
    "anticipative": ("anticipatif",),
    "anticipatives": ("anticipatif",),
    "anticité": ("anticité",),
    "anticléricale": ("anticlérical",),
    "anticléricales": ("anticlérical",),
    "anticlérical": ("anticlérical",),
    "anticléricaux": ("anticlérical",),
    "anticlinale": ("anticlinal",),
    "anticlinales": ("anticlinal",),
    "anticlinal": ("anticlinal",),
    "anticlinaux": ("anticlinal",),
    "anticoccidien": ("anticoccidien",),
    "anticoccidienne": ("anticoccidien",),
    "anticoccidiennes": ("anticoccidien",),
    "anticoccidiens": ("anticoccidien",),
    "anticollision": ("anticollision",),
    "anticoloniale": ("anticolonial",),
    "anticoloniales": ("anticolonial",),
    "anticolonial": ("anticolonial",),
    "anticoloniaux": ("anticolonial",),
    "anticolonialiste": ("anticolonialiste",),
    "anticolonialistes": ("anticolonialiste",),
    "anti-communiste": ("anti-communiste",),
    "anticommuniste": ("anticommuniste",),
    "anticommunistes": ("anticommuniste",),
    "anticommutatif": ("anticommutatif",),
    "anticommutatifs": ("anticommutatif",),
    "anticommutative": ("anticommutatif",),
    "anticommutatives": ("anticommutatif",),
    "anticomplément": ("anticomplément",),
    "anticomplémentaire": ("anticomplémentaire",),
    "anticomplémentaires": ("anticomplémentaire",),
    "anticompound": ("anticompound",),
    "anticonceptionnelle": ("anticonceptionnel",),
    "anticonceptionnelles": ("anticonceptionnel",),
    "anticonceptionnel": ("anticonceptionnel",),
    "anticonceptionnels": ("anticonceptionnel",),
    "anticoncordataire": ("anticoncordataire",),
    "anticoncordataires": ("anticoncordataire",),
    "anticoncurrentielle": ("anticoncurrentiel",),
    "anticoncurrentielles": ("anticoncurrentiel",),
    "anticoncurrentiel": ("anticoncurrentiel",),
    "anticoncurrentiels": ("anticoncurrentiel",),
    "anticonformiste": ("anticonformiste",),
    "anticonformistes": ("anticonformiste",),
    "anticongélation": ("anticongélation",),
    "anticonjoncturelle": ("anticonjoncturel",),
    "anticonjoncturelles": ("anticonjoncturel",),
    "anticonjoncturel": ("anticonjoncturel",),
    "anticonjoncturels": ("anticonjoncturel",),
    "anticonstitutionnelle": ("anticonstitutionnel",),
    "anticonstitutionnelles": ("anticonstitutionnel",),
    "anticonstitutionnel": ("anticonstitutionnel",),
    "anticonstitutionnels": ("anticonstitutionnel",),
    "anticoquelucheuse": ("anticoquelucheux",),
    "anticoquelucheuses": ("anticoquelucheux",),
    "anticoquelucheux": ("anticoquelucheux",),
    "anticorrosif": ("anticorrosif",),
    "anticorrosifs": ("anticorrosif",),
    "anticorrosive": ("anticorrosif",),
    "anticorrosives": ("anticorrosif",),
    "anticorrosion": ("anticorrosion",),
    "anticoulures": ("anticoulures",),
    "anticoup": ("anticoup",),
    "anticouple": ("anticouple",),
    "anticrevaison": ("anticrevaison",),
    "anticrise": ("anticrise",),
    "anticryptogamique": ("anticryptogamique",),
    "anticryptogamiques": ("anticryptogamique",),
    "anticyclique": ("anticyclique",),
    "anticycliques": ("anticyclique",),
    "anticyclonale": ("anticyclonal",),
    "anticyclonales": ("anticyclonal",),
    "anticyclonal": ("anticyclonal",),
    "anticyclonaux": ("anticyclonal",),
    "anticyclonique": ("anticyclonique",),
    "anticycloniques": ("anticyclonique",),
    "anticytotoxique": ("anticytotoxique",),
    "anticytotoxiques": ("anticytotoxique",),
    "antidélinquance": ("antidélinquance",),
    "antidémocratique": ("antidémocratique",),
    "antidémocratiques": ("antidémocratique",),
    "antidengue": ("antidengue",),
    "antidépresseur": ("antidépresseur",),
    "antidépresseurs": ("antidépresseur",),
    "antidépressif": ("antidépressif",),
    "antidépressifs": ("antidépressif",),
    "antidépressive": ("antidépressif",),
    "antidépressives": ("antidépressif",),
    "antidiabétique": ("antidiabétique",),
    "antidiabétiques": ("antidiabétique",),
    "antidiarrhéique": ("antidiarrhéique",),
    "antidiarrhéiques": ("antidiarrhéique",),
    "antidiphtérique": ("antidiphtérique",),
    "antidiphtériques": ("antidiphtérique",),
    "antidiurétique": ("antidiurétique",),
    "antidiurétiques": ("antidiurétique",),
    "antidogmatique": ("antidogmatique",),
    "antidogmatiques": ("antidogmatique",),
    "antidopage": ("antidopage",),
    "antidoping": ("antidoping",),
    "antidotique": ("antidotique",),
    "antidotiques": ("antidotique",),
    "antidouleur": ("antidouleur",),
    "antidrogue": ("antidrogue",),
    "antidromique": ("antidromique",),
    "antidromiques": ("antidromique",),
    "anti-dumping": ("anti-dumping",),
    "antidumping": ("antidumping",),
    "antiéconomique": ("antiéconomique",),
    "antiéconomiques": ("antiéconomique",),
    "antiémétique": ("antiémétique",),
    "antiémétiques": ("antiémétique",),
    "antiémeute": ("antiémeute",),
    "antiémeutes": ("antiémeute",),
    "antiémulsion": ("antiémulsion",),
    "antiengin": ("antiengin",),
    "antiengins": ("antiengin",),
    "antiépileptique": ("antiépileptique",),
    "antiépileptiques": ("antiépileptique",),
    "antiesclavagiste": ("antiesclavagiste",),
    "antiesclavagistes": ("antiesclavagiste",),
    "antiestrogène": ("antiestrogène",),
    "antiestrogènes": ("antiestrogène",),
    "antiétatique": ("antiétatique",),
    "antiétatiques": ("antiétatique",),
    "antiévangélique": ("antiévangélique",),
    "antiévangéliques": ("antiévangélique",),
    "antiévanouissement": ("antiévanouissement",),
    "antifading": ("antifading",),
    "antifarinage": ("antifarinage",),
    "antifasciste": ("antifasciste",),
    "antifascistes": ("antifasciste",),
    "antifatigue": ("antifatigue",),
    "antifédéraliste": ("antifédéraliste",),
    "antifédéralistes": ("antifédéraliste",),
    "antiféministe": ("antiféministe",),
    "antiféministes": ("antiféministe",),
    "antiferroélectrique": ("antiferroélectrique",),
    "antiferroélectriques": ("antiferroélectrique",),
    "antiferromagnétique": ("antiferromagnétique",),
    "antiferromagnétiques": ("antiferromagnétique",),
    "antifeu": ("antifeu",),
    "antifibrinolytique": ("antifibrinolytique",),
    "antifibrinolytiques": ("antifibrinolytique",),
    "antiflash": ("antiflash",),
    "antiflocons": ("antiflocons",),
    "antiflottation": ("antiflottation",),
    "antifolinique": ("antifolinique",),
    "antifoliniques": ("antifolinique",),
    "antifolique": ("antifolique",),
    "antifoliques": ("antifolique",),
    "antifongique": ("antifongique",),
    "antifongiques": ("antifongique",),
    "antiforces": ("antiforces",),
    "antifouling": ("antifouling",),
    "antifrançaise": ("antifrançais",),
    "antifrançaises": ("antifrançais",),
    "antifrançais": ("antifrançais",),
    "antifriction": ("antifriction",),
    "antifumée": ("antifumée",),
    "antifungique": ("antifungique",),
    "antifungiques": ("antifungique",),
    "antigalactique": ("antigalactique",),
    "antigalactiques": ("antigalactique",),
    "antigang": ("antigang",),
    "antigangréneuse": ("antigangréneux",),
    "antigangréneuses": ("antigangréneux",),
    "antigangréneux": ("antigangréneux",),
    "antigaspi": ("antigaspi",),
    "antigauchiste": ("antigauchiste",),
    "antigauchistes": ("antigauchiste",),
    "antigaulliste": ("antigaulliste",),
    "antigaullistes": ("antigaulliste",),
    "antigel": ("antigel",),
    "antigène": ("antigène",),
    "antigènes": ("antigène",),
    "antigénémique": ("antigénémique",),
    "antigénémiques": ("antigénémique",),
    "antigénique": ("antigénique",),
    "antigéniques": ("antigénique",),
    "antigiratoire": ("antigiratoire",),
    "antigiratoires": ("antigiratoire",),
    "antigivre": ("antigivre",),
    "antiglaucomateuse": ("antiglaucomateux",),
    "antiglaucomateuses": ("antiglaucomateux",),
    "antiglaucomateux": ("antiglaucomateux",),
    "antiglisse": ("antiglisse",),
    "antiglobule": ("antiglobule",),
    "antiglucocorticoïde": ("antiglucocorticoïde",),
    "antigonadotrope": ("antigonadotrope",),
    "antigonide": ("antigonide",),
    "antigonides": ("antigonide",),
    "antigoutteuse": ("antigoutteux",),
    "antigoutteuses": ("antigoutteux",),
    "antigoutteux": ("antigoutteux",),
    "anti-gouvernementale": ("anti-gouvernemental",),
    "antigouvernementale": ("antigouvernemental",),
    "anti-gouvernementales": ("anti-gouvernemental",),
    "antigouvernementales": ("antigouvernemental",),
    "anti-gouvernemental": ("anti-gouvernemental",),
    "antigouvernemental": ("antigouvernemental",),
    "anti-gouvernementaux": ("anti-gouvernemental",),
    "antigouvernementaux": ("antigouvernemental",),
    "antigravitationnelle": ("antigravitationnel",),
    "antigravitationnelles": ("antigravitationnel",),
    "antigravitationnel": ("antigravitationnel",),
    "antigravitationnels": ("antigravitationnel",),
    "antigrégaire": ("antigrégaire",),
    "antigrégaires": ("antigrégaire",),
    "antigrève": ("antigrève",),
    "antigrippale": ("antigrippal",),
    "antigrippales": ("antigrippal",),
    "antigrippal": ("antigrippal",),
    "antigrippaux": ("antigrippal",),
    "antigrisouteuse": ("antigrisouteux",),
    "antigrisouteuses": ("antigrisouteux",),
    "antigrisouteux": ("antigrisouteux",),
    "antiguérilla": ("antiguérilla",),
    "antihalo": ("antihalo",),
    "antihausse": ("antihausse",),
    "antihélicoptère": ("antihélicoptère",),
    "antihélicoptères": ("antihélicoptère",),
    "antihelminthique": ("antihelminthique",),
    "antihelminthiques": ("antihelminthique",),
    "antihémophilique": ("antihémophilique",),
    "antihémophiliques": ("antihémophilique",),
    "antihémorragique": ("antihémorragique",),
    "antihémorragiques": ("antihémorragique",),
    "antihermitien": ("antihermitien",),
    "antihermitienne": ("antihermitien",),
    "antihermitiennes": ("antihermitien",),
    "antihermitiens": ("antihermitien",),
    "antihistaminique": ("antihistaminique",),
    "antihistaminiques": ("antihistaminique",),
    "antiholomorphe": ("antiholomorphe",),
    "antiholomorphes": ("antiholomorphe",),
    "antihoraire": ("antihoraire",),
    "antihoraires": ("antihoraire",),
    "antihormone": ("antihormone",),
    "antihumaniste": ("antihumaniste",),
    "antihumanistes": ("antihumaniste",),
    "antihygiénique": ("antihygiénique",),
    "antihygiéniques": ("antihygiénique",),
    "antihypertenseur": ("antihypertenseur",),
    "antiimpéraliste": ("antiimpéraliste",),
    "antiimpéralistes": ("antiimpéraliste",),
    "anti-infectieux": ("anti-infectieux",),
    "anti-inflammatoire": ("anti-inflammatoire",),
    "anti-inflammatoires": ("anti-inflammatoire",),
    "antiinflationniste": ("antiinflationniste",),
    "antiinflationnistes": ("antiinflationniste",),
    "antiintellectualiste": ("antiintellectualiste",),
    "antiintellectualistes": ("antiintellectualiste",),
    "antijanséniste": ("antijanséniste",),
    "antijansénistes": ("antijanséniste",),
    "antijeunes": ("antijeunes",),
    "antijuif": ("antijuif",),
    "antijuifs": ("antijuif",),
    "antijuive": ("antijuif",),
    "antijuives": ("antijuif",),
    "antijungle": ("antijungle",),
    "antilacet": ("antilacet",),
    "antilaiteuse": ("antilaiteux",),
    "antilaiteuses": ("antilaiteux",),
    "antilaiteux": ("antilaiteux",),
    "antilarvaire": ("antilarvaire",),
    "antilarvaires": ("antilarvaire",),
    "antiléniniste": ("antiléniniste",),
    "antiléninistes": ("antiléniniste",),
    "antileucémique": ("antileucémique",),
    "antileucémiques": ("antileucémique",),
    "antileucoplaquettaire": ("antileucoplaquettaire",),
    "antileucoplaquettaires": ("antileucoplaquettaire",),
    "antilibérale": ("antilibéral",),
    "antilibérales": ("antilibéral",),
    "antilibéral": ("antilibéral",),
    "antilibéraux": ("antilibéral",),
    "antilithique": ("antilithique",),
    "antilithiques": ("antilithique",),
    "antillaise": ("antillais",),
    "antillaises": ("antillais",),
    "antillais": ("antillais",),
    "antilogue": ("antilogue",),
    "antilogues": ("antilogue",),
    "antilope": ("antilope",),
    "antilueur": ("antilueur",),
    "antilymphocytaire": ("antilymphocytaire",),
    "antilymphocytaires": ("antilymphocytaire",),
    "antimaçonnique": ("antimaçonnique",),
    "antimaçonniques": ("antimaçonnique",),
    "antimaffia": ("antimaffia",),
    "antimafia": ("antimafia",),
    "antimalarique": ("antimalarique",),
    "antimalariques": ("antimalarique",),
    "antimaoïste": ("antimaoïste",),
    "antimaoïstes": ("antimaoïste",),
    "antimarasme": ("antimarasme",),
    "antimarxiste": ("antimarxiste",),
    "antimarxistes": ("antimarxiste",),
    "antiméningococcique": ("antiméningococcique",),
    "antiméningococciques": ("antiméningococcique",),
    "antimentaliste": ("antimentaliste",),
    "antimentalistes": ("antimentaliste",),
    "antimicrobien": ("antimicrobien",),
    "antimicrobienne": ("antimicrobien",),
    "antimicrobiennes": ("antimicrobien",),
    "antimicrobiens": ("antimicrobien",),
    "antimigraineuse": ("antimigraineux",),
    "antimigraineuses": ("antimigraineux",),
    "antimigraineux": ("antimigraineux",),
    "antimilitariste": ("antimilitariste",),
    "antimilitaristes": ("antimilitariste",),
    "antiminérale": ("antiminéral",),
    "antiminérales": ("antiminéral",),
    "antiminéral": ("antiminéral",),
    "antiminéraux": ("antiminéral",),
    "antimissile": ("antimissile",),
    "antimissiles": ("antimissile",),
    "antimite": ("antimite",),
    "antimites": ("antimite",),
    "antimitotique": ("antimitotique",),
    "antimitotiques": ("antimitotique",),
    "antimoderne": ("antimoderne",),
    "antimodernes": ("antimoderne",),
    "antimonarchique": ("antimonarchique",),
    "antimonarchiques": ("antimonarchique",),
    "antimonarchiste": ("antimonarchiste",),
    "antimonarchistes": ("antimonarchiste",),
    "antimondialisation": ("antimondialisation",),
    "antimoniale": ("antimonial",),
    "antimoniales": ("antimonial",),
    "antimonial": ("antimonial",),
    "antimoniaux": ("antimonial",),
    "antimonieuse": ("antimonieux",),
    "antimonieuses": ("antimonieux",),
    "antimonieux": ("antimonieux",),
    "antimoniopotassique": ("antimoniopotassique",),
    "antimoniopotassiques": ("antimoniopotassique",),
    "antimonique": ("antimonique",),
    "antimoniques": ("antimonique",),
    "antimonopole": ("antimonopole",),
    "antimonopoles": ("antimonopole",),
    "antimorbilleuse": ("antimorbilleux",),
    "antimorbilleuses": ("antimorbilleux",),
    "antimorbilleux": ("antimorbilleux",),
    "antimorphinique": ("antimorphinique",),
    "antimorphiniques": ("antimorphinique",),
    "antimousse": ("antimousse",),
    "antimycosique": ("antimycosique",),
    "antimycosiques": ("antimycosique",),
    "antimycotique": ("antimycotique",),
    "antimycotiques": ("antimycotique",),
    "antinataliste": ("antinataliste",),
    "antinatalistes": ("antinataliste",),
    "antinationale": ("antinational",),
    "antinationales": ("antinational",),
    "antinational": ("antinational",),
    "antinationaux": ("antinational",),
    "antinaturelle": ("antinaturel",),
    "antinaturelles": ("antinaturel",),
    "antinaturel": ("antinaturel",),
    "antinaturels": ("antinaturel",),
    "antinavire": ("antinavire",),
    "antinavires": ("antinavire",),
    "antinéoplasique": ("antinéoplasique",),
    "antinéoplasiques": ("antinéoplasique",),
    "antinévralgique": ("antinévralgique",),
    "antinévralgiques": ("antinévralgique",),
    "antinévritique": ("antinévritique",),
    "antinévritiques": ("antinévritique",),
    "antinidateur": ("antinidateur",),
    "antinidateurs": ("antinidateur",),
    "antinidatrice": ("antinidateur",),
    "antinidatrices": ("antinidateur",),
    "antinidatoire": ("antinidatoire",),
    "antinidatoires": ("antinidatoire",),
    "antinodale": ("antinodal",),
    "antinodales": ("antinodal",),
    "antinodal": ("antinodal",),
    "antinodaux": ("antinodal",),
    "antinomien": ("antinomien",),
    "antinomienne": ("antinomien",),
    "antinomiennes": ("antinomien",),
    "antinomiens": ("antinomien",),
    "antinomique": ("antinomique",),
    "antinomiques": ("antinomique",),
    "antinucléaire": ("antinucléaire",),
    "antinucléaires": ("antinucléaire",),
    "antioccidentale": ("antioccidental",),
    "anti-occidentales": ("anti-occidental",),
    "antioccidentales": ("antioccidental",),
    "anti-occidental": ("anti-occidental",),
    "antioccidental": ("antioccidental",),
    "antioccidentaux": ("antioccidental",),
    "anti-ourlien": ("anti-ourlien",),
    "antiourlien": ("antiourlien",),
    "antiourlienne": ("antiourlien",),
    "antiourliennes": ("antiourlien",),
    "anti-ourliens": ("anti-ourlien",),
    "antiourliens": ("antiourlien",),
    "antioxygène": ("antioxygène",),
    "antipalestinien": ("antipalestinien",),
    "antipalestinienne": ("antipalestinien",),
    "antipalestiniennes": ("antipalestinien",),
    "antipalestiniens": ("antipalestinien",),
    "antipaludéen": ("antipaludéen",),
    "antipaludéenne": ("antipaludéen",),
    "antipaludéennes": ("antipaludéen",),
    "antipaludéens": ("antipaludéen",),
    "antipaludique": ("antipaludique",),
    "antipaludiques": ("antipaludique",),
    "antiparallèle": ("antiparallèle",),
    "antiparallèles": ("antiparallèle",),
    "antiparasitaire": ("antiparasitaire",),
    "antiparasitaires": ("antiparasitaire",),
    "antiparasite": ("antiparasite",),
    "antiparasites": ("antiparasite",),
    "antiparkinsonien": ("antiparkinsonien",),
    "antiparkinsonienne": ("antiparkinsonien",),
    "antiparkinsoniennes": ("antiparkinsonien",),
    "antiparkinsoniens": ("antiparkinsonien",),
    "antiparlementaire": ("antiparlementaire",),
    "antiparlementaires": ("antiparlementaire",),
    "antiparti": ("antiparti",),
    "antipathique": ("antipathique",),
    "antipathiques": ("antipathique",),
    "antipatriotique": ("antipatriotique",),
    "antipatriotiques": ("antipatriotique",),
    "antipeaux": ("antipeaux",),
    "antipédagogique": ("antipédagogique",),
    "antipédagogiques": ("antipédagogique",),
    "antipelliculaire": ("antipelliculaire",),
    "antipelliculaires": ("antipelliculaire",),
    "antipériplanaire": ("antipériplanaire",),
    "antipériplanaires": ("antipériplanaire",),
    "antipéristaltique": ("antipéristaltique",),
    "antipéristaltiques": ("antipéristaltique",),
    "antipernicieuse": ("antipernicieux",),
    "antipernicieuses": ("antipernicieux",),
    "antipernicieux": ("antipernicieux",),
    "antipersonnel": ("antipersonnel",),
    "antiphallinique": ("antiphallinique",),
    "antiphalliniques": ("antiphallinique",),
    "antiphernale": ("antiphernal",),
    "antiphernales": ("antiphernal",),
    "antiphernal": ("antiphernal",),
    "antiphernaux": ("antiphernal",),
    "antiphlogistique": ("antiphlogistique",),
    "antiphlogistiques": ("antiphlogistique",),
    "antiphonique": ("antiphonique",),
    "antiphoniques": ("antiphonique",),
    "antipilonnement": ("antipilonnement",),
    "antiplaquettaire": ("antiplaquettaire",),
    "antiplaquettaires": ("antiplaquettaire",),
    "antiplastique": ("antiplastique",),
    "antiplastiques": ("antiplastique",),
    "antipluraliste": ("antipluraliste",),
    "antipluralistes": ("antipluraliste",),
    "antipneumococcique": ("antipneumococcique",),
    "antipneumococciques": ("antipneumococcique",),
    "antipodaire": ("antipodaire",),
    "antipodaires": ("antipodaire",),
    "antipodale": ("antipodal",),
    "antipodales": ("antipodal",),
    "antipodal": ("antipodal",),
    "antipodaux": ("antipodal",),
    "antipodiste": ("antipodiste",),
    "antipodistes": ("antipodiste",),
    "antipoétique": ("antipoétique",),
    "antipoétiques": ("antipoétique",),
    "antipoils": ("antipoils",),
    "antipoison": ("antipoison",),
    "antipoisons": ("antipoison",),
    "antipolio": ("antipolio",),
    "antipoliomyélitique": ("antipoliomyélitique",),
    "antipoliomyélitiques": ("antipoliomyélitique",),
    "antipollution": ("antipollution",),
    "antipolyurique": ("antipolyurique",),
    "antipolyuriques": ("antipolyurique",),
    "antiprincipale": ("antiprincipal",),
    "antiprincipales": ("antiprincipal",),
    "antiprincipal": ("antiprincipal",),
    "antiprincipaux": ("antiprincipal",),
    "antiprogestamimétique": ("antiprogestamimétique",),
    "antiprogestamimétiques": ("antiprogestamimétique",),
    "antiprogestatif": ("antiprogestatif",),
    "antiprogestatifs": ("antiprogestatif",),
    "antiprogestative": ("antiprogestatif",),
    "antiprogestatives": ("antiprogestatif",),
    "antiprogestérone": ("antiprogestérone",),
    "antiprolactine": ("antiprolactine",),
    "antiprolifératif": ("antiprolifératif",),
    "antiprolifératifs": ("antiprolifératif",),
    "antiproliférative": ("antiprolifératif",),
    "antiprolifératives": ("antiprolifératif",),
    "antiprotéase": ("antiprotéase",),
    "antiprotectionniste": ("antiprotectionniste",),
    "antiprotectionnistes": ("antiprotectionniste",),
    "antiprotozoaire": ("antiprotozoaire",),
    "antiprotozoaires": ("antiprotozoaire",),
    "antiprurigineuse": ("antiprurigineux",),
    "antiprurigineuses": ("antiprurigineux",),
    "antiprurigineux": ("antiprurigineux",),
    "antipsorique": ("antipsorique",),
    "antipsoriques": ("antipsorique",),
    "antipsychiatrique": ("antipsychiatrique",),
    "antipsychiatriques": ("antipsychiatrique",),
    "antipsychotique": ("antipsychotique",),
    "antipsychotiques": ("antipsychotique",),
    "antipullorique": ("antipullorique",),
    "antipulloriques": ("antipullorique",),
    "antiputride": ("antiputride",),
    "antiputrides": ("antiputride",),
    "antipyorrhéique": ("antipyorrhéique",),
    "antipyorrhéiques": ("antipyorrhéique",),
    "antipyrétique": ("antipyrétique",),
    "antipyrétiques": ("antipyrétique",),
    "antiquée": ("antiqué",),
    "antiquées": ("antiqué",),
    "antiqué": ("antiqué",),
    "antique": ("antique",),
    "antiqués": ("antiqué",),
    "antiques": ("antique",),
    "antiquinquennat": ("antiquinquennat",),
    "antirabique": ("antirabique",),
    "antirabiques": ("antirabique",),
    "antirachitique": ("antirachitique",),
    "antirachitiques": ("antirachitique",),
    "antiraciste": ("antiraciste",),
    "antiracistes": ("antiraciste",),
    "antiradar": ("antiradar",),
    "antiradiation": ("antiradiation",),
    "antirationnelle": ("antirationnel",),
    "antirationnelles": ("antirationnel",),
    "antirationnel": ("antirationnel",),
    "antirationnels": ("antirationnel",),
    "antiréactif": ("antiréactif",),
    "antiréactifs": ("antiréactif",),
    "antiréactive": ("antiréactif",),
    "antiréactives": ("antiréactif",),
    "antireflet": ("antireflet",),
    "antireflets": ("antireflet",),
    "antiréglementaire": ("antiréglementaire",),
    "antiréglementaires": ("antiréglementaire",),
    "antirelâchement": ("antirelâchement",),
    "antireligieuse": ("antireligieux",),
    "anti-religieuses": ("anti-religieux",),
    "antireligieuses": ("antireligieux",),
    "antireligieux": ("antireligieux",),
    "antiretombées": ("antiretombées",),
    "antiretour": ("antiretour",),
    "antirétrovirale": ("antirétroviral",),
    "antirétrovirales": ("antirétroviral",),
    "antirétroviral": ("antirétroviral",),
    "antirétroviraux": ("antirétroviral",),
    "antirévisionniste": ("antirévisionniste",),
    "antirévisionnistes": ("antirévisionniste",),
    "antirhésus": ("antirhésus",),
    "antirhumatismale": ("antirhumatismal",),
    "antirhumatismales": ("antirhumatismal",),
    "antirhumatismal": ("antirhumatismal",),
    "antirhumatismaux": ("antirhumatismal",),
    "antirides": ("antirides",),
    "antirotatoire": ("antirotatoire",),
    "antirotatoires": ("antirotatoire",),
    "antirougeoleuse": ("antirougeoleux",),
    "antirougeoleuses": ("antirougeoleux",),
    "antirougeoleux": ("antirougeoleux",),
    "antirouille": ("antirouille",),
    "antiroulis": ("antiroulis",),
    "antirubéoleuse": ("antirubéoleux",),
    "anti-rubéoleuses": ("anti-rubéoleux",),
    "antirubéoleuses": ("antirubéoleux",),
    "antirubéoleux": ("antirubéoleux",),
    "antirubéolique": ("antirubéolique",),
    "anti-rubéoliques": ("anti-rubéolique",),
    "antirubéoliques": ("antirubéolique",),
    "antirusse": ("antirusse",),
    "antirusses": ("antirusse",),
    "antisalissure": ("antisalissure",),
    "antisatellite": ("antisatellite",),
    "antiscabieuse": ("antiscabieux",),
    "antiscabieuses": ("antiscabieux",),
    "antiscabieux": ("antiscabieux",),
    "antiscientifique": ("antiscientifique",),
    "antiscientifiques": ("antiscientifique",),
    "antiscorbutique": ("antiscorbutique",),
    "antiscorbutiques": ("antiscorbutique",),
    "antiséborrhéique": ("antiséborrhéique",),
    "antiséborrhéiques": ("antiséborrhéique",),
    "antisécheresse": ("antisécheresse",),
    "antisécrétoire": ("antisécrétoire",),
    "antisécrétoires": ("antisécrétoire",),
    "antisecte": ("antisecte",),
    "antisectes": ("antisecte",),
    "antiségrégationniste": ("antiségrégationniste",),
    "antiségrégationnistes": ("antiségrégationniste",),
    "antiséisme": ("antiséisme",),
    "antiséismes": ("antiséisme",),
    "antisémite": ("antisémite",),
    "antisémites": ("antisémite",),
    "antisémitique": ("antisémitique",),
    "antisémitiques": ("antisémitique",),
    "antiseptique": ("antiseptique",),
    "antiseptiques": ("antiseptique",),
    "antisexiste": ("antisexiste",),
    "antisexistes": ("antisexiste",),
    "antisida": ("antisida",),
    "antisioniste": ("antisioniste",),
    "antisionistes": ("antisioniste",),
    "antisismique": ("antisismique",),
    "antisismiques": ("antisismique",),
    "antisociale": ("antisocial",),
    "antisociales": ("antisocial",),
    "antisocial": ("antisocial",),
    "antisociaux": ("antisocial",),
    "antisocialiste": ("antisocialiste",),
    "antisocialistes": ("antisocialiste",),
    "antisolaire": ("antisolaire",),
    "antisolaires": ("antisolaire",),
    "antisouffle": ("antisouffle",),
    "antisoviétique": ("antisoviétique",),
    "antisoviétiques": ("antisoviétique",),
    "antispasmodique": ("antispasmodique",),
    "antispasmodiques": ("antispasmodique",),
    "antispastique": ("antispastique",),
    "antispastiques": ("antispastique",),
    "antisportif": ("antisportif",),
    "antisportifs": ("antisportif",),
    "antisportive": ("antisportif",),
    "antisportives": ("antisportif",),
    "antistalinien": ("antistalinien",),
    "antistalinienne": ("antistalinien",),
    "antistaliniennes": ("antistalinien",),
    "antistaliniens": ("antistalinien",),
    "antistatique": ("antistatique",),
    "antistatiques": ("antistatique",),
    "antistreptococcique": ("antistreptococcique",),
    "antistreptococciques": ("antistreptococcique",),
    "antistress": ("antistress",),
    "antistructuraliste": ("antistructuraliste",),
    "antistructuralistes": ("antistructuraliste",),
    "antisudorale": ("antisudoral",),
    "antisudorales": ("antisudoral",),
    "antisudoral": ("antisudoral",),
    "antisudoraux": ("antisudoral",),
    "antisuie": ("antisuie",),
    "antisurface": ("antisurface",),
    "antisymétrique": ("antisymétrique",),
    "antisymétriques": ("antisymétrique",),
    "antisyndicale": ("antisyndical",),
    "antisyndicales": ("antisyndical",),
    "antisyndical": ("antisyndical",),
    "antisyndicaux": ("antisyndical",),
    "antisynthétique": ("antisynthétique",),
    "antisynthétiques": ("antisynthétique",),
    "antisyphilitique": ("antisyphilitique",),
    "antisyphilitiques": ("antisyphilitique",),
    "antitabac": ("antitabac",),
    "antitabagique": ("antitabagique",),
    "antitabagiques": ("antitabagique",),
    "antitache": ("antitache",),
    "antitartre": ("antitartre",),
    "antiterne": ("antiterne",),
    "antiternes": ("antiterne",),
    "antiterroriste": ("antiterroriste",),
    "antiterroristes": ("antiterroriste",),
    "antitétanique": ("antitétanique",),
    "antitétaniques": ("antitétanique",),
    "antithermique": ("antithermique",),
    "antithermiques": ("antithermique",),
    "antithétique": ("antithétique",),
    "antithétiques": ("antithétique",),
    "antithyroïdien": ("antithyroïdien",),
    "antithyroïdienne": ("antithyroïdien",),
    "antithyroïdiennes": ("antithyroïdien",),
    "antithyroïdiens": ("antithyroïdien",),
    "antitissulaire": ("antitissulaire",),
    "antitissulaires": ("antitissulaire",),
    "antitotalitaire": ("antitotalitaire",),
    "antitotalitaires": ("antitotalitaire",),
    "antitout": ("antitout",),
    "antitoxique": ("antitoxique",),
    "antitoxiques": ("antitoxique",),
    "antitrac": ("antitrac",),
    "antitrappe": ("antitrappe",),
    "antitrinitaire": ("antitrinitaire",),
    "antitrinitaires": ("antitrinitaire",),
    "antitrinitarien": ("antitrinitarien",),
    "antitrinitarienne": ("antitrinitarien",),
    "antitrinitariennes": ("antitrinitarien",),
    "antitrinitariens": ("antitrinitarien",),
    "antitrust": ("antitrust",),
    "antituberculeuse": ("antituberculeux",),
    "antituberculeuses": ("antituberculeux",),
    "antituberculeux": ("antituberculeux",),
    "antitumorale": ("antitumoral",),
    "antitumorales": ("antitumoral",),
    "anti-tumoral": ("anti-tumoral",),
    "antitumoral": ("antitumoral",),
    "anti-tumoraux": ("anti-tumoral",),
    "antitumoraux": ("antitumoral",),
    "antitussif": ("antitussif",),
    "antitussifs": ("antitussif",),
    "antitussive": ("antitussif",),
    "antitussives": ("antitussif",),
    "antityphique": ("antityphique",),
    "antityphiques": ("antityphique",),
    "antityphoïdique": ("antityphoïdique",),
    "antityphoïdiques": ("antityphoïdique",),
    "antityphoparatyphique": ("antityphoparatyphique",),
    "antityphoparatyphiques": ("antityphoparatyphique",),
    "antiulcéreuse": ("antiulcéreux",),
    "antiulcéreuses": ("antiulcéreux",),
    "antiulcéreux": ("antiulcéreux",),
    "antiunitaire": ("antiunitaire",),
    "antiunitaires": ("antiunitaire",),
    "antiusure": ("antiusure",),
    "antivaccine": ("antivaccine",),
    "antivaricelleuse": ("antivaricelleux",),
    "antivaricelleuses": ("antivaricelleux",),
    "antivaricelleux": ("antivaricelleux",),
    "antivarices": ("antivarices",),
    "antivariolique": ("antivariolique",),
    "antivarioliques": ("antivariolique",),
    "antivéhicules": ("antivéhicules",),
    "antivénéneuse": ("antivénéneux",),
    "antivénéneuses": ("antivénéneux",),
    "antivénéneux": ("antivénéneux",),
    "antivénérien": ("antivénérien",),
    "antivénérienne": ("antivénérien",),
    "antivénériennes": ("antivénérien",),
    "antivénériens": ("antivénérien",),
    "antivenimeuse": ("antivenimeux",),
    "antivenimeuses": ("antivenimeux",),
    "antivenimeux": ("antivenimeux",),
    "antivibratile": ("antivibratile",),
    "antivibratiles": ("antivibratile",),
    "antiviolence": ("antiviolence",),
    "antivirale": ("antiviral",),
    "antivirales": ("antiviral",),
    "antiviral": ("antiviral",),
    "antiviraux": ("antiviral",),
    "antivitaminique": ("antivitaminique",),
    "antivitaminiques": ("antivitaminique",),
    "antivivisectionniste": ("antivivisectionniste",),
    "antivivisectionnistes": ("antivivisectionniste",),
    "antivoile": ("antivoile",),
    "antivol": ("antivol",),
    "antivomitif": ("antivomitif",),
    "antivomitifs": ("antivomitif",),
    "antivomitive": ("antivomitif",),
    "antivomitives": ("antivomitif",),
    "antivrilleur": ("antivrilleur",),
    "antivrilleurs": ("antivrilleur",),
    "antixérophtalmique": ("antixérophtalmique",),
    "antixérophtalmiques": ("antixérophtalmique",),
    "antizymique": ("antizymique",),
    "antizymiques": ("antizymique",),
    "antoiniste": ("antoiniste",),
    "antoinistes": ("antoiniste",),
    "antonine": ("antonine",),
    "antonines": ("antonine",),
    "antonyme": ("antonyme",),
    "antonymes": ("antonyme",),
    "antonymique": ("antonymique",),
    "antonymiques": ("antonymique",),
    "antrale": ("antral",),
    "antrales": ("antral",),
    "antral": ("antral",),
    "antraux": ("antral",),
    "anurique": ("anurique",),
    "anuriques": ("anurique",),
    "anversoise": ("anversois",),
    "anversoises": ("anversois",),
    "anversois": ("anversois",),
    "anxieuse": ("anxieux",),
    "anxieuses": ("anxieux",),
    "anxieux": ("anxieux",),
    "anxiogène": ("anxiogène",),
    "anxiogènes": ("anxiogène",),
    "anxiolytique": ("anxiolytique",),
    "anxiolytiques": ("anxiolytique",),
    "aoristique": ("aoristique",),
    "aoristiques": ("aoristique",),
    "aortique": ("aortique",),
    "aortiques": ("aortique",),
    "apache": ("apache",),
    "apaches": ("apache",),
    "apagogique": ("apagogique",),
    "apagogiques": ("apagogique",),
    "apanagère": ("apanager",),
    "apanagères": ("apanager",),
    "apanager": ("apanager",),
    "apanagers": ("apanager",),
    "apathique": ("apathique",),
    "apathiques": ("apathique",),
    "apatride": ("apatride",),
    "apatrides": ("apatride",),
    "aperceptible": ("aperceptible",),
    "aperceptibles": ("aperceptible",),
    "aperceptif": ("aperceptif",),
    "aperceptifs": ("aperceptif",),
    "aperceptive": ("aperceptif",),
    "aperceptives": ("aperceptif",),
    "apercevable": ("apercevable",),
    "apercevables": ("apercevable",),
    "apériodique": ("apériodique",),
    "apériodiques": ("apériodique",),
    "apériteur": ("apériteur",),
    "apériteurs": ("apériteur",),
    "apéritrice": ("apériteur",),
    "apéritrices": ("apériteur",),
    "apéritif": ("apéritif",),
    "apéritifs": ("apéritif",),
    "apéritive": ("apéritif",),
    "apéritives": ("apéritif",),
    "apétale": ("apétale",),
    "apétales": ("apétale",),
    "apexien": ("apexien",),
    "apexienne": ("apexien",),
    "apexiennes": ("apexien",),
    "apexiens": ("apexien",),
    "aphake": ("aphake",),
    "aphakes": ("aphake",),
    "aphaque": ("aphaque",),
    "aphaques": ("aphaque",),
    "aphasique": ("aphasique",),
    "aphasiques": ("aphasique",),
    "aphétique": ("aphétique",),
    "aphétiques": ("aphétique",),
    "aphlogistique": ("aphlogistique",),
    "aphlogistiques": ("aphlogistique",),
    "aphone": ("aphone",),
    "aphones": ("aphone",),
    "aphonique": ("aphonique",),
    "aphoniques": ("aphonique",),
    "aphoristique": ("aphoristique",),
    "aphoristiques": ("aphoristique",),
    "aphotique": ("aphotique",),
    "aphotiques": ("aphotique",),
    "aphrodisiaque": ("aphrodisiaque",),
    "aphrodisiaques": ("aphrodisiaque",),
    "aphteuse": ("aphteux",),
    "aphteuses": ("aphteux",),
    "aphteux": ("aphteux",),
    "aphtoïde": ("aphtoïde",),
    "aphtoïdes": ("aphtoïde",),
    "aphylactique": ("aphylactique",),
    "aphylactiques": ("aphylactique",),
    "aphylle": ("aphylle",),
    "aphylles": ("aphylle",),
    "aphytale": ("aphytal",),
    "aphytales": ("aphytal",),
    "aphytal": ("aphytal",),
    "aphytaux": ("aphytal",),
    "apicale": ("apical",),
    "apicales": ("apical",),
    "apical": ("apical",),
    "apicaux": ("apical",),
    "apiciflore": ("apiciflore",),
    "apiciflores": ("apiciflore",),
    "apiciforme": ("apiciforme",),
    "apiciformes": ("apiciforme",),
    "apico-alvéolaire": ("apico-alvéolaire",),
    "apico-dentale": ("apico-dental",),
    "apicodentale": ("apicodental",),
    "apico-dentales": ("apico-dental",),
    "apicodentales": ("apicodental",),
    "apicodental": ("apicodental",),
    "apico-dentaux": ("apico-dental",),
    "apicodentaux": ("apicodental",),
    "apico-labiale": ("apicolabial",),
    "apicolabiale": ("apicolabial",),
    "apicolabiales": ("apicolabial",),
    "apicolabial": ("apicolabial",),
    "apicolabiaux": ("apicolabial",),
    "apicole": ("apicole",),
    "apicoles": ("apicole",),
    "apiculturale": ("apicultural",),
    "apiculturales": ("apicultural",),
    "apicultural": ("apicultural",),
    "apiculturaux": ("apicultural",),
    "apiforme": ("apiforme",),
    "apiformes": ("apiforme",),
    "apifuge": ("apifuge",),
    "apifuges": ("apifuge",),
    "apivore": ("apivore",),
    "apivores": ("apivore",),
    "aplacentaire": ("aplacentaire",),
    "aplacentaires": ("aplacentaire",),
    "aplanétique": ("aplanétique",),
    "aplanétiques": ("aplanétique",),
    "aplasique": ("aplasique",),
    "aplasiques": ("aplasique",),
    "aplastique": ("aplastique",),
    "aplastiques": ("aplastique",),
    "apneustique": ("apneustique",),
    "apneustiques": ("apneustique",),
    "apocalyptique": ("apocalyptique",),
    "apocalyptiques": ("apocalyptique",),
    "apochromatique": ("apochromatique",),
    "apochromatiques": ("apochromatique",),
    "apocryphe": ("apocryphe",),
    "apocryphes": ("apocryphe",),
    "apocytaire": ("apocytaire",),
    "apocytaires": ("apocytaire",),
    "apode": ("apode",),
    "apodes": ("apode",),
    "apodictique": ("apodictique",),
    "apodictiques": ("apodictique",),
    "apogamique": ("apogamique",),
    "apogamiques": ("apogamique",),
    "apolitique": ("apolitique",),
    "apolitiques": ("apolitique",),
    "apollinaire": ("apollinaire",),
    "apollinaires": ("apollinaire",),
    "apollinariste": ("apollinariste",),
    "apollinaristes": ("apollinariste",),
    "apollinien": ("apollinien",),
    "apollinienne": ("apollinien",),
    "apolliniennes": ("apollinien",),
    "apolliniens": ("apollinien",),
    "apologétique": ("apologétique",),
    "apologétiques": ("apologétique",),
    "apolytique": ("apolytique",),
    "apolytiques": ("apolytique",),
    "apomorphe": ("apomorphe",),
    "apomorphes": ("apomorphe",),
    "aponévrotique": ("aponévrotique",),
    "aponévrotiques": ("aponévrotique",),
    "apophantique": ("apophantique",),
    "apophantiques": ("apophantique",),
    "apophatique": ("apophatique",),
    "apophatiques": ("apophatique",),
    "apophysaire": ("apophysaire",),
    "apophysaires": ("apophysaire",),
    "apoplectiforme": ("apoplectiforme",),
    "apoplectiformes": ("apoplectiforme",),
    "apoplectique": ("apoplectique",),
    "apoplectiques": ("apoplectique",),
    "apoplectoïde": ("apoplectoïde",),
    "apoplectoïdes": ("apoplectoïde",),
    "aporétique": ("aporétique",),
    "aporétiques": ("aporétique",),
    "aposématique": ("aposématique",),
    "aposématiques": ("aposématique",),
    "apostérioriste": ("apostérioriste",),
    "apostérioristes": ("apostérioriste",),
    "apostolique": ("apostolique",),
    "apostoliques": ("apostolique",),
    "apotropaïque": ("apotropaïque",),
    "apotropaïques": ("apotropaïque",),
    "appalachien": ("appalachien",),
    "appalachienne": ("appalachien",),
    "appalachiennes": ("appalachien",),
    "appalachiens": ("appalachien",),
    "appareillable": ("appareillable",),
    "appareillables": ("appareillable",),
    "appelable": ("appelable",),
    "appelables": ("appelable",),
    "appellatif": ("appellatif",),
    "appellatifs": ("appellatif",),
    "appellative": ("appellatif",),
    "appellatives": ("appellatif",),
    "appendiculaire": ("appendiculaire",),
    "appendiculaires": ("appendiculaire",),
    "appétible": ("appétible",),
    "appétibles": ("appétible",),
    "appienne": ("appienne",),
    "appiennes": ("appienne",),
    "applaudissable": ("applaudissable",),
    "applaudissables": ("applaudissable",),
    "applicable": ("applicable",),
    "applicables": ("applicable",),
    "applicateur": ("applicateur",),
    "applicateurs": ("applicateur",),
    "applicatrice": ("applicateur",),
    "applicatrices": ("applicateur",),
    "apporteur": ("apporteur",),
    "apporteurs": ("apporteur",),
    "apporteuse": ("apporteur",),
    "apporteuses": ("apporteur",),
    "appositif": ("appositif",),
    "appositifs": ("appositif",),
    "appositive": ("appositif",),
    "appositives": ("appositif",),
    "appréciable": ("appréciable",),
    "appréciables": ("appréciable",),
    "appréciateur": ("appréciateur",),
    "appréciateurs": ("appréciateur",),
    "appréciatrice": ("appréciateur",),
    "appréciatrices": ("appréciateur",),
    "appréciatif": ("appréciatif",),
    "appréciatifs": ("appréciatif",),
    "appréciative": ("appréciatif",),
    "appréciatives": ("appréciatif",),
    "appréhensif": ("appréhensif",),
    "appréhensifs": ("appréhensif",),
    "appréhensive": ("appréhensif",),
    "appréhensives": ("appréhensif",),
    "apprivoisable": ("apprivoisable",),
    "apprivoisables": ("apprivoisable",),
    "apprivoiseur": ("apprivoiseur",),
    "apprivoiseurs": ("apprivoiseur",),
    "apprivoiseuse": ("apprivoiseur",),
    "apprivoiseuses": ("apprivoiseur",),
    "approbateur": ("approbateur",),
    "approbateurs": ("approbateur",),
    "approbatrice": ("approbateur",),
    "approbatrices": ("approbateur",),
    "approbatif": ("approbatif",),
    "approbatifs": ("approbatif",),
    "approbative": ("approbatif",),
    "approbatives": ("approbatif",),
    "approchable": ("approchable",),
    "approchables": ("approchable",),
    "appropriable": ("appropriable",),
    "appropriables": ("appropriable",),
    "approuvable": ("approuvable",),
    "approuvables": ("approuvable",),
    "approvisionneur": ("approvisionneur",),
    "approvisionneurs": ("approvisionneur",),
    "approvisionneuse": ("approvisionneur",),
    "approvisionneuses": ("approvisionneur",),
    "approximatif": ("approximatif",),
    "approximatifs": ("approximatif",),
    "approximative": ("approximatif",),
    "approximatives": ("approximatif",),
    "apractognosique": ("apractognosique",),
    "apractognosiques": ("apractognosique",),
    "apragmatique": ("apragmatique",),
    "apragmatiques": ("apragmatique",),
    "apraxique": ("apraxique",),
    "apraxiques": ("apraxique",),
    "âpre": ("âpre",),
    "âpres": ("âpre",),
    "apriorique": ("apriorique",),
    "aprioriques": ("apriorique",),
    "aprioriste": ("aprioriste",),
    "aprioristes": ("aprioriste",),
    "aprioristique": ("aprioristique",),
    "aprioristiques": ("aprioristique",),
    "aprioritique": ("aprioritique",),
    "aprioritiques": ("aprioritique",),
    "aprotique": ("aprotique",),
    "aprotiques": ("aprotique",),
    "apsidale": ("apsidal",),
    "apsidales": ("apsidal",),
    "apsidal": ("apsidal",),
    "apsidaux": ("apsidal",),
    "apte": ("apte",),
    "aptes": ("apte",),
    "aptère": ("aptère",),
    "aptères": ("aptère",),
    "apulien": ("apulien",),
    "apulienne": ("apulien",),
    "apuliennes": ("apulien",),
    "apuliens": ("apulien",),
    "apyre": ("apyre",),
    "apyres": ("apyre",),
    "apyrétique": ("apyrétique",),
    "apyrétiques": ("apyrétique",),
    "apyrogène": ("apyrogène",),
    "apyrogènes": ("apyrogène",),
    "aquacole": ("aquacole",),
    "aquacoles": ("aquacole",),
    "aquafortiste": ("aquafortiste",),
    "aquafortistes": ("aquafortiste",),
    "aquarellable": ("aquarellable",),
    "aquarellables": ("aquarellable",),
    "aquariophile": ("aquariophile",),
    "aquariophiles": ("aquariophile",),
    "aquatique": ("aquatique",),
    "aquatiques": ("aquatique",),
    "aquatubulaire": ("aquatubulaire",),
    "aquatubulaires": ("aquatubulaire",),
    "aqueuse": ("aqueux",),
    "aqueuses": ("aqueux",),
    "aqueux": ("aqueux",),
    "aquicole": ("aquicole",),
    "aquicoles": ("aquicole",),
    "aquifère": ("aquifère",),
    "aquifères": ("aquifère",),
    "aquilain": ("aquilain",),
    "aquilains": ("aquilain",),
    "aquilant": ("aquilant",),
    "aquilants": ("aquilant",),
    "aquilin": ("aquilin",),
    "aquilins": ("aquilin",),
    "aquitanien": ("aquitanien",),
    "aquitanienne": ("aquitanien",),
    "aquitaniennes": ("aquitanien",),
    "aquitaniens": ("aquitanien",),
    "arabe": ("arabe",),
    "arabes": ("arabe",),
    "arabica": ("arabica",),
    "arabique": ("arabique",),
    "arabiques": ("arabique",),
    "arabiste": ("arabiste",),
    "arabistes": ("arabiste",),
    "arable": ("arable",),
    "arables": ("arable",),
    "arabo-altaïque": ("arabo-altaïque",),
    "arabo-berbère": ("arabo-berbère",),
    "arabo-berbères": ("arabo-berbère",),
    "arabo-islamique": ("arabo-islamique",),
    "arabo-musulmane": ("arabo-musulman",),
    "arabo-musulmanes": ("arabo-musulman",),
    "arabo-musulman": ("arabo-musulman",),
    "arabo-musulmans": ("arabo-musulman",),
    "arabonique": ("arabonique",),
    "araboniques": ("arabonique",),
    "arabo-persique": ("arabo-persique",),
    "arabophone": ("arabophone",),
    "arabophones": ("arabophone",),
    "arachidique": ("arachidique",),
    "arachidiques": ("arachidique",),
    "arachidonique": ("arachidonique",),
    "arachidoniques": ("arachidonique",),
    "arachinodique": ("arachinodique",),
    "arachinodiques": ("arachinodique",),
    "arachnéen": ("arachnéen",),
    "arachnéenne": ("arachnéen",),
    "arachnéennes": ("arachnéen",),
    "arachnéens": ("arachnéen",),
    "arachnodactyle": ("arachnodactyle",),
    "arachnodactyles": ("arachnodactyle",),
    "arachnoïde": ("arachnoïde",),
    "arachnoïdes": ("arachnoïde",),
    "arachnoïdien": ("arachnoïdien",),
    "arachnoïdienne": ("arachnoïdien",),
    "arachnoïdiennes": ("arachnoïdien",),
    "arachnoïdiens": ("arachnoïdien",),
    "arachnologique": ("arachnologique",),
    "arachnologiques": ("arachnologique",),
    "aragonaise": ("aragonais",),
    "aragonaises": ("aragonais",),
    "aragonais": ("aragonais",),
    "araméen": ("araméen",),
    "araméenne": ("araméen",),
    "araméennes": ("araméen",),
    "araméens": ("araméen",),
    "araméophone": ("araméophone",),
    "araméophones": ("araméophone",),
    "aramide": ("aramide",),
    "aramides": ("aramide",),
    "aranéen": ("aranéen",),
    "aranéenne": ("aranéen",),
    "aranéennes": ("aranéen",),
    "aranéens": ("aranéen",),
    "aranéeuse": ("aranéeux",),
    "aranéeuses": ("aranéeux",),
    "aranéeux": ("aranéeux",),
    "aranéologique": ("aranéologique",),
    "aranéologiques": ("aranéologique",),
    "aratoire": ("aratoire",),
    "aratoires": ("aratoire",),
    "arbitrable": ("arbitrable",),
    "arbitrables": ("arbitrable",),
    "arbitragiste": ("arbitragiste",),
    "arbitragistes": ("arbitragiste",),
    "arbitraire": ("arbitraire",),
    "arbitraires": ("arbitraire",),
    "arbitrale": ("arbitral",),
    "arbitrales": ("arbitral",),
    "arbitral": ("arbitral",),
    "arbitraux": ("arbitral",),
    "arboricole": ("arboricole",),
    "arboricoles": ("arboricole",),
    "arbustif": ("arbustif",),
    "arbustifs": ("arbustif",),
    "arbustive": ("arbustif",),
    "arbustives": ("arbustif",),
    "arcadien": ("arcadien",),
    "arcadienne": ("arcadien",),
    "arcadiennes": ("arcadien",),
    "arcadiens": ("arcadien",),
    "archaïque": ("archaïque",),
    "archaïques": ("archaïque",),
    "archangélique": ("archangélique",),
    "archangéliques": ("archangélique",),
    "archanthropien": ("archanthropien",),
    "archanthropienne": ("archanthropien",),
    "archanthropiennes": ("archanthropien",),
    "archanthropiens": ("archanthropien",),
    "archéen": ("archéen",),
    "archéenne": ("archéen",),
    "archéennes": ("archéen",),
    "archéens": ("archéen",),
    "archéologique": ("archéologique",),
    "archéologiques": ("archéologique",),
    "archéozoïque": ("archéozoïque",),
    "archéozoïques": ("archéozoïque",),
    "archéozoologique": ("archéozoologique",),
    "archéozoologiques": ("archéozoologique",),
    "archétypale": ("archétypal",),
    "archétypales": ("archétypal",),
    "archétypal": ("archétypal",),
    "archétypaux": ("archétypal",),
    "archétypique": ("archétypique",),
    "archétypiques": ("archétypique",),
    "archicérébelleuse": ("archicérébelleux",),
    "archicérébelleuses": ("archicérébelleux",),
    "archicérébelleux": ("archicérébelleux",),
    "archiducale": ("archiducal",),
    "archiducales": ("archiducal",),
    "archiducal": ("archiducal",),
    "archiducaux": ("archiducal",),
    "archiépiscopale": ("archiépiscopal",),
    "archiépiscopales": ("archiépiscopal",),
    "archiépiscopal": ("archiépiscopal",),
    "archiépiscopaux": ("archiépiscopal",),
    "archifolle": ("archifou",),
    "archifolles": ("archifou",),
    "archifou": ("archifou",),
    "archifous": ("archifou",),
    "archiloquien": ("archiloquien",),
    "archiloquienne": ("archiloquien",),
    "archiloquiennes": ("archiloquien",),
    "archiloquiens": ("archiloquien",),
    "archimédien": ("archimédien",),
    "archimédienne": ("archimédien",),
    "archimédiennes": ("archimédien",),
    "archimédiens": ("archimédien",),
    "archimillionnaire": ("archimillionnaire",),
    "archimillionnaires": ("archimillionnaire",),
    "archipalliale": ("archipallial",),
    "archipalliales": ("archipallial",),
    "archipallial": ("archipallial",),
    "archipalliaux": ("archipallial",),
    "archipélagique": ("archipélagique",),
    "archipélagiques": ("archipélagique",),
    "archipresbytérale": ("archipresbytéral",),
    "archipresbytérales": ("archipresbytéral",),
    "archipresbytéral": ("archipresbytéral",),
    "archipresbytéraux": ("archipresbytéral",),
    "architectonique": ("architectonique",),
    "architectoniques": ("architectonique",),
    "architecturale": ("architectural",),
    "architecturales": ("architectural",),
    "architectural": ("architectural",),
    "architecturaux": ("architectural",),
    "archivistique": ("archivistique",),
    "archivistiques": ("archivistique",),
    "arciforme": ("arciforme",),
    "arciformes": ("arciforme",),
    "arctique": ("arctique",),
    "arctiques": ("arctique",),
    "ardasse": ("ardasse",),
    "ardasses": ("ardasse",),
    "ardéchoise": ("ardéchois",),
    "ardéchoises": ("ardéchois",),
    "ardéchois": ("ardéchois",),
    "ardennaise": ("ardennais",),
    "ardennaises": ("ardennais",),
    "ardennais": ("ardennais",),
    "ardoisière": ("ardoisier",),
    "ardoisières": ("ardoisier",),
    "ardoisier": ("ardoisier",),
    "ardoisiers": ("ardoisier",),
    "aréflexique": ("aréflexique",),
    "aréflexiques": ("aréflexique",),
    "arégénératif": ("arégénératif",),
    "arégénératifs": ("arégénératif",),
    "arégénérative": ("arégénératif",),
    "arégénératives": ("arégénératif",),
    "aréique": ("aréique",),
    "aréiques": ("aréique",),
    "areligieuse": ("areligieux",),
    "areligieuses": ("areligieux",),
    "areligieux": ("areligieux",),
    "arénicole": ("arénicole",),
    "arénicoles": ("arénicole",),
    "arénigien": ("arénigien",),
    "arénigienne": ("arénigien",),
    "arénigiennes": ("arénigien",),
    "arénigiens": ("arénigien",),
    "arénophile": ("arénophile",),
    "arénophiles": ("arénophile",),
    "arénophite": ("arénophite",),
    "arénophites": ("arénophite",),
    "aréographique": ("aréographique",),
    "aréographiques": ("aréographique",),
    "aréolaire": ("aréolaire",),
    "aréolaires": ("aréolaire",),
    "aréométrique": ("aréométrique",),
    "aréométriques": ("aréométrique",),
    "arêtière": ("arêtière",),
    "arêtières": ("arêtière",),
    "argentale": ("argental",),
    "argentales": ("argental",),
    "argental": ("argental",),
    "argentaux": ("argental",),
    "argentifère": ("argentifère",),
    "argentifères": ("argentifère",),
    "argentique": ("argentique",),
    "argentiques": ("argentique",),
    "argien": ("argien",),
    "argienne": ("argien",),
    "argiennes": ("argien",),
    "argiens": ("argien",),
    "argileuse": ("argileux",),
    "argileuses": ("argileux",),
    "argileux": ("argileux",),
    "argilique": ("argilique",),
    "argiliques": ("argilique",),
    "argilo-calcaire": ("argilo-calcaire",),
    "argilo-calcaires": ("argilo-calcaire",),
    "argilo-sableuses": ("argilo-sableux",),
    "argilo-sablonneuses": ("argilo-sablonneux",),
    "argotique": ("argotique",),
    "argotiques": ("argotique",),
    "argumentaire": ("argumentaire",),
    "argumentaires": ("argumentaire",),
    "argumentale": ("argumental",),
    "argumentales": ("argumental",),
    "argumental": ("argumental",),
    "argumentaux": ("argumental",),
    "argumentatif": ("argumentatif",),
    "argumentatifs": ("argumentatif",),
    "argumentative": ("argumentatif",),
    "argumentatives": ("argumentatif",),
    "argyrophile": ("argyrophile",),
    "argyrophiles": ("argyrophile",),
    "aride": ("aride",),
    "arides": ("aride",),
    "ariégeoise": ("ariégeois",),
    "ariégeoises": ("ariégeois",),
    "ariégeois": ("ariégeois",),
    "arien": ("arien",),
    "arienne": ("arien",),
    "ariennes": ("arien",),
    "ariens": ("arien",),
    "arioso": ("arioso",),
    "aristo": ("aristo",),
    "aristos": ("aristo",),
    "aristocrate": ("aristocrate",),
    "aristocrates": ("aristocrate",),
    "aristocratique": ("aristocratique",),
    "aristocratiques": ("aristocratique",),
    "aristophanesque": ("aristophanesque",),
    "aristophanesques": ("aristophanesque",),
    "aristotélicien": ("aristotélicien",),
    "aristotélicienne": ("aristotélicien",),
    "aristotéliciennes": ("aristotélicien",),
    "aristotéliciens": ("aristotélicien",),
    "aristotélique": ("aristotélique",),
    "aristotéliques": ("aristotélique",),
    "arithmétique": ("arithmétique",),
    "arithmétiques": ("arithmétique",),
    "arithmologique": ("arithmologique",),
    "arithmologiques": ("arithmologique",),
    "arithmomane": ("arithmomane",),
    "arithmomanes": ("arithmomane",),
    "arlequin": ("arlequin",),
    "arlequins": ("arlequin",),
    "arlésien": ("arlésien",),
    "arlésienne": ("arlésien",),
    "arlésiennes": ("arlésien",),
    "arlésiens": ("arlésien",),
    "arménien": ("arménien",),
    "arménienne": ("arménien",),
    "arméniennes": ("arménien",),
    "arméniens": ("arménien",),
    "armillaire": ("armillaire",),
    "armillaires": ("armillaire",),
    "arminien": ("arminien",),
    "arminienne": ("arminien",),
    "arminiennes": ("arminien",),
    "arminiens": ("arminien",),
    "armoriale": ("armorial",),
    "armoriales": ("armorial",),
    "armorial": ("armorial",),
    "armoriaux": ("armorial",),
    "armorique": ("armorique",),
    "armoriques": ("armorique",),
    "armurière": ("armurier",),
    "armurières": ("armurier",),
    "armurier": ("armurier",),
    "armuriers": ("armurier",),
    "aromale": ("aromal",),
    "aromales": ("aromal",),
    "aromal": ("aromal",),
    "aromaux": ("aromal",),
    "aromatique": ("aromatique",),
    "aromatiques": ("aromatique",),
    "arpenteuse": ("arpenteuse",),
    "arpenteuses": ("arpenteuse",),
    "arrangeable": ("arrangeable",),
    "arrangeables": ("arrangeable",),
    "arraphique": ("arraphique",),
    "arraphiques": ("arraphique",),
    "arrecteur": ("arrecteur",),
    "arrecteurs": ("arrecteur",),
    "arrhénotoque": ("arrhénotoque",),
    "arrhénotoques": ("arrhénotoque",),
    "arriérée": ("arriéré",),
    "arriérées": ("arriéré",),
    "arriéré": ("arriéré",),
    "arrière": ("arrière",),
    "arriérés": ("arriéré",),
    "arriviste": ("arriviste",),
    "arrivistes": ("arriviste",),
    "arrosable": ("arrosable",),
    "arrosables": ("arrosable",),
    "arroseur": ("arroseur",),
    "arroseurs": ("arroseur",),
    "arroseuse": ("arroseur",),
    "arroseuses": ("arroseur",),
    "arsenicale": ("arsenical",),
    "arsenicales": ("arsenical",),
    "arsenical": ("arsenical",),
    "arsenicaux": ("arsenical",),
    "arsénieuse": ("arsénieux",),
    "arsénieuses": ("arsénieux",),
    "arsénieux": ("arsénieux",),
    "arsénifère": ("arsénifère",),
    "arsénifères": ("arsénifère",),
    "arsénique": ("arsénique",),
    "arséniques": ("arsénique",),
    "arsin": ("arsin",),
    "arsins": ("arsin",),
    "arsinique": ("arsinique",),
    "arsiniques": ("arsinique",),
    "arsonique": ("arsonique",),
    "arsoniques": ("arsonique",),
    "arsouille": ("arsouille",),
    "arsouilles": ("arsouille",),
    "artérielle": ("artériel",),
    "artérielles": ("artériel",),
    "artériel": ("artériel",),
    "artériels": ("artériel",),
    "artériolaire": ("artériolaire",),
    "artériolaires": ("artériolaire",),
    "artériolocapillaire": ("artériolocapillaire",),
    "artériolocapillaires": ("artériolocapillaire",),
    "artériopathique": ("artériopathique",),
    "artériopathiques": ("artériopathique",),
    "artérioscléreuse": ("artérioscléreux",),
    "artérioscléreuses": ("artérioscléreux",),
    "artérioscléreux": ("artérioscléreux",),
    "artéritique": ("artéritique",),
    "artéritiques": ("artéritique",),
    "artésien": ("artésien",),
    "artésienne": ("artésien",),
    "artésiennes": ("artésien",),
    "artésiens": ("artésien",),
    "arthralgique": ("arthralgique",),
    "arthralgiques": ("arthralgique",),
    "arthritique": ("arthritique",),
    "arthritiques": ("arthritique",),
    "arthromyalgique": ("arthromyalgique",),
    "arthromyalgiques": ("arthromyalgique",),
    "arthropathique": ("arthropathique",),
    "arthropathiques": ("arthropathique",),
    "arthroscopique": ("arthroscopique",),
    "arthroscopiques": ("arthroscopique",),
    "arthrosique": ("arthrosique",),
    "arthrosiques": ("arthrosique",),
    "arthrosynoviale": ("arthrosynovial",),
    "arthrosynoviales": ("arthrosynovial",),
    "arthrosynovial": ("arthrosynovial",),
    "arthrosynoviaux": ("arthrosynovial",),
    "articulaire": ("articulaire",),
    "articulaires": ("articulaire",),
    "articulateur": ("articulateur",),
    "articulateurs": ("articulateur",),
    "articulatrice": ("articulateur",),
    "articulatrices": ("articulateur",),
    "articulatoire": ("articulatoire",),
    "articulatoires": ("articulatoire",),
    "artificielle": ("artificiel",),
    "artificielles": ("artificiel",),
    "artificiel": ("artificiel",),
    "artificiels": ("artificiel",),
    "artificieuse": ("artificieux",),
    "artificieuses": ("artificieux",),
    "artificieux": ("artificieux",),
    "artisanale": ("artisanal",),
    "artisanales": ("artisanal",),
    "artisanal": ("artisanal",),
    "artisanaux": ("artisanal",),
    "artiste": ("artiste",),
    "artistes": ("artiste",),
    "artistique": ("artistique",),
    "artistiques": ("artistique",),
    "arvale": ("arvale",),
    "arvales": ("arvale",),
    "arvicole": ("arvicole",),
    "arvicoles": ("arvicole",),
    "aryballisque": ("aryballisque",),
    "aryballisques": ("aryballisque",),
    "aryen": ("aryen",),
    "aryenne": ("aryen",),
    "aryennes": ("aryen",),
    "aryens": ("aryen",),
    "aryténoïde": ("aryténoïde",),
    "aryténoïdes": ("aryténoïde",),
    "aryténoïdien": ("aryténoïdien",),
    "aryténoïdienne": ("aryténoïdien",),
    "aryténoïdiennes": ("aryténoïdien",),
    "aryténoïdiens": ("aryténoïdien",),
    "arythmique": ("arythmique",),
    "arythmiques": ("arythmique",),
    "ascensionnelle": ("ascensionnel",),
    "ascensionnelles": ("ascensionnel",),
    "ascensionnel": ("ascensionnel",),
    "ascensionnels": ("ascensionnel",),
    "ascétique": ("ascétique",),
    "ascétiques": ("ascétique",),
    "ascitique": ("ascitique",),
    "ascitiques": ("ascitique",),
    "asclépiade": ("asclépiade",),
    "asclépiades": ("asclépiade",),
    "asconique": ("asconique",),
    "asconiques": ("asconique",),
    "ascorbique": ("ascorbique",),
    "ascorbiques": ("ascorbique",),
    "aséismique": ("aséismique",),
    "aséismiques": ("aséismique",),
    "asémantique": ("asémantique",),
    "asémantiques": ("asémantique",),
    "aseptique": ("aseptique",),
    "aseptiques": ("aseptique",),
    "asexuelle": ("asexuel",),
    "asexuelles": ("asexuel",),
    "asexuel": ("asexuel",),
    "asexuels": ("asexuel",),
    "ashkenaze": ("ashkenaze",),
    "ashkénaze": ("ashkénaze",),
    "ashkenazes": ("ashkenaze",),
    "ashkénazes": ("ashkénaze",),
    "asianique": ("asianique",),
    "asianiques": ("asianique",),
    "asiate": ("asiate",),
    "asiates": ("asiate",),
    "asiatique": ("asiatique",),
    "asiatiques": ("asiatique",),
    "asilaire": ("asilaire",),
    "asilaires": ("asilaire",),
    "asinien": ("asinien",),
    "asinienne": ("asinien",),
    "asiniennes": ("asinien",),
    "asiniens": ("asinien",),
    "asociable": ("asociable",),
    "asociables": ("asociable",),
    "asociale": ("asocial",),
    "asociales": ("asocial",),
    "asocial": ("asocial",),
    "asociaux": ("asocial",),
    "aspartique": ("aspartique",),
    "aspartiques": ("aspartique",),
    "aspécifique": ("aspécifique",),
    "aspécifiques": ("aspécifique",),
    "aspectuelle": ("aspectuel",),
    "aspectuelles": ("aspectuel",),
    "aspectuel": ("aspectuel",),
    "aspectuels": ("aspectuel",),
    "asperme": ("asperme",),
    "aspermes": ("asperme",),
    "asphalteuse": ("asphalteux",),
    "asphalteuses": ("asphalteux",),
    "asphalteux": ("asphalteux",),
    "asphaltique": ("asphaltique",),
    "asphaltiques": ("asphaltique",),
    "asphyxique": ("asphyxique",),
    "asphyxiques": ("asphyxique",),
    "aspirateur": ("aspirateur",),
    "aspirateurs": ("aspirateur",),
    "aspiratrice": ("aspirateur",),
    "aspiratrices": ("aspirateur",),
    "aspiratif": ("aspiratif",),
    "aspiratifs": ("aspiratif",),
    "aspirative": ("aspiratif",),
    "aspiratives": ("aspiratif",),
    "aspiratoire": ("aspiratoire",),
    "aspiratoires": ("aspiratoire",),
    "assadien": ("assadien",),
    "assadienne": ("assadien",),
    "assadiennes": ("assadien",),
    "assadiens": ("assadien",),
    "assainisseur": ("assainisseur",),
    "assainisseurs": ("assainisseur",),
    "assainisseuse": ("assainisseur",),
    "assainisseuses": ("assainisseur",),
    "assamaise": ("assamais",),
    "assamaises": ("assamais",),
    "assamais": ("assamais",),
    "assertif": ("assertif",),
    "assertifs": ("assertif",),
    "assertive": ("assertif",),
    "assertives": ("assertif",),
    "assertorique": ("assertorique",),
    "assertoriques": ("assertorique",),
    "asservisseur": ("asservisseur",),
    "asservisseurs": ("asservisseur",),
    "asservisseuse": ("asservisseur",),
    "asservisseuses": ("asservisseur",),
    "assessorale": ("assessoral",),
    "assessorales": ("assessoral",),
    "assessoral": ("assessoral",),
    "assessoraux": ("assessoral",),
    "assessoriale": ("assessorial",),
    "assessoriales": ("assessorial",),
    "assessorial": ("assessorial",),
    "assessoriaux": ("assessorial",),
    "assignable": ("assignable",),
    "assignables": ("assignable",),
    "assimilable": ("assimilable",),
    "assimilables": ("assimilable",),
    "assimilateur": ("assimilateur",),
    "assimilateurs": ("assimilateur",),
    "assimilatrice": ("assimilateur",),
    "assimilatrices": ("assimilateur",),
    "assimilationniste": ("assimilationniste",),
    "assimilationnistes": ("assimilationniste",),
    "assimilatoire": ("assimilatoire",),
    "assimilatoires": ("assimilatoire",),
    "assise": ("assis",),
    "assises": ("assis",),
    "assis": ("assis",),
    "associable": ("associable",),
    "associables": ("associable",),
    "associatif": ("associatif",),
    "associatifs": ("associatif",),
    "associative": ("associatif",),
    "associatives": ("associatif",),
    "associationniste": ("associationniste",),
    "associationnistes": ("associationniste",),
    "assomptif": ("assomptif",),
    "assomptifs": ("assomptif",),
    "assomptive": ("assomptif",),
    "assomptives": ("assomptif",),
    "assomptionniste": ("assomptionniste",),
    "assomptionnistes": ("assomptionniste",),
    "assouvissable": ("assouvissable",),
    "assouvissables": ("assouvissable",),
    "assurable": ("assurable",),
    "assurables": ("assurable",),
    "assurancielle": ("assuranciel",),
    "assurancielles": ("assuranciel",),
    "assuranciel": ("assuranciel",),
    "assuranciels": ("assuranciel",),
    "assyrien": ("assyrien",),
    "assyrienne": ("assyrien",),
    "assyriennes": ("assyrien",),
    "assyriens": ("assyrien",),
    "assyriologique": ("assyriologique",),
    "assyriologiques": ("assyriologique",),
    "astacologique": ("astacologique",),
    "astacologiques": ("astacologique",),
    "astatique": ("astatique",),
    "astatiques": ("astatique",),
    "astéréognosique": ("astéréognosique",),
    "astéréognosiques": ("astéréognosique",),
    "asthénique": ("asthénique",),
    "asthéniques": ("asthénique",),
    "asthénodépressif": ("asthénodépressif",),
    "asthénodépressifs": ("asthénodépressif",),
    "asthénodépressive": ("asthénodépressif",),
    "asthénodépressives": ("asthénodépressif",),
    "asthmatique": ("asthmatique",),
    "asthmatiques": ("asthmatique",),
    "astigmate": ("astigmate",),
    "astigmates": ("astigmate",),
    "astome": ("astome",),
    "astomes": ("astome",),
    "astragalien": ("astragalien",),
    "astragalienne": ("astragalien",),
    "astragaliennes": ("astragalien",),
    "astragaliens": ("astragalien",),
    "astrale": ("astral",),
    "astrales": ("astral",),
    "astral": ("astral",),
    "astraux": ("astral",),
    "astrogéodésique": ("astrogéodésique",),
    "astrogéodésiques": ("astrogéodésique",),
    "astrologique": ("astrologique",),
    "astrologiques": ("astrologique",),
    "astrométrique": ("astrométrique",),
    "astrométriques": ("astrométrique",),
    "astronautique": ("astronautique",),
    "astronautiques": ("astronautique",),
    "astronomique": ("astronomique",),
    "astronomiques": ("astronomique",),
    "astrophotographique": ("astrophotographique",),
    "astrophotographiques": ("astrophotographique",),
    "astrophysique": ("astrophysique",),
    "astrophysiques": ("astrophysique",),
    "astucieuse": ("astucieux",),
    "astucieuses": ("astucieux",),
    "astucieux": ("astucieux",),
    "asturien": ("asturien",),
    "asturienne": ("asturien",),
    "asturiennes": ("asturien",),
    "asturiens": ("asturien",),
    "asyllogistique": ("asyllogistique",),
    "asyllogistiques": ("asyllogistique",),
    "asymétrique": ("asymétrique",),
    "asymétriques": ("asymétrique",),
    "asymptomatique": ("asymptomatique",),
    "asymptomatiques": ("asymptomatique",),
    "asymptote": ("asymptote",),
    "asymptotes": ("asymptote",),
    "asymptotique": ("asymptotique",),
    "asymptotiques": ("asymptotique",),
    "asynchrone": ("asynchrone",),
    "asynchrones": ("asynchrone",),
    "asyntactique": ("asyntactique",),
    "asyntactiques": ("asyntactique",),
    "asyntaxique": ("asyntaxique",),
    "asyntaxiques": ("asyntaxique",),
    "asystolique": ("asystolique",),
    "asystoliques": ("asystolique",),
    "ataraxique": ("ataraxique",),
    "ataraxiques": ("ataraxique",),
    "atavique": ("atavique",),
    "ataviques": ("atavique",),
    "ataxique": ("ataxique",),
    "ataxiques": ("ataxique",),
    "atélectasique": ("atélectasique",),
    "atélectasiques": ("atélectasique",),
    "atéléiotique": ("atéléiotique",),
    "atéléiotiques": ("atéléiotique",),
    "atélique": ("atélique",),
    "atéliques": ("atélique",),
    "atemporelle": ("atemporel",),
    "atemporelles": ("atemporel",),
    "atemporel": ("atemporel",),
    "atemporels": ("atemporel",),
    "atérien": ("atérien",),
    "atérienne": ("atérien",),
    "atériennes": ("atérien",),
    "atériens": ("atérien",),
    "athée": ("athée",),
    "athées": ("athée",),
    "athéistique": ("athéistique",),
    "athéistiques": ("athéistique",),
    "athématique": ("athématique",),
    "athématiques": ("athématique",),
    "athénien": ("athénien",),
    "athénienne": ("athénien",),
    "athéniennes": ("athénien",),
    "athéniens": ("athénien",),
    "athermane": ("athermane",),
    "athermanes": ("athermane",),
    "athermique": ("athermique",),
    "athermiques": ("athermique",),
    "athéromateuse": ("athéromateux",),
    "athéromateuses": ("athéromateux",),
    "athéromateux": ("athéromateux",),
    "athéroscléreuse": ("athéroscléreux",),
    "athéroscléreuses": ("athéroscléreux",),
    "athéroscléreux": ("athéroscléreux",),
    "athétosique": ("athétosique",),
    "athétosiques": ("athétosique",),
    "athlétique": ("athlétique",),
    "athlétiques": ("athlétique",),
    "athrepsique": ("athrepsique",),
    "athrepsiques": ("athrepsique",),
    "athrombopénique": ("athrombopénique",),
    "athrombopéniques": ("athrombopénique",),
    "athymique": ("athymique",),
    "athymiques": ("athymique",),
    "atlantique": ("atlantique",),
    "atlantiques": ("atlantique",),
    "atlantiste": ("atlantiste",),
    "atlantistes": ("atlantiste",),
    "atloïdien": ("atloïdien",),
    "atloïdienne": ("atloïdien",),
    "atloïdiennes": ("atloïdien",),
    "atloïdiens": ("atloïdien",),
    "atmosphérique": ("atmosphérique",),
    "atmosphériques": ("atmosphérique",),
    "atomique": ("atomique",),
    "atomiques": ("atomique",),
    "atomiste": ("atomiste",),
    "atomistes": ("atomiste",),
    "atomistique": ("atomistique",),
    "atomistiques": ("atomistique",),
    "atone": ("atone",),
    "atones": ("atone",),
    "atonique": ("atonique",),
    "atoniques": ("atonique",),
    "atopique": ("atopique",),
    "atopiques": ("atopique",),
    "atoxique": ("atoxique",),
    "atoxiques": ("atoxique",),
    "atrabilaire": ("atrabilaire",),
    "atrabilaires": ("atrabilaire",),
    "atramentaire": ("atramentaire",),
    "atramentaires": ("atramentaire",),
    "atrésique": ("atrésique",),
    "atrésiques": ("atrésique",),
    "atriale": ("atrial",),
    "atriales": ("atrial",),
    "atrial": ("atrial",),
    "atriaux": ("atrial",),
    "atriodigitale": ("atriodigital",),
    "atriodigitales": ("atriodigital",),
    "atriodigital": ("atriodigital",),
    "atriodigitaux": ("atriodigital",),
    "atroce": ("atroce",),
    "atroces": ("atroce",),
    "atrophique": ("atrophique",),
    "atrophiques": ("atrophique",),
    "atropinique": ("atropinique",),
    "atropiniques": ("atropinique",),
    "atropique": ("atropique",),
    "atropiques": ("atropique",),
    "atroque": ("atroque",),
    "atroques": ("atroque",),
    "attalide": ("attalide",),
    "attalides": ("attalide",),
    "attaquable": ("attaquable",),
    "attaquables": ("attaquable",),
    "attelable": ("attelable",),
    "attelables": ("attelable",),
    "attentatoire": ("attentatoire",),
    "attentatoires": ("attentatoire",),
    "attentif": ("attentif",),
    "attentifs": ("attentif",),
    "attentive": ("attentif",),
    "attentives": ("attentif",),
    "attentionnelle": ("attentionnel",),
    "attentionnelles": ("attentionnel",),
    "attentionnel": ("attentionnel",),
    "attentionnels": ("attentionnel",),
    "attentiste": ("attentiste",),
    "attentistes": ("attentiste",),
    "attique": ("attique",),
    "attiques": ("attique",),
    "attirable": ("attirable",),
    "attirables": ("attirable",),
    "attractif": ("attractif",),
    "attractifs": ("attractif",),
    "attractive": ("attractif",),
    "attractives": ("attractif",),
    "attribuable": ("attribuable",),
    "attribuables": ("attribuable",),
    "attributif": ("attributif",),
    "attributifs": ("attributif",),
    "attributive": ("attributif",),
    "attributives": ("attributif",),
    "attributionniste": ("attributionniste",),
    "attributionnistes": ("attributionniste",),
    "atypique": ("atypique",),
    "atypiques": ("atypique",),
    "aubère": ("aubère",),
    "aubères": ("aubère",),
    "aubergine": ("aubergine",),
    "auboise": ("aubois",),
    "auboises": ("aubois",),
    "aubois": ("aubois",),
    "auburn": ("auburn",),
    "auburnien": ("auburnien",),
    "auburnienne": ("auburnien",),
    "auburniennes": ("auburnien",),
    "auburniens": ("auburnien",),
    "audacieuse": ("audacieux",),
    "audacieuses": ("audacieux",),
    "audacieux": ("audacieux",),
    "audible": ("audible",),
    "audibles": ("audible",),
    "audiencière": ("audiencier",),
    "audiencières": ("audiencier",),
    "audiencier": ("audiencier",),
    "audienciers": ("audiencier",),
    "audimétrique": ("audimétrique",),
    "audimétriques": ("audimétrique",),
    "audio": ("audio",),
    "audiodigitale": ("audiodigital",),
    "audiodigitales": ("audiodigital",),
    "audiodigital": ("audiodigital",),
    "audiodigitaux": ("audiodigital",),
    "audiologique": ("audiologique",),
    "audiologiques": ("audiologique",),
    "audiométrique": ("audiométrique",),
    "audiométriques": ("audiométrique",),
    "audionumérique": ("audionumérique",),
    "audionumériques": ("audionumérique",),
    "audio-oral": ("audio-oral",),
    "audio-oraux": ("audio-oral",),
    "audiophonologique": ("audiophonologique",),
    "audiophonologiques": ("audiophonologique",),
    "audio-visuelle": ("audio-visuel",),
    "audiovisuelle": ("audiovisuel",),
    "audiovisuelles": ("audiovisuel",),
    "audio-visuel": ("audio-visuel",),
    "audiovisuel": ("audiovisuel",),
    "audio-visuels": ("audio-visuel",),
    "audiovisuels": ("audiovisuel",),
    "auditif": ("auditif",),
    "auditifs": ("auditif",),
    "auditive": ("auditif",),
    "auditives": ("auditif",),
    "audoise": ("audois",),
    "audoises": ("audois",),
    "audois": ("audois",),
    "audomaroise": ("audomarois",),
    "audomaroises": ("audomarois",),
    "audomarois": ("audomarois",),
    "audonien": ("audonien",),
    "audonienne": ("audonien",),
    "audoniennes": ("audonien",),
    "audoniens": ("audonien",),
    "augeron": ("augeron",),
    "augeronne": ("augeron",),
    "augeronnes": ("augeron",),
    "augerons": ("augeron",),
    "augmentable": ("augmentable",),
    "augmentables": ("augmentable",),
    "augmentatif": ("augmentatif",),
    "augmentatifs": ("augmentatif",),
    "augmentative": ("augmentatif",),
    "augmentatives": ("augmentatif",),
    "augurale": ("augural",),
    "augurales": ("augural",),
    "augural": ("augural",),
    "auguraux": ("augural",),
    "augustale": ("augustal",),
    "augustales": ("augustal",),
    "augustal": ("augustal",),
    "augustaux": ("augustal",),
    "auguste": ("auguste",),
    "augustes": ("auguste",),
    "augustinien": ("augustinien",),
    "augustinienne": ("augustinien",),
    "augustiniennes": ("augustinien",),
    "augustiniens": ("augustinien",),
    "aulique": ("aulique",),
    "auliques": ("aulique",),
    "aurélien": ("aurélien",),
    "aurélienne": ("aurélien",),
    "auréliennes": ("aurélien",),
    "auréliens": ("aurélien",),
    "aureuse": ("aureux",),
    "aureuses": ("aureux",),
    "aureux": ("aureux",),
    "auriculaire": ("auriculaire",),
    "auriculaires": ("auriculaire",),
    "auriculo-cardiaques": ("auriculo-cardiaque",),
    "auriculo-temporal": ("auriculo-temporal",),
    "auriculo-ventriculaires": ("auriculo-ventriculaire",),
    "aurifère": ("aurifère",),
    "aurifères": ("aurifère",),
    "aurifique": ("aurifique",),
    "aurifiques": ("aurifique",),
    "aurignacien": ("aurignacien",),
    "aurignacienne": ("aurignacien",),
    "aurignaciennes": ("aurignacien",),
    "aurignaciens": ("aurignacien",),
    "aurique": ("aurique",),
    "auriques": ("aurique",),
    "aurocéramique": ("aurocéramique",),
    "aurocéramiques": ("aurocéramique",),
    "aurorale": ("auroral",),
    "aurorales": ("auroral",),
    "auroral": ("auroral",),
    "auroraux": ("auroral",),
    "aurore": ("aurore",),
    "auscultatoire": ("auscultatoire",),
    "auscultatoires": ("auscultatoire",),
    "ausonnien": ("ausonnien",),
    "ausonnienne": ("ausonnien",),
    "ausonniennes": ("ausonnien",),
    "ausonniens": ("ausonnien",),
    "austénitique": ("austénitique",),
    "austénitiques": ("austénitique",),
    "austénoferritique": ("austénoferritique",),
    "austénoferritiques": ("austénoferritique",),
    "austère": ("austère",),
    "austères": ("austère",),
    "australanthropien": ("australanthropien",),
    "australanthropienne": ("australanthropien",),
    "australanthropiennes": ("australanthropien",),
    "australanthropiens": ("australanthropien",),
    "australien": ("australien",),
    "australienne": ("australien",),
    "australiennes": ("australien",),
    "australiens": ("australien",),
    "austrégale": ("austrégal",),
    "austrégales": ("austrégal",),
    "austrégal": ("austrégal",),
    "austrégaux": ("austrégal",),
    "austro-bavaroise": ("austro-bavarois",),
    "austro-hongroise": ("austro-hongrois",),
    "austro-hongrois": ("austro-hongrois",),
    "austromarxiste": ("austromarxiste",),
    "austromarxistes": ("austromarxiste",),
    "austronésien": ("austronésien",),
    "austronésienne": ("austronésien",),
    "austronésiennes": ("austronésien",),
    "austronésiens": ("austronésien",),
    "autarcique": ("autarcique",),
    "autarciques": ("autarcique",),
    "authentique": ("authentique",),
    "authentiques": ("authentique",),
    "authonnière": ("authonnier",),
    "authonnières": ("authonnier",),
    "authonnier": ("authonnier",),
    "authonniers": ("authonnier",),
    "autiste": ("autiste",),
    "autistes": ("autiste",),
    "autistique": ("autistique",),
    "autistiques": ("autistique",),
    "autoaccusateur": ("autoaccusateur",),
    "autoaccusateurs": ("autoaccusateur",),
    "autoaccusatrice": ("autoaccusateur",),
    "auto-accusatrices": ("autoaccusateur",),
    "autoaccusatrices": ("autoaccusateur",),
    "autoadaptatif": ("autoadaptatif",),
    "autoadaptatifs": ("autoadaptatif",),
    "auto-adaptative": ("auto-adaptatif",),
    "autoadaptative": ("autoadaptatif",),
    "autoadaptatives": ("autoadaptatif",),
    "autoadhésif": ("autoadhésif",),
    "auto-adhésifs": ("autoadhésif",),
    "autoadhésifs": ("autoadhésif",),
    "autoadhésive": ("autoadhésif",),
    "autoadhésives": ("autoadhésif",),
    "autoagressif": ("autoagressif",),
    "autoagressifs": ("autoagressif",),
    "autoagressive": ("autoagressif",),
    "autoagressives": ("autoagressif",),
    "autoamorceur": ("autoamorceur",),
    "autoamorceurs": ("autoamorceur",),
    "autoamorceuse": ("autoamorceur",),
    "autoamorceuses": ("autoamorceur",),
    "auto-analytiques": ("autoanalytique",),
    "autoantigénique": ("autoantigénique",),
    "autoantigéniques": ("autoantigénique",),
    "autobiographique": ("autobiographique",),
    "autobiographiques": ("autobiographique",),
    "autocassable": ("autocassable",),
    "autocassables": ("autocassable",),
    "autocéphale": ("autocéphale",),
    "autocéphales": ("autocéphale",),
    "autochrome": ("autochrome",),
    "autochromes": ("autochrome",),
    "autochtone": ("autochtone",),
    "autochtones": ("autochtone",),
    "autocinétique": ("autocinétique",),
    "autocinétiques": ("autocinétique",),
    "autoclavable": ("autoclavable",),
    "autoclavables": ("autoclavable",),
    "autoclave": ("autoclave",),
    "autoclaves": ("autoclave",),
    "autocollimateur": ("autocollimateur",),
    "autocollimateurs": ("autocollimateur",),
    "autocollimatrice": ("autocollimateur",),
    "autocollimatrices": ("autocollimateur",),
    "autocompatible": ("autocompatible",),
    "autocompatibles": ("autocompatible",),
    "autocompensateur": ("autocompensateur",),
    "autocompensateurs": ("autocompensateur",),
    "autocompensatrice": ("autocompensateur",),
    "autocompensatrices": ("autocompensateur",),
    "autocopique": ("autocopique",),
    "autocopiques": ("autocopique",),
    "autocorrecteur": ("autocorrecteur",),
    "autocorrecteurs": ("autocorrecteur",),
    "autocorrectrice": ("autocorrecteur",),
    "autocorrectrices": ("autocorrecteur",),
    "autocorrectif": ("autocorrectif",),
    "autocorrectifs": ("autocorrectif",),
    "autocorrective": ("autocorrectif",),
    "autocorrectives": ("autocorrectif",),
    "autocratique": ("autocratique",),
    "autocratiques": ("autocratique",),
    "autodéfroissable": ("autodéfroissable",),
    "autodéfroissables": ("autodéfroissable",),
    "autodépréciatif": ("autodépréciatif",),
    "autodépréciatifs": ("autodépréciatif",),
    "autodépréciative": ("autodépréciatif",),
    "autodépréciatives": ("autodépréciatif",),
    "autodestructeur": ("autodestructeur",),
    "autodestructeurs": ("autodestructeur",),
    "autodestructrice": ("autodestructeur",),
    "autodestructrices": ("autodestructeur",),
    "autodidacte": ("autodidacte",),
    "autodidactes": ("autodidacte",),
    "autodidactique": ("autodidactique",),
    "autodidactiques": ("autodidactique",),
    "autodirecteur": ("autodirecteur",),
    "autodirecteurs": ("autodirecteur",),
    "autodirectrice": ("autodirecteur",),
    "autodirectrices": ("autodirecteur",),
    "autodurcissable": ("autodurcissable",),
    "autodurcissables": ("autodurcissable",),
    "autodynamique": ("autodynamique",),
    "autodynamiques": ("autodynamique",),
    "autoélévateur": ("autoélévateur",),
    "autoélévateurs": ("autoélévateur",),
    "autoélévatrice": ("autoélévateur",),
    "autoélévatrices": ("autoélévateur",),
    "autoépurateur": ("autoépurateur",),
    "autoépurateurs": ("autoépurateur",),
    "autoépuratrice": ("autoépurateur",),
    "autoépuratrices": ("autoépurateur",),
    "autoérotique": ("autoérotique",),
    "autoérotiques": ("autoérotique",),
    "autoexcitateur": ("autoexcitateur",),
    "autoexcitateurs": ("autoexcitateur",),
    "autoexcitatrice": ("autoexcitateur",),
    "autoexcitatrices": ("autoexcitateur",),
    "autoexplosif": ("autoexplosif",),
    "autoexplosifs": ("autoexplosif",),
    "autoexplosive": ("autoexplosif",),
    "autoexplosives": ("autoexplosif",),
    "autoextinguible": ("autoextinguible",),
    "autoextinguibles": ("autoextinguible",),
    "autofertile": ("autofertile",),
    "autofertiles": ("autofertile",),
    "autofocus": ("autofocus",),
    "autogame": ("autogame",),
    "autogames": ("autogame",),
    "autogène": ("autogène",),
    "autogènes": ("autogène",),
    "autogestionnaire": ("autogestionnaire",),
    "autogestionnaires": ("autogestionnaire",),
    "autograisseur": ("autograisseur",),
    "autograisseurs": ("autograisseur",),
    "autograisseuse": ("autograisseur",),
    "autograisseuses": ("autograisseur",),
    "autographe": ("autographe",),
    "autographes": ("autographe",),
    "autographique": ("autographique",),
    "autographiques": ("autographique",),
    "autoimmunitaire": ("autoimmunitaire",),
    "autoimmunitaires": ("autoimmunitaire",),
    "autoïque": ("autoïque",),
    "autoïques": ("autoïque",),
    "autolanceur": ("autolanceur",),
    "autolanceurs": ("autolanceur",),
    "autolavable": ("autolavable",),
    "autolavables": ("autolavable",),
    "autologue": ("autologue",),
    "autologues": ("autologue",),
    "automatique": ("automatique",),
    "automatiques": ("automatique",),
    "automécoïque": ("automécoïque",),
    "automécoïques": ("automécoïque",),
    "automnale": ("automnal",),
    "automnales": ("automnal",),
    "automnal": ("automnal",),
    "automnaux": ("automnal",),
    "automobile": ("automobile",),
    "automobiles": ("automobile",),
    "automobilisable": ("automobilisable",),
    "automobilisables": ("automobilisable",),
    "automorphe": ("automorphe",),
    "automorphes": ("automorphe",),
    "automoteur": ("automoteur",),
    "automoteurs": ("automoteur",),
    "automotrice": ("automoteur",),
    "automotrices": ("automoteur",),
    "automutilateur": ("automutilateur",),
    "automutilateurs": ("automutilateur",),
    "automutilatrice": ("automutilateur",),
    "automutilatrices": ("automutilateur",),
    "autonome": ("autonome",),
    "autonomes": ("autonome",),
    "autonomiste": ("autonomiste",),
    "autonomistes": ("autonomiste",),
    "autonyme": ("autonyme",),
    "autonymes": ("autonyme",),
    "autonymique": ("autonymique",),
    "autonymiques": ("autonymique",),
    "autoperceuse": ("autoperceuse",),
    "autoperceuses": ("autoperceuse",),
    "autoplastique": ("autoplastique",),
    "autoplastiques": ("autoplastique",),
    "autopolaire": ("autopolaire",),
    "autopolaires": ("autopolaire",),
    "autoporteur": ("autoporteur",),
    "autoporteurs": ("autoporteur",),
    "autoporteuse": ("autoporteur",),
    "autoporteuses": ("autoporteur",),
    "autopropulseur": ("autopropulseur",),
    "autopropulseurs": ("autopropulseur",),
    "autopublicitaire": ("autopublicitaire",),
    "autopublicitaires": ("autopublicitaire",),
    "autopunitif": ("autopunitif",),
    "autopunitifs": ("autopunitif",),
    "autopunitive": ("autopunitif",),
    "autopunitives": ("autopunitif",),
    "autoradio": ("autoradio",),
    "autoréactif": ("autoréactif",),
    "autoréactifs": ("autoréactif",),
    "autoréactive": ("autoréactif",),
    "autoréactives": ("autoréactif",),
    "autoréducteur": ("autoréducteur",),
    "autoréducteurs": ("autoréducteur",),
    "autoréductrice": ("autoréducteur",),
    "autoréductrices": ("autoréducteur",),
    "autoréférentielle": ("autoréférentiel",),
    "autoréférentielles": ("autoréférentiel",),
    "autoréférentiel": ("autoréférentiel",),
    "autoréférentiels": ("autoréférentiel",),
    "autoréglable": ("autoréglable",),
    "autoréglables": ("autoréglable",),
    "autorégulateur": ("autorégulateur",),
    "autorégulateurs": ("autorégulateur",),
    "autorégulatrice": ("autorégulateur",),
    "autorégulatrices": ("autorégulateur",),
    "autoréparable": ("autoréparable",),
    "autoréparables": ("autoréparable",),
    "autoreproducteur": ("autoreproducteur",),
    "autoreproducteurs": ("autoreproducteur",),
    "autoreproductrice": ("autoreproducteur",),
    "autoreproductrices": ("autoreproducteur",),
    "autoreproductible": ("autoreproductible",),
    "autoreproductibles": ("autoreproductible",),
    "autorisable": ("autorisable",),
    "autorisables": ("autorisable",),
    "autoritaire": ("autoritaire",),
    "autoritaires": ("autoritaire",),
    "autoroutière": ("autoroutier",),
    "autoroutières": ("autoroutier",),
    "autoroutier": ("autoroutier",),
    "autoroutiers": ("autoroutier",),
    "autoscopique": ("autoscopique",),
    "autoscopiques": ("autoscopique",),
    "autosexable": ("autosexable",),
    "autosexables": ("autosexable",),
    "autositaire": ("autositaire",),
    "autositaires": ("autositaire",),
    "autosomale": ("autosomal",),
    "autosomales": ("autosomal",),
    "autosomal": ("autosomal",),
    "autosomaux": ("autosomal",),
    "autosomique": ("autosomique",),
    "autosomiques": ("autosomique",),
    "autostable": ("autostable",),
    "autostables": ("autostable",),
    "autostérile": ("autostérile",),
    "autostériles": ("autostérile",),
    "autosuggestif": ("autosuggestif",),
    "autosuggestifs": ("autosuggestif",),
    "autosuggestive": ("autosuggestif",),
    "autosuggestives": ("autosuggestif",),
    "autosymétrique": ("autosymétrique",),
    "autosymétriques": ("autosymétrique",),
    "autotoxique": ("autotoxique",),
    "autotoxiques": ("autotoxique",),
    "autotrophe": ("autotrophe",),
    "autotrophes": ("autotrophe",),
    "autovérificateur": ("autovérificateur",),
    "autovérificateurs": ("autovérificateur",),
    "autovérificatrice": ("autovérificateur",),
    "autovérificatrices": ("autovérificateur",),
    "autovireur": ("autovireur",),
    "autovireurs": ("autovireur",),
    "autre": ("autre",),
    "autres": ("autre",),
    "autrichien": ("autrichien",),
    "autrichienne": ("autrichien",),
    "autrichiennes": ("autrichien",),
    "autrichiens": ("autrichien",),
    "auxiliaire": ("auxiliaire",),
    "auxiliaires": ("auxiliaire",),
    "auxiliateur": ("auxiliateur",),
    "auxiliateurs": ("auxiliateur",),
    "auxiliatrice": ("auxiliateur",),
    "auxiliatrices": ("auxiliateur",),
    "auxologique": ("auxologique",),
    "auxologiques": ("auxologique",),
    "avalancheuse": ("avalancheux",),
    "avalancheuses": ("avalancheux",),
    "avalancheux": ("avalancheux",),
    "avaliseur": ("avaliseur",),
    "avaliseurs": ("avaliseur",),
    "avaliseuse": ("avaliseur",),
    "avaliseuses": ("avaliseur",),
    "avaliste": ("avaliste",),
    "avalistes": ("avaliste",),
    "avant": ("avant",),
    "avantageuse": ("avantageux",),
    "avantageuses": ("avantageux",),
    "avantageux": ("avantageux",),
    "avant-coureur": ("avant-coureur",),
    "avant-coureurs": ("avant-coureur",),
    "avant-dernière": ("avant-dernier",),
    "avant-dernier": ("avant-dernier",),
    "avant-gardiste": ("avant-gardiste",),
    "avant-gardistes": ("avant-gardiste",),
    "avare": ("avare",),
    "avares": ("avare",),
    "avaricieuse": ("avaricieux",),
    "avaricieuses": ("avaricieux",),
    "avaricieux": ("avaricieux",),
    "avasculaire": ("avasculaire",),
    "avasculaires": ("avasculaire",),
    "aventureuse": ("aventureux",),
    "aventureuses": ("aventureux",),
    "aventureux": ("aventureux",),
    "aventurière": ("aventurier",),
    "aventurières": ("aventurier",),
    "aventurier": ("aventurier",),
    "aventuriers": ("aventurier",),
    "aventuriste": ("aventuriste",),
    "aventuristes": ("aventuriste",),
    "averroïste": ("averroïste",),
    "averroïstes": ("averroïste",),
    "aversif": ("aversif",),
    "aversifs": ("aversif",),
    "aversive": ("aversif",),
    "aversives": ("aversif",),
    "avertisseur": ("avertisseur",),
    "avertisseurs": ("avertisseur",),
    "avertisseuse": ("avertisseur",),
    "avertisseuses": ("avertisseur",),
    "aveugle": ("aveugle",),
    "aveugles": ("aveugle",),
    "aveyronnaise": ("aveyronnais",),
    "aveyronnaises": ("aveyronnais",),
    "aveyronnais": ("aveyronnais",),
    "aviaire": ("aviaire",),
    "aviaires": ("aviaire",),
    "aviale": ("aviale",),
    "aviales": ("aviale",),
    "avicole": ("avicole",),
    "avicoles": ("avicole",),
    "avide": ("avide",),
    "avides": ("avide",),
    "avien": ("avien",),
    "avienne": ("avien",),
    "aviennes": ("avien",),
    "aviens": ("avien",),
    "aviforme": ("aviforme",),
    "aviformes": ("aviforme",),
    "avocassière": ("avocassier",),
    "avocassières": ("avocassier",),
    "avocassier": ("avocassier",),
    "avocassiers": ("avocassier",),
    "avoriazien": ("avoriazien",),
    "avoriazienne": ("avoriazien",),
    "avoriaziennes": ("avoriazien",),
    "avoriaziens": ("avoriazien",),
    "avouable": ("avouable",),
    "avouables": ("avouable",),
    "avunculaire": ("avunculaire",),
    "avunculaires": ("avunculaire",),
    "avunculocale": ("avunculocal",),
    "avunculocales": ("avunculocal",),
    "avunculocal": ("avunculocal",),
    "avunculocaux": ("avunculocal",),
    "axène": ("axène",),
    "axènes": ("axène",),
    "axénique": ("axénique",),
    "axéniques": ("axénique",),
    "axiale": ("axial",),
    "axiales": ("axial",),
    "axial": ("axial",),
    "axiaux": ("axial",),
    "axile": ("axile",),
    "axiles": ("axile",),
    "axillaire": ("axillaire",),
    "axillaires": ("axillaire",),
    "axiologique": ("axiologique",),
    "axiologiques": ("axiologique",),
    "axiomatique": ("axiomatique",),
    "axiomatiques": ("axiomatique",),
    "axiomatisable": ("axiomatisable",),
    "axiomatisables": ("axiomatisable",),
    "axisymétrique": ("axisymétrique",),
    "axisymétriques": ("axisymétrique",),
    "axonale": ("axonal",),
    "axonales": ("axonal",),
    "axonal": ("axonal",),
    "axonaux": ("axonal",),
    "axonique": ("axonique",),
    "axoniques": ("axonique",),
    "axonométrique": ("axonométrique",),
    "axonométriques": ("axonométrique",),
    "aymara": ("aymara",),
    "aymaras": ("aymara",),
    "ayurvédique": ("ayurvédique",),
    "ayurvédiques": ("ayurvédique",),
    "azanien": ("azanien",),
    "azanienne": ("azanien",),
    "azaniennes": ("azanien",),
    "azaniens": ("azanien",),
    "azéotrope": ("azéotrope",),
    "azéotropes": ("azéotrope",),
    "azéotropique": ("azéotropique",),
    "azéotropiques": ("azéotropique",),
    "azerbaïdjanaise": ("azerbaïdjanais",),
    "azerbaïdjanaises": ("azerbaïdjanais",),
    "azerbaïdjanais": ("azerbaïdjanais",),
    "azilien": ("azilien",),
    "azilienne": ("azilien",),
    "aziliennes": ("azilien",),
    "aziliens": ("azilien",),
    "azimutale": ("azimutal",),
    "azimutales": ("azimutal",),
    "azimutal": ("azimutal",),
    "azimutaux": ("azimutal",),
    "azoïque": ("azoïque",),
    "azoïques": ("azoïque",),
    "azonale": ("azonal",),
    "azonales": ("azonal",),
    "azonal": ("azonal",),
    "azonaux": ("azonal",),
    "azotémique": ("azotémique",),
    "azotémiques": ("azotémique",),
    "azoteuse": ("azoteux",),
    "azoteuses": ("azoteux",),
    "azoteux": ("azoteux",),
    "azothydrique": ("azothydrique",),
    "azothydriques": ("azothydrique",),
    "azotique": ("azotique",),
    "azotiques": ("azotique",),
    "azoxyque": ("azoxyque",),
    "azoxyques": ("azoxyque",),
    "aztèque": ("aztèque",),
    "aztèques": ("aztèque",),
    "azulénique": ("azulénique",),
    "azuléniques": ("azulénique",),
    "azulmique": ("azulmique",),
    "azulmiques": ("azulmique",),
    "azuréen": ("azuréen",),
    "azuréenne": ("azuréen",),
    "azuréennes": ("azuréen",),
    "azuréens": ("azuréen",),
    "azygos": ("azygos",),
    "azyme": ("azyme",),
    "azymes": ("azyme",),
    "azymique": ("azymique",),
    "azymiques": ("azymique",),
    "baasiste": ("baasiste",),
    "baasistes": ("baasiste",),
    "baassiste": ("baassiste",),
    "baassistes": ("baassiste",),
    "baba": ("baba",),
    "babas": ("baba",),
    "babelien": ("babelien",),
    "babelienne": ("babelien",),
    "babeliennes": ("babelien",),
    "babeliens": ("babelien",),
    "babiste": ("babiste",),
    "babistes": ("babiste",),
    "baby": ("baby",),
    "babylonien": ("babylonien",),
    "babylonienne": ("babylonien",),
    "babyloniennes": ("babylonien",),
    "babyloniens": ("babylonien",),
    "baccifère": ("baccifère",),
    "baccifères": ("baccifère",),
    "bacciforme": ("bacciforme",),
    "bacciformes": ("bacciforme",),
    "bachique": ("bachique",),
    "bachiques": ("bachique",),
    "bachoteur": ("bachoteur",),
    "bachoteurs": ("bachoteur",),
    "bachoteuse": ("bachoteur",),
    "bachoteuses": ("bachoteur",),
    "bacillaire": ("bacillaire",),
    "bacillaires": ("bacillaire",),
    "bacilliforme": ("bacilliforme",),
    "bacilliformes": ("bacilliforme",),
    "baconique": ("baconique",),
    "baconiques": ("baconique",),
    "bactéricide": ("bactéricide",),
    "bactéricides": ("bactéricide",),
    "bactériémique": ("bactériémique",),
    "bactériémiques": ("bactériémique",),
    "bactérien": ("bactérien",),
    "bactérienne": ("bactérien",),
    "bactériennes": ("bactérien",),
    "bactériens": ("bactérien",),
    "bactériologique": ("bactériologique",),
    "bactériologiques": ("bactériologique",),
    "bactériolytique": ("bactériolytique",),
    "bactériolytiques": ("bactériolytique",),
    "bactériostatique": ("bactériostatique",),
    "bactériostatiques": ("bactériostatique",),
    "bactrien": ("bactrien",),
    "bactrienne": ("bactrien",),
    "bactriennes": ("bactrien",),
    "bactriens": ("bactrien",),
    "badegoulien": ("badegoulien",),
    "badegoulienne": ("badegoulien",),
    "badegouliennes": ("badegoulien",),
    "badegouliens": ("badegoulien",),
    "badoise": ("badois",),
    "badoises": ("badois",),
    "badois": ("badois",),
    "bafouilleur": ("bafouilleur",),
    "bafouilleurs": ("bafouilleur",),
    "bafouilleuse": ("bafouilleur",),
    "bafouilleuses": ("bafouilleur",),
    "bagagère": ("bagager",),
    "bagagères": ("bagager",),
    "bagager": ("bagager",),
    "bagagers": ("bagager",),
    "bagarreur": ("bagarreur",),
    "bagarreurs": ("bagarreur",),
    "bagarreuse": ("bagarreur",),
    "bagarreuses": ("bagarreur",),
    "bailliagère": ("bailliager",),
    "bailliagères": ("bailliager",),
    "bailliager": ("bailliager",),
    "bailliagers": ("bailliager",),
    "baisable": ("baisable",),
    "baisables": ("baisable",),
    "bajocasse": ("bajocasse",),
    "bajocasses": ("bajocasse",),
    "baladeur": ("baladeur",),
    "baladeurs": ("baladeur",),
    "baladeuse": ("baladeur",),
    "baladeuses": ("baladeur",),
    "balais": ("balais",),
    "balaise": ("balaise",),
    "balaises": ("balaise",),
    "baleinière": ("baleinier",),
    "baleinières": ("baleinier",),
    "baleinier": ("baleinier",),
    "baleiniers": ("baleinier",),
    "balès": ("balès",),
    "balèze": ("balèze",),
    "balèzes": ("balèze",),
    "balinaise": ("balinais",),
    "balinaises": ("balinais",),
    "balinais": ("balinais",),
    "balistique": ("balistique",),
    "balistiques": ("balistique",),
    "balkanique": ("balkanique",),
    "balkaniques": ("balkanique",),
    "ballot": ("ballot",),
    "ballots": ("ballot",),
    "balnéaire": ("balnéaire",),
    "balnéaires": ("balnéaire",),
    "bâloise": ("bâlois",),
    "bâloises": ("bâlois",),
    "bâlois": ("bâlois",),
    "baloutche": ("baloutche",),
    "baloutches": ("baloutche",),
    "balsamique": ("balsamique",),
    "balsamiques": ("balsamique",),
    "balte": ("balte",),
    "baltes": ("balte",),
    "baltique": ("baltique",),
    "baltiques": ("baltique",),
    "balzacien": ("balzacien",),
    "balzacienne": ("balzacien",),
    "balzaciennes": ("balzacien",),
    "balzaciens": ("balzacien",),
    "bambara": ("bambara",),
    "bambaras": ("bambara",),
    "bambocheur": ("bambocheur",),
    "bambocheurs": ("bambocheur",),
    "bambocheuse": ("bambocheur",),
    "bambocheuses": ("bambocheur",),
    "bananière": ("bananier",),
    "bananières": ("bananier",),
    "bananier": ("bananier",),
    "bananiers": ("bananier",),
    "bancable": ("bancable",),
    "bancables": ("bancable",),
    "bancaire": ("bancaire",),
    "bancaires": ("bancaire",),
    "banco": ("banco",),
    "bancroche": ("bancroche",),
    "bancroches": ("bancroche",),
    "bandana": ("bandana",),
    "bangalaise": ("bangalais",),
    "bangalaises": ("bangalais",),
    "bangalais": ("bangalais",),
    "bangladaise": ("bangladais",),
    "bangladaises": ("bangladais",),
    "bangladais": ("bangladais",),
    "bannissable": ("bannissable",),
    "bannissables": ("bannissable",),
    "banquable": ("banquable",),
    "banquables": ("banquable",),
    "bantoïde": ("bantoïde",),
    "bantoïdes": ("bantoïde",),
    "baptismale": ("baptismal",),
    "baptismales": ("baptismal",),
    "baptismal": ("baptismal",),
    "baptismaux": ("baptismal",),
    "baptistaire": ("baptistaire",),
    "baptistaires": ("baptistaire",),
    "baptiste": ("baptiste",),
    "baptistes": ("baptiste",),
    "baratineur": ("baratineur",),
    "baratineurs": ("baratineur",),
    "baratineuse": ("baratineur",),
    "baratineuses": ("baratineur",),
    "barbare": ("barbare",),
    "barbares": ("barbare",),
    "barbaresque": ("barbaresque",),
    "barbaresques": ("barbaresque",),
    "barbe": ("barbe",),
    "barbes": ("barbe",),
    "barbeau": ("barbeau",),
    "barbiturique": ("barbiturique",),
    "barbituriques": ("barbiturique",),
    "barcelonaise": ("barcelonais",),
    "barcelonaises": ("barcelonais",),
    "barcelonais": ("barcelonais",),
    "barlong": ("barlong",),
    "barlongs": ("barlong",),
    "barlongue": ("barlong",),
    "barlongues": ("barlong",),
    "barocentrique": ("barocentrique",),
    "barocentriques": ("barocentrique",),
    "barométrique": ("barométrique",),
    "barométriques": ("barométrique",),
    "baronnale": ("baronnal",),
    "baronnales": ("baronnal",),
    "baronnal": ("baronnal",),
    "baronnaux": ("baronnal",),
    "baronne": ("baronne",),
    "baronnes": ("baronne",),
    "baronniale": ("baronnial",),
    "baronniales": ("baronnial",),
    "baronnial": ("baronnial",),
    "baronniaux": ("baronnial",),
    "baroque": ("baroque",),
    "baroques": ("baroque",),
    "baroqueuse": ("baroqueux",),
    "baroqueuses": ("baroqueux",),
    "baroqueux": ("baroqueux",),
    "barotraumatique": ("barotraumatique",),
    "barotraumatiques": ("barotraumatique",),
    "barotrope": ("barotrope",),
    "barotropes": ("barotrope",),
    "barycentrique": ("barycentrique",),
    "barycentriques": ("barycentrique",),
    "baryonique": ("baryonique",),
    "baryoniques": ("baryonique",),
    "baryton": ("baryton",),
    "bas": ("bas",),
    "basse": ("bas",),
    "basses": ("bas",),
    "basale": ("basal",),
    "basales": ("basal",),
    "basal": ("basal",),
    "basaux": ("basal",),
    "basalaire": ("basalaire",),
    "basalaires": ("basalaire",),
    "basaltique": ("basaltique",),
    "basaltiques": ("basaltique",),
    "basedowien": ("basedowien",),
    "basedowienne": ("basedowien",),
    "basedowiennes": ("basedowien",),
    "basedowiens": ("basedowien",),
    "basifuge": ("basifuge",),
    "basifuges": ("basifuge",),
    "basilaire": ("basilaire",),
    "basilaires": ("basilaire",),
    "basilicale": ("basilical",),
    "basilicales": ("basilical",),
    "basilical": ("basilical",),
    "basilicaux": ("basilical",),
    "basilique": ("basilique",),
    "basiliques": ("basilique",),
    "basiphile": ("basiphile",),
    "basiphiles": ("basiphile",),
    "basique": ("basique",),
    "basiques": ("basique",),
    "bas-jointées": ("bas-jointé",),
    "basocellulaire": ("basocellulaire",),
    "basocellulaires": ("basocellulaire",),
    "basochien": ("basochien",),
    "basochienne": ("basochien",),
    "basochiennes": ("basochien",),
    "basochiens": ("basochien",),
    "basophile": ("basophile",),
    "basophiles": ("basophile",),
    "basquaise": ("basquais",),
    "basquaises": ("basquais",),
    "basquais": ("basquais",),
    "basque": ("basque",),
    "basques": ("basque",),
    "bastiaise": ("bastiais",),
    "bastiaises": ("bastiais",),
    "bastiais": ("bastiais",),
    "basvestière": ("basvestier",),
    "basvestières": ("basvestier",),
    "basvestier": ("basvestier",),
    "basvestiers": ("basvestier",),
    "batailleur": ("batailleur",),
    "batailleurs": ("batailleur",),
    "batailleuse": ("batailleur",),
    "batailleuses": ("batailleur",),
    "batak": ("batak",),
    "bataks": ("batak",),
    "batave": ("batave",),
    "bataves": ("batave",),
    "batavique": ("batavique",),
    "bataviques": ("batavique",),
    "batch": ("batch",),
    "bateau": ("bateau",),
    "bateleur": ("bateleur",),
    "bateleurs": ("bateleur",),
    "bateleuse": ("bateleur",),
    "bateleuses": ("bateleur",),
    "batésien": ("batésien",),
    "batésienne": ("batésien",),
    "batésiennes": ("batésien",),
    "batésiens": ("batésien",),
    "bath": ("bath",),
    "bathyale": ("bathyal",),
    "bathyales": ("bathyal",),
    "bathyal": ("bathyal",),
    "bathyaux": ("bathyal",),
    "bathymétrique": ("bathymétrique",),
    "bathymétriques": ("bathymétrique",),
    "bathypélagique": ("bathypélagique",),
    "bathypélagiques": ("bathypélagique",),
    "bâtissable": ("bâtissable",),
    "bâtissables": ("bâtissable",),
    "bâtonnable": ("bâtonnable",),
    "bâtonnables": ("bâtonnable",),
    "battable": ("battable",),
    "battables": ("battable",),
    "baudelairien": ("baudelairien",),
    "baudelairienne": ("baudelairien",),
    "baudelairiennes": ("baudelairien",),
    "baudelairiens": ("baudelairien",),
    "bauxitique": ("bauxitique",),
    "bauxitiques": ("bauxitique",),
    "bavaroise": ("bavarois",),
    "bavaroises": ("bavarois",),
    "bavarois": ("bavarois",),
    "baveur": ("baveur",),
    "baveurs": ("baveur",),
    "baveuse": ("baveux",),
    "baveuses": ("baveux",),
    "baveux": ("baveux",),
    "bayadère": ("bayadère",),
    "bayadères": ("bayadère",),
    "béarnaise": ("béarnais",),
    "béarnaises": ("béarnais",),
    "béarnais": ("béarnais",),
    "béatifique": ("béatifique",),
    "béatifiques": ("béatifique",),
    "beau": ("beau",),
    "beaux": ("bel",),
    "belle": ("bel",),
    "belles": ("bel",),
    "beauceron": ("beauceron",),
    "beauceronne": ("beauceron",),
    "beauceronnes": ("beauceron",),
    "beaucerons": ("beauceron",),
    "bébé": ("bébé",),
    "bébête": ("bébête",),
    "bébêtes": ("bébête",),
    "bécarre": ("bécarre",),
    "béchique": ("béchique",),
    "béchiques": ("béchique",),
    "bée": ("bée",),
    "bées": ("bée",),
    "beethovenien": ("beethovenien",),
    "beethovénien": ("beethovénien",),
    "beethovenienne": ("beethovenien",),
    "beethovénienne": ("beethovénien",),
    "beethoveniennes": ("beethovenien",),
    "beethovéniennes": ("beethovénien",),
    "beethoveniens": ("beethovenien",),
    "beethovéniens": ("beethovénien",),
    "bégayeur": ("bégayeur",),
    "bégayeurs": ("bégayeur",),
    "bégayeuse": ("bégayeur",),
    "bégayeuses": ("bégayeur",),
    "béguë": ("bégu",),
    "béguës": ("bégu",),
    "bégu": ("bégu",),
    "bégus": ("bégu",),
    "bègue": ("bègue",),
    "bègues": ("bègue",),
    "bégueule": ("bégueule",),
    "bégueules": ("bégueule",),
    "behavioriste": ("behavioriste",),
    "béhavioriste": ("béhavioriste",),
    "behavioristes": ("behavioriste",),
    "béhavioristes": ("béhavioriste",),
    "béhaviouriste": ("béhaviouriste",),
    "béhaviouristes": ("béhaviouriste",),
    "beidellitique": ("beidellitique",),
    "beidellitiques": ("beidellitique",),
    "beige": ("beige",),
    "beiges": ("beige",),
    "beigeasse": ("beigeasse",),
    "beigeasses": ("beigeasse",),
    "beigeâtre": ("beigeâtre",),
    "beigeâtres": ("beigeâtre",),
    "bel": ("bel",),
    "belge": ("belge",),
    "belges": ("belge",),
    "belgoluxembourgeoise": ("belgoluxembourgeois",),
    "belgo-luxembourgeoises": ("belgo-luxembourgeois",),
    "belgoluxembourgeoises": ("belgoluxembourgeois",),
    "belgo-luxembourgeois": ("belgo-luxembourgeois",),
    "belgoluxembourgeois": ("belgoluxembourgeois",),
    "belgradoise": ("belgradois",),
    "belgradoises": ("belgradois",),
    "belgradois": ("belgradois",),
    "bellâtre": ("bellâtre",),
    "bellâtres": ("bellâtre",),
    "bellegardien": ("bellegardien",),
    "bellegardienne": ("bellegardien",),
    "bellegardiennes": ("bellegardien",),
    "bellegardiens": ("bellegardien",),
    "belliciste": ("belliciste",),
    "bellicistes": ("belliciste",),
    "belligène": ("belligène",),
    "belligènes": ("belligène",),
    "belliqueuse": ("belliqueux",),
    "belliqueuses": ("belliqueux",),
    "belliqueux": ("belliqueux",),
    "bellot": ("bellot",),
    "bellots": ("bellot",),
    "bellotte": ("bellot",),
    "bellottes": ("bellot",),
    "bémol": ("bémol",),
    "bénéfactif": ("bénéfactif",),
    "bénéfactifs": ("bénéfactif",),
    "bénéfactive": ("bénéfactif",),
    "bénéfactives": ("bénéfactif",),
    "bénéficiaire": ("bénéficiaire",),
    "bénéficiaires": ("bénéficiaire",),
    "bénéficiale": ("bénéficial",),
    "bénéficiales": ("bénéficial",),
    "bénéficial": ("bénéficial",),
    "bénéficiaux": ("bénéficial",),
    "bénéfique": ("bénéfique",),
    "bénéfiques": ("bénéfique",),
    "benêt": ("benêt",),
    "benêts": ("benêt",),
    "bénévole": ("bénévole",),
    "bénévoles": ("bénévole",),
    "bengalaise": ("bengalais",),
    "bengalaises": ("bengalais",),
    "bengalais": ("bengalais",),
    "bengali": ("bengali",),
    "bengalis": ("bengali",),
    "bengalophone": ("bengalophone",),
    "bengalophones": ("bengalophone",),
    "bénigne": ("bénin",),
    "bénignes": ("bénin",),
    "bénin": ("bénin",),
    "bénins": ("bénin",),
    "béninoise": ("béninois",),
    "béninoises": ("béninois",),
    "béninois": ("béninois",),
    "bénisseur": ("bénisseur",),
    "bénisseurs": ("bénisseur",),
    "bénisseuse": ("bénisseur",),
    "bénisseuses": ("bénisseur",),
    "benthique": ("benthique",),
    "benthiques": ("benthique",),
    "benzènedisulfonique": ("benzènedisulfonique",),
    "benzènedisulfoniques": ("benzènedisulfonique",),
    "benzènesulfinique": ("benzènesulfinique",),
    "benzènesulfiniques": ("benzènesulfinique",),
    "benzènesulfonique": ("benzènesulfonique",),
    "benzènesulfoniques": ("benzènesulfonique",),
    "benzénique": ("benzénique",),
    "benzéniques": ("benzénique",),
    "benzidinique": ("benzidinique",),
    "benzidiniques": ("benzidinique",),
    "benzilique": ("benzilique",),
    "benziliques": ("benzilique",),
    "benzodiazépinique": ("benzodiazépinique",),
    "benzodiazépiniques": ("benzodiazépinique",),
    "benzoin": ("benzoin",),
    "benzoins": ("benzoin",),
    "benzoïnique": ("benzoïnique",),
    "benzoïniques": ("benzoïnique",),
    "benzoïque": ("benzoïque",),
    "benzoïques": ("benzoïque",),
    "benzolique": ("benzolique",),
    "benzoliques": ("benzolique",),
    "benzoylbenzoïque": ("benzoylbenzoïque",),
    "benzoylbenzoïques": ("benzoylbenzoïque",),
    "benzoylhydratropique": ("benzoylhydratropique",),
    "benzoylhydratropiques": ("benzoylhydratropique",),
    "benzylique": ("benzylique",),
    "benzyliques": ("benzylique",),
    "béotien": ("béotien",),
    "béotienne": ("béotien",),
    "béotiennes": ("béotien",),
    "béotiens": ("béotien",),
    "berbère": ("berbère",),
    "berbères": ("berbère",),
    "berbériste": ("berbériste",),
    "berbéristes": ("berbériste",),
    "berbéronique": ("berbéronique",),
    "berbéroniques": ("berbéronique",),
    "berbérophone": ("berbérophone",),
    "berbérophones": ("berbérophone",),
    "berceur": ("berceur",),
    "berceurs": ("berceur",),
    "berceuse": ("berceur",),
    "berceuses": ("berceur",),
    "bergsonien": ("bergsonien",),
    "bergsonienne": ("bergsonien",),
    "bergsoniennes": ("bergsonien",),
    "bergsoniens": ("bergsonien",),
    "berlinoise": ("berlinois",),
    "berlinoises": ("berlinois",),
    "berlinois": ("berlinois",),
    "berliozien": ("berliozien",),
    "berliozienne": ("berliozien",),
    "berlioziennes": ("berliozien",),
    "berlioziens": ("berliozien",),
    "bernoise": ("bernois",),
    "bernoises": ("bernois",),
    "bernois": ("bernois",),
    "berrichon": ("berrichon",),
    "berrichonne": ("berrichon",),
    "berrichonnes": ("berrichon",),
    "berrichons": ("berrichon",),
    "berruyère": ("berruyer",),
    "berruyères": ("berruyer",),
    "berruyer": ("berruyer",),
    "berruyers": ("berruyer",),
    "besogneuse": ("besogneux",),
    "besogneuses": ("besogneux",),
    "besogneux": ("besogneux",),
    "besson": ("besson",),
    "bessonne": ("besson",),
    "bessonnes": ("besson",),
    "bessons": ("besson",),
    "bestiale": ("bestial",),
    "bestiales": ("bestial",),
    "bestial": ("bestial",),
    "bestiaux": ("bestial",),
    "bêta": ("bêta",),
    "bêtas": ("bêta",),
    "bêtasse": ("bêta",),
    "bêtasses": ("bêta",),
    "bête": ("bête",),
    "bêtes": ("bête",),
    "betteravière": ("betteravier",),
    "betteravières": ("betteravier",),
    "betteravier": ("betteravier",),
    "betteraviers": ("betteravier",),
    "beurrière": ("beurrier",),
    "beurrières": ("beurrier",),
    "beurrier": ("beurrier",),
    "beurriers": ("beurrier",),
    "beylicale": ("beylical",),
    "beylicales": ("beylical",),
    "beylical": ("beylical",),
    "beylicaux": ("beylical",),
    "biacide": ("biacide",),
    "biacides": ("biacide",),
    "biacromiale": ("biacromial",),
    "biacromiales": ("biacromial",),
    "biacromial": ("biacromial",),
    "biacromiaux": ("biacromial",),
    "biafraise": ("biafrais",),
    "biafraises": ("biafrais",),
    "biafrais": ("biafrais",),
    "biaise": ("biais",),
    "biaises": ("biais",),
    "biais": ("biais",),
    "biannuelle": ("biannuel",),
    "biannuelles": ("biannuel",),
    "biannuel": ("biannuel",),
    "biannuels": ("biannuel",),
    "biaurale": ("biaural",),
    "biaurales": ("biaural",),
    "biaural": ("biaural",),
    "biauraux": ("biaural",),
    "biauriculaire": ("biauriculaire",),
    "biauriculaires": ("biauriculaire",),
    "biaxe": ("biaxe",),
    "biaxes": ("biaxe",),
    "biaxiale": ("biaxial",),
    "biaxiales": ("biaxial",),
    "biaxial": ("biaxial",),
    "biaxiaux": ("biaxial",),
    "bibasique": ("bibasique",),
    "bibasiques": ("bibasique",),
    "bibliographique": ("bibliographique",),
    "bibliographiques": ("bibliographique",),
    "bibliologique": ("bibliologique",),
    "bibliologiques": ("bibliologique",),
    "bibliomane": ("bibliomane",),
    "bibliomanes": ("bibliomane",),
    "bibliomaniaque": ("bibliomaniaque",),
    "bibliomaniaques": ("bibliomaniaque",),
    "bibliométrique": ("bibliométrique",),
    "bibliométriques": ("bibliométrique",),
    "bibliophage": ("bibliophage",),
    "bibliophages": ("bibliophage",),
    "bibliophilique": ("bibliophilique",),
    "bibliophiliques": ("bibliophilique",),
    "bibliothécaire": ("bibliothécaire",),
    "bibliothécaires": ("bibliothécaire",),
    "bibliothéconomique": ("bibliothéconomique",),
    "bibliothéconomiques": ("bibliothéconomique",),
    "biblique": ("biblique",),
    "bibliques": ("biblique",),
    "bicâble": ("bicâble",),
    "bicâbles": ("bicâble",),
    "bicalcique": ("bicalcique",),
    "bicalciques": ("bicalcique",),
    "bicamérale": ("bicaméral",),
    "bicamérales": ("bicaméral",),
    "bicaméral": ("bicaméral",),
    "bicaméraux": ("bicaméral",),
    "bicarbone": ("bicarbone",),
    "bicarbones": ("bicarbone",),
    "bicentenaire": ("bicentenaire",),
    "bicentenaires": ("bicentenaire",),
    "bicéphale": ("bicéphale",),
    "bicéphales": ("bicéphale",),
    "bichromatique": ("bichromatique",),
    "bichromatiques": ("bichromatique",),
    "bichrome": ("bichrome",),
    "bichromes": ("bichrome",),
    "bichromique": ("bichromique",),
    "bichromiques": ("bichromique",),
    "bicipitale": ("bicipital",),
    "bicipitales": ("bicipital",),
    "bicipital": ("bicipital",),
    "bicipitaux": ("bicipital",),
    "bicirculaire": ("bicirculaire",),
    "bicirculaires": ("bicirculaire",),
    "biclonale": ("biclonal",),
    "biclonales": ("biclonal",),
    "biclonal": ("biclonal",),
    "biclonaux": ("biclonal",),
    "bicollatérale": ("bicollatéral",),
    "bicollatérales": ("bicollatéral",),
    "bicollatéral": ("bicollatéral",),
    "bicollatéraux": ("bicollatéral",),
    "bicolore": ("bicolore",),
    "bicolores": ("bicolore",),
    "biconcave": ("biconcave",),
    "biconcaves": ("biconcave",),
    "biconditionnelle": ("biconditionnel",),
    "biconditionnelles": ("biconditionnel",),
    "biconditionnel": ("biconditionnel",),
    "biconditionnels": ("biconditionnel",),
    "bicondylien": ("bicondylien",),
    "bicondylienne": ("bicondylien",),
    "bicondyliennes": ("bicondylien",),
    "bicondyliens": ("bicondylien",),
    "biconfessionnelle": ("biconfessionnel",),
    "biconfessionnelles": ("biconfessionnel",),
    "biconfessionnel": ("biconfessionnel",),
    "biconfessionnels": ("biconfessionnel",),
    "biconique": ("biconique",),
    "biconiques": ("biconique",),
    "biconvexe": ("biconvexe",),
    "biconvexes": ("biconvexe",),
    "bicorne": ("bicorne",),
    "bicornes": ("bicorne",),
    "bicouche": ("bicouche",),
    "bicourant": ("bicourant",),
    "bicristale": ("bicristal",),
    "bicristales": ("bicristal",),
    "bicristal": ("bicristal",),
    "bicristaux": ("bicristal",),
    "biculturelle": ("biculturel",),
    "biculturelles": ("biculturel",),
    "biculturel": ("biculturel",),
    "biculturels": ("biculturel",),
    "bicuspide": ("bicuspide",),
    "bicuspides": ("bicuspide",),
    "bicyclique": ("bicyclique",),
    "bicycliques": ("bicyclique",),
    "bicylindre": ("bicylindre",),
    "bidentate": ("bidentate",),
    "bidentates": ("bidentate",),
    "bidérive": ("bidérive",),
    "bidimensionnelle": ("bidimensionnel",),
    "bidimensionnelles": ("bidimensionnel",),
    "bidimensionnel": ("bidimensionnel",),
    "bidimensionnels": ("bidimensionnel",),
    "bidirectionnelle": ("bidirectionnel",),
    "bidirectionnelles": ("bidirectionnel",),
    "bidirectionnel": ("bidirectionnel",),
    "bidirectionnels": ("bidirectionnel",),
    "bidisciplinaire": ("bidisciplinaire",),
    "bidisciplinaires": ("bidisciplinaire",),
    "biélorusse": ("biélorusse",),
    "biélorusses": ("biélorusse",),
    "bien": ("bien",),
    "bien-aimée": ("bien-aimé",),
    "bien-aimé": ("bien-aimé",),
    "bien-aimés": ("bien-aimé",),
    "bienfaiteur": ("bienfaiteur",),
    "bienfaiteurs": ("bienfaiteur",),
    "bienfaitrice": ("bienfaiteur",),
    "bienfaitrices": ("bienfaiteur",),
    "bienheureuse": ("bienheureux",),
    "bienheureuses": ("bienheureux",),
    "bienheureux": ("bienheureux",),
    "biennale": ("biennal",),
    "biennales": ("biennal",),
    "biennal": ("biennal",),
    "biennaux": ("biennal",),
    "bien-pensante": ("bien-pensant",),
    "bien-pensantes": ("bien-pensant",),
    "bien-pensant": ("bien-pensant",),
    "bien-pensants": ("bien-pensant",),
    "bienvenant": ("bienvenant",),
    "bienvenants": ("bienvenant",),
    "bienvenue": ("bienvenu",),
    "bienvenues": ("bienvenu",),
    "bienvenu": ("bienvenu",),
    "bienvenus": ("bienvenu",),
    "biethnique": ("biethnique",),
    "biethniques": ("biethnique",),
    "biface": ("biface",),
    "bifaces": ("biface",),
    "bifaciale": ("bifacial",),
    "bifaciales": ("bifacial",),
    "bifacial": ("bifacial",),
    "bifaciaux": ("bifacial",),
    "bifactorielle": ("bifactoriel",),
    "bifactorielles": ("bifactoriel",),
    "bifactoriel": ("bifactoriel",),
    "bifactoriels": ("bifactoriel",),
    "bifide": ("bifide",),
    "bifides": ("bifide",),
    "bifilaire": ("bifilaire",),
    "bifilaires": ("bifilaire",),
    "biflèche": ("biflèche",),
    "biflèches": ("biflèche",),
    "bifocale": ("bifocal",),
    "bifocales": ("bifocal",),
    "bifocal": ("bifocal",),
    "bifocaux": ("bifocal",),
    "bifonctionnelle": ("bifonctionnel",),
    "bifonctionnelles": ("bifonctionnel",),
    "bifonctionnel": ("bifonctionnel",),
    "bifonctionnels": ("bifonctionnel",),
    "bifrons": ("bifrons",),
    "bigame": ("bigame",),
    "bigames": ("bigame",),
    "bigénique": ("bigénique",),
    "bigéniques": ("bigénique",),
    "bigle": ("bigle",),
    "bigles": ("bigle",),
    "bigleuse": ("bigleux",),
    "bigleuses": ("bigleux",),
    "bigleux": ("bigleux",),
    "bigouden": ("bigouden",),
    "bigoudens": ("bigouden",),
    "bigrille": ("bigrille",),
    "bigrilles": ("bigrille",),
    "bihari": ("bihari",),
    "biharis": ("bihari",),
    "bihebdomadaire": ("bihebdomadaire",),
    "bihebdomadaires": ("bihebdomadaire",),
    "bijectif": ("bijectif",),
    "bijectifs": ("bijectif",),
    "bijective": ("bijectif",),
    "bijectives": ("bijectif",),
    "bilabiale": ("bilabial",),
    "bilabiales": ("bilabial",),
    "bilabial": ("bilabial",),
    "bilabiaux": ("bilabial",),
    "bilantielle": ("bilantiel",),
    "bilantielles": ("bilantiel",),
    "bilantiel": ("bilantiel",),
    "bilantiels": ("bilantiel",),
    "bilatérale": ("bilatéral",),
    "bilatérales": ("bilatéral",),
    "bilatéral": ("bilatéral",),
    "bilatéraux": ("bilatéral",),
    "bileuse": ("bileux",),
    "bileuses": ("bileux",),
    "bileux": ("bileux",),
    "bilharzien": ("bilharzien",),
    "bilharzienne": ("bilharzien",),
    "bilharziennes": ("bilharzien",),
    "bilharziens": ("bilharzien",),
    "biliaire": ("biliaire",),
    "biliaires": ("biliaire",),
    "bilieuse": ("bilieux",),
    "bilieuses": ("bilieux",),
    "bilieux": ("bilieux",),
    "bilinéaire": ("bilinéaire",),
    "bilinéaires": ("bilinéaire",),
    "bilingue": ("bilingue",),
    "bilingues": ("bilingue",),
    "biliopancréatique": ("biliopancréatique",),
    "biliopancréatiques": ("biliopancréatique",),
    "bilioseptique": ("bilioseptique",),
    "bilioseptiques": ("bilioseptique",),
    "bilirubinémique": ("bilirubinémique",),
    "bilirubinémiques": ("bilirubinémique",),
    "bilocale": ("bilocal",),
    "bilocales": ("bilocal",),
    "bilocal": ("bilocal",),
    "bilocaux": ("bilocal",),
    "biloculaire": ("biloculaire",),
    "biloculaires": ("biloculaire",),
    "bimane": ("bimane",),
    "bimanes": ("bimane",),
    "bimanuelle": ("bimanuel",),
    "bimanuelles": ("bimanuel",),
    "bimanuel": ("bimanuel",),
    "bimanuels": ("bimanuel",),
    "bimensuelle": ("bimensuel",),
    "bimensuelles": ("bimensuel",),
    "bimensuel": ("bimensuel",),
    "bimensuels": ("bimensuel",),
    "bimestrielle": ("bimestriel",),
    "bimestrielles": ("bimestriel",),
    "bimestriel": ("bimestriel",),
    "bimestriels": ("bimestriel",),
    "bimétallique": ("bimétallique",),
    "bimétalliques": ("bimétallique",),
    "bimétalliste": ("bimétalliste",),
    "bimétallistes": ("bimétalliste",),
    "bimillénaire": ("bimillénaire",),
    "bimillénaires": ("bimillénaire",),
    "bimodale": ("bimodal",),
    "bimodales": ("bimodal",),
    "bimodal": ("bimodal",),
    "bimodaux": ("bimodal",),
    "bimoléculaire": ("bimoléculaire",),
    "bimoléculaires": ("bimoléculaire",),
    "bimoteur": ("bimoteur",),
    "bimoteurs": ("bimoteur",),
    "binaire": ("binaire",),
    "binaires": ("binaire",),
    "binasale": ("binasal",),
    "binasales": ("binasal",),
    "binasal": ("binasal",),
    "binasaux": ("binasal",),
    "binationale": ("binational",),
    "binationales": ("binational",),
    "binational": ("binational",),
    "binationaux": ("binational",),
    "binaurale": ("binaural",),
    "binaurales": ("binaural",),
    "binaural": ("binaural",),
    "binauraux": ("binaural",),
    "binauriculaire": ("binauriculaire",),
    "binauriculaires": ("binauriculaire",),
    "binoculaire": ("binoculaire",),
    "binoculaires": ("binoculaire",),
    "binomiale": ("binomial",),
    "binomiales": ("binomial",),
    "binomial": ("binomial",),
    "binomiaux": ("binomial",),
    "binominale": ("binominal",),
    "binominales": ("binominal",),
    "binominal": ("binominal",),
    "binominaux": ("binominal",),
    "bioacoustique": ("bioacoustique",),
    "bioacoustiques": ("bioacoustique",),
    "bioactif": ("bioactif",),
    "bioactifs": ("bioactif",),
    "bio-active": ("bio-actif",),
    "bioactive": ("bioactif",),
    "bioactives": ("bioactif",),
    "biobibliographique": ("biobibliographique",),
    "biobibliographiques": ("biobibliographique",),
    "biocalorimétrique": ("biocalorimétrique",),
    "biocalorimétriques": ("biocalorimétrique",),
    "biocellulaire": ("biocellulaire",),
    "biocellulaires": ("biocellulaire",),
    "biocénotique": ("biocénotique",),
    "biocénotiques": ("biocénotique",),
    "biochimique": ("biochimique",),
    "biochimiques": ("biochimique",),
    "biocide": ("biocide",),
    "biocides": ("biocide",),
    "bioclimatique": ("bioclimatique",),
    "bioclimatiques": ("bioclimatique",),
    "bioclimatologique": ("bioclimatologique",),
    "bioclimatologiques": ("bioclimatologique",),
    "bioclinique": ("bioclinique",),
    "biocliniques": ("bioclinique",),
    "biocoenotique": ("biocoenotique",),
    "biocoenotiques": ("biocoenotique",),
    "biocompatible": ("biocompatible",),
    "biocompatibles": ("biocompatible",),
    "biodégradable": ("biodégradable",),
    "bio-dégradables": ("bio-dégradable",),
    "biodégradables": ("biodégradable",),
    "biodétritique": ("biodétritique",),
    "biodétritiques": ("biodétritique",),
    "biodisponible": ("biodisponible",),
    "biodisponibles": ("biodisponible",),
    "biodynamique": ("biodynamique",),
    "biodynamiques": ("biodynamique",),
    "bioélectrique": ("bioélectrique",),
    "bioélectriques": ("bioélectrique",),
    "bioélectronique": ("bioélectronique",),
    "bioélectroniques": ("bioélectronique",),
    "bioénergétique": ("bioénergétique",),
    "bioénergétiques": ("bioénergétique",),
    "bioéthique": ("bioéthique",),
    "bioéthiques": ("bioéthique",),
    "biogénétique": ("biogénétique",),
    "biogénétiques": ("biogénétique",),
    "biogéochimique": ("biogéochimique",),
    "biogéochimiques": ("biogéochimique",),
    "biogéographique": ("biogéographique",),
    "biogéographiques": ("biogéographique",),
    "biographique": ("biographique",),
    "biographiques": ("biographique",),
    "biologique": ("biologique",),
    "biologiques": ("biologique",),
    "biomécanique": ("biomécanique",),
    "biomécaniques": ("biomécanique",),
    "biomédicale": ("biomédical",),
    "biomédicales": ("biomédical",),
    "biomédical": ("biomédical",),
    "biomédicaux": ("biomédical",),
    "biométrique": ("biométrique",),
    "biométriques": ("biométrique",),
    "biomimétique": ("biomimétique",),
    "biomimétiques": ("biomimétique",),
    "biomoléculaire": ("biomoléculaire",),
    "biomoléculaires": ("biomoléculaire",),
    "biomorphique": ("biomorphique",),
    "biomorphiques": ("biomorphique",),
    "bionique": ("bionique",),
    "bioniques": ("bionique",),
    "biophysique": ("biophysique",),
    "biophysiques": ("biophysique",),
    "biopsique": ("biopsique",),
    "biopsiques": ("biopsique",),
    "biorythmique": ("biorythmique",),
    "biorythmiques": ("biorythmique",),
    "biosphérique": ("biosphérique",),
    "biosphériques": ("biosphérique",),
    "biostatique": ("biostatique",),
    "biostatiques": ("biostatique",),
    "biostatistique": ("biostatistique",),
    "biostatistiques": ("biostatistique",),
    "biostratigraphique": ("biostratigraphique",),
    "biostratigraphiques": ("biostratigraphique",),
    "biotechnique": ("biotechnique",),
    "biotechniques": ("biotechnique",),
    "biotechnologique": ("biotechnologique",),
    "biotechnologiques": ("biotechnologique",),
    "bioterroriste": ("bioterroriste",),
    "bioterroristes": ("bioterroriste",),
    "biothérapique": ("biothérapique",),
    "biothérapiques": ("biothérapique",),
    "biotique": ("biotique",),
    "biotiques": ("biotique",),
    "biotypologique": ("biotypologique",),
    "biotypologiques": ("biotypologique",),
    "biovulaire": ("biovulaire",),
    "biovulaires": ("biovulaire",),
    "bipale": ("bipale",),
    "bipales": ("bipale",),
    "bipare": ("bipare",),
    "bipares": ("bipare",),
    "bipariétale": ("bipariétal",),
    "bipariétales": ("bipariétal",),
    "bipariétal": ("bipariétal",),
    "bipariétaux": ("bipariétal",),
    "bipartite": ("bipartite",),
    "bipartites": ("bipartite",),
    "bipède": ("bipède",),
    "bipèdes": ("bipède",),
    "bipennée": ("bipenné",),
    "bipennées": ("bipenné",),
    "bipenné": ("bipenné",),
    "bipenne": ("bipenne",),
    "bipennés": ("bipenné",),
    "bipennes": ("bipenne",),
    "biphasée": ("biphasé",),
    "biphasées": ("biphasé",),
    "biphasé": ("biphasé",),
    "biphase": ("biphase",),
    "biphasés": ("biphasé",),
    "biphases": ("biphase",),
    "biphasique": ("biphasique",),
    "biphasiques": ("biphasique",),
    "biphotonique": ("biphotonique",),
    "biphotoniques": ("biphotonique",),
    "biplace": ("biplace",),
    "biplaces": ("biplace",),
    "biplan": ("biplan",),
    "biplans": ("biplan",),
    "bipolaire": ("bipolaire",),
    "bipolaires": ("bipolaire",),
    "bipotentielle": ("bipotentiel",),
    "bipotentielles": ("bipotentiel",),
    "bipotentiel": ("bipotentiel",),
    "bipotentiels": ("bipotentiel",),
    "bipoutre": ("bipoutre",),
    "bipoutres": ("bipoutre",),
    "bipulmonaire": ("bipulmonaire",),
    "bipulmonaires": ("bipulmonaire",),
    "biquadratique": ("biquadratique",),
    "biquadratiques": ("biquadratique",),
    "biquotidien": ("biquotidien",),
    "biquotidienne": ("biquotidien",),
    "biquotidiennes": ("biquotidien",),
    "biquotidiens": ("biquotidien",),
    "biréactif": ("biréactif",),
    "biréactifs": ("biréactif",),
    "biréactive": ("biréactif",),
    "biréactives": ("biréactif",),
    "birotor": ("birotor",),
    "bise": ("bis",),
    "bises": ("bis",),
    "bis": ("bis",),
    "bisannuelle": ("bisannuel",),
    "bisannuelles": ("bisannuel",),
    "bisannuel": ("bisannuel",),
    "bisannuels": ("bisannuel",),
    "bisazoïque": ("bisazoïque",),
    "bisazoïques": ("bisazoïque",),
    "biscaïen": ("biscaïen",),
    "biscaïenne": ("biscaïen",),
    "biscaïennes": ("biscaïen",),
    "biscaïens": ("biscaïen",),
    "biscayen": ("biscayen",),
    "biscayenne": ("biscayen",),
    "biscayennes": ("biscayen",),
    "biscayens": ("biscayen",),
    "biséculaire": ("biséculaire",),
    "biséculaires": ("biséculaire",),
    "bisémique": ("bisémique",),
    "bisémiques": ("bisémique",),
    "bisériale": ("bisérial",),
    "bisériales": ("bisérial",),
    "bisérial": ("bisérial",),
    "bisériaux": ("bisérial",),
    "biset": ("biset",),
    "bisets": ("biset",),
    "bisexuelle": ("bisexuel",),
    "bisexuelles": ("bisexuel",),
    "bisexuel": ("bisexuel",),
    "bisexuels": ("bisexuel",),
    "bismarckien": ("bismarckien",),
    "bismarckienne": ("bismarckien",),
    "bismarckiennes": ("bismarckien",),
    "bismarckiens": ("bismarckien",),
    "bismurée": ("bismurée",),
    "bismurées": ("bismurée",),
    "bismuthique": ("bismuthique",),
    "bismuthiques": ("bismuthique",),
    "bisoc": ("bisoc",),
    "bisodique": ("bisodique",),
    "bisodiques": ("bisodique",),
    "bissecteur": ("bissecteur",),
    "bissecteurs": ("bissecteur",),
    "bissectrice": ("bissecteur",),
    "bissectrices": ("bissecteur",),
    "bissextile": ("bissextile",),
    "bissextiles": ("bissextile",),
    "bissexuelle": ("bissexuel",),
    "bissexuelles": ("bissexuel",),
    "bissexuel": ("bissexuel",),
    "bissexuels": ("bissexuel",),
    "bistable": ("bistable",),
    "bistables": ("bistable",),
    "bistatique": ("bistatique",),
    "bistatiques": ("bistatique",),
    "bistrée": ("bistré",),
    "bistrées": ("bistré",),
    "bistré": ("bistré",),
    "bistre": ("bistre",),
    "bistrés": ("bistré",),
    "bistres": ("bistre",),
    "bitable": ("bitable",),
    "bitables": ("bitable",),
    "bitemporale": ("bitemporal",),
    "bitemporales": ("bitemporal",),
    "bitemporal": ("bitemporal",),
    "bitemporaux": ("bitemporal",),
    "biterroise": ("biterrois",),
    "biterroises": ("biterrois",),
    "biterrois": ("biterrois",),
    "bitonale": ("bitonal",),
    "bitonales": ("bitonal",),
    "bitonal": ("bitonal",),
    "bitonaux": ("bitonal",),
    "bittable": ("bittable",),
    "bittables": ("bittable",),
    "bitumeuse": ("bitumeux",),
    "bitumeuses": ("bitumeux",),
    "bitumeux": ("bitumeux",),
    "bitumineuse": ("bitumineux",),
    "bitumineuses": ("bitumineux",),
    "bitumineux": ("bitumineux",),
    "biturbine": ("biturbine",),
    "biturbines": ("biturbine",),
    "biturbopropulseur": ("biturbopropulseur",),
    "biturbopropulseurs": ("biturbopropulseur",),
    "biunivoque": ("biunivoque",),
    "biunivoques": ("biunivoque",),
    "bivalve": ("bivalve",),
    "bivalves": ("bivalve",),
    "biventriculaire": ("biventriculaire",),
    "biventriculaires": ("biventriculaire",),
    "bivoie": ("bivoie",),
    "bivoies": ("bivoie",),
    "bizarde": ("bizarde",),
    "bizardes": ("bizarde",),
    "bizarre": ("bizarre",),
    "bizarres": ("bizarre",),
    "bizarroïde": ("bizarroïde",),
    "bizarroïdes": ("bizarroïde",),
    "bizone": ("bizone",),
    "bizones": ("bizone",),
    "bizygomatique": ("bizygomatique",),
    "bizygomatiques": ("bizygomatique",),
    "black": ("black",),
    "blacks": ("black",),
    "blagueur": ("blagueur",),
    "blagueurs": ("blagueur",),
    "blagueuse": ("blagueur",),
    "blagueuses": ("blagueur",),
    "blaisoise": ("blaisois",),
    "blaisoises": ("blaisois",),
    "blaisois": ("blaisois",),
    "blâmable": ("blâmable",),
    "blâmables": ("blâmable",),
    "blanche": ("blanc",),
    "blanches": ("blanc",),
    "blanc": ("blanc",),
    "blancs": ("blanc",),
    "blanchâtre": ("blanchâtre",),
    "blanchâtres": ("blanchâtre",),
    "blanquiste": ("blanquiste",),
    "blanquistes": ("blanquiste",),
    "blasphémateur": ("blasphémateur",),
    "blasphémateurs": ("blasphémateur",),
    "blasphématrice": ("blasphémateur",),
    "blasphématrices": ("blasphémateur",),
    "blasphématoire": ("blasphématoire",),
    "blasphématoires": ("blasphématoire",),
    "blastique": ("blastique",),
    "blastiques": ("blastique",),
    "blastocoelien": ("blastocoelien",),
    "blastocoelienne": ("blastocoelien",),
    "blastocoeliennes": ("blastocoelien",),
    "blastocoeliens": ("blastocoelien",),
    "blastodermique": ("blastodermique",),
    "blastodermiques": ("blastodermique",),
    "blastogénétique": ("blastogénétique",),
    "blastogénétiques": ("blastogénétique",),
    "blastogénique": ("blastogénique",),
    "blastogéniques": ("blastogénique",),
    "blastomycétien": ("blastomycétien",),
    "blastomycétienne": ("blastomycétien",),
    "blastomycétiennes": ("blastomycétien",),
    "blastomycétiens": ("blastomycétien",),
    "blastomycétique": ("blastomycétique",),
    "blastomycétiques": ("blastomycétique",),
    "blastoporale": ("blastoporal",),
    "blastoporales": ("blastoporal",),
    "blastoporal": ("blastoporal",),
    "blastoporaux": ("blastoporal",),
    "blèche": ("blèche",),
    "blèches": ("blèche",),
    "blême": ("blême",),
    "blêmes": ("blême",),
    "blennorragique": ("blennorragique",),
    "blennorragiques": ("blennorragique",),
    "blésoise": ("blésois",),
    "blésoises": ("blésois",),
    "blésois": ("blésois",),
    "blessable": ("blessable",),
    "blessables": ("blessable",),
    "blet": ("blet",),
    "blets": ("blet",),
    "blette": ("blet",),
    "blettes": ("blet",),
    "bleuâtre": ("bleuâtre",),
    "bleuâtres": ("bleuâtre",),
    "blocageuse": ("blocageux",),
    "blocageuses": ("blocageux",),
    "blocageux": ("blocageux",),
    "blocailleuse": ("blocailleux",),
    "blocailleuses": ("blocailleux",),
    "blocailleux": ("blocailleux",),
    "blondasse": ("blondasse",),
    "blondasses": ("blondasse",),
    "blondinet": ("blondinet",),
    "blondinets": ("blondinet",),
    "blondinette": ("blondinet",),
    "blondinettes": ("blondinet",),
    "bloqueur": ("bloqueur",),
    "bloqueurs": ("bloqueur",),
    "bloqueuse": ("bloqueur",),
    "bloqueuses": ("bloqueur",),
    "bluffeur": ("bluffeur",),
    "bluffeurs": ("bluffeur",),
    "bluffeuse": ("bluffeur",),
    "bluffeuses": ("bluffeur",),
    "bocagère": ("bocager",),
    "bocagères": ("bocager",),
    "bocager": ("bocager",),
    "bocagers": ("bocager",),
    "bocageuse": ("bocageux",),
    "bocageuses": ("bocageux",),
    "bocageux": ("bocageux",),
    "boche": ("boche",),
    "boches": ("boche",),
    "bochiman": ("bochiman",),
    "bochimans": ("bochiman",),
    "bodo": ("bodo",),
    "bodos": ("bodo",),
    "boer": ("boer",),
    "boers": ("boer",),
    "boeuf": ("boeuf",),
    "bogomilien": ("bogomilien",),
    "bogomilienne": ("bogomilien",),
    "bogomiliennes": ("bogomilien",),
    "bogomiliens": ("bogomilien",),
    "bohème": ("bohème",),
    "bohèmes": ("bohème",),
    "bohémien": ("bohémien",),
    "bohémienne": ("bohémien",),
    "bohémiennes": ("bohémien",),
    "bohémiens": ("bohémien",),
    "boiteuse": ("boiteux",),
    "boiteuses": ("boiteux",),
    "boiteux": ("boiteux",),
    "bolchevik": ("bolchevik",),
    "bolcheviks": ("bolchevik",),
    "bolchevique": ("bolchevique",),
    "bolcheviques": ("bolchevique",),
    "bolcheviste": ("bolcheviste",),
    "bolchevistes": ("bolcheviste",),
    "bolivien": ("bolivien",),
    "bolivienne": ("bolivien",),
    "boliviennes": ("bolivien",),
    "boliviens": ("bolivien",),
    "bolométrique": ("bolométrique",),
    "bolométriques": ("bolométrique",),
    "bolonaise": ("bolonais",),
    "bolonaises": ("bolonais",),
    "bolonais": ("bolonais",),
    "bon": ("bon",),
    "bonne": ("bon",),
    "bonnes": ("bon",),
    "bons": ("bon",),
    "bonapartiste": ("bonapartiste",),
    "bonapartistes": ("bonapartiste",),
    "bonasse": ("bonasse",),
    "bonasses": ("bonasse",),
    "bonhomme": ("bonhomme",),
    "bonhommes": ("bonhomme",),
    "bonnetière": ("bonnetier",),
    "bonnetières": ("bonnetier",),
    "bonnetier": ("bonnetier",),
    "bonnetiers": ("bonnetier",),
    "booléen": ("booléen",),
    "booléenne": ("booléen",),
    "booléennes": ("booléen",),
    "booléens": ("booléen",),
    "boolien": ("boolien",),
    "boolienne": ("boolien",),
    "booliennes": ("boolien",),
    "booliens": ("boolien",),
    "bordeaux": ("bordeaux",),
    "bordelaise": ("bordelais",),
    "bordelaises": ("bordelais",),
    "bordelais": ("bordelais",),
    "bordéleuse": ("bordéleux",),
    "bordéleuses": ("bordéleux",),
    "bordéleux": ("bordéleux",),
    "bordelière": ("bordelière",),
    "bordelières": ("bordelière",),
    "bordélique": ("bordélique",),
    "bordéliques": ("bordélique",),
    "borderline": ("borderline",),
    "bordière": ("bordier",),
    "bordières": ("bordier",),
    "bordier": ("bordier",),
    "bordiers": ("bordier",),
    "boréale": ("boréal",),
    "boréales": ("boréal",),
    "boréal": ("boréal",),
    "boréaux": ("boréal",),
    "borélien": ("borélien",),
    "borélienne": ("borélien",),
    "boréliennes": ("borélien",),
    "boréliens": ("borélien",),
    "borgésien": ("borgésien",),
    "borgésienne": ("borgésien",),
    "borgésiennes": ("borgésien",),
    "borgésiens": ("borgésien",),
    "borgne": ("borgne",),
    "borgnes": ("borgne",),
    "borique": ("borique",),
    "boriques": ("borique",),
    "borofluorhydrique": ("borofluorhydrique",),
    "borofluorhydriques": ("borofluorhydrique",),
    "boscot": ("boscot",),
    "boscots": ("boscot",),
    "boscotte": ("boscot",),
    "boscottes": ("boscot",),
    "bosniaque": ("bosniaque",),
    "bosniaques": ("bosniaque",),
    "bosnien": ("bosnien",),
    "bosnienne": ("bosnien",),
    "bosniennes": ("bosnien",),
    "bosniens": ("bosnien",),
    "bosseur": ("bosseur",),
    "bosseurs": ("bosseur",),
    "bosseuse": ("bosseur",),
    "bosseuses": ("bosseur",),
    "bostonien": ("bostonien",),
    "bostonienne": ("bostonien",),
    "bostoniennes": ("bostonien",),
    "bostoniens": ("bostonien",),
    "botanique": ("botanique",),
    "botaniques": ("botanique",),
    "botteleur": ("botteleur",),
    "botteleurs": ("botteleur",),
    "botteleuse": ("botteleur",),
    "botteleuses": ("botteleur",),
    "botticellien": ("botticellien",),
    "botticellienne": ("botticellien",),
    "botticelliennes": ("botticellien",),
    "botticelliens": ("botticellien",),
    "botulinique": ("botulinique",),
    "botuliniques": ("botulinique",),
    "botulique": ("botulique",),
    "botuliques": ("botulique",),
    "bouchée": ("bouché",),
    "bouchées": ("bouché",),
    "bouché": ("bouché",),
    "bouchés": ("bouché",),
    "bouchère": ("boucher",),
    "bouchères": ("boucher",),
    "boucher": ("boucher",),
    "bouchers": ("boucher",),
    "bouddhique": ("bouddhique",),
    "bouddhiques": ("bouddhique",),
    "bouddhiste": ("bouddhiste",),
    "bouddhistes": ("bouddhiste",),
    "boudeur": ("boudeur",),
    "boudeurs": ("boudeur",),
    "boudeuse": ("boudeur",),
    "boudeuses": ("boudeur",),
    "boueuse": ("boueux",),
    "boueuses": ("boueux",),
    "boueux": ("boueux",),
    "bouffe": ("bouffe",),
    "bouffes": ("bouffe",),
    "bouffeur": ("bouffeur",),
    "bouffeurs": ("bouffeur",),
    "bouffeuse": ("bouffeur",),
    "bouffeuses": ("bouffeur",),
    "bouffon": ("bouffon",),
    "bouffonne": ("bouffon",),
    "bouffonnes": ("bouffon",),
    "bouffons": ("bouffon",),
    "bougon": ("bougon",),
    "bougonne": ("bougon",),
    "bougonnes": ("bougon",),
    "bougons": ("bougon",),
    "bougonneur": ("bougonneur",),
    "bougonneurs": ("bougonneur",),
    "bougonneuse": ("bougonneur",),
    "bougonneuses": ("bougonneur",),
    "boulangère": ("boulanger",),
    "boulangères": ("boulanger",),
    "boulanger": ("boulanger",),
    "boulangers": ("boulanger",),
    "boulangiste": ("boulangiste",),
    "boulangistes": ("boulangiste",),
    "bouleuse": ("bouleux",),
    "bouleuses": ("bouleux",),
    "bouleux": ("bouleux",),
    "boulevardière": ("boulevardier",),
    "boulevardières": ("boulevardier",),
    "boulevardier": ("boulevardier",),
    "boulevardiers": ("boulevardier",),
    "boulimique": ("boulimique",),
    "boulimiques": ("boulimique",),
    "boulinière": ("boulinier",),
    "boulinières": ("boulinier",),
    "boulinier": ("boulinier",),
    "bouliniers": ("boulinier",),
    "bouliste": ("bouliste",),
    "boulistes": ("bouliste",),
    "boulonnaise": ("boulonnais",),
    "boulonnaises": ("boulonnais",),
    "boulonnais": ("boulonnais",),
    "boulot": ("boulot",),
    "boulots": ("boulot",),
    "boulotte": ("boulot",),
    "boulottes": ("boulot",),
    "bourbeuse": ("bourbeux",),
    "bourbeuses": ("bourbeux",),
    "bourbeux": ("bourbeux",),
    "bourbonien": ("bourbonien",),
    "bourbonienne": ("bourbonien",),
    "bourboniennes": ("bourbonien",),
    "bourboniens": ("bourbonien",),
    "bourbonnaise": ("bourbonnais",),
    "bourbonnaises": ("bourbonnais",),
    "bourbonnais": ("bourbonnais",),
    "bourdonneur": ("bourdonneur",),
    "bourdonneurs": ("bourdonneur",),
    "bourdonneuse": ("bourdonneur",),
    "bourdonneuses": ("bourdonneur",),
    "bourgeoise": ("bourgeois",),
    "bourgeoises": ("bourgeois",),
    "bourgeois": ("bourgeois",),
    "bourgeoisiale": ("bourgeoisial",),
    "bourgeoisiales": ("bourgeoisial",),
    "bourgeoisial": ("bourgeoisial",),
    "bourgeoisiaux": ("bourgeoisial",),
    "bourguignon": ("bourguignon",),
    "bourguignonne": ("bourguignon",),
    "bourguignonnes": ("bourguignon",),
    "bourguignons": ("bourguignon",),
    "bourlingueur": ("bourlingueur",),
    "bourlingueurs": ("bourlingueur",),
    "bourlingueuse": ("bourlingueur",),
    "bourlingueuses": ("bourlingueur",),
    "bourrable": ("bourrable",),
    "bourrables": ("bourrable",),
    "bourratif": ("bourratif",),
    "bourratifs": ("bourratif",),
    "bourrative": ("bourratif",),
    "bourratives": ("bourratif",),
    "boursicoteur": ("boursicoteur",),
    "boursicoteurs": ("boursicoteur",),
    "boursicoteuse": ("boursicoteur",),
    "boursicoteuses": ("boursicoteur",),
    "boursicotière": ("boursicotier",),
    "boursicotières": ("boursicotier",),
    "boursicotier": ("boursicotier",),
    "boursicotiers": ("boursicotier",),
    "boursière": ("boursier",),
    "boursières": ("boursier",),
    "boursier": ("boursier",),
    "boursiers": ("boursier",),
    "boutant": ("boutant",),
    "boutants": ("boutant",),
    "boutiquière": ("boutiquier",),
    "boutiquières": ("boutiquier",),
    "boutiquier": ("boutiquier",),
    "boutiquiers": ("boutiquier",),
    "boutiste": ("boutiste",),
    "boutistes": ("boutiste",),
    "boutonneuse": ("boutonneux",),
    "boutonneuses": ("boutonneux",),
    "boutonneux": ("boutonneux",),
    "bouvière": ("bouvier",),
    "bouvières": ("bouvier",),
    "bouvier": ("bouvier",),
    "bouviers": ("bouvier",),
    "bowénoïde": ("bowénoïde",),
    "bowénoïdes": ("bowénoïde",),
    "boycotteur": ("boycotteur",),
    "boycotteurs": ("boycotteur",),
    "boycotteuse": ("boycotteur",),
    "boycotteuses": ("boycotteur",),
    "brabançon": ("brabançon",),
    "brabançonne": ("brabançon",),
    "brabançonnes": ("brabançon",),
    "brabançons": ("brabançon",),
    "brachiale": ("brachial",),
    "brachiales": ("brachial",),
    "brachial": ("brachial",),
    "brachiaux": ("brachial",),
    "brachiocéphalique": ("brachiocéphalique",),
    "brachiocéphaliques": ("brachiocéphalique",),
    "brachyanticlinale": ("brachyanticlinal",),
    "brachyanticlinales": ("brachyanticlinal",),
    "brachyanticlinal": ("brachyanticlinal",),
    "brachyanticlinaux": ("brachyanticlinal",),
    "brachycatalectique": ("brachycatalectique",),
    "brachycatalectiques": ("brachycatalectique",),
    "brachycéphale": ("brachycéphale",),
    "brachycéphales": ("brachycéphale",),
    "brachycère": ("brachycère",),
    "brachycères": ("brachycère",),
    "brachydactyle": ("brachydactyle",),
    "brachydactyles": ("brachydactyle",),
    "brachysynclinale": ("brachysynclinal",),
    "brachysynclinales": ("brachysynclinal",),
    "brachysynclinal": ("brachysynclinal",),
    "brachysynclinaux": ("brachysynclinal",),
    "braconnière": ("braconnier",),
    "braconnières": ("braconnier",),
    "braconnier": ("braconnier",),
    "braconniers": ("braconnier",),
    "bractéale": ("bractéal",),
    "bractéales": ("bractéal",),
    "bractéal": ("bractéal",),
    "bractéaux": ("bractéal",),
    "brahmanique": ("brahmanique",),
    "brahmaniques": ("brahmanique",),
    "brahmaniste": ("brahmaniste",),
    "brahmanistes": ("brahmaniste",),
    "brahoui": ("brahoui",),
    "brahouis": ("brahoui",),
    "brailleur": ("brailleur",),
    "brailleurs": ("brailleur",),
    "brailleuse": ("brailleur",),
    "brailleuses": ("brailleur",),
    "branchiale": ("branchial",),
    "branchiales": ("branchial",),
    "branchial": ("branchial",),
    "branchiaux": ("branchial",),
    "brandebourgeoise": ("brandebourgeois",),
    "brandebourgeoises": ("brandebourgeois",),
    "brandebourgeois": ("brandebourgeois",),
    "branquignolle": ("branquignol",),
    "branquignolles": ("branquignol",),
    "branquignol": ("branquignol",),
    "branquignols": ("branquignol",),
    "braque": ("braque",),
    "braques": ("braque",),
    "brassicole": ("brassicole",),
    "brassicoles": ("brassicole",),
    "brassidique": ("brassidique",),
    "brassidiques": ("brassidique",),
    "bravache": ("bravache",),
    "bravaches": ("bravache",),
    "brave": ("brave",),
    "braves": ("brave",),
    "bréchiforme": ("bréchiforme",),
    "bréchiformes": ("bréchiforme",),
    "bréchique": ("bréchique",),
    "bréchiques": ("bréchique",),
    "brechtien": ("brechtien",),
    "brechtienne": ("brechtien",),
    "brechtiennes": ("brechtien",),
    "brechtiens": ("brechtien",),
    "bredouille": ("bredouille",),
    "bredouilles": ("bredouille",),
    "bredouilleur": ("bredouilleur",),
    "bredouilleurs": ("bredouilleur",),
    "bredouilleuse": ("bredouilleur",),
    "bredouilleuses": ("bredouilleur",),
    "bref": ("bref",),
    "brefs": ("bref",),
    "brève": ("bref",),
    "brèves": ("bref",),
    "bregmatique": ("bregmatique",),
    "bregmatiques": ("bregmatique",),
    "bréhaigne": ("bréhaigne",),
    "bréhaignes": ("bréhaigne",),
    "brejnévien": ("brejnévien",),
    "brejnévienne": ("brejnévien",),
    "brejnéviennes": ("brejnévien",),
    "brejnéviens": ("brejnévien",),
    "brêmoise": ("brêmois",),
    "brêmoises": ("brêmois",),
    "brêmois": ("brêmois",),
    "bréphoplastique": ("bréphoplastique",),
    "bréphoplastiques": ("bréphoplastique",),
    "brésilien": ("brésilien",),
    "brésilienne": ("brésilien",),
    "brésiliennes": ("brésilien",),
    "brésiliens": ("brésilien",),
    "brestoise": ("brestois",),
    "brestoises": ("brestois",),
    "brestois": ("brestois",),
    "breton": ("breton",),
    "bretonne": ("breton",),
    "bretonnes": ("breton",),
    "bretons": ("breton",),
    "breughélien": ("breughélien",),
    "breughélienne": ("breughélien",),
    "breughéliennes": ("breughélien",),
    "breughéliens": ("breughélien",),
    "brevetable": ("brevetable",),
    "brevetables": ("brevetable",),
    "bréviligne": ("bréviligne",),
    "brévilignes": ("bréviligne",),
    "brightique": ("brightique",),
    "brightiques": ("brightique",),
    "brillanteur": ("brillanteur",),
    "brillanteurs": ("brillanteur",),
    "brillanteuse": ("brillanteur",),
    "brillanteuses": ("brillanteur",),
    "brillantissime": ("brillantissime",),
    "brillantissimes": ("brillantissime",),
    "brindezingue": ("brindezingue",),
    "brindezingues": ("brindezingue",),
    "brique": ("brique",),
    "britannique": ("britannique",),
    "britanniques": ("britannique",),
    "brittonique": ("brittonique",),
    "brittoniques": ("brittonique",),
    "brocheur": ("brocheur",),
    "brocheurs": ("brocheur",),
    "brocheuse": ("brocheur",),
    "brocheuses": ("brocheur",),
    "brogneuse": ("brogneux",),
    "brogneuses": ("brogneux",),
    "brogneux": ("brogneux",),
    "bromacétique": ("bromacétique",),
    "bromacétiques": ("bromacétique",),
    "bromatologique": ("bromatologique",),
    "bromatologiques": ("bromatologique",),
    "bromhydrique": ("bromhydrique",),
    "bromhydriques": ("bromhydrique",),
    "bromique": ("bromique",),
    "bromiques": ("bromique",),
    "bromopotassique": ("bromopotassique",),
    "bromopotassiques": ("bromopotassique",),
    "bronchiale": ("bronchial",),
    "bronchiales": ("bronchial",),
    "bronchial": ("bronchial",),
    "bronchiaux": ("bronchial",),
    "bronchiolaire": ("bronchiolaire",),
    "bronchiolaires": ("bronchiolaire",),
    "bronchiolo-alvéolaire": ("bronchiolo-alvéolaire",),
    "bronchique": ("bronchique",),
    "bronchiques": ("bronchique",),
    "bronchiteuse": ("bronchiteux",),
    "bronchiteuses": ("bronchiteux",),
    "bronchiteux": ("bronchiteux",),
    "bronchitique": ("bronchitique",),
    "bronchitiques": ("bronchitique",),
    "bronchoconstricteur": ("bronchoconstricteur",),
    "bronchoconstricteurs": ("bronchoconstricteur",),
    "bronchoconstrictrice": ("bronchoconstricteur",),
    "bronchoconstrictrices": ("bronchoconstricteur",),
    "bronchodilatateur": ("bronchodilatateur",),
    "bronchodilatateurs": ("bronchodilatateur",),
    "bronchodilatatrice": ("bronchodilatateur",),
    "broncho-dilatatrices": ("bronchodilatateur",),
    "bronchodilatatrices": ("bronchodilatateur",),
    "bronchogénique": ("bronchogénique",),
    "bronchogéniques": ("bronchogénique",),
    "bronchographique": ("bronchographique",),
    "bronchographiques": ("bronchographique",),
    "broncho-pulmonaire": ("broncho-pulmonaire",),
    "bronchopulmonaire": ("bronchopulmonaire",),
    "broncho-pulmonaires": ("broncho-pulmonaire",),
    "bronchopulmonaires": ("bronchopulmonaire",),
    "bronchoscopique": ("bronchoscopique",),
    "bronchoscopiques": ("bronchoscopique",),
    "brouilleur": ("brouilleur",),
    "brouilleurs": ("brouilleur",),
    "brouillon": ("brouillon",),
    "brouillonne": ("brouillon",),
    "brouillonnes": ("brouillon",),
    "brouillons": ("brouillon",),
    "broussailleur": ("broussailleur",),
    "broussailleurs": ("broussailleur",),
    "broussailleuse": ("broussailleux",),
    "broussailleuses": ("broussailleux",),
    "broussailleux": ("broussailleux",),
    "brownien": ("brownien",),
    "brownienne": ("brownien",),
    "browniennes": ("brownien",),
    "browniens": ("brownien",),
    "broyeur": ("broyeur",),
    "broyeurs": ("broyeur",),
    "broyeuse": ("broyeur",),
    "broyeuses": ("broyeur",),
    "brugeoise": ("brugeois",),
    "brugeoises": ("brugeois",),
    "brugeois": ("brugeois",),
    "bruineuse": ("bruineux",),
    "bruineuses": ("bruineux",),
    "bruineux": ("bruineux",),
    "brumeuse": ("brumeux",),
    "brumeuses": ("brumeux",),
    "brumeux": ("brumeux",),
    "brunâtre": ("brunâtre",),
    "brunâtres": ("brunâtre",),
    "brunet": ("brunet",),
    "brunets": ("brunet",),
    "brunette": ("brunet",),
    "brunettes": ("brunet",),
    "brusque": ("brusque",),
    "brusques": ("brusque",),
    "brutale": ("brutal",),
    "brutales": ("brutal",),
    "brutal": ("brutal",),
    "brutaux": ("brutal",),
    "brutaliste": ("brutaliste",),
    "brutalistes": ("brutaliste",),
    "bruxelloise": ("bruxellois",),
    "bruxelloises": ("bruxellois",),
    "bruxellois": ("bruxellois",),
    "bryologique": ("bryologique",),
    "bryologiques": ("bryologique",),
    "bubonique": ("bubonique",),
    "buboniques": ("bubonique",),
    "buccale": ("buccal",),
    "buccales": ("buccal",),
    "buccal": ("buccal",),
    "buccaux": ("buccal",),
    "buccinateur": ("buccinateur",),
    "buccinateurs": ("buccinateur",),
    "buccinatrice": ("buccinateur",),
    "buccinatrices": ("buccinateur",),
    "bucco-dentaire": ("bucco-dentaire",),
    "bucco-dentaires": ("bucco-dentaire",),
    "bucco-nasale": ("bucco-nasal",),
    "bucco-pharyngées": ("bucco-pharyngé",),
    "bucco-pharyngien": ("bucco-pharyngien",),
    "bucco-pharyngiens": ("bucco-pharyngien",),
    "bûcheur": ("bûcheur",),
    "bûcheurs": ("bûcheur",),
    "bûcheuse": ("bûcheur",),
    "bûcheuses": ("bûcheur",),
    "bucolique": ("bucolique",),
    "bucoliques": ("bucolique",),
    "budgétaire": ("budgétaire",),
    "budgétaires": ("budgétaire",),
    "budgétivore": ("budgétivore",),
    "budgétivores": ("budgétivore",),
    "buiatrique": ("buiatrique",),
    "buiatriques": ("buiatrique",),
    "buissonneuse": ("buissonneux",),
    "buissonneuses": ("buissonneux",),
    "buissonneux": ("buissonneux",),
    "buissonnière": ("buissonnier",),
    "buissonnières": ("buissonnier",),
    "buissonnier": ("buissonnier",),
    "buissonniers": ("buissonnier",),
    "bulbaire": ("bulbaire",),
    "bulbaires": ("bulbaire",),
    "bulbeuse": ("bulbeux",),
    "bulbeuses": ("bulbeux",),
    "bulbeux": ("bulbeux",),
    "bulbifère": ("bulbifère",),
    "bulbifères": ("bulbifère",),
    "bulboprotubérantielle": ("bulboprotubérantiel",),
    "bulboprotubérantielles": ("bulboprotubérantiel",),
    "bulboprotubérantiel": ("bulboprotubérantiel",),
    "bulboprotubérantiels": ("bulboprotubérantiel",),
    "bulbospinale": ("bulbospinal",),
    "bulbospinales": ("bulbospinal",),
    "bulbospinal": ("bulbospinal",),
    "bulbospinaux": ("bulbospinal",),
    "bulgare": ("bulgare",),
    "bulgares": ("bulgare",),
    "bullaire": ("bullaire",),
    "bullaires": ("bullaire",),
    "bullée": ("bullé",),
    "bullées": ("bullé",),
    "bullé": ("bullé",),
    "bulle": ("bulle",),
    "bullés": ("bullé",),
    "bulleuse": ("bulleux",),
    "bulleuses": ("bulleux",),
    "bulleux": ("bulleux",),
    "bunodonte": ("bunodonte",),
    "bunodontes": ("bunodonte",),
    "buraliste": ("buraliste",),
    "buralistes": ("buraliste",),
    "bureaucratique": ("bureaucratique",),
    "bureaucratiques": ("bureaucratique",),
    "bureautique": ("bureautique",),
    "bureautiques": ("bureautique",),
    "burkinabé": ("burkinabé",),
    "burkinabés": ("burkinabé",),
    "burlesque": ("burlesque",),
    "burlesques": ("burlesque",),
    "bursale": ("bursal",),
    "bursales": ("bursal",),
    "bursal": ("bursal",),
    "bursaux": ("bursal",),
    "burundaise": ("burundais",),
    "burundaises": ("burundais",),
    "burundais": ("burundais",),
    "butière": ("butière",),
    "butières": ("butière",),
    "butineur": ("butineur",),
    "butineurs": ("butineur",),
    "butineuse": ("butineur",),
    "butineuses": ("butineur",),
    "butylique": ("butylique",),
    "butyliques": ("butylique",),
    "butyreuse": ("butyreux",),
    "butyreuses": ("butyreux",),
    "butyreux": ("butyreux",),
    "butyrique": ("butyrique",),
    "butyriques": ("butyrique",),
    "buvable": ("buvable",),
    "buvables": ("buvable",),
    "buvard": ("buvard",),
    "buvards": ("buvard",),
    "buveur": ("buveur",),
    "buveurs": ("buveur",),
    "buveuse": ("buveur",),
    "buveuses": ("buveur",),
    "byronien": ("byronien",),
    "byronienne": ("byronien",),
    "byroniennes": ("byronien",),
    "byroniens": ("byronien",),
    "byzantiniste": ("byzantiniste",),
    "byzantinistes": ("byzantiniste",),
    "cabaliste": ("cabaliste",),
    "cabalistes": ("cabaliste",),
    "cabalistique": ("cabalistique",),
    "cabalistiques": ("cabalistique",),
    "câblière": ("câblier",),
    "câblières": ("câblier",),
    "câblier": ("câblier",),
    "câbliers": ("câblier",),
    "câblodistributeur": ("câblodistributeur",),
    "câblodistributeurs": ("câblodistributeur",),
    "câblodistributrice": ("câblodistributeur",),
    "câblodistributrices": ("câblodistributeur",),
    "cabot": ("cabot",),
    "cabots": ("cabot",),
    "cabus": ("cabus",),
    "cacaoyère": ("cacaoyer",),
    "cacaoyères": ("cacaoyer",),
    "cacaoyer": ("cacaoyer",),
    "cacaoyers": ("cacaoyer",),
    "cachectique": ("cachectique",),
    "cachectiques": ("cachectique",),
    "cachemire": ("cachemire",),
    "cachemires": ("cachemire",),
    "cacher": ("cacher",),
    "cachottière": ("cachottier",),
    "cachottières": ("cachottier",),
    "cachottier": ("cachottier",),
    "cachottiers": ("cachottier",),
    "cachou": ("cachou",),
    "cachoutannique": ("cachoutannique",),
    "cachoutanniques": ("cachoutannique",),
    "cacochyme": ("cacochyme",),
    "cacochymes": ("cacochyme",),
    "cacodylique": ("cacodylique",),
    "cacodyliques": ("cacodylique",),
    "cacophage": ("cacophage",),
    "cacophages": ("cacophage",),
    "cacophonique": ("cacophonique",),
    "cacophoniques": ("cacophonique",),
    "cacuminale": ("cacuminal",),
    "cacuminales": ("cacuminal",),
    "cacuminal": ("cacuminal",),
    "cacuminaux": ("cacuminal",),
    "cadastrale": ("cadastral",),
    "cadastrales": ("cadastral",),
    "cadastral": ("cadastral",),
    "cadastraux": ("cadastral",),
    "cadavéreuse": ("cadavéreux",),
    "cadavéreuses": ("cadavéreux",),
    "cadavéreux": ("cadavéreux",),
    "cadavérique": ("cadavérique",),
    "cadavériques": ("cadavérique",),
    "cadet": ("cadet",),
    "cadets": ("cadet",),
    "cadette": ("cadet",),
    "cadettes": ("cadet",),
    "caduc": ("caduc",),
    "caducs": ("caduc",),
    "caduque": ("caduc",),
    "caduques": ("caduc",),
    "cadurcien": ("cadurcien",),
    "cadurcienne": ("cadurcien",),
    "cadurciennes": ("cadurcien",),
    "cadurciens": ("cadurcien",),
    "caecale": ("caecal",),
    "caecales": ("caecal",),
    "caecal": ("caecal",),
    "caecaux": ("caecal",),
    "caennaise": ("caennais",),
    "caennaises": ("caennais",),
    "caennais": ("caennais",),
    "cafardeur": ("cafardeur",),
    "cafardeurs": ("cafardeur",),
    "cafardeuse": ("cafardeux",),
    "cafardeuses": ("cafardeux",),
    "cafardeux": ("cafardeux",),
    "café": ("café",),
    "caféière": ("caféier",),
    "caféières": ("caféier",),
    "caféier": ("caféier",),
    "caféiers": ("caféier",),
    "caféique": ("caféique",),
    "caféiques": ("caféique",),
    "cafouilleur": ("cafouilleur",),
    "cafouilleurs": ("cafouilleur",),
    "cafouilleuse": ("cafouilleux",),
    "cafouilleuses": ("cafouilleux",),
    "cafouilleux": ("cafouilleux",),
    "cafre": ("cafre",),
    "cafres": ("cafre",),
    "cagneuse": ("cagneux",),
    "cagneuses": ("cagneux",),
    "cagneux": ("cagneux",),
    "cahoteuse": ("cahoteux",),
    "cahoteuses": ("cahoteux",),
    "cahoteux": ("cahoteux",),
    "caillée": ("caillé",),
    "caillées": ("caillé",),
    "caillé": ("caillé",),
    "caille": ("caille",),
    "caillés": ("caillé",),
    "caillouteuse": ("caillouteux",),
    "caillouteuses": ("caillouteux",),
    "caillouteux": ("caillouteux",),
    "cairote": ("cairote",),
    "cairotes": ("cairote",),
    "cajoleur": ("cajoleur",),
    "cajoleurs": ("cajoleur",),
    "cajoleuse": ("cajoleur",),
    "cajoleuses": ("cajoleur",),
    "cajun": ("cajun",),
    "cajuns": ("cajun",),
    "calabraise": ("calabrais",),
    "calabraises": ("calabrais",),
    "calabrais": ("calabrais",),
    "calaisien": ("calaisien",),
    "calaisienne": ("calaisien",),
    "calaisiennes": ("calaisien",),
    "calaisiens": ("calaisien",),
    "calaminaire": ("calaminaire",),
    "calaminaires": ("calaminaire",),
    "calamiteuse": ("calamiteux",),
    "calamiteuses": ("calamiteux",),
    "calamiteux": ("calamiteux",),
    "calcaire": ("calcaire",),
    "calcaires": ("calcaire",),
    "calcédonieuse": ("calcédonieux",),
    "calcédonieuses": ("calcédonieux",),
    "calcédonieux": ("calcédonieux",),
    "calcicole": ("calcicole",),
    "calcicoles": ("calcicole",),
    "calciférolique": ("calciférolique",),
    "calciféroliques": ("calciférolique",),
    "calciforme": ("calciforme",),
    "calciformes": ("calciforme",),
    "calcifuge": ("calcifuge",),
    "calcifuges": ("calcifuge",),
    "calcimagnésique": ("calcimagnésique",),
    "calcimagnésiques": ("calcimagnésique",),
    "calciorégulateur": ("calciorégulateur",),
    "calciorégulateurs": ("calciorégulateur",),
    "calciorégulatrice": ("calciorégulateur",),
    "calciorégulatrices": ("calciorégulateur",),
    "calciphile": ("calciphile",),
    "calciphiles": ("calciphile",),
    "calciphobe": ("calciphobe",),
    "calciphobes": ("calciphobe",),
    "calciprive": ("calciprive",),
    "calciprives": ("calciprive",),
    "calcique": ("calcique",),
    "calciques": ("calcique",),
    "calcosodique": ("calcosodique",),
    "calcosodiques": ("calcosodique",),
    "calculable": ("calculable",),
    "calculables": ("calculable",),
    "calculateur": ("calculateur",),
    "calculateurs": ("calculateur",),
    "calculatrice": ("calculateur",),
    "calculatrices": ("calculateur",),
    "calculeuse": ("calculeux",),
    "calculeuses": ("calculeux",),
    "calculeux": ("calculeux",),
    "caldoche": ("caldoche",),
    "caldoches": ("caldoche",),
    "calédonien": ("calédonien",),
    "calédonienne": ("calédonien",),
    "calédoniennes": ("calédonien",),
    "calédoniens": ("calédonien",),
    "calembouresque": ("calembouresque",),
    "calembouresques": ("calembouresque",),
    "calendaire": ("calendaire",),
    "calendaires": ("calendaire",),
    "calicielle": ("caliciel",),
    "calicielles": ("caliciel",),
    "caliciel": ("caliciel",),
    "caliciels": ("caliciel",),
    "caliciforme": ("caliciforme",),
    "caliciformes": ("caliciforme",),
    "califale": ("califal",),
    "califales": ("califal",),
    "califal": ("califal",),
    "califaux": ("califal",),
    "californien": ("californien",),
    "californienne": ("californien",),
    "californiennes": ("californien",),
    "californiens": ("californien",),
    "calippique": ("calippique",),
    "calippiques": ("calippique",),
    "calleuse": ("calleux",),
    "calleuses": ("calleux",),
    "calleux": ("calleux",),
    "calligraphique": ("calligraphique",),
    "calligraphiques": ("calligraphique",),
    "callippique": ("callippique",),
    "callippiques": ("callippique",),
    "callipyge": ("callipyge",),
    "callipyges": ("callipyge",),
    "callovien": ("callovien",),
    "callovienne": ("callovien",),
    "calloviennes": ("callovien",),
    "calloviens": ("callovien",),
    "calme": ("calme",),
    "calmes": ("calme",),
    "calomniateur": ("calomniateur",),
    "calomniateurs": ("calomniateur",),
    "calomniatrice": ("calomniateur",),
    "calomniatrices": ("calomniateur",),
    "calomnieuse": ("calomnieux",),
    "calomnieuses": ("calomnieux",),
    "calomnieux": ("calomnieux",),
    "caloporteur": ("caloporteur",),
    "caloporteurs": ("caloporteur",),
    "calorifère": ("calorifère",),
    "calorifères": ("calorifère",),
    "calorifique": ("calorifique",),
    "calorifiques": ("calorifique",),
    "calorifuge": ("calorifuge",),
    "calorifuges": ("calorifuge",),
    "calorimétrique": ("calorimétrique",),
    "calorimétriques": ("calorimétrique",),
    "caloriporteur": ("caloriporteur",),
    "caloriporteurs": ("caloriporteur",),
    "calorique": ("calorique",),
    "caloriques": ("calorique",),
    "calviniste": ("calviniste",),
    "calvinistes": ("calviniste",),
    "camarguaise": ("camarguais",),
    "camarguaises": ("camarguais",),
    "camarguais": ("camarguais",),
    "camargue": ("camargue",),
    "camargues": ("camargue",),
    "cambiaire": ("cambiaire",),
    "cambiaires": ("cambiaire",),
    "cambiale": ("cambial",),
    "cambiales": ("cambial",),
    "cambial": ("cambial",),
    "cambiaux": ("cambial",),
    "cambique": ("cambique",),
    "cambiques": ("cambique",),
    "cambiste": ("cambiste",),
    "cambistes": ("cambiste",),
    "cambodgien": ("cambodgien",),
    "cambodgienne": ("cambodgien",),
    "cambodgiennes": ("cambodgien",),
    "cambodgiens": ("cambodgien",),
    "cambrésien": ("cambrésien",),
    "cambrésienne": ("cambrésien",),
    "cambrésiennes": ("cambrésien",),
    "cambrésiens": ("cambrésien",),
    "cambrien": ("cambrien",),
    "cambrienne": ("cambrien",),
    "cambriennes": ("cambrien",),
    "cambriens": ("cambrien",),
    "camel": ("camel",),
    "caméléonesque": ("caméléonesque",),
    "caméléonesques": ("caméléonesque",),
    "cameline": ("cameline",),
    "camelines": ("cameline",),
    "camérale": ("caméral",),
    "camérales": ("caméral",),
    "caméral": ("caméral",),
    "caméraux": ("caméral",),
    "caméralistique": ("caméralistique",),
    "caméralistiques": ("caméralistique",),
    "camerounaise": ("camerounais",),
    "camerounaises": ("camerounais",),
    "camerounais": ("camerounais",),
    "camérulaire": ("camérulaire",),
    "camérulaires": ("camérulaire",),
    "campanaire": ("campanaire",),
    "campanaires": ("campanaire",),
    "campanien": ("campanien",),
    "campanienne": ("campanien",),
    "campaniennes": ("campanien",),
    "campaniens": ("campanien",),
    "campaniforme": ("campaniforme",),
    "campaniformes": ("campaniforme",),
    "camphorique": ("camphorique",),
    "camphoriques": ("camphorique",),
    "camphosulfonique": ("camphosulfonique",),
    "camphosulfoniques": ("camphosulfonique",),
    "campignien": ("campignien",),
    "campignienne": ("campignien",),
    "campigniennes": ("campignien",),
    "campigniens": ("campignien",),
    "campimétrique": ("campimétrique",),
    "campimétriques": ("campimétrique",),
    "campomélique": ("campomélique",),
    "campoméliques": ("campomélique",),
    "camuse": ("camus",),
    "camuses": ("camus",),
    "camus": ("camus",),
    "canadien": ("canadien",),
    "canadienne": ("canadien",),
    "canadiennes": ("canadien",),
    "canadiens": ("canadien",),
    "canaille": ("canaille",),
    "canailles": ("canaille",),
    "canaliculaire": ("canaliculaire",),
    "canaliculaires": ("canaliculaire",),
    "canalisable": ("canalisable",),
    "canalisables": ("canalisable",),
    "cananéen": ("cananéen",),
    "cananéenne": ("cananéen",),
    "cananéennes": ("cananéen",),
    "cananéens": ("cananéen",),
    "canaque": ("canaque",),
    "canaques": ("canaque",),
    "canari": ("canari",),
    "canarien": ("canarien",),
    "canarienne": ("canarien",),
    "canariennes": ("canarien",),
    "canariens": ("canarien",),
    "cancanière": ("cancanier",),
    "cancanières": ("cancanier",),
    "cancanier": ("cancanier",),
    "cancaniers": ("cancanier",),
    "cancéreuse": ("cancéreux",),
    "cancéreuses": ("cancéreux",),
    "cancéreux": ("cancéreux",),
    "cancérigène": ("cancérigène",),
    "cancérigènes": ("cancérigène",),
    "cancérogène": ("cancérogène",),
    "cancérogènes": ("cancérogène",),
    "cancérologique": ("cancérologique",),
    "cancérologiques": ("cancérologique",),
    "cancroïde": ("cancroïde",),
    "cancroïdes": ("cancroïde",),
    "candi": ("candi",),
    "candidacide": ("candidacide",),
    "candidacides": ("candidacide",),
    "candide": ("candide",),
    "candides": ("candide",),
    "caniculaire": ("caniculaire",),
    "caniculaires": ("caniculaire",),
    "cannabique": ("cannabique",),
    "cannabiques": ("cannabique",),
    "cannelle": ("cannelle",),
    "cannibale": ("cannibale",),
    "cannibales": ("cannibale",),
    "cannibalesque": ("cannibalesque",),
    "cannibalesques": ("cannibalesque",),
    "cannibalique": ("cannibalique",),
    "cannibaliques": ("cannibalique",),
    "canoéiste": ("canoéiste",),
    "canoéistes": ("canoéiste",),
    "canon": ("canon",),
    "canons": ("canon",),
    "canoniale": ("canonial",),
    "canoniales": ("canonial",),
    "canonial": ("canonial",),
    "canoniaux": ("canonial",),
    "canonique": ("canonique",),
    "canoniques": ("canonique",),
    "canonisable": ("canonisable",),
    "canonisables": ("canonisable",),
    "cantabile": ("cantabile",),
    "cantalien": ("cantalien",),
    "cantalienne": ("cantalien",),
    "cantaliennes": ("cantalien",),
    "cantaliens": ("cantalien",),
    "cantharidique": ("cantharidique",),
    "cantharidiques": ("cantharidique",),
    "cantilever": ("cantilever",),
    "cantonaise": ("cantonais",),
    "cantonaises": ("cantonais",),
    "cantonais": ("cantonais",),
    "cantonale": ("cantonal",),
    "cantonales": ("cantonal",),
    "cantonal": ("cantonal",),
    "cantonaux": ("cantonal",),
    "cantonnière": ("cantonnier",),
    "cantonnières": ("cantonnier",),
    "cantonnier": ("cantonnier",),
    "cantonniers": ("cantonnier",),
    "canularesque": ("canularesque",),
    "canularesques": ("canularesque",),
    "caodaïste": ("caodaïste",),
    "caodaïstes": ("caodaïste",),
    "caoutchouteuse": ("caoutchouteux",),
    "caoutchouteuses": ("caoutchouteux",),
    "caoutchouteux": ("caoutchouteux",),
    "caoutchoutière": ("caoutchoutier",),
    "caoutchoutières": ("caoutchoutier",),
    "caoutchoutier": ("caoutchoutier",),
    "caoutchoutiers": ("caoutchoutier",),
    "capable": ("capable",),
    "capables": ("capable",),
    "cap": ("cap",),
    "capacitaire": ("capacitaire",),
    "capacitaires": ("capacitaire",),
    "capacitif": ("capacitif",),
    "capacitifs": ("capacitif",),
    "capacitive": ("capacitif",),
    "capacitives": ("capacitif",),
    "capétien": ("capétien",),
    "capétienne": ("capétien",),
    "capétiennes": ("capétien",),
    "capétiens": ("capétien",),
    "capillaire": ("capillaire",),
    "capillaires": ("capillaire",),
    "capillarotoxique": ("capillarotoxique",),
    "capillarotoxiques": ("capillarotoxique",),
    "capillarotrope": ("capillarotrope",),
    "capillarotropes": ("capillarotrope",),
    "capitale": ("capital",),
    "capitales": ("capital",),
    "capital": ("capital",),
    "capitaux": ("capital",),
    "capitalisable": ("capitalisable",),
    "capitalisables": ("capitalisable",),
    "capitaliste": ("capitaliste",),
    "capitalistes": ("capitaliste",),
    "capitalistique": ("capitalistique",),
    "capitalistiques": ("capitalistique",),
    "capiteuse": ("capiteux",),
    "capiteuses": ("capiteux",),
    "capiteux": ("capiteux",),
    "capitonneur": ("capitonneur",),
    "capitonneurs": ("capitonneur",),
    "capitonneuse": ("capitonneur",),
    "capitonneuses": ("capitonneur",),
    "capitulaire": ("capitulaire",),
    "capitulaires": ("capitulaire",),
    "capon": ("capon",),
    "caponne": ("capon",),
    "caponnes": ("capon",),
    "capons": ("capon",),
    "capot": ("capot",),
    "cappadocien": ("cappadocien",),
    "cappadocienne": ("cappadocien",),
    "cappadociennes": ("cappadocien",),
    "cappadociens": ("cappadocien",),
    "câpre": ("câpre",),
    "câpres": ("câpre",),
    "câpresse": ("câpre",),
    "câpresses": ("câpre",),
    "capricieuse": ("capricieux",),
    "capricieuses": ("capricieux",),
    "capricieux": ("capricieux",),
    "caprique": ("caprique",),
    "capriques": ("caprique",),
    "caproïque": ("caproïque",),
    "caproïques": ("caproïque",),
    "caprylique": ("caprylique",),
    "capryliques": ("caprylique",),
    "capsien": ("capsien",),
    "capsienne": ("capsien",),
    "capsiennes": ("capsien",),
    "capsiens": ("capsien",),
    "capsulaire": ("capsulaire",),
    "capsulaires": ("capsulaire",),
    "captatif": ("captatif",),
    "captatifs": ("captatif",),
    "captative": ("captatif",),
    "captatives": ("captatif",),
    "captatoire": ("captatoire",),
    "captatoires": ("captatoire",),
    "captieuse": ("captieux",),
    "captieuses": ("captieux",),
    "captieux": ("captieux",),
    "captif": ("captif",),
    "captifs": ("captif",),
    "captive": ("captif",),
    "captives": ("captif",),
    "capturable": ("capturable",),
    "capturables": ("capturable",),
    "cap-verdien": ("cap-verdien",),
    "cap-verdienne": ("cap-verdien",),
    "cap-verdiennes": ("cap-verdien",),
    "cap-verdiens": ("cap-verdien",),
    "caractérielle": ("caractériel",),
    "caractérielles": ("caractériel",),
    "caractériel": ("caractériel",),
    "caractériels": ("caractériel",),
    "caractéristique": ("caractéristique",),
    "caractéristiques": ("caractéristique",),
    "caractérologique": ("caractérologique",),
    "caractérologiques": ("caractérologique",),
    "caraïbe": ("caraïbe",),
    "caraïbes": ("caraïbe",),
    "caraïte": ("caraïte",),
    "caraïtes": ("caraïte",),
    "caramel": ("caramel",),
    "caraque": ("caraque",),
    "caraques": ("caraque",),
    "caravagesque": ("caravagesque",),
    "caravagesques": ("caravagesque",),
    "caravagiste": ("caravagiste",),
    "caravagistes": ("caravagiste",),
    "caravanière": ("caravanier",),
    "caravanières": ("caravanier",),
    "caravanier": ("caravanier",),
    "caravaniers": ("caravanier",),
    "carbamique": ("carbamique",),
    "carbamiques": ("carbamique",),
    "carbénique": ("carbénique",),
    "carbéniques": ("carbénique",),
    "carbochimique": ("carbochimique",),
    "carbochimiques": ("carbochimique",),
    "carbocyclique": ("carbocyclique",),
    "carbocycliques": ("carbocyclique",),
    "carbogazeuse": ("carbogazeux",),
    "carbogazeuses": ("carbogazeux",),
    "carbogazeux": ("carbogazeux",),
    "carbonifère": ("carbonifère",),
    "carbonifères": ("carbonifère",),
    "carbonique": ("carbonique",),
    "carboniques": ("carbonique",),
    "carbonylée": ("carbonylé",),
    "carbonylées": ("carbonylé",),
    "carbonylé": ("carbonylé",),
    "carbonyle": ("carbonyle",),
    "carbonylés": ("carbonylé",),
    "carbonyles": ("carbonyle",),
    "carbothioïque": ("carbothioïque",),
    "carbothioïques": ("carbothioïque",),
    "carboxyglutarique": ("carboxyglutarique",),
    "carboxyglutariques": ("carboxyglutarique",),
    "carboxylique": ("carboxylique",),
    "carboxyliques": ("carboxylique",),
    "carburateur": ("carburateur",),
    "carburateurs": ("carburateur",),
    "carburatrice": ("carburateur",),
    "carburatrices": ("carburateur",),
    "carcérale": ("carcéral",),
    "carcérales": ("carcéral",),
    "carcéral": ("carcéral",),
    "carcéraux": ("carcéral",),
    "carcino-embryonnaire": ("carcino-embryonnaire",),
    "carcinoembryonnaire": ("carcinoembryonnaire",),
    "carcinoembryonnaires": ("carcinoembryonnaire",),
    "carcinogène": ("carcinogène",),
    "carcinogènes": ("carcinogène",),
    "carcinogénétique": ("carcinogénétique",),
    "carcinogénétiques": ("carcinogénétique",),
    "carcinoïde": ("carcinoïde",),
    "carcinoïdes": ("carcinoïde",),
    "carcinologique": ("carcinologique",),
    "carcinologiques": ("carcinologique",),
    "carcinolytique": ("carcinolytique",),
    "carcinolytiques": ("carcinolytique",),
    "carcinomateuse": ("carcinomateux",),
    "carcinomateuses": ("carcinomateux",),
    "carcinomateux": ("carcinomateux",),
    "cardiale": ("cardial",),
    "cardiales": ("cardial",),
    "cardial": ("cardial",),
    "cardiaux": ("cardial",),
    "cardialgique": ("cardialgique",),
    "cardialgiques": ("cardialgique",),
    "cardiaque": ("cardiaque",),
    "cardiaques": ("cardiaque",),
    "cardiazolique": ("cardiazolique",),
    "cardiazoliques": ("cardiazolique",),
    "cardinale": ("cardinal",),
    "cardinales": ("cardinal",),
    "cardinal": ("cardinal",),
    "cardinaux": ("cardinal",),
    "cardinalice": ("cardinalice",),
    "cardinalices": ("cardinalice",),
    "cardioaccélérateur": ("cardioaccélérateur",),
    "cardioaccélérateurs": ("cardioaccélérateur",),
    "cardioaccélératrice": ("cardioaccélérateur",),
    "cardioaccélératrices": ("cardioaccélérateur",),
    "cardio-auditive": ("cardio-auditif",),
    "cardiobulbaire": ("cardiobulbaire",),
    "cardiobulbaires": ("cardiobulbaire",),
    "cardio-circulatoires": ("cardio-circulatoire",),
    "cardiofaciale": ("cardiofacial",),
    "cardiofaciales": ("cardiofacial",),
    "cardiofacial": ("cardiofacial",),
    "cardiofaciaux": ("cardiofacial",),
    "cardiogénique": ("cardiogénique",),
    "cardiogéniques": ("cardiogénique",),
    "cardiographique": ("cardiographique",),
    "cardiographiques": ("cardiographique",),
    "cardioïde": ("cardioïde",),
    "cardioïdes": ("cardioïde",),
    "cardiologique": ("cardiologique",),
    "cardiologiques": ("cardiologique",),
    "cardiomégalique": ("cardiomégalique",),
    "cardiomégaliques": ("cardiomégalique",),
    "cardiomodérateur": ("cardiomodérateur",),
    "cardiomodérateurs": ("cardiomodérateur",),
    "cardiomodératrice": ("cardiomodérateur",),
    "cardiomodératrices": ("cardiomodérateur",),
    "cardionecteur": ("cardionecteur",),
    "cardionecteurs": ("cardionecteur",),
    "cardionectrice": ("cardionecteur",),
    "cardionectrices": ("cardionecteur",),
    "cardiopathe": ("cardiopathe",),
    "cardiopathes": ("cardiopathe",),
    "cardiopulmonaire": ("cardiopulmonaire",),
    "cardiopulmonaires": ("cardiopulmonaire",),
    "cardiorégulateur": ("cardiorégulateur",),
    "cardiorégulateurs": ("cardiorégulateur",),
    "cardiorégulatrice": ("cardiorégulateur",),
    "cardiorégulatrices": ("cardiorégulateur",),
    "cardio-rénal": ("cardio-rénal",),
    "cardio-rénaux": ("cardio-rénal",),
    "cardio-respiratoire": ("cardio-respiratoire",),
    "cardiorespiratoire": ("cardiorespiratoire",),
    "cardiorespiratoires": ("cardiorespiratoire",),
    "cardiosélectif": ("cardiosélectif",),
    "cardiosélectifs": ("cardiosélectif",),
    "cardiosélective": ("cardiosélectif",),
    "cardiosélectives": ("cardiosélectif",),
    "cardiostimulateur": ("cardiostimulateur",),
    "cardiostimulateurs": ("cardiostimulateur",),
    "cardiostimulatrice": ("cardiostimulateur",),
    "cardiostimulatrices": ("cardiostimulateur",),
    "cardiothoracique": ("cardiothoracique",),
    "cardiothoraciques": ("cardiothoracique",),
    "cardiotonique": ("cardiotonique",),
    "cardiotoniques": ("cardiotonique",),
    "cardiotoxique": ("cardiotoxique",),
    "cardiotoxiques": ("cardiotoxique",),
    "cardio-tubérositaire": ("cardio-tubérositaire",),
    "cardio-vasculaire": ("cardio-vasculaire",),
    "cardiovasculaire": ("cardiovasculaire",),
    "cardiovasculaires": ("cardiovasculaire",),
    "carélien": ("carélien",),
    "carélienne": ("carélien",),
    "caréliennes": ("carélien",),
    "caréliens": ("carélien",),
    "carencielle": ("carenciel",),
    "carencielles": ("carenciel",),
    "carenciel": ("carenciel",),
    "carenciels": ("carenciel",),
    "carentielle": ("carentiel",),
    "carentielles": ("carentiel",),
    "carentiel": ("carentiel",),
    "carentiels": ("carentiel",),
    "caresseur": ("caresseur",),
    "caresseurs": ("caresseur",),
    "caresseuse": ("caresseur",),
    "caresseuses": ("caresseur",),
    "cargo": ("cargo",),
    "caribéen": ("caribéen",),
    "caribéenne": ("caribéen",),
    "caribéennes": ("caribéen",),
    "caribéens": ("caribéen",),
    "caricaturale": ("caricatural",),
    "caricaturales": ("caricatural",),
    "caricatural": ("caricatural",),
    "caricaturaux": ("caricatural",),
    "carieuse": ("carieux",),
    "carieuses": ("carieux",),
    "carieux": ("carieux",),
    "carioca": ("carioca",),
    "cariocas": ("carioca",),
    "caritatif": ("caritatif",),
    "caritatifs": ("caritatif",),
    "caritative": ("caritatif",),
    "caritatives": ("caritatif",),
    "carliste": ("carliste",),
    "carlistes": ("carliste",),
    "carmélite": ("carmélite",),
    "carmélites": ("carmélite",),
    "carmin": ("carmin",),
    "carminatif": ("carminatif",),
    "carminatifs": ("carminatif",),
    "carminative": ("carminatif",),
    "carminatives": ("carminatif",),
    "carnassière": ("carnassier",),
    "carnassières": ("carnassier",),
    "carnassier": ("carnassier",),
    "carnassiers": ("carnassier",),
    "carnavalesque": ("carnavalesque",),
    "carnavalesques": ("carnavalesque",),
    "carniolien": ("carniolien",),
    "carniolienne": ("carniolien",),
    "carnioliennes": ("carniolien",),
    "carnioliens": ("carniolien",),
    "carnivore": ("carnivore",),
    "carnivores": ("carnivore",),
    "carolingien": ("carolingien",),
    "carolingienne": ("carolingien",),
    "carolingiennes": ("carolingien",),
    "carolingiens": ("carolingien",),
    "carolo-macériennes": ("carolo-macérien",),
    "carotide": ("carotide",),
    "carotides": ("carotide",),
    "carotidien": ("carotidien",),
    "carotidienne": ("carotidien",),
    "carotidiennes": ("carotidien",),
    "carotidiens": ("carotidien",),
    "carotinoïde": ("carotinoïde",),
    "carotinoïdes": ("carotinoïde",),
    "carotte": ("carotte",),
    "carotteur": ("carotteur",),
    "carotteurs": ("carotteur",),
    "carotteuse": ("carotteur",),
    "carotteuses": ("carotteur",),
    "carottière": ("carottier",),
    "carottières": ("carottier",),
    "carottier": ("carottier",),
    "carottiers": ("carottier",),
    "carpatique": ("carpatique",),
    "carpatiques": ("carpatique",),
    "carpellaire": ("carpellaire",),
    "carpellaires": ("carpellaire",),
    "carpentrassien": ("carpentrassien",),
    "carpentrassienne": ("carpentrassien",),
    "carpentrassiennes": ("carpentrassien",),
    "carpentrassiens": ("carpentrassien",),
    "carphologique": ("carphologique",),
    "carphologiques": ("carphologique",),
    "carpien": ("carpien",),
    "carpienne": ("carpien",),
    "carpiennes": ("carpien",),
    "carpiens": ("carpien",),
    "carpique": ("carpique",),
    "carpiques": ("carpique",),
    "carpologique": ("carpologique",),
    "carpologiques": ("carpologique",),
    "carpophage": ("carpophage",),
    "carpophages": ("carpophage",),
    "carrossable": ("carrossable",),
    "carrossables": ("carrossable",),
    "cartésien": ("cartésien",),
    "cartésienne": ("cartésien",),
    "cartésiennes": ("cartésien",),
    "cartésiens": ("cartésien",),
    "carteuse": ("carteux",),
    "carteuses": ("carteux",),
    "carteux": ("carteux",),
    "carthaginoise": ("carthaginois",),
    "carthaginoises": ("carthaginois",),
    "carthaginois": ("carthaginois",),
    "cartiériste": ("cartiériste",),
    "cartiéristes": ("cartiériste",),
    "cartilagineuse": ("cartilagineux",),
    "cartilagineuses": ("cartilagineux",),
    "cartilagineux": ("cartilagineux",),
    "cartographique": ("cartographique",),
    "cartographiques": ("cartographique",),
    "cartonneuse": ("cartonneux",),
    "cartonneuses": ("cartonneux",),
    "cartonneux": ("cartonneux",),
    "cartonnière": ("cartonnier",),
    "cartonnières": ("cartonnier",),
    "cartonnier": ("cartonnier",),
    "cartonniers": ("cartonnier",),
    "cartophile": ("cartophile",),
    "cartophiles": ("cartophile",),
    "cartusien": ("cartusien",),
    "cartusienne": ("cartusien",),
    "cartusiennes": ("cartusien",),
    "cartusiens": ("cartusien",),
    "carva": ("carva",),
    "caryoclasique": ("caryoclasique",),
    "caryoclasiques": ("caryoclasique",),
    "caryogamique": ("caryogamique",),
    "caryogamiques": ("caryogamique",),
    "caryolytique": ("caryolytique",),
    "caryolytiques": ("caryolytique",),
    "caryotypique": ("caryotypique",),
    "caryotypiques": ("caryotypique",),
    "casable": ("casable",),
    "casables": ("casable",),
    "casanière": ("casanier",),
    "casanières": ("casanier",),
    "casanier": ("casanier",),
    "casaniers": ("casanier",),
    "cascadeur": ("cascadeur",),
    "cascadeurs": ("cascadeur",),
    "cascadeuse": ("cascadeur",),
    "cascadeuses": ("cascadeur",),
    "cascher": ("cascher",),
    "caséeuse": ("caséeux",),
    "caséeuses": ("caséeux",),
    "caséeux": ("caséeux",),
    "caséiforme": ("caséiforme",),
    "caséiformes": ("caséiforme",),
    "caséolytique": ("caséolytique",),
    "caséolytiques": ("caséolytique",),
    "casher": ("casher",),
    "caspien": ("caspien",),
    "caspienne": ("caspien",),
    "caspiennes": ("caspien",),
    "caspiens": ("caspien",),
    "cassable": ("cassable",),
    "cassables": ("cassable",),
    "casseur": ("casseur",),
    "casseurs": ("casseur",),
    "casseuse": ("casseur",),
    "casseuses": ("casseur",),
    "castor": ("castor",),
    "castrale": ("castral",),
    "castrales": ("castral",),
    "castral": ("castral",),
    "castraux": ("castral",),
    "castrateur": ("castrateur",),
    "castrateurs": ("castrateur",),
    "castratrice": ("castrateur",),
    "castratrices": ("castrateur",),
    "castriste": ("castriste",),
    "castristes": ("castriste",),
    "casuelle": ("casuel",),
    "casuelles": ("casuel",),
    "casuel": ("casuel",),
    "casuels": ("casuel",),
    "catabatique": ("catabatique",),
    "catabatiques": ("catabatique",),
    "catabolique": ("catabolique",),
    "cataboliques": ("catabolique",),
    "cataclastique": ("cataclastique",),
    "cataclastiques": ("cataclastique",),
    "cataclinale": ("cataclinal",),
    "cataclinales": ("cataclinal",),
    "cataclinal": ("cataclinal",),
    "cataclinaux": ("cataclinal",),
    "cataclysmale": ("cataclysmal",),
    "cataclysmales": ("cataclysmal",),
    "cataclysmal": ("cataclysmal",),
    "cataclysmaux": ("cataclysmal",),
    "cataclysmique": ("cataclysmique",),
    "cataclysmiques": ("cataclysmique",),
    "catacrote": ("catacrote",),
    "catacrotes": ("catacrote",),
    "catadioptrique": ("catadioptrique",),
    "catadioptriques": ("catadioptrique",),
    "catagène": ("catagène",),
    "catagènes": ("catagène",),
    "cataire": ("cataire",),
    "cataires": ("cataire",),
    "catalaniste": ("catalaniste",),
    "catalanistes": ("catalaniste",),
    "catalectique": ("catalectique",),
    "catalectiques": ("catalectique",),
    "cataleptiforme": ("cataleptiforme",),
    "cataleptiformes": ("cataleptiforme",),
    "cataleptique": ("cataleptique",),
    "cataleptiques": ("cataleptique",),
    "catalytique": ("catalytique",),
    "catalytiques": ("catalytique",),
    "cataméniale": ("cataménial",),
    "cataméniales": ("cataménial",),
    "cataménial": ("cataménial",),
    "cataméniaux": ("cataménial",),
    "cataphorétique": ("cataphorétique",),
    "cataphorétiques": ("cataphorétique",),
    "cataphractaire": ("cataphractaire",),
    "cataphractaires": ("cataphractaire",),
    "cataphracte": ("cataphracte",),
    "cataphractes": ("cataphracte",),
    "cataplectique": ("cataplectique",),
    "cataplectiques": ("cataplectique",),
    "catapultable": ("catapultable",),
    "catapultables": ("catapultable",),
    "catarrhale": ("catarrhal",),
    "catarrhales": ("catarrhal",),
    "catarrhal": ("catarrhal",),
    "catarrhaux": ("catarrhal",),
    "catarrheuse": ("catarrheux",),
    "catarrheuses": ("catarrheux",),
    "catarrheux": ("catarrheux",),
    "catastrophique": ("catastrophique",),
    "catastrophiques": ("catastrophique",),
    "catastrophiste": ("catastrophiste",),
    "catastrophistes": ("catastrophiste",),
    "catatonique": ("catatonique",),
    "catatoniques": ("catatonique",),
    "catazonale": ("catazonal",),
    "catazonales": ("catazonal",),
    "catazonal": ("catazonal",),
    "catazonaux": ("catazonal",),
    "catéchistique": ("catéchistique",),
    "catéchistiques": ("catéchistique",),
    "catécholergique": ("catécholergique",),
    "catécholergiques": ("catécholergique",),
    "catéchuménale": ("catéchuménal",),
    "catéchuménales": ("catéchuménal",),
    "catéchuménal": ("catéchuménal",),
    "catéchuménaux": ("catéchuménal",),
    "catégorématique": ("catégorématique",),
    "catégorématiques": ("catégorématique",),
    "catégorielle": ("catégoriel",),
    "catégorielles": ("catégoriel",),
    "catégoriel": ("catégoriel",),
    "catégoriels": ("catégoriel",),
    "catégorique": ("catégorique",),
    "catégoriques": ("catégorique",),
    "caténaire": ("caténaire",),
    "caténaires": ("caténaire",),
    "cathare": ("cathare",),
    "cathares": ("cathare",),
    "cathartique": ("cathartique",),
    "cathartiques": ("cathartique",),
    "cathédrale": ("cathédral",),
    "cathédrales": ("cathédral",),
    "cathédral": ("cathédral",),
    "cathédraux": ("cathédral",),
    "catho": ("catho",),
    "cathos": ("catho",),
    "cathodique": ("cathodique",),
    "cathodiques": ("cathodique",),
    "catholique": ("catholique",),
    "catholiques": ("catholique",),
    "cationique": ("cationique",),
    "cationiques": ("cationique",),
    "cationotropique": ("cationotropique",),
    "cationotropiques": ("cationotropique",),
    "catiopexique": ("catiopexique",),
    "catiopexiques": ("catiopexique",),
    "catoptrique": ("catoptrique",),
    "catoptriques": ("catoptrique",),
    "caucasien": ("caucasien",),
    "caucasienne": ("caucasien",),
    "caucasiennes": ("caucasien",),
    "caucasiens": ("caucasien",),
    "caucasique": ("caucasique",),
    "caucasiques": ("caucasique",),
    "cauchemardesque": ("cauchemardesque",),
    "cauchemardesques": ("cauchemardesque",),
    "cauchemardeuse": ("cauchemardeux",),
    "cauchemardeuses": ("cauchemardeux",),
    "cauchemardeux": ("cauchemardeux",),
    "cauchoise": ("cauchois",),
    "cauchoises": ("cauchois",),
    "cauchois": ("cauchois",),
    "caudale": ("caudal",),
    "caudales": ("caudal",),
    "caudal": ("caudal",),
    "caudaux": ("caudal",),
    "caudines": ("caudines",),
    "caulinaire": ("caulinaire",),
    "caulinaires": ("caulinaire",),
    "causalgique": ("causalgique",),
    "causalgiques": ("causalgique",),
    "causaliste": ("causaliste",),
    "causalistes": ("causaliste",),
    "causatif": ("causatif",),
    "causatifs": ("causatif",),
    "causative": ("causatif",),
    "causatives": ("causatif",),
    "causeur": ("causeur",),
    "causeurs": ("causeur",),
    "causeuse": ("causeur",),
    "causeuses": ("causeur",),
    "caustique": ("caustique",),
    "caustiques": ("caustique",),
    "cauteleuse": ("cauteleux",),
    "cauteleuses": ("cauteleux",),
    "cauteleux": ("cauteleux",),
    "cavaleur": ("cavaleur",),
    "cavaleurs": ("cavaleur",),
    "cavaleuse": ("cavaleur",),
    "cavaleuses": ("cavaleur",),
    "cavalière": ("cavalier",),
    "cavalières": ("cavalier",),
    "cavalier": ("cavalier",),
    "cavaliers": ("cavalier",),
    "cave": ("cave",),
    "caves": ("cave",),
    "caverneuse": ("caverneux",),
    "caverneuses": ("caverneux",),
    "caverneux": ("caverneux",),
    "cavernicole": ("cavernicole",),
    "cavernicoles": ("cavernicole",),
    "cavicorne": ("cavicorne",),
    "cavicornes": ("cavicorne",),
    "cavitaire": ("cavitaire",),
    "cavitaires": ("cavitaire",),
    "cavographique": ("cavographique",),
    "cavographiques": ("cavographique",),
    "cavopulmonaire": ("cavopulmonaire",),
    "cavopulmonaires": ("cavopulmonaire",),
    "cawcher": ("cawcher",),
    "cédétiste": ("cédétiste",),
    "cédétistes": ("cédétiste",),
    "cédulaire": ("cédulaire",),
    "cédulaires": ("cédulaire",),
    "cégésimale": ("cégésimal",),
    "cégésimales": ("cégésimal",),
    "cégésimal": ("cégésimal",),
    "cégésimaux": ("cégésimal",),
    "cégétiste": ("cégétiste",),
    "cégétistes": ("cégétiste",),
    "céladon": ("céladon",),
    "célèbre": ("célèbre",),
    "célèbres": ("célèbre",),
    "célébrissime": ("célébrissime",),
    "célébrissimes": ("célébrissime",),
    "céleste": ("céleste",),
    "célestes": ("céleste",),
    "céliaque": ("céliaque",),
    "céliaques": ("céliaque",),
    "célibataire": ("célibataire",),
    "célibataires": ("célibataire",),
    "cellulaire": ("cellulaire",),
    "cellulaires": ("cellulaire",),
    "cellulalgique": ("cellulalgique",),
    "cellulalgiques": ("cellulalgique",),
    "cellulifuge": ("cellulifuge",),
    "cellulifuges": ("cellulifuge",),
    "cellulipète": ("cellulipète",),
    "cellulipètes": ("cellulipète",),
    "celluliteuse": ("celluliteux",),
    "celluliteuses": ("celluliteux",),
    "celluliteux": ("celluliteux",),
    "cellulitique": ("cellulitique",),
    "cellulitiques": ("cellulitique",),
    "celluloïdique": ("celluloïdique",),
    "celluloïdiques": ("celluloïdique",),
    "cellulolympathique": ("cellulolympathique",),
    "cellulolympathiques": ("cellulolympathique",),
    "cellulolymphatique": ("cellulolymphatique",),
    "cellulolymphatiques": ("cellulolymphatique",),
    "cellulosique": ("cellulosique",),
    "cellulosiques": ("cellulosique",),
    "celte": ("celte",),
    "celtes": ("celte",),
    "celtique": ("celtique",),
    "celtiques": ("celtique",),
    "cémenteuse": ("cémenteux",),
    "cémenteuses": ("cémenteux",),
    "cémenteux": ("cémenteux",),
    "cendreuse": ("cendreux",),
    "cendreuses": ("cendreux",),
    "cendreux": ("cendreux",),
    "cénesthésique": ("cénesthésique",),
    "cénesthésiques": ("cénesthésique",),
    "cénobitique": ("cénobitique",),
    "cénobitiques": ("cénobitique",),
    "cénogénétique": ("cénogénétique",),
    "cénogénétiques": ("cénogénétique",),
    "cénozoïque": ("cénozoïque",),
    "cénozoïques": ("cénozoïque",),
    "censière": ("censier",),
    "censières": ("censier",),
    "censier": ("censier",),
    "censiers": ("censier",),
    "censitaire": ("censitaire",),
    "censitaires": ("censitaire",),
    "censoriale": ("censorial",),
    "censoriales": ("censorial",),
    "censorial": ("censorial",),
    "censoriaux": ("censorial",),
    "censuelle": ("censuel",),
    "censuelles": ("censuel",),
    "censuel": ("censuel",),
    "censuels": ("censuel",),
    "censurable": ("censurable",),
    "censurables": ("censurable",),
    "centenaire": ("centenaire",),
    "centenaires": ("centenaire",),
    "centennale": ("centennal",),
    "centennales": ("centennal",),
    "centennal": ("centennal",),
    "centennaux": ("centennal",),
    "centésimale": ("centésimal",),
    "centésimales": ("centésimal",),
    "centésimal": ("centésimal",),
    "centésimaux": ("centésimal",),
    "centième": ("centième",),
    "centièmes": ("centième",),
    "centigrade": ("centigrade",),
    "centigrades": ("centigrade",),
    "centimétrique": ("centimétrique",),
    "centimétriques": ("centimétrique",),
    "centinormale": ("centinormal",),
    "centinormales": ("centinormal",),
    "centinormal": ("centinormal",),
    "centinormaux": ("centinormal",),
    "centrale": ("central",),
    "centrales": ("central",),
    "central": ("central",),
    "centraux": ("central",),
    "centralisateur": ("centralisateur",),
    "centralisateurs": ("centralisateur",),
    "centralisatrice": ("centralisateur",),
    "centralisatrices": ("centralisateur",),
    "centraliste": ("centraliste",),
    "centralistes": ("centraliste",),
    "centre-africaines": ("centre-africain",),
    "centre-européen": ("centre-européen",),
    "centre-européenne": ("centre-européen",),
    "centrencéphalique": ("centrencéphalique",),
    "centrencéphaliques": ("centrencéphalique",),
    "centrifuge": ("centrifuge",),
    "centrifuges": ("centrifuge",),
    "centripète": ("centripète",),
    "centripètes": ("centripète",),
    "centriste": ("centriste",),
    "centristes": ("centriste",),
    "centroacinaire": ("centroacinaire",),
    "centroacinaires": ("centroacinaire",),
    "centrolobulaire": ("centrolobulaire",),
    "centrolobulaires": ("centrolobulaire",),
    "centromédullaire": ("centromédullaire",),
    "centromédullaires": ("centromédullaire",),
    "centronucléaire": ("centronucléaire",),
    "centronucléaires": ("centronucléaire",),
    "centuple": ("centuple",),
    "centuples": ("centuple",),
    "céphalalgique": ("céphalalgique",),
    "céphalalgiques": ("céphalalgique",),
    "céphalique": ("céphalique",),
    "céphaliques": ("céphalique",),
    "céphalogyre": ("céphalogyre",),
    "céphalogyres": ("céphalogyre",),
    "céphalométrique": ("céphalométrique",),
    "céphalométriques": ("céphalométrique",),
    "céphalo-rachidien": ("céphalo-rachidien",),
    "céphalorachidien": ("céphalorachidien",),
    "céphalo-rachidienne": ("céphalo-rachidien",),
    "céphalorachidienne": ("céphalorachidien",),
    "céphalorachidiennes": ("céphalorachidien",),
    "céphalorachidiens": ("céphalorachidien",),
    "cérame": ("cérame",),
    "cérames": ("cérame",),
    "céramique": ("céramique",),
    "céramiques": ("céramique",),
    "céramiste": ("céramiste",),
    "céramistes": ("céramiste",),
    "céramométallique": ("céramométallique",),
    "céramométalliques": ("céramométallique",),
    "céramoplastique": ("céramoplastique",),
    "céramoplastiques": ("céramoplastique",),
    "cercale": ("cercal",),
    "cercales": ("cercal",),
    "cercal": ("cercal",),
    "cercaux": ("cercal",),
    "céréalière": ("céréalier",),
    "céréalières": ("céréalier",),
    "céréalier": ("céréalier",),
    "céréaliers": ("céréalier",),
    "cérébelleuse": ("cérébelleux",),
    "cérébelleuses": ("cérébelleux",),
    "cérébelleux": ("cérébelleux",),
    "cérébrale": ("cérébral",),
    "cérébrales": ("cérébral",),
    "cérébral": ("cérébral",),
    "cérébraux": ("cérébral",),
    "cérébroïde": ("cérébroïde",),
    "cérébroïdes": ("cérébroïde",),
    "cérébrospinale": ("cérébrospinal",),
    "cérébro-spinales": ("cérébro-spinal",),
    "cérébrospinales": ("cérébrospinal",),
    "cérébrospinal": ("cérébrospinal",),
    "cérébrospinaux": ("cérébrospinal",),
    "cérébrovasculaire": ("cérébrovasculaire",),
    "cérébrovasculaires": ("cérébrovasculaire",),
    "cérémoniale": ("cérémonial",),
    "cérémoniales": ("cérémonial",),
    "cérémonial": ("cérémonial",),
    "cérémoniaux": ("cérémonial",),
    "cérémonielle": ("cérémoniel",),
    "cérémonielles": ("cérémoniel",),
    "cérémoniel": ("cérémoniel",),
    "cérémoniels": ("cérémoniel",),
    "cérémonieuse": ("cérémonieux",),
    "cérémonieuses": ("cérémonieux",),
    "cérémonieux": ("cérémonieux",),
    "céreuse": ("céreux",),
    "céreuses": ("céreux",),
    "céreux": ("céreux",),
    "cérifère": ("cérifère",),
    "cérifères": ("cérifère",),
    "cérigène": ("cérigène",),
    "cérigènes": ("cérigène",),
    "cérique": ("cérique",),
    "cériques": ("cérique",),
    "cerise": ("cerise",),
    "cernable": ("cernable",),
    "cernables": ("cernable",),
    "cérotique": ("cérotique",),
    "cérotiques": ("cérotique",),
    "certificateur": ("certificateur",),
    "certificateurs": ("certificateur",),
    "certificatrice": ("certificateur",),
    "certificatrices": ("certificateur",),
    "certificatif": ("certificatif",),
    "certificatifs": ("certificatif",),
    "certificative": ("certificatif",),
    "certificatives": ("certificatif",),
    "céruléen": ("céruléen",),
    "céruléenne": ("céruléen",),
    "céruléennes": ("céruléen",),
    "céruléens": ("céruléen",),
    "cérumineuse": ("cérumineux",),
    "cérumineuses": ("cérumineux",),
    "cérumineux": ("cérumineux",),
    "cerve": ("cerve",),
    "cerves": ("cerve",),
    "cervicale": ("cervical",),
    "cervicales": ("cervical",),
    "cervical": ("cervical",),
    "cervicaux": ("cervical",),
    "cervicobrachiale": ("cervicobrachial",),
    "cervicobrachiales": ("cervicobrachial",),
    "cervicobrachial": ("cervicobrachial",),
    "cervicobrachiaux": ("cervicobrachial",),
    "cervier": ("cervier",),
    "cerviers": ("cervier",),
    "cérylique": ("cérylique",),
    "céryliques": ("cérylique",),
    "césarien": ("césarien",),
    "césarienne": ("césarien",),
    "césariennes": ("césarien",),
    "césariens": ("césarien",),
    "césaropapiste": ("césaropapiste",),
    "césaropapistes": ("césaropapiste",),
    "cespiteuse": ("cespiteux",),
    "cespiteuses": ("cespiteux",),
    "cespiteux": ("cespiteux",),
    "cessible": ("cessible",),
    "cessibles": ("cessible",),
    "cétogène": ("cétogène",),
    "cétogènes": ("cétogène",),
    "cétoglutarique": ("cétoglutarique",),
    "cétoglutariques": ("cétoglutarique",),
    "cétolytique": ("cétolytique",),
    "cétolytiques": ("cétolytique",),
    "cétonique": ("cétonique",),
    "cétoniques": ("cétonique",),
    "ceylanaise": ("ceylanais",),
    "ceylanaises": ("ceylanais",),
    "ceylanais": ("ceylanais",),
    "cézannien": ("cézannien",),
    "cézannienne": ("cézannien",),
    "cézanniennes": ("cézannien",),
    "cézanniens": ("cézannien",),
    "chahuteur": ("chahuteur",),
    "chahuteurs": ("chahuteur",),
    "chahuteuse": ("chahuteur",),
    "chahuteuses": ("chahuteur",),
    "chair": ("chair",),
    "chalcographique": ("chalcographique",),
    "chalcographiques": ("chalcographique",),
    "chalcolithique": ("chalcolithique",),
    "chalcolithiques": ("chalcolithique",),
    "chaldéen": ("chaldéen",),
    "chaldéenne": ("chaldéen",),
    "chaldéennes": ("chaldéen",),
    "chaldéens": ("chaldéen",),
    "chaleureuse": ("chaleureux",),
    "chaleureuses": ("chaleureux",),
    "chaleureux": ("chaleureux",),
    "chalonnaise": ("chalonnais",),
    "chalonnaises": ("chalonnais",),
    "chalonnais": ("chalonnais",),
    "cham": ("cham",),
    "chams": ("cham",),
    "chamailleur": ("chamailleur",),
    "chamailleurs": ("chamailleur",),
    "chamailleuse": ("chamailleur",),
    "chamailleuses": ("chamailleur",),
    "chamanique": ("chamanique",),
    "chamaniques": ("chamanique",),
    "chamaniste": ("chamaniste",),
    "chamanistes": ("chamaniste",),
    "chamanistique": ("chamanistique",),
    "chamanistiques": ("chamanistique",),
    "chambriste": ("chambriste",),
    "chambristes": ("chambriste",),
    "chameau": ("chameau",),
    "chameaux": ("chameau",),
    "chamelière": ("chamelier",),
    "chamelières": ("chamelier",),
    "chamelier": ("chamelier",),
    "chameliers": ("chamelier",),
    "chamitique": ("chamitique",),
    "chamitiques": ("chamitique",),
    "chamois": ("chamois",),
    "champagne": ("champagne",),
    "champenoise": ("champenois",),
    "champenoises": ("champenois",),
    "champenois": ("champenois",),
    "champêtre": ("champêtre",),
    "champêtres": ("champêtre",),
    "champi": ("champi",),
    "champis": ("champis",),
    "champisse": ("champis",),
    "champisses": ("champis",),
    "champignonneuse": ("champignonneux",),
    "champignonneuses": ("champignonneux",),
    "champignonneux": ("champignonneux",),
    "champion": ("champion",),
    "championne": ("champion",),
    "championnes": ("champion",),
    "champions": ("champion",),
    "chan": ("chan",),
    "chans": ("chan",),
    "chanceuse": ("chanceux",),
    "chanceuses": ("chanceux",),
    "chanceux": ("chanceux",),
    "chancrelleuse": ("chancrelleux",),
    "chancrelleuses": ("chancrelleux",),
    "chancrelleux": ("chancrelleux",),
    "chancreuse": ("chancreux",),
    "chancreuses": ("chancreux",),
    "chancreux": ("chancreux",),
    "chandlérien": ("chandlérien",),
    "chandlérienne": ("chandlérien",),
    "chandlériennes": ("chandlérien",),
    "chandlériens": ("chandlérien",),
    "changeable": ("changeable",),
    "changeables": ("changeable",),
    "chansonnière": ("chansonnier",),
    "chansonnières": ("chansonnier",),
    "chansonnier": ("chansonnier",),
    "chansonniers": ("chansonnier",),
    "chantable": ("chantable",),
    "chantables": ("chantable",),
    "chantilly": ("chantilly",),
    "chanvreuse": ("chanvreux",),
    "chanvreuses": ("chanvreux",),
    "chanvreux": ("chanvreux",),
    "chanvrière": ("chanvrier",),
    "chanvrières": ("chanvrier",),
    "chanvrier": ("chanvrier",),
    "chanvriers": ("chanvrier",),
    "chaotique": ("chaotique",),
    "chaotiques": ("chaotique",),
    "chapardeur": ("chapardeur",),
    "chapardeurs": ("chapardeur",),
    "chapardeuse": ("chapardeur",),
    "chapardeuses": ("chapardeur",),
    "chapelière": ("chapelier",),
    "chapelières": ("chapelier",),
    "chapelier": ("chapelier",),
    "chapeliers": ("chapelier",),
    "chaperonnière": ("chaperonnier",),
    "chaperonnières": ("chaperonnier",),
    "chaperonnier": ("chaperonnier",),
    "chaperonniers": ("chaperonnier",),
    "chapitrale": ("chapitral",),
    "chapitrales": ("chapitral",),
    "chapitral": ("chapitral",),
    "chapitraux": ("chapitral",),
    "chaplinesque": ("chaplinesque",),
    "chaplinesques": ("chaplinesque",),
    "charbonneuse": ("charbonneux",),
    "charbonneuses": ("charbonneux",),
    "charbonneux": ("charbonneux",),
    "charbonnière": ("charbonnier",),
    "charbonnières": ("charbonnier",),
    "charbonnier": ("charbonnier",),
    "charbonniers": ("charbonnier",),
    "charcutière": ("charcutier",),
    "charcutières": ("charcutier",),
    "charcutier": ("charcutier",),
    "charcutiers": ("charcutier",),
    "charentaise": ("charentais",),
    "charentaises": ("charentais",),
    "charentais": ("charentais",),
    "chargeable": ("chargeable",),
    "chargeables": ("chargeable",),
    "charien": ("charien",),
    "charienne": ("charien",),
    "chariennes": ("charien",),
    "chariens": ("charien",),
    "charismatique": ("charismatique",),
    "charismatiques": ("charismatique",),
    "charitable": ("charitable",),
    "charitables": ("charitable",),
    "charlatan": ("charlatan",),
    "charlatans": ("charlatan",),
    "charlatanesque": ("charlatanesque",),
    "charlatanesques": ("charlatanesque",),
    "charmeur": ("charmeur",),
    "charmeurs": ("charmeur",),
    "charmeuse": ("charmeur",),
    "charmeuses": ("charmeur",),
    "charnelle": ("charnel",),
    "charnelles": ("charnel",),
    "charnel": ("charnel",),
    "charnels": ("charnel",),
    "charnockitique": ("charnockitique",),
    "charnockitiques": ("charnockitique",),
    "charolaise": ("charolais",),
    "charolaises": ("charolais",),
    "charolais": ("charolais",),
    "charollaise": ("charollais",),
    "charollaises": ("charollais",),
    "charollais": ("charollais",),
    "charpentière": ("charpentier",),
    "charpentières": ("charpentier",),
    "charpentier": ("charpentier",),
    "charpentiers": ("charpentier",),
    "charretière": ("charretier",),
    "charretières": ("charretier",),
    "charretier": ("charretier",),
    "charretiers": ("charretier",),
    "charriable": ("charriable",),
    "charriables": ("charriable",),
    "chartiste": ("chartiste",),
    "chartistes": ("chartiste",),
    "chartreuse": ("chartreux",),
    "chartreuses": ("chartreux",),
    "chartreux": ("chartreux",),
    "chassable": ("chassable",),
    "chassables": ("chassable",),
    "chasséen": ("chasséen",),
    "chasséenne": ("chasséen",),
    "chasséennes": ("chasséen",),
    "chasséens": ("chasséen",),
    "chasseresse": ("chasseresse",),
    "chasseresses": ("chasseresse",),
    "chasseur": ("chasseur",),
    "chasseurs": ("chasseur",),
    "chasseuse": ("chasseur",),
    "chasseuses": ("chasseur",),
    "chassieuse": ("chassieux",),
    "chassieuses": ("chassieux",),
    "chassieux": ("chassieux",),
    "chaste": ("chaste",),
    "chastes": ("chaste",),
    "chat": ("chat",),
    "chats": ("chat",),
    "chatte": ("chat",),
    "chattes": ("chat",),
    "châtelperronien": ("châtelperronien",),
    "châtelperronienne": ("châtelperronien",),
    "châtelperroniennes": ("châtelperronien",),
    "châtelperroniens": ("châtelperronien",),
    "chatouilleur": ("chatouilleur",),
    "chatouilleurs": ("chatouilleur",),
    "chatouilleuse": ("chatouilleux",),
    "chatouilleuses": ("chatouilleux",),
    "chatouilleux": ("chatouilleux",),
    "chaudefonnière": ("chaudefonnier",),
    "chaudefonnières": ("chaudefonnier",),
    "chaudefonnier": ("chaudefonnier",),
    "chaudefonniers": ("chaudefonnier",),
    "chaudronnière": ("chaudronnier",),
    "chaudronnières": ("chaudronnier",),
    "chaudronnier": ("chaudronnier",),
    "chaudronniers": ("chaudronnier",),
    "chauffable": ("chauffable",),
    "chauffables": ("chauffable",),
    "chauffeur": ("chauffeur",),
    "chauffeurs": ("chauffeur",),
    "chauffeuse": ("chauffeur",),
    "chauffeuses": ("chauffeur",),
    "chaulmoogrique": ("chaulmoogrique",),
    "chaulmoogriques": ("chaulmoogrique",),
    "chauve": ("chauve",),
    "chauves": ("chauve",),
    "chauviniste": ("chauviniste",),
    "chauvinistes": ("chauviniste",),
    "chavirable": ("chavirable",),
    "chavirables": ("chavirable",),
    "cheap": ("cheap",),
    "cheiro-oral": ("cheiro-oral",),
    "cheiro-oraux": ("cheiro-oral",),
    "cheiropodale": ("cheiropodal",),
    "cheiropodales": ("cheiropodal",),
    "cheiropodal": ("cheiropodal",),
    "cheiropodaux": ("cheiropodal",),
    "chélate": ("chélate",),
    "chélates": ("chélate",),
    "chelem": ("chelem",),
    "chélidonique": ("chélidonique",),
    "chélidoniques": ("chélidonique",),
    "chelléen": ("chelléen",),
    "chelléenne": ("chelléen",),
    "chelléennes": ("chelléen",),
    "chelléens": ("chelléen",),
    "chéloïde": ("chéloïde",),
    "chéloïdes": ("chéloïde",),
    "chéloïdien": ("chéloïdien",),
    "chéloïdienne": ("chéloïdien",),
    "chéloïdiennes": ("chéloïdien",),
    "chéloïdiens": ("chéloïdien",),
    "chémocepteur": ("chémocepteur",),
    "chémocepteurs": ("chémocepteur",),
    "chémoceptrice": ("chémocepteur",),
    "chémoceptrices": ("chémocepteur",),
    "chémorécepteur": ("chémorécepteur",),
    "chémorécepteurs": ("chémorécepteur",),
    "chémoréceptrice": ("chémorécepteur",),
    "chémoréceptrices": ("chémorécepteur",),
    "chémosensible": ("chémosensible",),
    "chémosensibles": ("chémosensible",),
    "chémotactique": ("chémotactique",),
    "chémotactiques": ("chémotactique",),
    "chémotique": ("chémotique",),
    "chémotiques": ("chémotique",),
    "chénodésoxycholique": ("chénodésoxycholique",),
    "chénodésoxycholiques": ("chénodésoxycholique",),
    "chère": ("cher",),
    "chères": ("cher",),
    "cher": ("cher",),
    "chers": ("cher",),
    "cherbourgeoise": ("cherbourgeois",),
    "cherbourgeoises": ("cherbourgeois",),
    "cherbourgeois": ("cherbourgeois",),
    "chercheur": ("chercheur",),
    "chercheurs": ("chercheur",),
    "chercheuse": ("chercheur",),
    "chercheuses": ("chercheur",),
    "chérifien": ("chérifien",),
    "chérifienne": ("chérifien",),
    "chérifiennes": ("chérifien",),
    "chérifiens": ("chérifien",),
    "chérissable": ("chérissable",),
    "chérissables": ("chérissable",),
    "chérot": ("chérot",),
    "chétif": ("chétif",),
    "chétifs": ("chétif",),
    "chétive": ("chétif",),
    "chétives": ("chétif",),
    "chevaleresque": ("chevaleresque",),
    "chevaleresques": ("chevaleresque",),
    "chiadeur": ("chiadeur",),
    "chiadeurs": ("chiadeur",),
    "chiadeuse": ("chiadeur",),
    "chiadeuses": ("chiadeur",),
    "chialeur": ("chialeur",),
    "chialeurs": ("chialeur",),
    "chialeuse": ("chialeur",),
    "chialeuses": ("chialeur",),
    "chiasmatique": ("chiasmatique",),
    "chiasmatiques": ("chiasmatique",),
    "chic": ("chic",),
    "chics": ("chic",),
    "chicaneur": ("chicaneur",),
    "chicaneurs": ("chicaneur",),
    "chicaneuse": ("chicaneur",),
    "chicaneuses": ("chicaneur",),
    "chicanière": ("chicanier",),
    "chicanières": ("chicanier",),
    "chicanier": ("chicanier",),
    "chicaniers": ("chicanier",),
    "chicano": ("chicano",),
    "chicanos": ("chicano",),
    "chiche": ("chiche",),
    "chiches": ("chiche",),
    "chichiteuse": ("chichiteux",),
    "chichiteuses": ("chichiteux",),
    "chichiteux": ("chichiteux",),
    "chien": ("chien",),
    "chienne": ("chien",),
    "chiennes": ("chien",),
    "chiens": ("chien",),
    "chiffonnable": ("chiffonnable",),
    "chiffonnables": ("chiffonnable",),
    "chiffonnière": ("chiffonnière",),
    "chiffonnières": ("chiffonnière",),
    "chiffrable": ("chiffrable",),
    "chiffrables": ("chiffrable",),
    "chiite": ("chiite",),
    "chiites": ("chiite",),
    "chiliastique": ("chiliastique",),
    "chiliastiques": ("chiliastique",),
    "chilien": ("chilien",),
    "chilienne": ("chilien",),
    "chiliennes": ("chilien",),
    "chiliens": ("chilien",),
    "chimérique": ("chimérique",),
    "chimériques": ("chimérique",),
    "chimiatrique": ("chimiatrique",),
    "chimiatriques": ("chimiatrique",),
    "chimiocepteur": ("chimiocepteur",),
    "chimiocepteurs": ("chimiocepteur",),
    "chimioceptrice": ("chimiocepteur",),
    "chimioceptrices": ("chimiocepteur",),
    "chimiorécepteur": ("chimiorécepteur",),
    "chimiorécepteurs": ("chimiorécepteur",),
    "chimioréceptrice": ("chimiorécepteur",),
    "chimioréceptrices": ("chimiorécepteur",),
    "chimiosensible": ("chimiosensible",),
    "chimiosensibles": ("chimiosensible",),
    "chimiosynthétique": ("chimiosynthétique",),
    "chimiosynthétiques": ("chimiosynthétique",),
    "chimiotactique": ("chimiotactique",),
    "chimiotactiques": ("chimiotactique",),
    "chimiothérapeutique": ("chimiothérapeutique",),
    "chimiothérapeutiques": ("chimiothérapeutique",),
    "chimiothérapique": ("chimiothérapique",),
    "chimiothérapiques": ("chimiothérapique",),
    "chimique": ("chimique",),
    "chimiques": ("chimique",),
    "chinoise": ("chinois",),
    "chinoises": ("chinois",),
    "chinois": ("chinois",),
    "chipeur": ("chipeur",),
    "chipeurs": ("chipeur",),
    "chipeuse": ("chipeur",),
    "chipeuses": ("chipeur",),
    "chipoteur": ("chipoteur",),
    "chipoteurs": ("chipoteur",),
    "chipoteuse": ("chipoteur",),
    "chipoteuses": ("chipoteur",),
    "chirale": ("chiral",),
    "chirales": ("chiral",),
    "chiral": ("chiral",),
    "chiraux": ("chiral",),
    "chirographaire": ("chirographaire",),
    "chirographaires": ("chirographaire",),
    "chirographique": ("chirographique",),
    "chirographiques": ("chirographique",),
    "chirologique": ("chirologique",),
    "chirologiques": ("chirologique",),
    "chiropodale": ("chiropodal",),
    "chiropodales": ("chiropodal",),
    "chiropodal": ("chiropodal",),
    "chiropodaux": ("chiropodal",),
    "chiropraxique": ("chiropraxique",),
    "chiropraxiques": ("chiropraxique",),
    "chirurgicale": ("chirurgical",),
    "chirurgicales": ("chirurgical",),
    "chirurgical": ("chirurgical",),
    "chirurgicaux": ("chirurgical",),
    "chitineuse": ("chitineux",),
    "chitineuses": ("chitineux",),
    "chitineux": ("chitineux",),
    "chloracétique": ("chloracétique",),
    "chloracétiques": ("chloracétique",),
    "chlorendique": ("chlorendique",),
    "chlorendiques": ("chlorendique",),
    "chloreuse": ("chloreux",),
    "chloreuses": ("chloreux",),
    "chloreux": ("chloreux",),
    "chlorhydrique": ("chlorhydrique",),
    "chlorhydriques": ("chlorhydrique",),
    "chlorique": ("chlorique",),
    "chloriques": ("chlorique",),
    "chlorocarbonique": ("chlorocarbonique",),
    "chlorocarboniques": ("chlorocarbonique",),
    "chloroformique": ("chloroformique",),
    "chloroformiques": ("chloroformique",),
    "chlorométhylique": ("chlorométhylique",),
    "chlorométhyliques": ("chlorométhylique",),
    "chlorométrique": ("chlorométrique",),
    "chlorométriques": ("chlorométrique",),
    "chlorophyllien": ("chlorophyllien",),
    "chlorophyllienne": ("chlorophyllien",),
    "chlorophylliennes": ("chlorophyllien",),
    "chlorophylliens": ("chlorophyllien",),
    "chloroplatinique": ("chloroplatinique",),
    "chloroplatiniques": ("chloroplatinique",),
    "chloroprive": ("chloroprive",),
    "chloroprives": ("chloroprive",),
    "chloropropionique": ("chloropropionique",),
    "chloropropioniques": ("chloropropionique",),
    "chlorosulfureuse": ("chlorosulfureux",),
    "chlorosulfureuses": ("chlorosulfureux",),
    "chlorosulfureux": ("chlorosulfureux",),
    "chlorosulfurique": ("chlorosulfurique",),
    "chlorosulfuriques": ("chlorosulfurique",),
    "chlorotique": ("chlorotique",),
    "chlorotiques": ("chlorotique",),
    "chnoque": ("chnoque",),
    "chnoques": ("chnoque",),
    "choanoïde": ("choanoïde",),
    "choanoïdes": ("choanoïde",),
    "chochotte": ("chochotte",),
    "chochottes": ("chochotte",),
    "chocolat": ("chocolat",),
    "chocolatière": ("chocolatier",),
    "chocolatières": ("chocolatier",),
    "chocolatier": ("chocolatier",),
    "chocolatiers": ("chocolatier",),
    "cholagogue": ("cholagogue",),
    "cholagogues": ("cholagogue",),
    "cholalique": ("cholalique",),
    "cholaliques": ("cholalique",),
    "cholécystocinétique": ("cholécystocinétique",),
    "cholécystocinétiques": ("cholécystocinétique",),
    "cholécystokinétique": ("cholécystokinétique",),
    "cholécystokinétiques": ("cholécystokinétique",),
    "cholédocien": ("cholédocien",),
    "cholédocienne": ("cholédocien",),
    "cholédociennes": ("cholédocien",),
    "cholédociens": ("cholédocien",),
    "cholédococholédocien": ("cholédococholédocien",),
    "cholédococholédocienne": ("cholédococholédocien",),
    "cholédococholédociennes": ("cholédococholédocien",),
    "cholédococholédociens": ("cholédococholédocien",),
    "cholédocojéjunale": ("cholédocojéjunal",),
    "cholédocojéjunales": ("cholédocojéjunal",),
    "cholédocojéjunal": ("cholédocojéjunal",),
    "cholédocojéjunaux": ("cholédocojéjunal",),
    "cholédoque": ("cholédoque",),
    "cholédoques": ("cholédoque",),
    "cholélitholythique": ("cholélitholythique",),
    "cholélitholythiques": ("cholélitholythique",),
    "cholépoétique": ("cholépoétique",),
    "cholépoétiques": ("cholépoétique",),
    "cholépoïétique": ("cholépoïétique",),
    "cholépoïétiques": ("cholépoïétique",),
    "cholérétique": ("cholérétique",),
    "cholérétiques": ("cholérétique",),
    "cholériforme": ("cholériforme",),
    "cholériformes": ("cholériforme",),
    "cholérique": ("cholérique",),
    "cholériques": ("cholérique",),
    "cholestatique": ("cholestatique",),
    "cholestatiques": ("cholestatique",),
    "cholestérique": ("cholestérique",),
    "cholestériques": ("cholestérique",),
    "cholestérolique": ("cholestérolique",),
    "cholestéroliques": ("cholestérolique",),
    "cholestérolytique": ("cholestérolytique",),
    "cholestérolytiques": ("cholestérolytique",),
    "cholïambique": ("cholïambique",),
    "cholïambiques": ("cholïambique",),
    "cholinergique": ("cholinergique",),
    "cholinergiques": ("cholinergique",),
    "cholinolytique": ("cholinolytique",),
    "cholinolytiques": ("cholinolytique",),
    "cholinomimétique": ("cholinomimétique",),
    "cholinomimétiques": ("cholinomimétique",),
    "cholique": ("cholique",),
    "choliques": ("cholique",),
    "cholostatique": ("cholostatique",),
    "cholostatiques": ("cholostatique",),
    "chômable": ("chômable",),
    "chômables": ("chômable",),
    "chondrale": ("chondral",),
    "chondrales": ("chondral",),
    "chondral": ("chondral",),
    "chondraux": ("chondral",),
    "chondrocostale": ("chondrocostal",),
    "chondrocostales": ("chondrocostal",),
    "chondrocostal": ("chondrocostal",),
    "chondrocostaux": ("chondrocostal",),
    "chondroïde": ("chondroïde",),
    "chondroïdes": ("chondroïde",),
    "chondrosternale": ("chondrosternal",),
    "chondrosternales": ("chondrosternal",),
    "chondrosternal": ("chondrosternal",),
    "chondrosternaux": ("chondrosternal",),
    "choquable": ("choquable",),
    "choquables": ("choquable",),
    "choragique": ("choragique",),
    "choragiques": ("choragique",),
    "chorégique": ("chorégique",),
    "chorégiques": ("chorégique",),
    "chorégraphique": ("chorégraphique",),
    "chorégraphiques": ("chorégraphique",),
    "choréiforme": ("choréiforme",),
    "choréiformes": ("choréiforme",),
    "choréique": ("choréique",),
    "choréiques": ("choréique",),
    "choréo-athétosiques": ("choréo-athétosique",),
    "choriale": ("chorial",),
    "choriales": ("chorial",),
    "chorial": ("chorial",),
    "choriaux": ("chorial",),
    "chorïambique": ("chorïambique",),
    "chorïambiques": ("chorïambique",),
    "chorionique": ("chorionique",),
    "chorioniques": ("chorionique",),
    "chorioptique": ("chorioptique",),
    "chorioptiques": ("chorioptique",),
    "choriorétinien": ("choriorétinien",),
    "choriorétinienne": ("choriorétinien",),
    "choriorétiniennes": ("choriorétinien",),
    "choriorétiniens": ("choriorétinien",),
    "chorographique": ("chorographique",),
    "chorographiques": ("chorographique",),
    "choroïde": ("choroïde",),
    "choroïdes": ("choroïde",),
    "choroïdien": ("choroïdien",),
    "choroïdienne": ("choroïdien",),
    "choroïdiennes": ("choroïdien",),
    "choroïdiens": ("choroïdien",),
    "chose": ("chose",),
    "choses": ("chose",),
    "chosiste": ("chosiste",),
    "chosistes": ("chosiste",),
    "chou": ("chou",),
    "chouette": ("chouette",),
    "chouettes": ("chouette",),
    "chrématistique": ("chrématistique",),
    "chrématistiques": ("chrématistique",),
    "chrétien": ("chrétien",),
    "chrétienne": ("chrétien",),
    "chrétiennes": ("chrétien",),
    "chrétiens": ("chrétien",),
    "chrétien-démocrate": ("chrétien-démocrate",),
    "chrétien-démocrates": ("chrétien-démocrate",),
    "chrismale": ("chrismal",),
    "chrismales": ("chrismal",),
    "chrismal": ("chrismal",),
    "chrismaux": ("chrismal",),
    "christique": ("christique",),
    "christiques": ("christique",),
    "christologique": ("christologique",),
    "christologiques": ("christologique",),
    "chromaffine": ("chromaffine",),
    "chromaffines": ("chromaffine",),
    "chromagogue": ("chromagogue",),
    "chromagogues": ("chromagogue",),
    "chromammonique": ("chromammonique",),
    "chromammoniques": ("chromammonique",),
    "chromatable": ("chromatable",),
    "chromatables": ("chromatable",),
    "chromatinien": ("chromatinien",),
    "chromatinienne": ("chromatinien",),
    "chromatiniennes": ("chromatinien",),
    "chromatiniens": ("chromatinien",),
    "chromatique": ("chromatique",),
    "chromatiques": ("chromatique",),
    "chromatographique": ("chromatographique",),
    "chromatographiques": ("chromatographique",),
    "chromeuse": ("chromeux",),
    "chromeuses": ("chromeux",),
    "chromeux": ("chromeux",),
    "chromique": ("chromique",),
    "chromiques": ("chromique",),
    "chromogène": ("chromogène",),
    "chromogènes": ("chromogène",),
    "chromophile": ("chromophile",),
    "chromophiles": ("chromophile",),
    "chromophobe": ("chromophobe",),
    "chromophobes": ("chromophobe",),
    "chromosomique": ("chromosomique",),
    "chromosomiques": ("chromosomique",),
    "chromosphérique": ("chromosphérique",),
    "chromosphériques": ("chromosphérique",),
    "chromotropique": ("chromotropique",),
    "chromotropiques": ("chromotropique",),
    "chronaxique": ("chronaxique",),
    "chronaxiques": ("chronaxique",),
    "chronique": ("chronique",),
    "chroniques": ("chronique",),
    "chronogénétique": ("chronogénétique",),
    "chronogénétiques": ("chronogénétique",),
    "chronographique": ("chronographique",),
    "chronographiques": ("chronographique",),
    "chronologique": ("chronologique",),
    "chronologiques": ("chronologique",),
    "chronométrique": ("chronométrique",),
    "chronométriques": ("chronométrique",),
    "chronophage": ("chronophage",),
    "chronophages": ("chronophage",),
    "chronophotographique": ("chronophotographique",),
    "chronophotographiques": ("chronophotographique",),
    "chronotrope": ("chronotrope",),
    "chronotropes": ("chronotrope",),
    "chrysanthémique": ("chrysanthémique",),
    "chrysanthémiques": ("chrysanthémique",),
    "chrysophanique": ("chrysophanique",),
    "chrysophaniques": ("chrysophanique",),
    "chthonien": ("chthonien",),
    "chthonienne": ("chthonien",),
    "chthoniennes": ("chthonien",),
    "chthoniens": ("chthonien",),
    "chtimi": ("chtimi",),
    "chtimis": ("chtimi",),
    "chtonien": ("chtonien",),
    "chtonienne": ("chtonien",),
    "chtoniennes": ("chtonien",),
    "chtoniens": ("chtonien",),
    "chuchoteur": ("chuchoteur",),
    "chuchoteurs": ("chuchoteur",),
    "chuchoteuse": ("chuchoteur",),
    "chuchoteuses": ("chuchoteur",),
    "churrigueresque": ("churrigueresque",),
    "churrigueresques": ("churrigueresque",),
    "chylaire": ("chylaire",),
    "chylaires": ("chylaire",),
    "chyleuse": ("chyleux",),
    "chyleuses": ("chyleux",),
    "chyleux": ("chyleux",),
    "chylifère": ("chylifère",),
    "chylifères": ("chylifère",),
    "chyliforme": ("chyliforme",),
    "chyliformes": ("chyliforme",),
    "chypriote": ("chypriote",),
    "chypriotes": ("chypriote",),
    "cibiste": ("cibiste",),
    "cibistes": ("cibiste",),
    "cicatricielle": ("cicatriciel",),
    "cicatricielles": ("cicatriciel",),
    "cicatriciel": ("cicatriciel",),
    "cicatriciels": ("cicatriciel",),
    "cicatrisable": ("cicatrisable",),
    "cicatrisables": ("cicatrisable",),
    "cicéronien": ("cicéronien",),
    "cicéronienne": ("cicéronien",),
    "cicéroniennes": ("cicéronien",),
    "cicéroniens": ("cicéronien",),
    "cidricole": ("cidricole",),
    "cidricoles": ("cidricole",),
    "ciliaire": ("ciliaire",),
    "ciliaires": ("ciliaire",),
    "cilicien": ("cilicien",),
    "cilicienne": ("cilicien",),
    "ciliciennes": ("cilicien",),
    "ciliciens": ("cilicien",),
    "cimentaire": ("cimentaire",),
    "cimentaires": ("cimentaire",),
    "cinchoméronique": ("cinchoméronique",),
    "cinchoméroniques": ("cinchoméronique",),
    "cinchoninique": ("cinchoninique",),
    "cinchoniniques": ("cinchoninique",),
    "cinchonique": ("cinchonique",),
    "cinchoniques": ("cinchonique",),
    "cinémaniaque": ("cinémaniaque",),
    "cinémaniaques": ("cinémaniaque",),
    "cinématique": ("cinématique",),
    "cinématiques": ("cinématique",),
    "cinématographique": ("cinématographique",),
    "cinématographiques": ("cinématographique",),
    "cinéolique": ("cinéolique",),
    "cinéoliques": ("cinéolique",),
    "cinéphage": ("cinéphage",),
    "cinéphages": ("cinéphage",),
    "cinéphile": ("cinéphile",),
    "cinéphiles": ("cinéphile",),
    "cinéphilique": ("cinéphilique",),
    "cinéphiliques": ("cinéphilique",),
    "cinéraire": ("cinéraire",),
    "cinéraires": ("cinéraire",),
    "cinéritique": ("cinéritique",),
    "cinéritiques": ("cinéritique",),
    "cinésiologique": ("cinésiologique",),
    "cinésiologiques": ("cinésiologique",),
    "cinesthésique": ("cinesthésique",),
    "cinesthésiques": ("cinesthésique",),
    "cinétique": ("cinétique",),
    "cinétiques": ("cinétique",),
    "cinétiste": ("cinétiste",),
    "cinétistes": ("cinétiste",),
    "cingalaise": ("cingalais",),
    "cingalaises": ("cingalais",),
    "cingalais": ("cingalais",),
    "cinghalaise": ("cinghalais",),
    "cinghalaises": ("cinghalais",),
    "cinghalais": ("cinghalais",),
    "cingulaire": ("cingulaire",),
    "cingulaires": ("cingulaire",),
    "cinnamique": ("cinnamique",),
    "cinnamiques": ("cinnamique",),
    "cinoque": ("cinoque",),
    "cinoques": ("cinoque",),
    "cinquantenaire": ("cinquantenaire",),
    "cinquantenaires": ("cinquantenaire",),
    "cinquantième": ("cinquantième",),
    "cinquantièmes": ("cinquantième",),
    "cinquième": ("cinquième",),
    "cinquièmes": ("cinquième",),
    "circadien": ("circadien",),
    "circadienne": ("circadien",),
    "circadiennes": ("circadien",),
    "circadiens": ("circadien",),
    "circalittorale": ("circalittoral",),
    "circalittorales": ("circalittoral",),
    "circalittoral": ("circalittoral",),
    "circalittoraux": ("circalittoral",),
    "circalunaire": ("circalunaire",),
    "circalunaires": ("circalunaire",),
    "circannien": ("circannien",),
    "circannienne": ("circannien",),
    "circanniennes": ("circannien",),
    "circanniens": ("circannien",),
    "circannuelle": ("circannuel",),
    "circannuelles": ("circannuel",),
    "circannuel": ("circannuel",),
    "circannuels": ("circannuel",),
    "circaseptidien": ("circaseptidien",),
    "circaseptidienne": ("circaseptidien",),
    "circaseptidiennes": ("circaseptidien",),
    "circaseptidiens": ("circaseptidien",),
    "circassien": ("circassien",),
    "circassienne": ("circassien",),
    "circassiennes": ("circassien",),
    "circassiens": ("circassien",),
    "circatidale": ("circatidal",),
    "circatidales": ("circatidal",),
    "circatidal": ("circatidal",),
    "circatidaux": ("circatidal",),
    "circatrigintidien": ("circatrigintidien",),
    "circatrigintidienne": ("circatrigintidien",),
    "circatrigintidiennes": ("circatrigintidien",),
    "circatrigintidiens": ("circatrigintidien",),
    "circavigintidien": ("circavigintidien",),
    "circavigintidienne": ("circavigintidien",),
    "circavigintidiennes": ("circavigintidien",),
    "circavigintidiens": ("circavigintidien",),
    "circompolaire": ("circompolaire",),
    "circompolaires": ("circompolaire",),
    "circoncise": ("circoncis",),
    "circoncises": ("circoncis",),
    "circoncis": ("circoncis",),
    "circonférentielle": ("circonférentiel",),
    "circonférentielles": ("circonférentiel",),
    "circonférentiel": ("circonférentiel",),
    "circonférentiels": ("circonférentiel",),
    "circonflexe": ("circonflexe",),
    "circonflexes": ("circonflexe",),
    "circonscriptible": ("circonscriptible",),
    "circonscriptibles": ("circonscriptible",),
    "circonscriptionnaire": ("circonscriptionnaire",),
    "circonscriptionnaires": ("circonscriptionnaire",),
    "circonstancielle": ("circonstanciel",),
    "circonstancielles": ("circonstanciel",),
    "circonstanciel": ("circonstanciel",),
    "circonstanciels": ("circonstanciel",),
    "circonvolutif": ("circonvolutif",),
    "circonvolutifs": ("circonvolutif",),
    "circonvolutive": ("circonvolutif",),
    "circonvolutives": ("circonvolutif",),
    "circulaire": ("circulaire",),
    "circulaires": ("circulaire",),
    "circulatoire": ("circulatoire",),
    "circulatoires": ("circulatoire",),
    "circumantarctique": ("circumantarctique",),
    "circumantarctiques": ("circumantarctique",),
    "circumlunaire": ("circumlunaire",),
    "circumlunaires": ("circumlunaire",),
    "circumpilaire": ("circumpilaire",),
    "circumpilaires": ("circumpilaire",),
    "circumpolaire": ("circumpolaire",),
    "circumpolaires": ("circumpolaire",),
    "circumstellaire": ("circumstellaire",),
    "circumstellaires": ("circumstellaire",),
    "circumterrestre": ("circumterrestre",),
    "circumterrestres": ("circumterrestre",),
    "circumzénithale": ("circumzénithal",),
    "circumzénithales": ("circumzénithal",),
    "circumzénithal": ("circumzénithal",),
    "circumzénithaux": ("circumzénithal",),
    "cireuse": ("cireux",),
    "cireuses": ("cireux",),
    "cireux": ("cireux",),
    "cirière": ("cirier",),
    "cirières": ("cirier",),
    "cirier": ("cirier",),
    "ciriers": ("cirier",),
    "cirreuse": ("cirreux",),
    "cirreuses": ("cirreux",),
    "cirreux": ("cirreux",),
    "cirrhogène": ("cirrhogène",),
    "cirrhogènes": ("cirrhogène",),
    "cirrhotique": ("cirrhotique",),
    "cirrhotiques": ("cirrhotique",),
    "cirsoïde": ("cirsoïde",),
    "cirsoïdes": ("cirsoïde",),
    "ciselière": ("ciselier",),
    "ciselières": ("ciselier",),
    "ciselier": ("ciselier",),
    "ciseliers": ("ciselier",),
    "cisjordanien": ("cisjordanien",),
    "cisjordanienne": ("cisjordanien",),
    "cisjordaniennes": ("cisjordanien",),
    "cisjordaniens": ("cisjordanien",),
    "cissoïdale": ("cissoïdal",),
    "cissoïdales": ("cissoïdal",),
    "cissoïdal": ("cissoïdal",),
    "cissoïdaux": ("cissoïdal",),
    "cistercien": ("cistercien",),
    "cistercienne": ("cistercien",),
    "cisterciennes": ("cistercien",),
    "cisterciens": ("cistercien",),
    "cisternale": ("cisternal",),
    "cisternales": ("cisternal",),
    "cisternal": ("cisternal",),
    "cisternaux": ("cisternal",),
    "citable": ("citable",),
    "citables": ("citable",),
    "citateur": ("citateur",),
    "citateurs": ("citateur",),
    "citatrice": ("citateur",),
    "citatrices": ("citateur",),
    "citoyen": ("citoyen",),
    "citoyenne": ("citoyen",),
    "citoyennes": ("citoyen",),
    "citoyens": ("citoyen",),
    "citraconique": ("citraconique",),
    "citraconiques": ("citraconique",),
    "citrique": ("citrique",),
    "citriques": ("citrique",),
    "citron": ("citron",),
    "çivaïte": ("çivaïte",),
    "çivaïtes": ("çivaïte",),
    "civilisable": ("civilisable",),
    "civilisables": ("civilisable",),
    "civilisateur": ("civilisateur",),
    "civilisateurs": ("civilisateur",),
    "civilisatrice": ("civilisateur",),
    "civilisatrices": ("civilisateur",),
    "civilisationnelle": ("civilisationnel",),
    "civilisationnelles": ("civilisationnel",),
    "civilisationnel": ("civilisationnel",),
    "civilisationnels": ("civilisationnel",),
    "civique": ("civique",),
    "civiques": ("civique",),
    "clactonien": ("clactonien",),
    "clactonienne": ("clactonien",),
    "clactoniennes": ("clactonien",),
    "clactoniens": ("clactonien",),
    "cladistique": ("cladistique",),
    "cladistiques": ("cladistique",),
    "clairet": ("clairet",),
    "clairets": ("clairet",),
    "clairette": ("clairet",),
    "clairettes": ("clairet",),
    "clangoreuse": ("clangoreux",),
    "clangoreuses": ("clangoreux",),
    "clangoreux": ("clangoreux",),
    "clanique": ("clanique",),
    "claniques": ("clanique",),
    "claniste": ("claniste",),
    "clanistes": ("claniste",),
    "clapoteuse": ("clapoteux",),
    "clapoteuses": ("clapoteux",),
    "clapoteux": ("clapoteux",),
    "clarificateur": ("clarificateur",),
    "clarificateurs": ("clarificateur",),
    "clarificatrice": ("clarificateur",),
    "clarificatrices": ("clarificateur",),
    "clasmocytaire": ("clasmocytaire",),
    "clasmocytaires": ("clasmocytaire",),
    "classable": ("classable",),
    "classables": ("classable",),
    "classée": ("classé",),
    "classées": ("classé",),
    "classé": ("classé",),
    "classe": ("classe",),
    "classés": ("classé",),
    "classificateur": ("classificateur",),
    "classificateurs": ("classificateur",),
    "classificatrice": ("classificateur",),
    "classificatrices": ("classificateur",),
    "classificatoire": ("classificatoire",),
    "classificatoires": ("classificatoire",),
    "classique": ("classique",),
    "classiques": ("classique",),
    "clastique": ("clastique",),
    "clastiques": ("clastique",),
    "clastogène": ("clastogène",),
    "clastogènes": ("clastogène",),
    "claudélien": ("claudélien",),
    "claudélienne": ("claudélien",),
    "claudéliennes": ("claudélien",),
    "claudéliens": ("claudélien",),
    "claudien": ("claudien",),
    "claudienne": ("claudien",),
    "claudiennes": ("claudien",),
    "claudiens": ("claudien",),
    "claustrale": ("claustral",),
    "claustrales": ("claustral",),
    "claustral": ("claustral",),
    "claustraux": ("claustral",),
    "claustrophobe": ("claustrophobe",),
    "claustrophobes": ("claustrophobe",),
    "claustrophobique": ("claustrophobique",),
    "claustrophobiques": ("claustrophobique",),
    "claveleuse": ("claveleux",),
    "claveleuses": ("claveleux",),
    "claveleux": ("claveleux",),
    "claviculaire": ("claviculaire",),
    "claviculaires": ("claviculaire",),
    "clé": ("clé",),
    "cleptomane": ("cleptomane",),
    "cleptomanes": ("cleptomane",),
    "cléricale": ("clérical",),
    "cléricales": ("clérical",),
    "clérical": ("clérical",),
    "cléricaux": ("clérical",),
    "clicheur": ("clicheur",),
    "clicheurs": ("clicheur",),
    "clicheuse": ("clicheur",),
    "clicheuses": ("clicheur",),
    "clientélaire": ("clientélaire",),
    "clientélaires": ("clientélaire",),
    "clientéliste": ("clientéliste",),
    "clientélistes": ("clientéliste",),
    "climatérique": ("climatérique",),
    "climatériques": ("climatérique",),
    "climatique": ("climatique",),
    "climatiques": ("climatique",),
    "climatiseur": ("climatiseur",),
    "climatiseurs": ("climatiseur",),
    "climatiseuse": ("climatiseur",),
    "climatiseuses": ("climatiseur",),
    "climatologique": ("climatologique",),
    "climatologiques": ("climatologique",),
    "climatothérapique": ("climatothérapique",),
    "climatothérapiques": ("climatothérapique",),
    "clinale": ("clinal",),
    "clinales": ("clinal",),
    "clinal": ("clinal",),
    "clinaux": ("clinal",),
    "clinicien": ("clinicien",),
    "clinicienne": ("clinicien",),
    "cliniciennes": ("clinicien",),
    "cliniciens": ("clinicien",),
    "clinique": ("clinique",),
    "cliniques": ("clinique",),
    "clinographique": ("clinographique",),
    "clinographiques": ("clinographique",),
    "clinoïde": ("clinoïde",),
    "clinoïdes": ("clinoïde",),
    "clinorhombique": ("clinorhombique",),
    "clinorhombiques": ("clinorhombique",),
    "clinostatique": ("clinostatique",),
    "clinostatiques": ("clinostatique",),
    "cliquable": ("cliquable",),
    "cliquables": ("cliquable",),
    "clitique": ("clitique",),
    "clitiques": ("clitique",),
    "clitoridien": ("clitoridien",),
    "clitoridienne": ("clitoridien",),
    "clitoridiennes": ("clitoridien",),
    "clitoridiens": ("clitoridien",),
    "clitreuse": ("clitreux",),
    "clitreuses": ("clitreux",),
    "clitreux": ("clitreux",),
    "clivable": ("clivable",),
    "clivables": ("clivable",),
    "cloacale": ("cloacal",),
    "cloacales": ("cloacal",),
    "cloacal": ("cloacal",),
    "cloacaux": ("cloacal",),
    "clochée": ("cloché",),
    "clochées": ("cloché",),
    "cloché": ("cloché",),
    "cloche": ("cloche",),
    "clochés": ("cloché",),
    "cloches": ("cloche",),
    "cloisonniste": ("cloisonniste",),
    "cloisonnistes": ("cloisonniste",),
    "clonale": ("clonal",),
    "clonales": ("clonal",),
    "clonal": ("clonal",),
    "clonaux": ("clonal",),
    "clonique": ("clonique",),
    "cloniques": ("clonique",),
    "clonogénique": ("clonogénique",),
    "clonogéniques": ("clonogénique",),
    "close": ("clos",),
    "closes": ("clos",),
    "clos": ("clos",),
    "clouable": ("clouable",),
    "clouables": ("clouable",),
    "clownesque": ("clownesque",),
    "clownesques": ("clownesque",),
    "clunisien": ("clunisien",),
    "clunisienne": ("clunisien",),
    "clunisiennes": ("clunisien",),
    "clunisiens": ("clunisien",),
    "coadjuteur": ("coadjuteur",),
    "coadjuteurs": ("coadjuteur",),
    "coadjutrice": ("coadjuteur",),
    "coadjutrices": ("coadjuteur",),
    "coagulable": ("coagulable",),
    "coagulables": ("coagulable",),
    "coagulateur": ("coagulateur",),
    "coagulateurs": ("coagulateur",),
    "coagulatrice": ("coagulateur",),
    "coagulatrices": ("coagulateur",),
    "coagulolytique": ("coagulolytique",),
    "coagulolytiques": ("coagulolytique",),
    "coatomique": ("coatomique",),
    "coatomiques": ("coatomique",),
    "coaxiale": ("coaxial",),
    "coaxiales": ("coaxial",),
    "coaxial": ("coaxial",),
    "coaxiaux": ("coaxial",),
    "cobalteuse": ("cobalteux",),
    "cobalteuses": ("cobalteux",),
    "cobalteux": ("cobalteux",),
    "cobaltique": ("cobaltique",),
    "cobaltiques": ("cobaltique",),
    "cocaïnique": ("cocaïnique",),
    "cocaïniques": ("cocaïnique",),
    "cocaïnomane": ("cocaïnomane",),
    "cocaïnomanes": ("cocaïnomane",),
    "cocarcinogène": ("cocarcinogène",),
    "cocarcinogènes": ("cocarcinogène",),
    "cocardière": ("cocardier",),
    "cocardières": ("cocardier",),
    "cocardier": ("cocardier",),
    "cocardiers": ("cocardier",),
    "cocasse": ("cocasse",),
    "cocasses": ("cocasse",),
    "coccygien": ("coccygien",),
    "coccygienne": ("coccygien",),
    "coccygiennes": ("coccygien",),
    "coccygiens": ("coccygien",),
    "coccypubien": ("coccypubien",),
    "coccypubienne": ("coccypubien",),
    "coccypubiennes": ("coccypubien",),
    "coccypubiens": ("coccypubien",),
    "cochère": ("cochère",),
    "cochères": ("cochère",),
    "cochinchinoise": ("cochinchinois",),
    "cochinchinoises": ("cochinchinois",),
    "cochinchinois": ("cochinchinois",),
    "cochléaire": ("cochléaire",),
    "cochléaires": ("cochléaire",),
    "cochon": ("cochon",),
    "cochonne": ("cochon",),
    "cochonnes": ("cochon",),
    "cochons": ("cochon",),
    "cockney": ("cockney",),
    "coco": ("coco",),
    "cocos": ("coco",),
    "cocufiable": ("cocufiable",),
    "cocufiables": ("cocufiable",),
    "cocyclique": ("cocyclique",),
    "cocycliques": ("cocyclique",),
    "codable": ("codable",),
    "codables": ("codable",),
    "codemanderesse": ("codemandeur",),
    "codemanderesses": ("codemandeur",),
    "codemandeur": ("codemandeur",),
    "codemandeurs": ("codemandeur",),
    "codicillaire": ("codicillaire",),
    "codicillaires": ("codicillaire",),
    "codifiable": ("codifiable",),
    "codifiables": ("codifiable",),
    "codificateur": ("codificateur",),
    "codificateurs": ("codificateur",),
    "codificatrice": ("codificateur",),
    "codificatrices": ("codificateur",),
    "codifieur": ("codifieur",),
    "codifieurs": ("codifieur",),
    "codifieuse": ("codifieur",),
    "codifieuses": ("codifieur",),
    "codirecteur": ("codirecteur",),
    "codirecteurs": ("codirecteur",),
    "codirectrice": ("codirecteur",),
    "codirectrices": ("codirecteur",),
    "codonataire": ("codonataire",),
    "codonataires": ("codonataire",),
    "codonateur": ("codonateur",),
    "codonateurs": ("codonateur",),
    "codonatrice": ("codonateur",),
    "codonatrices": ("codonateur",),
    "coéchangiste": ("coéchangiste",),
    "coéchangistes": ("coéchangiste",),
    "coéditeur": ("coéditeur",),
    "coéditeurs": ("coéditeur",),
    "coéditrice": ("coéditeur",),
    "coéditrices": ("coéditeur",),
    "coeliaque": ("coeliaque",),
    "coeliaques": ("coeliaque",),
    "coelioscopique": ("coelioscopique",),
    "coelioscopiques": ("coelioscopique",),
    "coelomique": ("coelomique",),
    "coelomiques": ("coelomique",),
    "coelosomien": ("coelosomien",),
    "coelosomienne": ("coelosomien",),
    "coelosomiennes": ("coelosomien",),
    "coelosomiens": ("coelosomien",),
    "coercible": ("coercible",),
    "coercibles": ("coercible",),
    "coercitif": ("coercitif",),
    "coercitifs": ("coercitif",),
    "coercitive": ("coercitif",),
    "coercitives": ("coercitif",),
    "coéternelle": ("coéternel",),
    "coéternelles": ("coéternel",),
    "coéternel": ("coéternel",),
    "coéternels": ("coéternel",),
    "coévolutif": ("coévolutif",),
    "coévolutifs": ("coévolutif",),
    "coévolutive": ("coévolutif",),
    "coévolutives": ("coévolutif",),
    "coexécuteur": ("coexécuteur",),
    "coexécuteurs": ("coexécuteur",),
    "coexécutrice": ("coexécuteur",),
    "coexécutrices": ("coexécuteur",),
    "coextensif": ("coextensif",),
    "coextensifs": ("coextensif",),
    "coextensive": ("coextensif",),
    "coextensives": ("coextensif",),
    "cofinale": ("cofinal",),
    "cofinales": ("cofinal",),
    "cofinal": ("cofinal",),
    "cofinaux": ("cofinal",),
    "cognatique": ("cognatique",),
    "cognatiques": ("cognatique",),
    "cogneur": ("cogneur",),
    "cogneurs": ("cogneur",),
    "cogneuse": ("cogneur",),
    "cogneuses": ("cogneur",),
    "cognitif": ("cognitif",),
    "cognitifs": ("cognitif",),
    "cognitive": ("cognitif",),
    "cognitives": ("cognitif",),
    "cognitiviste": ("cognitiviste",),
    "cognitivistes": ("cognitiviste",),
    "cognoscible": ("cognoscible",),
    "cognoscibles": ("cognoscible",),
    "cohésif": ("cohésif",),
    "cohésifs": ("cohésif",),
    "cohésive": ("cohésif",),
    "cohésives": ("cohésif",),
    "cohésifère": ("cohésifère",),
    "cohésifères": ("cohésifère",),
    "coi": ("coi",),
    "cois": ("coi",),
    "coite": ("coi",),
    "coites": ("coi",),
    "coïtale": ("coïtal",),
    "coïtales": ("coïtal",),
    "coïtal": ("coïtal",),
    "coïtaux": ("coïtal",),
    "cokéfiable": ("cokéfiable",),
    "cokéfiables": ("cokéfiable",),
    "colbertiste": ("colbertiste",),
    "colbertistes": ("colbertiste",),
    "colcrete": ("colcrete",),
    "colcretes": ("colcrete",),
    "coléreuse": ("coléreux",),
    "coléreuses": ("coléreux",),
    "coléreux": ("coléreux",),
    "colérique": ("colérique",),
    "colériques": ("colérique",),
    "colibacillaire": ("colibacillaire",),
    "colibacillaires": ("colibacillaire",),
    "coliforme": ("coliforme",),
    "coliformes": ("coliforme",),
    "colinéaire": ("colinéaire",),
    "colinéaires": ("colinéaire",),
    "colique": ("colique",),
    "coliques": ("colique",),
    "colitique": ("colitique",),
    "colitiques": ("colitique",),
    "collabo": ("collabo",),
    "collabos": ("collabo",),
    "collaboratif": ("collaboratif",),
    "collaboratifs": ("collaboratif",),
    "collaborative": ("collaboratif",),
    "collaboratives": ("collaboratif",),
    "collaborationniste": ("collaborationniste",),
    "collaborationnistes": ("collaborationniste",),
    "collagénofibreuse": ("collagénofibreux",),
    "collagénofibreuses": ("collagénofibreux",),
    "collagénofibreux": ("collagénofibreux",),
    "collagénolytique": ("collagénolytique",),
    "collagénolytiques": ("collagénolytique",),
    "collatérale": ("collatéral",),
    "collatérales": ("collatéral",),
    "collatéral": ("collatéral",),
    "collatéraux": ("collatéral",),
    "collecteur": ("collecteur",),
    "collecteurs": ("collecteur",),
    "collectrice": ("collecteur",),
    "collectrices": ("collecteur",),
    "collectif": ("collectif",),
    "collectifs": ("collectif",),
    "collective": ("collectif",),
    "collectives": ("collectif",),
    "collectiviste": ("collectiviste",),
    "collectivistes": ("collectiviste",),
    "collégiale": ("collégial",),
    "collégiales": ("collégial",),
    "collégial": ("collégial",),
    "collégiaux": ("collégial",),
    "colligatif": ("colligatif",),
    "colligatifs": ("colligatif",),
    "colligative": ("colligatif",),
    "colligatives": ("colligatif",),
    "collinaire": ("collinaire",),
    "collinaires": ("collinaire",),
    "collisionnelle": ("collisionnel",),
    "collisionnelles": ("collisionnel",),
    "collisionnel": ("collisionnel",),
    "collisionnels": ("collisionnel",),
    "collocable": ("collocable",),
    "collocables": ("collocable",),
    "colloïdale": ("colloïdal",),
    "colloïdales": ("colloïdal",),
    "colloïdal": ("colloïdal",),
    "colloïdaux": ("colloïdal",),
    "colloïde": ("colloïde",),
    "colloïdes": ("colloïde",),
    "colloïdoclasique": ("colloïdoclasique",),
    "colloïdoclasiques": ("colloïdoclasique",),
    "collusoire": ("collusoire",),
    "collusoires": ("collusoire",),
    "colombien": ("colombien",),
    "colombienne": ("colombien",),
    "colombiennes": ("colombien",),
    "colombiens": ("colombien",),
    "colombophile": ("colombophile",),
    "colombophiles": ("colombophile",),
    "colongère": ("colonger",),
    "colongères": ("colonger",),
    "colonger": ("colonger",),
    "colongers": ("colonger",),
    "coloniaire": ("coloniaire",),
    "coloniaires": ("coloniaire",),
    "coloniale": ("colonial",),
    "coloniales": ("colonial",),
    "colonial": ("colonial",),
    "coloniaux": ("colonial",),
    "colonialiste": ("colonialiste",),
    "colonialistes": ("colonialiste",),
    "colonisable": ("colonisable",),
    "colonisables": ("colonisable",),
    "colonisateur": ("colonisateur",),
    "colonisateurs": ("colonisateur",),
    "colonisatrice": ("colonisateur",),
    "colonisatrices": ("colonisateur",),
    "colonnaire": ("colonnaire",),
    "colonnaires": ("colonnaire",),
    "colorable": ("colorable",),
    "colorables": ("colorable",),
    "colorectale": ("colorectal",),
    "colorectales": ("colorectal",),
    "colorectal": ("colorectal",),
    "colorectaux": ("colorectal",),
    "colorieur": ("colorieur",),
    "colorieurs": ("colorieur",),
    "colorimétrique": ("colorimétrique",),
    "colorimétriques": ("colorimétrique",),
    "colossale": ("colossal",),
    "colossales": ("colossal",),
    "colossal": ("colossal",),
    "colossaux": ("colossal",),
    "colporteur": ("colporteur",),
    "colporteurs": ("colporteur",),
    "colporteuse": ("colporteur",),
    "colporteuses": ("colporteur",),
    "colpotrope": ("colpotrope",),
    "colpotropes": ("colpotrope",),
    "columnaire": ("columnaire",),
    "columnaires": ("columnaire",),
    "comanche": ("comanche",),
    "comanches": ("comanche",),
    "comanique": ("comanique",),
    "comaniques": ("comanique",),
    "comateuse": ("comateux",),
    "comateuses": ("comateux",),
    "comateux": ("comateux",),
    "comatique": ("comatique",),
    "comatiques": ("comatique",),
    "comatogène": ("comatogène",),
    "comatogènes": ("comatogène",),
    "combatif": ("combatif",),
    "combatifs": ("combatif",),
    "combative": ("combatif",),
    "combatives": ("combatif",),
    "combientième": ("combientième",),
    "combientièmes": ("combientième",),
    "combinable": ("combinable",),
    "combinables": ("combinable",),
    "combinatoire": ("combinatoire",),
    "combinatoires": ("combinatoire",),
    "comble": ("comble",),
    "combles": ("comble",),
    "combustible": ("combustible",),
    "combustibles": ("combustible",),
    "comédien": ("comédien",),
    "comédienne": ("comédien",),
    "comédiennes": ("comédien",),
    "comédiens": ("comédien",),
    "comestible": ("comestible",),
    "comestibles": ("comestible",),
    "cométaire": ("cométaire",),
    "cométaires": ("cométaire",),
    "comiciale": ("comicial",),
    "comiciales": ("comicial",),
    "comicial": ("comicial",),
    "comiciaux": ("comicial",),
    "comique": ("comique",),
    "comiques": ("comique",),
    "comitiale": ("comitial",),
    "comitiales": ("comitial",),
    "comitial": ("comitial",),
    "comitiaux": ("comitial",),
    "commanditaire": ("commanditaire",),
    "commanditaires": ("commanditaire",),
    "commémorable": ("commémorable",),
    "commémorables": ("commémorable",),
    "commémoratif": ("commémoratif",),
    "commémoratifs": ("commémoratif",),
    "commémorative": ("commémoratif",),
    "commémoratives": ("commémoratif",),
    "commendataire": ("commendataire",),
    "commendataires": ("commendataire",),
    "commensale": ("commensal",),
    "commensales": ("commensal",),
    "commensal": ("commensal",),
    "commensaux": ("commensal",),
    "commensurable": ("commensurable",),
    "commensurables": ("commensurable",),
    "commerçable": ("commerçable",),
    "commerçables": ("commerçable",),
    "commerciale": ("commercial",),
    "commerciales": ("commercial",),
    "commercial": ("commercial",),
    "commerciaux": ("commercial",),
    "commercialisable": ("commercialisable",),
    "commercialisables": ("commercialisable",),
    "comminatoire": ("comminatoire",),
    "comminatoires": ("comminatoire",),
    "comminutif": ("comminutif",),
    "comminutifs": ("comminutif",),
    "comminutive": ("comminutif",),
    "comminutives": ("comminutif",),
    "commissoire": ("commissoire",),
    "commissoires": ("commissoire",),
    "commissurale": ("commissural",),
    "commissurales": ("commissural",),
    "commissural": ("commissural",),
    "commissuraux": ("commissural",),
    "commode": ("commode",),
    "commodes": ("commode",),
    "commotionnelle": ("commotionnel",),
    "commotionnelles": ("commotionnel",),
    "commotionnel": ("commotionnel",),
    "commotionnels": ("commotionnel",),
    "commuable": ("commuable",),
    "commuables": ("commuable",),
    "communale": ("communal",),
    "communales": ("communal",),
    "communal": ("communal",),
    "communaux": ("communal",),
    "communaliste": ("communaliste",),
    "communalistes": ("communaliste",),
    "communautaire": ("communautaire",),
    "communautaires": ("communautaire",),
    "communautariste": ("communautariste",),
    "communautaristes": ("communautariste",),
    "communicable": ("communicable",),
    "communicables": ("communicable",),
    "communicateur": ("communicateur",),
    "communicateurs": ("communicateur",),
    "communicatrice": ("communicateur",),
    "communicatrices": ("communicateur",),
    "communicatif": ("communicatif",),
    "communicatifs": ("communicatif",),
    "communicative": ("communicatif",),
    "communicatives": ("communicatif",),
    "communielle": ("communiel",),
    "communielles": ("communiel",),
    "communiel": ("communiel",),
    "communiels": ("communiel",),
    "communiste": ("communiste",),
    "communistes": ("communiste",),
    "commutable": ("commutable",),
    "commutables": ("commutable",),
    "commutatif": ("commutatif",),
    "commutatifs": ("commutatif",),
    "commutative": ("commutatif",),
    "commutatives": ("commutatif",),
    "comorien": ("comorien",),
    "comorienne": ("comorien",),
    "comoriennes": ("comorien",),
    "comoriens": ("comorien",),
    "compagnonnique": ("compagnonnique",),
    "compagnonniques": ("compagnonnique",),
    "comparable": ("comparable",),
    "comparables": ("comparable",),
    "comparateur": ("comparateur",),
    "comparateurs": ("comparateur",),
    "comparatrice": ("comparateur",),
    "comparatrices": ("comparateur",),
    "comparatif": ("comparatif",),
    "comparatifs": ("comparatif",),
    "comparative": ("comparatif",),
    "comparatives": ("comparatif",),
    "comparatiste": ("comparatiste",),
    "comparatistes": ("comparatiste",),
    "compartimentale": ("compartimental",),
    "compartimentales": ("compartimental",),
    "compartimental": ("compartimental",),
    "compartimentaux": ("compartimental",),
    "compassionnelle": ("compassionnel",),
    "compassionnelles": ("compassionnel",),
    "compassionnel": ("compassionnel",),
    "compassionnels": ("compassionnel",),
    "compatible": ("compatible",),
    "compatibles": ("compatible",),
    "compendieuse": ("compendieux",),
    "compendieuses": ("compendieux",),
    "compendieux": ("compendieux",),
    "compensable": ("compensable",),
    "compensables": ("compensable",),
    "compensateur": ("compensateur",),
    "compensateurs": ("compensateur",),
    "compensatrice": ("compensateur",),
    "compensatrices": ("compensateur",),
    "compensatif": ("compensatif",),
    "compensatifs": ("compensatif",),
    "compensative": ("compensatif",),
    "compensatives": ("compensatif",),
    "compensatoire": ("compensatoire",),
    "compensatoires": ("compensatoire",),
    "compétitif": ("compétitif",),
    "compétitifs": ("compétitif",),
    "compétitive": ("compétitif",),
    "compétitives": ("compétitif",),
    "compilable": ("compilable",),
    "compilables": ("compilable",),
    "complémentable": ("complémentable",),
    "complémentables": ("complémentable",),
    "complémentaire": ("complémentaire",),
    "complémentaires": ("complémentaire",),
    "complète": ("complet",),
    "complètes": ("complet",),
    "complet": ("complet",),
    "complets": ("complet",),
    "complétif": ("complétif",),
    "complétifs": ("complétif",),
    "complétive": ("complétif",),
    "complétives": ("complétif",),
    "complexée": ("complexé",),
    "complexées": ("complexé",),
    "complexé": ("complexé",),
    "complexe": ("complexe",),
    "complexés": ("complexé",),
    "complexes": ("complexe",),
    "complexométrique": ("complexométrique",),
    "complexométriques": ("complexométrique",),
    "complexuelle": ("complexuel",),
    "complexuelles": ("complexuel",),
    "complexuel": ("complexuel",),
    "complexuels": ("complexuel",),
    "complice": ("complice",),
    "complices": ("complice",),
    "complimenteur": ("complimenteur",),
    "complimenteurs": ("complimenteur",),
    "complimenteuse": ("complimenteur",),
    "complimenteuses": ("complimenteur",),
    "componentielle": ("componentiel",),
    "componentielles": ("componentiel",),
    "componentiel": ("componentiel",),
    "componentiels": ("componentiel",),
    "comportementale": ("comportemental",),
    "comportementales": ("comportemental",),
    "comportemental": ("comportemental",),
    "comportementaux": ("comportemental",),
    "comportementaliste": ("comportementaliste",),
    "comportementalistes": ("comportementaliste",),
    "composable": ("composable",),
    "composables": ("composable",),
    "composite": ("composite",),
    "composites": ("composite",),
    "compositionnelle": ("compositionnel",),
    "compositionnelles": ("compositionnel",),
    "compositionnel": ("compositionnel",),
    "compositionnels": ("compositionnel",),
    "compossible": ("compossible",),
    "compossibles": ("compossible",),
    "compound": ("compound",),
    "compradore": ("compradore",),
    "compradores": ("compradore",),
    "compréhensible": ("compréhensible",),
    "compréhensibles": ("compréhensible",),
    "compréhensif": ("compréhensif",),
    "compréhensifs": ("compréhensif",),
    "compréhensive": ("compréhensif",),
    "compréhensives": ("compréhensif",),
    "compresseur": ("compresseur",),
    "compresseurs": ("compresseur",),
    "compresseuse": ("compresseur",),
    "compresseuses": ("compresseur",),
    "compressible": ("compressible",),
    "compressibles": ("compressible",),
    "compressif": ("compressif",),
    "compressifs": ("compressif",),
    "compressive": ("compressif",),
    "compressives": ("compressif",),
    "comprimable": ("comprimable",),
    "comprimables": ("comprimable",),
    "comprise": ("compris",),
    "comprises": ("compris",),
    "compris": ("compris",),
    "compromissoire": ("compromissoire",),
    "compromissoires": ("compromissoire",),
    "comptabilisable": ("comptabilisable",),
    "comptabilisables": ("comptabilisable",),
    "comptable": ("comptable",),
    "comptables": ("comptable",),
    "comptant": ("comptant",),
    "compteur": ("compteur",),
    "compteurs": ("compteur",),
    "compteuse": ("compteur",),
    "compteuses": ("compteur",),
    "compulsif": ("compulsif",),
    "compulsifs": ("compulsif",),
    "compulsive": ("compulsif",),
    "compulsives": ("compulsif",),
    "compulsionnelle": ("compulsionnel",),
    "compulsionnelles": ("compulsionnel",),
    "compulsionnel": ("compulsionnel",),
    "compulsionnels": ("compulsionnel",),
    "computationnelle": ("computationnel",),
    "computationnelles": ("computationnel",),
    "computationnel": ("computationnel",),
    "computationnels": ("computationnel",),
    "comtale": ("comtal",),
    "comtales": ("comtal",),
    "comtal": ("comtal",),
    "comtaux": ("comtal",),
    "comtoise": ("comtois",),
    "comtoises": ("comtois",),
    "comtois": ("comtois",),
    "con": ("con",),
    "conne": ("con",),
    "connes": ("con",),
    "cons": ("con",),
    "conatif": ("conatif",),
    "conatifs": ("conatif",),
    "conative": ("conatif",),
    "conatives": ("conatif",),
    "concasseur": ("concasseur",),
    "concasseurs": ("concasseur",),
    "concasseuse": ("concasseur",),
    "concasseuses": ("concasseur",),
    "concave": ("concave",),
    "concaves": ("concave",),
    "concentrationnaire": ("concentrationnaire",),
    "concentrationnaires": ("concentrationnaire",),
    "concentrique": ("concentrique",),
    "concentriques": ("concentrique",),
    "conceptualiste": ("conceptualiste",),
    "conceptualistes": ("conceptualiste",),
    "conceptuelle": ("conceptuel",),
    "conceptuelles": ("conceptuel",),
    "conceptuel": ("conceptuel",),
    "conceptuels": ("conceptuel",),
    "concessible": ("concessible",),
    "concessibles": ("concessible",),
    "concessif": ("concessif",),
    "concessifs": ("concessif",),
    "concessive": ("concessif",),
    "concessives": ("concessif",),
    "concessionnaire": ("concessionnaire",),
    "concessionnaires": ("concessionnaire",),
    "concessionnelle": ("concessionnel",),
    "concessionnelles": ("concessionnel",),
    "concessionnel": ("concessionnel",),
    "concessionnels": ("concessionnel",),
    "concevable": ("concevable",),
    "concevables": ("concevable",),
    "conchoïdale": ("conchoïdal",),
    "conchoïdales": ("conchoïdal",),
    "conchoïdal": ("conchoïdal",),
    "conchoïdaux": ("conchoïdal",),
    "conchoïde": ("conchoïde",),
    "conchoïdes": ("conchoïde",),
    "conchylien": ("conchylien",),
    "conchylienne": ("conchylien",),
    "conchyliennes": ("conchylien",),
    "conchyliens": ("conchylien",),
    "conchyliologique": ("conchyliologique",),
    "conchyliologiques": ("conchyliologique",),
    "conciliable": ("conciliable",),
    "conciliables": ("conciliable",),
    "conciliaire": ("conciliaire",),
    "conciliaires": ("conciliaire",),
    "conciliateur": ("conciliateur",),
    "conciliateurs": ("conciliateur",),
    "conciliatrice": ("conciliateur",),
    "conciliatrices": ("conciliateur",),
    "conciliatoire": ("conciliatoire",),
    "conciliatoires": ("conciliatoire",),
    "concise": ("concis",),
    "concises": ("concis",),
    "concis": ("concis",),
    "conclusif": ("conclusif",),
    "conclusifs": ("conclusif",),
    "conclusive": ("conclusif",),
    "conclusives": ("conclusif",),
    "concordataire": ("concordataire",),
    "concordataires": ("concordataire",),
    "concordiste": ("concordiste",),
    "concordistes": ("concordiste",),
    "concrète": ("concret",),
    "concrètes": ("concret",),
    "concret": ("concret",),
    "concrets": ("concret",),
    "concrétisable": ("concrétisable",),
    "concrétisables": ("concrétisable",),
    "concupiscible": ("concupiscible",),
    "concupiscibles": ("concupiscible",),
    "concurrentielle": ("concurrentiel",),
    "concurrentielles": ("concurrentiel",),
    "concurrentiel": ("concurrentiel",),
    "concurrentiels": ("concurrentiel",),
    "concussionnaire": ("concussionnaire",),
    "concussionnaires": ("concussionnaire",),
    "condamnable": ("condamnable",),
    "condamnables": ("condamnable",),
    "condamnatoire": ("condamnatoire",),
    "condamnatoires": ("condamnatoire",),
    "condensable": ("condensable",),
    "condensables": ("condensable",),
    "condimentaire": ("condimentaire",),
    "condimentaires": ("condimentaire",),
    "conditionnelle": ("conditionnel",),
    "conditionnelles": ("conditionnel",),
    "conditionnel": ("conditionnel",),
    "conditionnels": ("conditionnel",),
    "conducteur": ("conducteur",),
    "conducteurs": ("conducteur",),
    "conductrice": ("conducteur",),
    "conductrices": ("conducteur",),
    "conductible": ("conductible",),
    "conductibles": ("conductible",),
    "conductif": ("conductif",),
    "conductifs": ("conductif",),
    "conductive": ("conductif",),
    "conductives": ("conductif",),
    "conductimétrique": ("conductimétrique",),
    "conductimétriques": ("conductimétrique",),
    "conduplicatif": ("conduplicatif",),
    "conduplicatifs": ("conduplicatif",),
    "conduplicative": ("conduplicatif",),
    "conduplicatives": ("conduplicatif",),
    "condylien": ("condylien",),
    "condylienne": ("condylien",),
    "condyliennes": ("condylien",),
    "condyliens": ("condylien",),
    "confédérale": ("confédéral",),
    "confédérales": ("confédéral",),
    "confédéral": ("confédéral",),
    "confédéraux": ("confédéral",),
    "confédérateur": ("confédérateur",),
    "confédérateurs": ("confédérateur",),
    "confédératrice": ("confédérateur",),
    "confédératrices": ("confédérateur",),
    "confessionnelle": ("confessionnel",),
    "confessionnelles": ("confessionnel",),
    "confessionnel": ("confessionnel",),
    "confessionnels": ("confessionnel",),
    "confessoire": ("confessoire",),
    "confessoires": ("confessoire",),
    "confidentielle": ("confidentiel",),
    "confidentielles": ("confidentiel",),
    "confidentiel": ("confidentiel",),
    "confidentiels": ("confidentiel",),
    "configurable": ("configurable",),
    "configurables": ("configurable",),
    "confirmatif": ("confirmatif",),
    "confirmatifs": ("confirmatif",),
    "confirmative": ("confirmatif",),
    "confirmatives": ("confirmatif",),
    "confiscable": ("confiscable",),
    "confiscables": ("confiscable",),
    "confiscatoire": ("confiscatoire",),
    "confiscatoires": ("confiscatoire",),
    "confiturière": ("confiturier",),
    "confiturières": ("confiturier",),
    "confiturier": ("confiturier",),
    "confituriers": ("confiturier",),
    "conflictuelle": ("conflictuel",),
    "conflictuelles": ("conflictuel",),
    "conflictuel": ("conflictuel",),
    "conflictuels": ("conflictuel",),
    "confocale": ("confocal",),
    "confocales": ("confocal",),
    "confocal": ("confocal",),
    "confocaux": ("confocal",),
    "conformationnelle": ("conformationnel",),
    "conformationnelles": ("conformationnel",),
    "conformationnel": ("conformationnel",),
    "conformationnels": ("conformationnel",),
    "conformée": ("conformé",),
    "conformées": ("conformé",),
    "conformé": ("conformé",),
    "conforme": ("conforme",),
    "conformés": ("conformé",),
    "conformes": ("conforme",),
    "conformiste": ("conformiste",),
    "conformistes": ("conformiste",),
    "confortable": ("confortable",),
    "confortables": ("confortable",),
    "confraternelle": ("confraternel",),
    "confraternelles": ("confraternel",),
    "confraternel": ("confraternel",),
    "confraternels": ("confraternel",),
    "confucéen": ("confucéen",),
    "confucéenne": ("confucéen",),
    "confucéennes": ("confucéen",),
    "confucéens": ("confucéen",),
    "confucianiste": ("confucianiste",),
    "confucianistes": ("confucianiste",),
    "confuse": ("confus",),
    "confuses": ("confus",),
    "confus": ("confus",),
    "confusionnelle": ("confusionnel",),
    "confusionnelles": ("confusionnel",),
    "confusionnel": ("confusionnel",),
    "confusionnels": ("confusionnel",),
    "confusionniste": ("confusionniste",),
    "confusionnistes": ("confusionniste",),
    "congéable": ("congéable",),
    "congéables": ("congéable",),
    "congédiable": ("congédiable",),
    "congédiables": ("congédiable",),
    "congelable": ("congelable",),
    "congelables": ("congelable",),
    "congénère": ("congénère",),
    "congénères": ("congénère",),
    "congénique": ("congénique",),
    "congéniques": ("congénique",),
    "congénitale": ("congénital",),
    "congénitales": ("congénital",),
    "congénital": ("congénital",),
    "congénitaux": ("congénital",),
    "congestif": ("congestif",),
    "congestifs": ("congestif",),
    "congestive": ("congestif",),
    "congestives": ("congestif",),
    "conglobata": ("conglobata",),
    "conglomérale": ("congloméral",),
    "conglomérales": ("congloméral",),
    "congloméral": ("congloméral",),
    "congloméraux": ("congloméral",),
    "conglutinatif": ("conglutinatif",),
    "conglutinatifs": ("conglutinatif",),
    "conglutinative": ("conglutinatif",),
    "conglutinatives": ("conglutinatif",),
    "congolaise": ("congolais",),
    "congolaises": ("congolais",),
    "congolais": ("congolais",),
    "congophile": ("congophile",),
    "congophiles": ("congophile",),
    "congratulatoire": ("congratulatoire",),
    "congratulatoires": ("congratulatoire",),
    "congréganiste": ("congréganiste",),
    "congréganistes": ("congréganiste",),
    "congrégationaliste": ("congrégationaliste",),
    "congrégationalistes": ("congrégationaliste",),
    "congruiste": ("congruiste",),
    "congruistes": ("congruiste",),
    "conifère": ("conifère",),
    "conifères": ("conifère",),
    "coniférylique": ("coniférylique",),
    "coniféryliques": ("coniférylique",),
    "conique": ("conique",),
    "coniques": ("conique",),
    "conirostre": ("conirostre",),
    "conirostres": ("conirostre",),
    "conjecturale": ("conjectural",),
    "conjecturales": ("conjectural",),
    "conjectural": ("conjectural",),
    "conjecturaux": ("conjectural",),
    "conjonctif": ("conjonctif",),
    "conjonctifs": ("conjonctif",),
    "conjonctive": ("conjonctif",),
    "conjonctives": ("conjonctif",),
    "conjonctionnelle": ("conjonctionnel",),
    "conjonctionnelles": ("conjonctionnel",),
    "conjonctionnel": ("conjonctionnel",),
    "conjonctionnels": ("conjonctionnel",),
    "conjonctivale": ("conjonctival",),
    "conjonctivales": ("conjonctival",),
    "conjonctival": ("conjonctival",),
    "conjonctivaux": ("conjonctival",),
    "conjoncturelle": ("conjoncturel",),
    "conjoncturelles": ("conjoncturel",),
    "conjoncturel": ("conjoncturel",),
    "conjoncturels": ("conjoncturel",),
    "conjugable": ("conjugable",),
    "conjugables": ("conjugable",),
    "conjugale": ("conjugal",),
    "conjugales": ("conjugal",),
    "conjugal": ("conjugal",),
    "conjugaux": ("conjugal",),
    "conjurateur": ("conjurateur",),
    "conjurateurs": ("conjurateur",),
    "conjuratrice": ("conjurateur",),
    "conjuratrices": ("conjurateur",),
    "conjuratoire": ("conjuratoire",),
    "conjuratoires": ("conjuratoire",),
    "connaissable": ("connaissable",),
    "connaissables": ("connaissable",),
    "connaisseur": ("connaisseur",),
    "connaisseurs": ("connaisseur",),
    "connaisseuse": ("connaisseur",),
    "connaisseuses": ("connaisseur",),
    "connaturelle": ("connaturel",),
    "connaturelles": ("connaturel",),
    "connaturel": ("connaturel",),
    "connaturels": ("connaturel",),
    "conneau": ("conneau",),
    "conneaux": ("conneau",),
    "connectable": ("connectable",),
    "connectables": ("connectable",),
    "connectif": ("connectif",),
    "connectifs": ("connectif",),
    "connective": ("connectif",),
    "connectives": ("connectif",),
    "connexe": ("connexe",),
    "connexes": ("connexe",),
    "connexionniste": ("connexionniste",),
    "connexionnistes": ("connexionniste",),
    "connotatif": ("connotatif",),
    "connotatifs": ("connotatif",),
    "connotative": ("connotatif",),
    "connotatives": ("connotatif",),
    "conoïde": ("conoïde",),
    "conoïdes": ("conoïde",),
    "conorénale": ("conorénal",),
    "conorénales": ("conorénal",),
    "conorénal": ("conorénal",),
    "conorénaux": ("conorénal",),
    "conquise": ("conquis",),
    "conquises": ("conquis",),
    "conquis": ("conquis",),
    "consciencieuse": ("consciencieux",),
    "consciencieuses": ("consciencieux",),
    "consciencieux": ("consciencieux",),
    "consécrateur": ("consécrateur",),
    "consécrateurs": ("consécrateur",),
    "consécratrice": ("consécrateur",),
    "consécratrices": ("consécrateur",),
    "consécutif": ("consécutif",),
    "consécutifs": ("consécutif",),
    "consécutive": ("consécutif",),
    "consécutives": ("consécutif",),
    "conseillable": ("conseillable",),
    "conseillables": ("conseillable",),
    "conseilliste": ("conseilliste",),
    "conseillistes": ("conseilliste",),
    "consensualiste": ("consensualiste",),
    "consensualistes": ("consensualiste",),
    "consensuelle": ("consensuel",),
    "consensuelles": ("consensuel",),
    "consensuel": ("consensuel",),
    "consensuels": ("consensuel",),
    "conservateur": ("conservateur",),
    "conservateurs": ("conservateur",),
    "conservatrice": ("conservateur",),
    "conservatrices": ("conservateur",),
    "conservatif": ("conservatif",),
    "conservatifs": ("conservatif",),
    "conservative": ("conservatif",),
    "conservatives": ("conservatif",),
    "conservatiste": ("conservatiste",),
    "conservatistes": ("conservatiste",),
    "conservatoire": ("conservatoire",),
    "conservatoires": ("conservatoire",),
    "considérable": ("considérable",),
    "considérables": ("considérable",),
    "consistométrique": ("consistométrique",),
    "consistométriques": ("consistométrique",),
    "consistoriale": ("consistorial",),
    "consistoriales": ("consistorial",),
    "consistorial": ("consistorial",),
    "consistoriaux": ("consistorial",),
    "consolable": ("consolable",),
    "consolables": ("consolable",),
    "consolateur": ("consolateur",),
    "consolateurs": ("consolateur",),
    "consolatrice": ("consolateur",),
    "consolatrices": ("consolateur",),
    "consolidable": ("consolidable",),
    "consolidables": ("consolidable",),
    "consolidateur": ("consolidateur",),
    "consolidateurs": ("consolidateur",),
    "consolidatrice": ("consolidateur",),
    "consolidatrices": ("consolidateur",),
    "consommable": ("consommable",),
    "consommables": ("consommable",),
    "consommateur": ("consommateur",),
    "consommateurs": ("consommateur",),
    "consommatrice": ("consommateur",),
    "consommatrices": ("consommateur",),
    "consommatoire": ("consommatoire",),
    "consommatoires": ("consommatoire",),
    "consomptible": ("consomptible",),
    "consomptibles": ("consomptible",),
    "consomptif": ("consomptif",),
    "consomptifs": ("consomptif",),
    "consomptive": ("consomptif",),
    "consomptives": ("consomptif",),
    "consonantique": ("consonantique",),
    "consonantiques": ("consonantique",),
    "consort": ("consort",),
    "consorts": ("consort",),
    "consortiale": ("consortial",),
    "consortiales": ("consortial",),
    "consortial": ("consortial",),
    "consortiaux": ("consortial",),
    "conspirateur": ("conspirateur",),
    "conspirateurs": ("conspirateur",),
    "conspiratrice": ("conspirateur",),
    "conspiratrices": ("conspirateur",),
    "constantinien": ("constantinien",),
    "constantinienne": ("constantinien",),
    "constantiniennes": ("constantinien",),
    "constantiniens": ("constantinien",),
    "constatable": ("constatable",),
    "constatables": ("constatable",),
    "constatif": ("constatif",),
    "constatifs": ("constatif",),
    "constative": ("constatif",),
    "constatives": ("constatif",),
    "constitutif": ("constitutif",),
    "constitutifs": ("constitutif",),
    "constitutive": ("constitutif",),
    "constitutives": ("constitutif",),
    "constitutionnaliste": ("constitutionnaliste",),
    "constitutionnalistes": ("constitutionnaliste",),
    "constitutionnelle": ("constitutionnel",),
    "constitutionnelles": ("constitutionnel",),
    "constitutionnel": ("constitutionnel",),
    "constitutionnels": ("constitutionnel",),
    "constricteur": ("constricteur",),
    "constricteurs": ("constricteur",),
    "constrictif": ("constrictif",),
    "constrictifs": ("constrictif",),
    "constrictive": ("constrictif",),
    "constrictives": ("constrictif",),
    "constrictor": ("constrictor",),
    "constrictors": ("constrictor",),
    "constructeur": ("constructeur",),
    "constructeurs": ("constructeur",),
    "constructrice": ("constructeur",),
    "constructrices": ("constructeur",),
    "constructible": ("constructible",),
    "constructibles": ("constructible",),
    "constructif": ("constructif",),
    "constructifs": ("constructif",),
    "constructive": ("constructif",),
    "constructives": ("constructif",),
    "constructiviste": ("constructiviste",),
    "constructivistes": ("constructiviste",),
    "consubstantielle": ("consubstantiel",),
    "consubstantielles": ("consubstantiel",),
    "consubstantiel": ("consubstantiel",),
    "consubstantiels": ("consubstantiel",),
    "consulable": ("consulable",),
    "consulables": ("consulable",),
    "consulaire": ("consulaire",),
    "consulaires": ("consulaire",),
    "consultable": ("consultable",),
    "consultables": ("consultable",),
    "consultatif": ("consultatif",),
    "consultatifs": ("consultatif",),
    "consultative": ("consultatif",),
    "consultatives": ("consultatif",),
    "consulteur": ("consulteur",),
    "consulteurs": ("consulteur",),
    "consultrice": ("consulteur",),
    "consultrices": ("consulteur",),
    "consumable": ("consumable",),
    "consumables": ("consumable",),
    "consumériste": ("consumériste",),
    "consuméristes": ("consumériste",),
    "contagieuse": ("contagieux",),
    "contagieuses": ("contagieux",),
    "contagieux": ("contagieux",),
    "containérisable": ("containérisable",),
    "containérisables": ("containérisable",),
    "contaminateur": ("contaminateur",),
    "contaminateurs": ("contaminateur",),
    "contaminatrice": ("contaminateur",),
    "contaminatrices": ("contaminateur",),
    "contemplateur": ("contemplateur",),
    "contemplateurs": ("contemplateur",),
    "contemplatrice": ("contemplateur",),
    "contemplatrices": ("contemplateur",),
    "contemplatif": ("contemplatif",),
    "contemplatifs": ("contemplatif",),
    "contemplative": ("contemplatif",),
    "contemplatives": ("contemplatif",),
    "contempteur": ("contempteur",),
    "contempteurs": ("contempteur",),
    "contemptrice": ("contempteur",),
    "contemptrices": ("contempteur",),
    "conteneurisable": ("conteneurisable",),
    "conteneurisables": ("conteneurisable",),
    "contentieuse": ("contentieux",),
    "contentieuses": ("contentieux",),
    "contentieux": ("contentieux",),
    "contentif": ("contentif",),
    "contentifs": ("contentif",),
    "contentive": ("contentif",),
    "contentives": ("contentif",),
    "contestable": ("contestable",),
    "contestables": ("contestable",),
    "contestataire": ("contestataire",),
    "contestataires": ("contestataire",),
    "contestateur": ("contestateur",),
    "contestateurs": ("contestateur",),
    "contestatrice": ("contestateur",),
    "contestatrices": ("contestateur",),
    "contextuelle": ("contextuel",),
    "contextuelles": ("contextuel",),
    "contextuel": ("contextuel",),
    "contextuels": ("contextuel",),
    "contiguë": ("contigu",),
    "contiguës": ("contigu",),
    "contigu": ("contigu",),
    "contigus": ("contigu",),
    "continentale": ("continental",),
    "continentales": ("continental",),
    "continental": ("continental",),
    "continentaux": ("continental",),
    "contingentaire": ("contingentaire",),
    "contingentaires": ("contingentaire",),
    "continuatif": ("continuatif",),
    "continuatifs": ("continuatif",),
    "continuative": ("continuatif",),
    "continuatives": ("continuatif",),
    "continuelle": ("continuel",),
    "continuelles": ("continuel",),
    "continuel": ("continuel",),
    "continuels": ("continuel",),
    "contournable": ("contournable",),
    "contournables": ("contournable",),
    "contraceptif": ("contraceptif",),
    "contraceptifs": ("contraceptif",),
    "contraceptive": ("contraceptif",),
    "contraceptives": ("contraceptif",),
    "contractable": ("contractable",),
    "contractables": ("contractable",),
    "contractée": ("contracté",),
    "contractées": ("contracté",),
    "contracté": ("contracté",),
    "contracte": ("contracte",),
    "contractés": ("contracté",),
    "contractes": ("contracte",),
    "contractile": ("contractile",),
    "contractiles": ("contractile",),
    "contractionniste": ("contractionniste",),
    "contractionnistes": ("contractionniste",),
    "contractualisable": ("contractualisable",),
    "contractualisables": ("contractualisable",),
    "contractualiste": ("contractualiste",),
    "contractualistes": ("contractualiste",),
    "contractuelle": ("contractuel",),
    "contractuelles": ("contractuel",),
    "contractuel": ("contractuel",),
    "contractuels": ("contractuel",),
    "contradictoire": ("contradictoire",),
    "contradictoires": ("contradictoire",),
    "contrahoraire": ("contrahoraire",),
    "contrahoraires": ("contrahoraire",),
    "contraignable": ("contraignable",),
    "contraignables": ("contraignable",),
    "contraire": ("contraire",),
    "contraires": ("contraire",),
    "contralatérale": ("contralatéral",),
    "contralatérales": ("contralatéral",),
    "contralatéral": ("contralatéral",),
    "contralatéraux": ("contralatéral",),
    "contrapuntique": ("contrapuntique",),
    "contrapuntiques": ("contrapuntique",),
    "contrarotatif": ("contrarotatif",),
    "contrarotatifs": ("contrarotatif",),
    "contrarotative": ("contrarotatif",),
    "contrarotatives": ("contrarotatif",),
    "contrastif": ("contrastif",),
    "contrastifs": ("contrastif",),
    "contrastive": ("contrastif",),
    "contrastives": ("contrastif",),
    "contraventionnelle": ("contraventionnel",),
    "contraventionnelles": ("contraventionnel",),
    "contraventionnel": ("contraventionnel",),
    "contraventionnels": ("contraventionnel",),
    "contraversif": ("contraversif",),
    "contraversifs": ("contraversif",),
    "contraversive": ("contraversif",),
    "contraversives": ("contraversif",),
    "contrebandière": ("contrebandier",),
    "contrebandières": ("contrebandier",),
    "contrebandier": ("contrebandier",),
    "contrebandiers": ("contrebandier",),
    "contreproductif": ("contreproductif",),
    "contreproductifs": ("contreproductif",),
    "contreproductive": ("contreproductif",),
    "contreproductives": ("contreproductif",),
    "contresignataire": ("contresignataire",),
    "contresignataires": ("contresignataire",),
    "contribuable": ("contribuable",),
    "contribuables": ("contribuable",),
    "contributeur": ("contributeur",),
    "contributeurs": ("contributeur",),
    "contributrice": ("contributeur",),
    "contributrices": ("contributeur",),
    "contributif": ("contributif",),
    "contributifs": ("contributif",),
    "contributive": ("contributif",),
    "contributives": ("contributif",),
    "contributoire": ("contributoire",),
    "contributoires": ("contributoire",),
    "contrictif": ("contrictif",),
    "contrictifs": ("contrictif",),
    "contrictive": ("contrictif",),
    "contrictives": ("contrictif",),
    "contrôlable": ("contrôlable",),
    "contrôlables": ("contrôlable",),
    "controlatérale": ("controlatéral",),
    "controlatérales": ("controlatéral",),
    "controlatéral": ("controlatéral",),
    "controlatéraux": ("controlatéral",),
    "contrôleur": ("contrôleur",),
    "contrôleurs": ("contrôleur",),
    "contrôleuse": ("contrôleur",),
    "contrôleuses": ("contrôleur",),
    "controversable": ("controversable",),
    "controversables": ("controversable",),
    "contumace": ("contumace",),
    "contumaces": ("contumace",),
    "contumax": ("contumax",),
    "contuse": ("contus",),
    "contuses": ("contus",),
    "contus": ("contus",),
    "contusif": ("contusif",),
    "contusifs": ("contusif",),
    "contusive": ("contusif",),
    "contusives": ("contusif",),
    "contusiforme": ("contusiforme",),
    "contusiformes": ("contusiforme",),
    "convectif": ("convectif",),
    "convectifs": ("convectif",),
    "convective": ("convectif",),
    "convectives": ("convectif",),
    "convenable": ("convenable",),
    "convenables": ("convenable",),
    "conventionnaliste": ("conventionnaliste",),
    "conventionnalistes": ("conventionnaliste",),
    "conventionnelle": ("conventionnel",),
    "conventionnelles": ("conventionnel",),
    "conventionnel": ("conventionnel",),
    "conventionnels": ("conventionnel",),
    "conventuelle": ("conventuel",),
    "conventuelles": ("conventuel",),
    "conventuel": ("conventuel",),
    "conventuels": ("conventuel",),
    "converse": ("converse",),
    "converses": ("converse",),
    "convers": ("convers",),
    "conversationnelle": ("conversationnel",),
    "conversationnelles": ("conversationnel",),
    "conversationnel": ("conversationnel",),
    "conversationnels": ("conversationnel",),
    "conversible": ("conversible",),
    "conversibles": ("conversible",),
    "convertible": ("convertible",),
    "convertibles": ("convertible",),
    "convertissable": ("convertissable",),
    "convertissables": ("convertissable",),
    "convertisseur": ("convertisseur",),
    "convertisseurs": ("convertisseur",),
    "convertisseuse": ("convertisseur",),
    "convertisseuses": ("convertisseur",),
    "convexe": ("convexe",),
    "convexes": ("convexe",),
    "conviviale": ("convivial",),
    "conviviales": ("convivial",),
    "convivial": ("convivial",),
    "conviviaux": ("convivial",),
    "convocable": ("convocable",),
    "convocables": ("convocable",),
    "convoitable": ("convoitable",),
    "convoitables": ("convoitable",),
    "convoiteur": ("convoiteur",),
    "convoiteurs": ("convoiteur",),
    "convoiteuse": ("convoiteur",),
    "convoiteuses": ("convoiteur",),
    "convolable": ("convolable",),
    "convolables": ("convolable",),
    "convoyeur": ("convoyeur",),
    "convoyeurs": ("convoyeur",),
    "convoyeuse": ("convoyeur",),
    "convoyeuses": ("convoyeur",),
    "convulsif": ("convulsif",),
    "convulsifs": ("convulsif",),
    "convulsive": ("convulsif",),
    "convulsives": ("convulsif",),
    "cool": ("cool",),
    "coopérateur": ("coopérateur",),
    "coopérateurs": ("coopérateur",),
    "coopératrice": ("coopérateur",),
    "coopératrices": ("coopérateur",),
    "coopératif": ("coopératif",),
    "coopératifs": ("coopératif",),
    "coopérative": ("coopératif",),
    "coopératives": ("coopératif",),
    "coordinateur": ("coordinateur",),
    "coordinateurs": ("coordinateur",),
    "coordinatrice": ("coordinateur",),
    "coordinatrices": ("coordinateur",),
    "coordonnable": ("coordonnable",),
    "coordonnables": ("coordonnable",),
    "coordonnateur": ("coordonnateur",),
    "coordonnateurs": ("coordonnateur",),
    "coordonnatrice": ("coordonnateur",),
    "coordonnatrices": ("coordonnateur",),
    "coorganisateur": ("coorganisateur",),
    "coorganisateurs": ("coorganisateur",),
    "coorganisatrice": ("coorganisateur",),
    "coorganisatrices": ("coorganisateur",),
    "copernicien": ("copernicien",),
    "copernicienne": ("copernicien",),
    "coperniciennes": ("copernicien",),
    "coperniciens": ("copernicien",),
    "copiable": ("copiable",),
    "copiables": ("copiable",),
    "copieuse": ("copieux",),
    "copieuses": ("copieux",),
    "copieux": ("copieux",),
    "coplanaire": ("coplanaire",),
    "coplanaires": ("coplanaire",),
    "coprologique": ("coprologique",),
    "coprologiques": ("coprologique",),
    "coprophage": ("coprophage",),
    "coprophages": ("coprophage",),
    "coprophile": ("coprophile",),
    "coprophiles": ("coprophile",),
    "coprophilique": ("coprophilique",),
    "coprophiliques": ("coprophilique",),
    "copte": ("copte",),
    "coptes": ("copte",),
    "copulateur": ("copulateur",),
    "copulateurs": ("copulateur",),
    "copulatrice": ("copulateur",),
    "copulatrices": ("copulateur",),
    "copulatif": ("copulatif",),
    "copulatifs": ("copulatif",),
    "copulative": ("copulatif",),
    "copulatives": ("copulatif",),
    "coquelicot": ("coquelicot",),
    "coquelucheuse": ("coquelucheux",),
    "coquelucheuses": ("coquelucheux",),
    "coquelucheux": ("coquelucheux",),
    "coqueluchoïde": ("coqueluchoïde",),
    "coqueluchoïdes": ("coqueluchoïde",),
    "coquet": ("coquet",),
    "coquets": ("coquet",),
    "coquette": ("coquet",),
    "coquettes": ("coquet",),
    "coquilleuse": ("coquilleux",),
    "coquilleuses": ("coquilleux",),
    "coquilleux": ("coquilleux",),
    "coquillière": ("coquillier",),
    "coquillières": ("coquillier",),
    "coquillier": ("coquillier",),
    "coquilliers": ("coquillier",),
    "coracoïde": ("coracoïde",),
    "coracoïdes": ("coracoïde",),
    "coracoïdien": ("coracoïdien",),
    "coracoïdienne": ("coracoïdien",),
    "coracoïdiennes": ("coracoïdien",),
    "coracoïdiens": ("coracoïdien",),
    "corail": ("corail",),
    "corailleur": ("corailleur",),
    "corailleurs": ("corailleur",),
    "corailleuse": ("corailleur",),
    "corailleuses": ("corailleur",),
    "corallien": ("corallien",),
    "corallienne": ("corallien",),
    "coralliennes": ("corallien",),
    "coralliens": ("corallien",),
    "corallifère": ("corallifère",),
    "corallifères": ("corallifère",),
    "coralliforme": ("coralliforme",),
    "coralliformes": ("coralliforme",),
    "coralligène": ("coralligène",),
    "coralligènes": ("coralligène",),
    "corallivore": ("corallivore",),
    "corallivores": ("corallivore",),
    "coralloïde": ("coralloïde",),
    "coralloïdes": ("coralloïde",),
    "coranique": ("coranique",),
    "coraniques": ("coranique",),
    "corbin": ("corbin",),
    "corbins": ("corbin",),
    "cordiale": ("cordial",),
    "cordiales": ("cordial",),
    "cordial": ("cordial",),
    "cordiaux": ("cordial",),
    "cordiforme": ("cordiforme",),
    "cordiformes": ("cordiforme",),
    "cordonale": ("cordonal",),
    "cordonales": ("cordonal",),
    "cordonal": ("cordonal",),
    "cordonaux": ("cordonal",),
    "coréen": ("coréen",),
    "coréenne": ("coréen",),
    "coréennes": ("coréen",),
    "coréens": ("coréen",),
    "coréférentielle": ("coréférentiel",),
    "coréférentielles": ("coréférentiel",),
    "coréférentiel": ("coréférentiel",),
    "coréférentiels": ("coréférentiel",),
    "coresponsable": ("coresponsable",),
    "coresponsables": ("coresponsable",),
    "corfiote": ("corfiote",),
    "corfiotes": ("corfiote",),
    "coriace": ("coriace",),
    "coriaces": ("coriace",),
    "coricide": ("coricide",),
    "coricides": ("coricide",),
    "corinthien": ("corinthien",),
    "corinthienne": ("corinthien",),
    "corinthiennes": ("corinthien",),
    "corinthiens": ("corinthien",),
    "cornéen": ("cornéen",),
    "cornéenne": ("cornéen",),
    "cornéennes": ("cornéen",),
    "cornéens": ("cornéen",),
    "cornélien": ("cornélien",),
    "cornélienne": ("cornélien",),
    "cornéliennes": ("cornélien",),
    "cornéliens": ("cornélien",),
    "corneur": ("corneur",),
    "corneurs": ("corneur",),
    "corneuse": ("corneux",),
    "corneuses": ("corneux",),
    "corneux": ("corneux",),
    "corniaud": ("corniaud",),
    "corniauds": ("corniaud",),
    "cornichon": ("cornichon",),
    "cornière": ("cornier",),
    "cornières": ("cornier",),
    "cornier": ("cornier",),
    "corniers": ("cornier",),
    "corniforme": ("corniforme",),
    "corniformes": ("corniforme",),
    "corniot": ("corniot",),
    "corniots": ("corniot",),
    "cornique": ("cornique",),
    "corniques": ("cornique",),
    "cornouaillaise": ("cornouaillais",),
    "cornouaillaises": ("cornouaillais",),
    "cornouaillais": ("cornouaillais",),
    "corolliforme": ("corolliforme",),
    "corolliformes": ("corolliforme",),
    "coronaire": ("coronaire",),
    "coronaires": ("coronaire",),
    "coronale": ("coronal",),
    "coronales": ("coronal",),
    "coronal": ("coronal",),
    "coronaux": ("coronal",),
    "coronarien": ("coronarien",),
    "coronarienne": ("coronarien",),
    "coronariennes": ("coronarien",),
    "coronariens": ("coronarien",),
    "coronoïde": ("coronoïde",),
    "coronoïdes": ("coronoïde",),
    "corporatif": ("corporatif",),
    "corporatifs": ("corporatif",),
    "corporative": ("corporatif",),
    "corporatives": ("corporatif",),
    "corporatiste": ("corporatiste",),
    "corporatistes": ("corporatiste",),
    "corporéale": ("corporéal",),
    "corporéales": ("corporéal",),
    "corporéal": ("corporéal",),
    "corporéaux": ("corporéal",),
    "corporelle": ("corporel",),
    "corporelles": ("corporel",),
    "corporel": ("corporel",),
    "corporels": ("corporel",),
    "corpusculaire": ("corpusculaire",),
    "corpusculaires": ("corpusculaire",),
    "corpusculeuse": ("corpusculeux",),
    "corpusculeuses": ("corpusculeux",),
    "corpusculeux": ("corpusculeux",),
    "correcteur": ("correcteur",),
    "correcteurs": ("correcteur",),
    "correctrice": ("correcteur",),
    "correctrices": ("correcteur",),
    "correctif": ("correctif",),
    "correctifs": ("correctif",),
    "corrective": ("correctif",),
    "correctives": ("correctif",),
    "correctionnelle": ("correctionnel",),
    "correctionnelles": ("correctionnel",),
    "correctionnel": ("correctionnel",),
    "correctionnels": ("correctionnel",),
    "corrélable": ("corrélable",),
    "corrélables": ("corrélable",),
    "corrélatif": ("corrélatif",),
    "corrélatifs": ("corrélatif",),
    "corrélative": ("corrélatif",),
    "corrélatives": ("corrélatif",),
    "corrélationnelle": ("corrélationnel",),
    "corrélationnelles": ("corrélationnel",),
    "corrélationnel": ("corrélationnel",),
    "corrélationnels": ("corrélationnel",),
    "corrézien": ("corrézien",),
    "corrézienne": ("corrézien",),
    "corréziennes": ("corrézien",),
    "corréziens": ("corrézien",),
    "corrigeable": ("corrigeable",),
    "corrigeables": ("corrigeable",),
    "corrigible": ("corrigible",),
    "corrigibles": ("corrigible",),
    "corrosif": ("corrosif",),
    "corrosifs": ("corrosif",),
    "corrosive": ("corrosif",),
    "corrosives": ("corrosif",),
    "corroyeur": ("corroyeur",),
    "corroyeurs": ("corroyeur",),
    "corroyeuse": ("corroyeur",),
    "corroyeuses": ("corroyeur",),
    "corrupteur": ("corrupteur",),
    "corrupteurs": ("corrupteur",),
    "corruptrice": ("corrupteur",),
    "corruptrices": ("corrupteur",),
    "corruptible": ("corruptible",),
    "corruptibles": ("corruptible",),
    "corsaire": ("corsaire",),
    "corsaires": ("corsaire",),
    "corsée": ("corsé",),
    "corsées": ("corsé",),
    "corsé": ("corsé",),
    "corse": ("corse",),
    "corsés": ("corsé",),
    "corses": ("corse",),
    "corsetière": ("corsetier",),
    "corsetières": ("corsetier",),
    "corsetier": ("corsetier",),
    "corsetiers": ("corsetier",),
    "corticale": ("cortical",),
    "corticales": ("cortical",),
    "cortical": ("cortical",),
    "corticaux": ("cortical",),
    "corticoïde": ("corticoïde",),
    "corticoïdes": ("corticoïde",),
    "corticomimétique": ("corticomimétique",),
    "corticomimétiques": ("corticomimétique",),
    "corticominéralotrope": ("corticominéralotrope",),
    "corticominéralotropes": ("corticominéralotrope",),
    "corticoprive": ("corticoprive",),
    "corticoprives": ("corticoprive",),
    "corticostéroïde": ("corticostéroïde",),
    "corticostéroïdes": ("corticostéroïde",),
    "corticosurrénale": ("corticosurrénal",),
    "corticosurrénales": ("corticosurrénal",),
    "corticosurrénal": ("corticosurrénal",),
    "corticosurrénaux": ("corticosurrénal",),
    "corticosurrénalien": ("corticosurrénalien",),
    "corticosurrénalienne": ("corticosurrénalien",),
    "corticosurrénaliennes": ("corticosurrénalien",),
    "corticosurrénaliens": ("corticosurrénalien",),
    "corticotrope": ("corticotrope",),
    "corticotropes": ("corticotrope",),
    "cortinique": ("cortinique",),
    "cortiniques": ("cortinique",),
    "cortiqueuse": ("cortiqueux",),
    "cortiqueuses": ("cortiqueux",),
    "cortiqueux": ("cortiqueux",),
    "cortisolique": ("cortisolique",),
    "cortisoliques": ("cortisolique",),
    "cortisonique": ("cortisonique",),
    "cortisoniques": ("cortisonique",),
    "corvéable": ("corvéable",),
    "corvéables": ("corvéable",),
    "corymbiforme": ("corymbiforme",),
    "corymbiformes": ("corymbiforme",),
    "cosaque": ("cosaque",),
    "cosaques": ("cosaque",),
    "cosignataire": ("cosignataire",),
    "cosignataires": ("cosignataire",),
    "cosismale": ("cosismal",),
    "cosismales": ("cosismal",),
    "cosismal": ("cosismal",),
    "cosismaux": ("cosismal",),
    "cosmétique": ("cosmétique",),
    "cosmétiques": ("cosmétique",),
    "cosmétologique": ("cosmétologique",),
    "cosmétologiques": ("cosmétologique",),
    "cosmique": ("cosmique",),
    "cosmiques": ("cosmique",),
    "cosmogonique": ("cosmogonique",),
    "cosmogoniques": ("cosmogonique",),
    "cosmographique": ("cosmographique",),
    "cosmographiques": ("cosmographique",),
    "cosmologique": ("cosmologique",),
    "cosmologiques": ("cosmologique",),
    "cosmophysique": ("cosmophysique",),
    "cosmophysiques": ("cosmophysique",),
    "cosmopolite": ("cosmopolite",),
    "cosmopolites": ("cosmopolite",),
    "cosphérique": ("cosphérique",),
    "cosphériques": ("cosphérique",),
    "costale": ("costal",),
    "costales": ("costal",),
    "costal": ("costal",),
    "costaux": ("costal",),
    "costaricien": ("costaricien",),
    "costaricienne": ("costaricien",),
    "costariciennes": ("costaricien",),
    "costariciens": ("costaricien",),
    "costumière": ("costumier",),
    "costumières": ("costumier",),
    "costumier": ("costumier",),
    "costumiers": ("costumier",),
    "cotable": ("cotable",),
    "cotables": ("cotable",),
    "cotée": ("coté",),
    "cotées": ("coté",),
    "coté": ("coté",),
    "cotés": ("coté",),
    "cotidale": ("cotidal",),
    "cotidales": ("cotidal",),
    "cotidal": ("cotidal",),
    "cotidaux": ("cotidal",),
    "côtière": ("côtier",),
    "côtières": ("côtier",),
    "côtier": ("côtier",),
    "côtiers": ("côtier",),
    "cotonneuse": ("cotonneux",),
    "cotonneuses": ("cotonneux",),
    "cotonneux": ("cotonneux",),
    "cotonnière": ("cotonnier",),
    "cotonnières": ("cotonnier",),
    "cotonnier": ("cotonnier",),
    "cotonniers": ("cotonnier",),
    "cotyloïde": ("cotyloïde",),
    "cotyloïdes": ("cotyloïde",),
    "cotyloïdien": ("cotyloïdien",),
    "cotyloïdienne": ("cotyloïdien",),
    "cotyloïdiennes": ("cotyloïdien",),
    "cotyloïdiens": ("cotyloïdien",),
    "coucheur": ("coucheur",),
    "coucheurs": ("coucheur",),
    "coucheuse": ("coucheur",),
    "coucheuses": ("coucheur",),
    "couchitique": ("couchitique",),
    "couchitiques": ("couchitique",),
    "coudée": ("coudé",),
    "coudées": ("coudé",),
    "coudé": ("coudé",),
    "coudés": ("coudé",),
    "couenneuse": ("couenneux",),
    "couenneuses": ("couenneux",),
    "couenneux": ("couenneux",),
    "coufique": ("coufique",),
    "coufiques": ("coufique",),
    "couillon": ("couillon",),
    "couillonne": ("couillon",),
    "couillonnes": ("couillon",),
    "couillons": ("couillon",),
    "coulable": ("coulable",),
    "coulables": ("coulable",),
    "coulis": ("coulis",),
    "coulisse": ("coulis",),
    "coulisses": ("coulis",),
    "coumarinique": ("coumarinique",),
    "coumariniques": ("coumarinique",),
    "coumarique": ("coumarique",),
    "coumariques": ("coumarique",),
    "country": ("country",),
    "coupable": ("coupable",),
    "coupables": ("coupable",),
    "coupeur": ("coupeur",),
    "coupeurs": ("coupeur",),
    "coupeuse": ("coupeur",),
    "coupeuses": ("coupeur",),
    "courable": ("courable",),
    "courables": ("courable",),
    "courageuse": ("courageux",),
    "courageuses": ("courageux",),
    "courageux": ("courageux",),
    "courantologique": ("courantologique",),
    "courantologiques": ("courantologique",),
    "courbée": ("courbé",),
    "courbées": ("courbé",),
    "courbé": ("courbé",),
    "courbe": ("courbe",),
    "courbés": ("courbé",),
    "courbes": ("courbe",),
    "coureur": ("coureur",),
    "coureurs": ("coureur",),
    "coureuse": ("coureur",),
    "coureuses": ("coureur",),
    "courtoise": ("courtois",),
    "courtoises": ("courtois",),
    "courtois": ("courtois",),
    "coûteuse": ("coûteux",),
    "coûteuses": ("coûteux",),
    "coûteux": ("coûteux",),
    "coutumière": ("coutumier",),
    "coutumières": ("coutumier",),
    "coutumier": ("coutumier",),
    "coutumiers": ("coutumier",),
    "couturière": ("couturier",),
    "couturières": ("couturier",),
    "couturier": ("couturier",),
    "couturiers": ("couturier",),
    "couvi": ("couvi",),
    "couvis": ("couvi",),
    "coxale": ("coxal",),
    "coxales": ("coxal",),
    "coxal": ("coxal",),
    "coxaux": ("coxal",),
    "coxalgique": ("coxalgique",),
    "coxalgiques": ("coxalgique",),
    "coxarthrosique": ("coxarthrosique",),
    "coxarthrosiques": ("coxarthrosique",),
    "coxo-fémorale": ("coxo-fémoral",),
    "crabier": ("crabier",),
    "crabiers": ("crabier",),
    "cracheur": ("cracheur",),
    "cracheurs": ("cracheur",),
    "cracheuse": ("cracheur",),
    "cracheuses": ("cracheur",),
    "crack": ("crack",),
    "cracks": ("crack",),
    "cracra": ("cracra",),
    "crade": ("crade",),
    "crades": ("crade",),
    "cradingue": ("cradingue",),
    "cradingues": ("cradingue",),
    "crado": ("crado",),
    "craintif": ("craintif",),
    "craintifs": ("craintif",),
    "craintive": ("craintif",),
    "craintives": ("craintif",),
    "crampon": ("crampon",),
    "crâne": ("crâne",),
    "crânes": ("crâne",),
    "crâneur": ("crâneur",),
    "crâneurs": ("crâneur",),
    "crâneuse": ("crâneur",),
    "crâneuses": ("crâneur",),
    "crânien": ("crânien",),
    "crânienne": ("crânien",),
    "crâniennes": ("crânien",),
    "crâniens": ("crânien",),
    "craniofaciale": ("craniofacial",),
    "craniofaciales": ("craniofacial",),
    "craniofacial": ("craniofacial",),
    "craniofaciaux": ("craniofacial",),
    "craniologique": ("craniologique",),
    "craniologiques": ("craniologique",),
    "craniométrique": ("craniométrique",),
    "craniométriques": ("craniométrique",),
    "crapule": ("crapule",),
    "crapules": ("crapule",),
    "crapuleuse": ("crapuleux",),
    "crapuleuses": ("crapuleux",),
    "crapuleux": ("crapuleux",),
    "crasse": ("crasse",),
    "crasses": ("crasse",),
    "crasseuse": ("crasseux",),
    "crasseuses": ("crasseux",),
    "crasseux": ("crasseux",),
    "cratériforme": ("cratériforme",),
    "cratériformes": ("cratériforme",),
    "cratonique": ("cratonique",),
    "cratoniques": ("cratonique",),
    "crayeuse": ("crayeux",),
    "crayeuses": ("crayeux",),
    "crayeux": ("crayeux",),
    "créancière": ("créancier",),
    "créancières": ("créancier",),
    "créancier": ("créancier",),
    "créanciers": ("créancier",),
    "créateur": ("créateur",),
    "créateurs": ("créateur",),
    "créatrice": ("créateur",),
    "créatrices": ("créateur",),
    "créatif": ("créatif",),
    "créatifs": ("créatif",),
    "créative": ("créatif",),
    "créatives": ("créatif",),
    "créationniste": ("créationniste",),
    "créationnistes": ("créationniste",),
    "créatique": ("créatique",),
    "créatiques": ("créatique",),
    "crédible": ("crédible",),
    "crédibles": ("crédible",),
    "crédirentière": ("crédirentier",),
    "crédirentières": ("crédirentier",),
    "crédirentier": ("crédirentier",),
    "crédirentiers": ("crédirentier",),
    "créditeur": ("créditeur",),
    "créditeurs": ("créditeur",),
    "créditrice": ("créditeur",),
    "créditrices": ("créditeur",),
    "crédule": ("crédule",),
    "crédules": ("crédule",),
    "crématiste": ("crématiste",),
    "crématistes": ("crématiste",),
    "crématoire": ("crématoire",),
    "crématoires": ("crématoire",),
    "crème": ("crème",),
    "crémeuse": ("crémeux",),
    "crémeuses": ("crémeux",),
    "crémeux": ("crémeux",),
    "crénobiologique": ("crénobiologique",),
    "crénobiologiques": ("crénobiologique",),
    "crénothérapique": ("crénothérapique",),
    "crénothérapiques": ("crénothérapique",),
    "créole": ("créole",),
    "créoles": ("créole",),
    "crêpeur": ("crêpeur",),
    "crêpeurs": ("crêpeur",),
    "crépusculaire": ("crépusculaire",),
    "crépusculaires": ("crépusculaire",),
    "cressonnière": ("cressonnier",),
    "cressonnières": ("cressonnier",),
    "cressonnier": ("cressonnier",),
    "cressonniers": ("cressonnier",),
    "crétino-goitreuse": ("crétino-goitreux",),
    "crétinoïde": ("crétinoïde",),
    "crétinoïdes": ("crétinoïde",),
    "crétique": ("crétique",),
    "crétiques": ("crétique",),
    "crétoise": ("crétois",),
    "crétoises": ("crétois",),
    "crétois": ("crétois",),
    "creusoise": ("creusois",),
    "creusoises": ("creusois",),
    "creusois": ("creusois",),
    "creuse": ("creux",),
    "creuses": ("creux",),
    "creux": ("creux",),
    "criailleur": ("criailleur",),
    "criailleurs": ("criailleur",),
    "criailleuse": ("criailleur",),
    "criailleuses": ("criailleur",),
    "cricoïde": ("cricoïde",),
    "cricoïdes": ("cricoïde",),
    "criméen": ("criméen",),
    "criméenne": ("criméen",),
    "criméennes": ("criméen",),
    "criméens": ("criméen",),
    "criminalisable": ("criminalisable",),
    "criminalisables": ("criminalisable",),
    "criminalistique": ("criminalistique",),
    "criminalistiques": ("criminalistique",),
    "criminelle": ("criminel",),
    "criminelles": ("criminel",),
    "criminel": ("criminel",),
    "criminels": ("criminel",),
    "criminogène": ("criminogène",),
    "criminogènes": ("criminogène",),
    "cristallifère": ("cristallifère",),
    "cristallifères": ("cristallifère",),
    "cristallinien": ("cristallinien",),
    "cristallinienne": ("cristallinien",),
    "cristalliniennes": ("cristallinien",),
    "cristalliniens": ("cristallinien",),
    "cristallisable": ("cristallisable",),
    "cristallisables": ("cristallisable",),
    "cristalloblastique": ("cristalloblastique",),
    "cristalloblastiques": ("cristalloblastique",),
    "cristallochimique": ("cristallochimique",),
    "cristallochimiques": ("cristallochimique",),
    "cristallographique": ("cristallographique",),
    "cristallographiques": ("cristallographique",),
    "cristalloïdale": ("cristalloïdal",),
    "cristalloïdales": ("cristalloïdal",),
    "cristalloïdal": ("cristalloïdal",),
    "cristalloïdaux": ("cristalloïdal",),
    "cristalloïde": ("cristalloïde",),
    "cristalloïdes": ("cristalloïde",),
    "cristallophyllien": ("cristallophyllien",),
    "cristallophyllienne": ("cristallophyllien",),
    "cristallophylliennes": ("cristallophyllien",),
    "cristallophylliens": ("cristallophyllien",),
    "criticable": ("criticable",),
    "criticables": ("criticable",),
    "criticiste": ("criticiste",),
    "criticistes": ("criticiste",),
    "critiquable": ("critiquable",),
    "critiquables": ("critiquable",),
    "critique": ("critique",),
    "critiques": ("critique",),
    "critiqueur": ("critiqueur",),
    "critiqueurs": ("critiqueur",),
    "critiqueuse": ("critiqueur",),
    "critiqueuses": ("critiqueur",),
    "croate": ("croate",),
    "croates": ("croate",),
    "crocéique": ("crocéique",),
    "crocéiques": ("crocéique",),
    "crochetable": ("crochetable",),
    "crochetables": ("crochetable",),
    "croiseur": ("croiseur",),
    "croiseurs": ("croiseur",),
    "croqueur": ("croqueur",),
    "croqueurs": ("croqueur",),
    "croqueuse": ("croqueur",),
    "croqueuses": ("croqueur",),
    "croquignolet": ("croquignolet",),
    "croquignolets": ("croquignolet",),
    "croquignolette": ("croquignolet",),
    "croquignolettes": ("croquignolet",),
    "crotonique": ("crotonique",),
    "crotoniques": ("crotonique",),
    "crotteuse": ("crotteux",),
    "crotteuses": ("crotteux",),
    "crotteux": ("crotteux",),
    "crotylique": ("crotylique",),
    "crotyliques": ("crotylique",),
    "croupale": ("croupal",),
    "croupales": ("croupal",),
    "croupal": ("croupal",),
    "croupaux": ("croupal",),
    "croupeuse": ("croupeux",),
    "croupeuses": ("croupeux",),
    "croupeux": ("croupeux",),
    "croûteuse": ("croûteux",),
    "croûteuses": ("croûteux",),
    "croûteux": ("croûteux",),
    "croyable": ("croyable",),
    "croyables": ("croyable",),
    "cruche": ("cruche",),
    "cruciale": ("crucial",),
    "cruciales": ("crucial",),
    "crucial": ("crucial",),
    "cruciaux": ("crucial",),
    "crucifère": ("crucifère",),
    "crucifères": ("crucifère",),
    "cruciforme": ("cruciforme",),
    "cruciformes": ("cruciforme",),
    "cruelle": ("cruel",),
    "cruelles": ("cruel",),
    "cruel": ("cruel",),
    "cruels": ("cruel",),
    "crurale": ("crural",),
    "crurales": ("crural",),
    "crural": ("crural",),
    "cruraux": ("crural",),
    "crustale": ("crustal",),
    "crustales": ("crustal",),
    "crustal": ("crustal",),
    "crustaux": ("crustal",),
    "cryoconducteur": ("cryoconducteur",),
    "cryoconducteurs": ("cryoconducteur",),
    "cryoconductrice": ("cryoconducteur",),
    "cryoconductrices": ("cryoconducteur",),
    "cryoélectronique": ("cryoélectronique",),
    "cryoélectroniques": ("cryoélectronique",),
    "cryoélectrotechnique": ("cryoélectrotechnique",),
    "cryoélectrotechniques": ("cryoélectrotechnique",),
    "cryogène": ("cryogène",),
    "cryogènes": ("cryogène",),
    "cryogénique": ("cryogénique",),
    "cryogéniques": ("cryogénique",),
    "cryomagnétique": ("cryomagnétique",),
    "cryomagnétiques": ("cryomagnétique",),
    "cryométrique": ("cryométrique",),
    "cryométriques": ("cryométrique",),
    "cryophile": ("cryophile",),
    "cryophiles": ("cryophile",),
    "cryophysique": ("cryophysique",),
    "cryophysiques": ("cryophysique",),
    "cryoprécipitable": ("cryoprécipitable",),
    "cryoprécipitables": ("cryoprécipitable",),
    "cryoprotecteur": ("cryoprotecteur",),
    "cryoprotecteurs": ("cryoprotecteur",),
    "cryoprotectrice": ("cryoprotecteur",),
    "cryoprotectrices": ("cryoprotecteur",),
    "cryoscopique": ("cryoscopique",),
    "cryoscopiques": ("cryoscopique",),
    "cryostatique": ("cryostatique",),
    "cryostatiques": ("cryostatique",),
    "cryotechnique": ("cryotechnique",),
    "cryotechniques": ("cryotechnique",),
    "cryptique": ("cryptique",),
    "cryptiques": ("cryptique",),
    "cryptocalviniste": ("cryptocalviniste",),
    "cryptocalvinistes": ("cryptocalviniste",),
    "cryptocommuniste": ("cryptocommuniste",),
    "cryptocommunistes": ("cryptocommuniste",),
    "cryptogame": ("cryptogame",),
    "cryptogames": ("cryptogame",),
    "cryptogamique": ("cryptogamique",),
    "cryptogamiques": ("cryptogamique",),
    "cryptogénétique": ("cryptogénétique",),
    "cryptogénétiques": ("cryptogénétique",),
    "cryptogénique": ("cryptogénique",),
    "cryptogéniques": ("cryptogénique",),
    "cryptographique": ("cryptographique",),
    "cryptographiques": ("cryptographique",),
    "cryptologique": ("cryptologique",),
    "cryptologiques": ("cryptologique",),
    "cryptoniscien": ("cryptoniscien",),
    "cryptoniscienne": ("cryptoniscien",),
    "cryptonisciennes": ("cryptoniscien",),
    "cryptonisciens": ("cryptoniscien",),
    "cryptopsychique": ("cryptopsychique",),
    "cryptopsychiques": ("cryptopsychique",),
    "cryptorchide": ("cryptorchide",),
    "cryptorchides": ("cryptorchide",),
    "cube": ("cube",),
    "cubes": ("cube",),
    "cubique": ("cubique",),
    "cubiques": ("cubique",),
    "cubiste": ("cubiste",),
    "cubistes": ("cubiste",),
    "cubitale": ("cubital",),
    "cubitales": ("cubital",),
    "cubital": ("cubital",),
    "cubitaux": ("cubital",),
    "cuboïde": ("cuboïde",),
    "cuboïdes": ("cuboïde",),
    "cucu": ("cucu",),
    "cucul": ("cucul",),
    "cueilleur": ("cueilleur",),
    "cueilleurs": ("cueilleur",),
    "cueilleuse": ("cueilleur",),
    "cueilleuses": ("cueilleur",),
    "cuistre": ("cuistre",),
    "cuistres": ("cuistre",),
    "cuivreuse": ("cuivreux",),
    "cuivreuses": ("cuivreux",),
    "cuivreux": ("cuivreux",),
    "cuivrique": ("cuivrique",),
    "cuivriques": ("cuivrique",),
    "cul": ("cul",),
    "culard": ("culard",),
    "culards": ("culard",),
    "culbutable": ("culbutable",),
    "culbutables": ("culbutable",),
    "culinaire": ("culinaire",),
    "culinaires": ("culinaire",),
    "culminatif": ("culminatif",),
    "culminatifs": ("culminatif",),
    "culminative": ("culminatif",),
    "culminatives": ("culminatif",),
    "culpabilisateur": ("culpabilisateur",),
    "culpabilisateurs": ("culpabilisateur",),
    "culpabilisatrice": ("culpabilisateur",),
    "culpabilisatrices": ("culpabilisateur",),
    "cultéraniste": ("cultéraniste",),
    "cultéranistes": ("cultéraniste",),
    "cultivable": ("cultivable",),
    "cultivables": ("cultivable",),
    "cultuelle": ("cultuel",),
    "cultuelles": ("cultuel",),
    "cultuel": ("cultuel",),
    "cultuels": ("cultuel",),
    "culturale": ("cultural",),
    "culturales": ("cultural",),
    "cultural": ("cultural",),
    "culturaux": ("cultural",),
    "culturaliste": ("culturaliste",),
    "culturalistes": ("culturaliste",),
    "culturelle": ("culturel",),
    "culturelles": ("culturel",),
    "culturel": ("culturel",),
    "culturels": ("culturel",),
    "culturiste": ("culturiste",),
    "culturistes": ("culturiste",),
    "cuminique": ("cuminique",),
    "cuminiques": ("cuminique",),
    "cumulable": ("cumulable",),
    "cumulables": ("cumulable",),
    "cumulatif": ("cumulatif",),
    "cumulatifs": ("cumulatif",),
    "cumulative": ("cumulatif",),
    "cumulatives": ("cumulatif",),
    "cunéiforme": ("cunéiforme",),
    "cunéiformes": ("cunéiforme",),
    "cunicole": ("cunicole",),
    "cunicoles": ("cunicole",),
    "cuniculicole": ("cuniculicole",),
    "cuniculicoles": ("cuniculicole",),
    "cupide": ("cupide",),
    "cupides": ("cupide",),
    "cuprifère": ("cuprifère",),
    "cuprifères": ("cuprifère",),
    "cuprique": ("cuprique",),
    "cupriques": ("cuprique",),
    "cuproammoniacale": ("cuproammoniacal",),
    "cuproammoniacales": ("cuproammoniacal",),
    "cuproammoniacal": ("cuproammoniacal",),
    "cuproammoniacaux": ("cuproammoniacal",),
    "cuprolithique": ("cuprolithique",),
    "cuprolithiques": ("cuprolithique",),
    "curable": ("curable",),
    "curables": ("curable",),
    "curarimimétique": ("curarimimétique",),
    "curarimimétiques": ("curarimimétique",),
    "curatif": ("curatif",),
    "curatifs": ("curatif",),
    "curative": ("curatif",),
    "curatives": ("curatif",),
    "curiale": ("curial",),
    "curiales": ("curial",),
    "curial": ("curial",),
    "curiaux": ("curial",),
    "curiate": ("curiate",),
    "curiates": ("curiate",),
    "curieuse": ("curieux",),
    "curieuses": ("curieux",),
    "curieux": ("curieux",),
    "cursif": ("cursif",),
    "cursifs": ("cursif",),
    "cursive": ("cursif",),
    "cursives": ("cursif",),
    "curule": ("curule",),
    "curules": ("curule",),
    "curvatif": ("curvatif",),
    "curvatifs": ("curvatif",),
    "curvative": ("curvatif",),
    "curvatives": ("curvatif",),
    "curviligne": ("curviligne",),
    "curvilignes": ("curviligne",),
    "cushingoïde": ("cushingoïde",),
    "cushingoïdes": ("cushingoïde",),
    "cutanéomuqueuse": ("cutanéomuqueux",),
    "cutanéomuqueuses": ("cutanéomuqueux",),
    "cutanéomuqueux": ("cutanéomuqueux",),
    "cuticulaire": ("cuticulaire",),
    "cuticulaires": ("cuticulaire",),
    "cyanacétique": ("cyanacétique",),
    "cyanacétiques": ("cyanacétique",),
    "cyan": ("cyan",),
    "cyanhydrique": ("cyanhydrique",),
    "cyanhydriques": ("cyanhydrique",),
    "cyanique": ("cyanique",),
    "cyaniques": ("cyanique",),
    "cyanotique": ("cyanotique",),
    "cyanotiques": ("cyanotique",),
    "cyanurique": ("cyanurique",),
    "cyanuriques": ("cyanurique",),
    "cybernéticien": ("cybernéticien",),
    "cybernéticienne": ("cybernéticien",),
    "cybernéticiennes": ("cybernéticien",),
    "cybernéticiens": ("cybernéticien",),
    "cybernétique": ("cybernétique",),
    "cybernétiques": ("cybernétique",),
    "cyberterroriste": ("cyberterroriste",),
    "cyberterroristes": ("cyberterroriste",),
    "cyclable": ("cyclable",),
    "cyclables": ("cyclable",),
    "cycladique": ("cycladique",),
    "cycladiques": ("cycladique",),
    "cyclanique": ("cyclanique",),
    "cyclaniques": ("cyclanique",),
    "cyclique": ("cyclique",),
    "cycliques": ("cyclique",),
    "cycliste": ("cycliste",),
    "cyclistes": ("cycliste",),
    "cyclogénétique": ("cyclogénétique",),
    "cyclogénétiques": ("cyclogénétique",),
    "cyclohexanique": ("cyclohexanique",),
    "cyclohexaniques": ("cyclohexanique",),
    "cycloïdale": ("cycloïdal",),
    "cycloïdales": ("cycloïdal",),
    "cycloïdal": ("cycloïdal",),
    "cycloïdaux": ("cycloïdal",),
    "cycloïde": ("cycloïde",),
    "cycloïdes": ("cycloïde",),
    "cyclonale": ("cyclonal",),
    "cyclonales": ("cyclonal",),
    "cyclonal": ("cyclonal",),
    "cyclonaux": ("cyclonal",),
    "cyclonique": ("cyclonique",),
    "cycloniques": ("cyclonique",),
    "cyclopéen": ("cyclopéen",),
    "cyclopéenne": ("cyclopéen",),
    "cyclopéennes": ("cyclopéen",),
    "cyclopéens": ("cyclopéen",),
    "cyclopien": ("cyclopien",),
    "cyclopienne": ("cyclopien",),
    "cyclopiennes": ("cyclopien",),
    "cyclopiens": ("cyclopien",),
    "cycloplégique": ("cycloplégique",),
    "cycloplégiques": ("cycloplégique",),
    "cyclostrophique": ("cyclostrophique",),
    "cyclostrophiques": ("cyclostrophique",),
    "cyclothymique": ("cyclothymique",),
    "cyclothymiques": ("cyclothymique",),
    "cyclotomique": ("cyclotomique",),
    "cyclotomiques": ("cyclotomique",),
    "cyclotouriste": ("cyclotouriste",),
    "cyclotouristes": ("cyclotouriste",),
    "cylindrique": ("cylindrique",),
    "cylindriques": ("cylindrique",),
    "cylindroïde": ("cylindroïde",),
    "cylindroïdes": ("cylindroïde",),
    "cylindromateuse": ("cylindromateux",),
    "cylindromateuses": ("cylindromateux",),
    "cylindromateux": ("cylindromateux",),
    "cylindro-ogival": ("cylindro-ogival",),
    "cylindro-ogivaux": ("cylindro-ogival",),
    "cymrique": ("cymrique",),
    "cymriques": ("cymrique",),
    "cynégétique": ("cynégétique",),
    "cynégétiques": ("cynégétique",),
    "cynique": ("cynique",),
    "cyniques": ("cynique",),
    "cynogénétique": ("cynogénétique",),
    "cynogénétiques": ("cynogénétique",),
    "cynologique": ("cynologique",),
    "cynologiques": ("cynologique",),
    "cynophile": ("cynophile",),
    "cynophiles": ("cynophile",),
    "cyphotique": ("cyphotique",),
    "cyphotiques": ("cyphotique",),
    "cypriaque": ("cypriaque",),
    "cypriaques": ("cypriaque",),
    "cypriote": ("cypriote",),
    "cypriotes": ("cypriote",),
    "cyprique": ("cyprique",),
    "cypriques": ("cyprique",),
    "cyrénaïque": ("cyrénaïque",),
    "cyrénaïques": ("cyrénaïque",),
    "cyrillique": ("cyrillique",),
    "cyrilliques": ("cyrillique",),
    "cystineuse": ("cystineux",),
    "cystineuses": ("cystineux",),
    "cystineux": ("cystineux",),
    "cystinurique": ("cystinurique",),
    "cystinuriques": ("cystinurique",),
    "cystique": ("cystique",),
    "cystiques": ("cystique",),
    "cystoïde": ("cystoïde",),
    "cystoïdes": ("cystoïde",),
    "cystoscopique": ("cystoscopique",),
    "cystoscopiques": ("cystoscopique",),
    "cytoarchitectonique": ("cytoarchitectonique",),
    "cytoarchitectoniques": ("cytoarchitectonique",),
    "cytochimique": ("cytochimique",),
    "cytochimiques": ("cytochimique",),
    "cytocide": ("cytocide",),
    "cytocides": ("cytocide",),
    "cytogénétique": ("cytogénétique",),
    "cytogénétiques": ("cytogénétique",),
    "cyto-hormonal": ("cyto-hormonal",),
    "cyto-hormonaux": ("cyto-hormonal",),
    "cytologique": ("cytologique",),
    "cytologiques": ("cytologique",),
    "cytolytique": ("cytolytique",),
    "cytolytiques": ("cytolytique",),
    "cytomégalique": ("cytomégalique",),
    "cytomégaliques": ("cytomégalique",),
    "cytopathique": ("cytopathique",),
    "cytopathiques": ("cytopathique",),
    "cytopathogène": ("cytopathogène",),
    "cytopathogènes": ("cytopathogène",),
    "cytopexique": ("cytopexique",),
    "cytopexiques": ("cytopexique",),
    "cytophysique": ("cytophysique",),
    "cytophysiques": ("cytophysique",),
    "cytoplasique": ("cytoplasique",),
    "cytoplasiques": ("cytoplasique",),
    "cytoplasmique": ("cytoplasmique",),
    "cytoplasmiques": ("cytoplasmique",),
    "cytoprotecteur": ("cytoprotecteur",),
    "cytoprotecteurs": ("cytoprotecteur",),
    "cytoprotectrice": ("cytoprotecteur",),
    "cytoprotectrices": ("cytoprotecteur",),
    "cytoréducteur": ("cytoréducteur",),
    "cytoréducteurs": ("cytoréducteur",),
    "cytoréductrice": ("cytoréducteur",),
    "cytoréductrices": ("cytoréducteur",),
    "cytosolique": ("cytosolique",),
    "cytosoliques": ("cytosolique",),
    "cytostatique": ("cytostatique",),
    "cytostatiques": ("cytostatique",),
    "cytotactique": ("cytotactique",),
    "cytotactiques": ("cytotactique",),
    "cytotaxigène": ("cytotaxigène",),
    "cytotaxigènes": ("cytotaxigène",),
    "cytotoxique": ("cytotoxique",),
    "cytotoxiques": ("cytotoxique",),
    "cytotrope": ("cytotrope",),
    "cytotropes": ("cytotrope",),
    "dace": ("dace",),
    "daces": ("dace",),
    "dacique": ("dacique",),
    "daciques": ("dacique",),
    "dacitique": ("dacitique",),
    "dacitiques": ("dacitique",),
    "dacquoise": ("dacquois",),
    "dacquoises": ("dacquois",),
    "dacquois": ("dacquois",),
    "dacryogène": ("dacryogène",),
    "dacryogènes": ("dacryogène",),
    "dacrystique": ("dacrystique",),
    "dacrystiques": ("dacrystique",),
    "dactylique": ("dactylique",),
    "dactyliques": ("dactylique",),
    "dactylographique": ("dactylographique",),
    "dactylographiques": ("dactylographique",),
    "dactylologique": ("dactylologique",),
    "dactylologiques": ("dactylologique",),
    "dada": ("dada",),
    "dadaïste": ("dadaïste",),
    "dadaïstes": ("dadaïste",),
    "dahoméen": ("dahoméen",),
    "dahoméenne": ("dahoméen",),
    "dahoméennes": ("dahoméen",),
    "dahoméens": ("dahoméen",),
    "d'ailleurs": ("d'ailleurs",),
    "dalmate": ("dalmate",),
    "dalmates": ("dalmate",),
    "daltonien": ("daltonien",),
    "daltonienne": ("daltonien",),
    "daltoniennes": ("daltonien",),
    "daltoniens": ("daltonien",),
    "damasien": ("damasien",),
    "damasienne": ("damasien",),
    "damasiennes": ("damasien",),
    "damasiens": ("damasien",),
    "dameur": ("dameur",),
    "dameurs": ("dameur",),
    "dameuse": ("dameur",),
    "dameuses": ("dameur",),
    "damnable": ("damnable",),
    "damnables": ("damnable",),
    "dangereuse": ("dangereux",),
    "dangereuses": ("dangereux",),
    "dangereux": ("dangereux",),
    "danien": ("danien",),
    "danienne": ("danien",),
    "daniennes": ("danien",),
    "daniens": ("danien",),
    "danoise": ("danois",),
    "danoises": ("danois",),
    "danois": ("danois",),
    "dansable": ("dansable",),
    "dansables": ("dansable",),
    "dantesque": ("dantesque",),
    "dantesques": ("dantesque",),
    "dantoniste": ("dantoniste",),
    "dantonistes": ("dantoniste",),
    "danubien": ("danubien",),
    "danubienne": ("danubien",),
    "danubiennes": ("danubien",),
    "danubiens": ("danubien",),
    "d'aplomb": ("d'aplomb",),
    "darbyste": ("darbyste",),
    "darbystes": ("darbyste",),
    "dartmorr": ("dartmorr",),
    "dartreuse": ("dartreux",),
    "dartreuses": ("dartreux",),
    "dartreux": ("dartreux",),
    "darwinien": ("darwinien",),
    "darwinienne": ("darwinien",),
    "darwiniennes": ("darwinien",),
    "darwiniens": ("darwinien",),
    "darwiniste": ("darwiniste",),
    "darwinistes": ("darwiniste",),
    "datable": ("datable",),
    "datables": ("datable",),
    "dateur": ("dateur",),
    "dateurs": ("dateur",),
    "dateuse": ("dateur",),
    "dateuses": ("dateur",),
    "datif": ("datif",),
    "datifs": ("datif",),
    "dative": ("datif",),
    "datives": ("datif",),
    "daubeur": ("daubeur",),
    "daubeurs": ("daubeur",),
    "daubeuse": ("daubeur",),
    "daubeuses": ("daubeur",),
    "dauphinoise": ("dauphinois",),
    "dauphinoises": ("dauphinois",),
    "dauphinois": ("dauphinois",),
    "d'autrefois": ("d'autrefois",),
    "d'avant-garde": ("d'avant-garde",),
    "débile": ("débile",),
    "débiles": ("débile",),
    "débineur": ("débineur",),
    "débineurs": ("débineur",),
    "débineuse": ("débineur",),
    "débineuses": ("débineur",),
    "débitable": ("débitable",),
    "débitables": ("débitable",),
    "débiteur": ("débiteur",),
    "débiteurs": ("débiteur",),
    "débitrice": ("débiteur",),
    "débitrices": ("débiteur",),
    "débitif": ("débitif",),
    "débitifs": ("débitif",),
    "débitive": ("débitif",),
    "débitives": ("débitif",),
    "débonnaire": ("débonnaire",),
    "débonnaires": ("débonnaire",),
    "débourbeur": ("débourbeur",),
    "débourbeurs": ("débourbeur",),
    "débourbeuse": ("débourbeur",),
    "débourbeuses": ("débourbeur",),
    "debout": ("debout",),
    "débrayable": ("débrayable",),
    "débrayables": ("débrayable",),
    "décachetable": ("décachetable",),
    "décachetables": ("décachetable",),
    "décadaire": ("décadaire",),
    "décadaires": ("décadaire",),
    "décaèdre": ("décaèdre",),
    "décaèdres": ("décaèdre",),
    "décagonale": ("décagonal",),
    "décagonales": ("décagonal",),
    "décagonal": ("décagonal",),
    "décagonaux": ("décagonal",),
    "décagone": ("décagone",),
    "décagones": ("décagone",),
    "décamétrique": ("décamétrique",),
    "décamétriques": ("décamétrique",),
    "décanale": ("décanal",),
    "décanales": ("décanal",),
    "décanal": ("décanal",),
    "décanaux": ("décanal",),
    "décanoïque": ("décanoïque",),
    "décanoïques": ("décanoïque",),
    "décantable": ("décantable",),
    "décantables": ("décantable",),
    "décanteur": ("décanteur",),
    "décanteurs": ("décanteur",),
    "décanteuse": ("décanteur",),
    "décanteuses": ("décanteur",),
    "décapeur": ("décapeur",),
    "décapeurs": ("décapeur",),
    "décapeuse": ("décapeur",),
    "décapeuses": ("décapeur",),
    "décapode": ("décapode",),
    "décapodes": ("décapode",),
    "décapotable": ("décapotable",),
    "décapotables": ("décapotable",),
    "décarburateur": ("décarburateur",),
    "décarburateurs": ("décarburateur",),
    "décarburatrice": ("décarburateur",),
    "décarburatrices": ("décarburateur",),
    "décastyle": ("décastyle",),
    "décastyles": ("décastyle",),
    "décasyllabe": ("décasyllabe",),
    "décasyllabes": ("décasyllabe",),
    "décasyllabique": ("décasyllabique",),
    "décasyllabiques": ("décasyllabique",),
    "décatisseur": ("décatisseur",),
    "décatisseurs": ("décatisseur",),
    "décatisseuse": ("décatisseur",),
    "décatisseuses": ("décatisseur",),
    "décelable": ("décelable",),
    "décelables": ("décelable",),
    "décembriste": ("décembriste",),
    "décembristes": ("décembriste",),
    "décemvirale": ("décemviral",),
    "décemvirales": ("décemviral",),
    "décemviral": ("décemviral",),
    "décemviraux": ("décemviral",),
    "décennale": ("décennal",),
    "décennales": ("décennal",),
    "décennal": ("décennal",),
    "décennaux": ("décennal",),
    "décentralisateur": ("décentralisateur",),
    "décentralisateurs": ("décentralisateur",),
    "décentralisatrice": ("décentralisateur",),
    "décentralisatrices": ("décentralisateur",),
    "décernable": ("décernable",),
    "décernables": ("décernable",),
    "déchaussées": ("déchaussés",),
    "déchaussés": ("déchaussés",),
    "déchaux": ("déchaux",),
    "déchiffrable": ("déchiffrable",),
    "déchiffrables": ("déchiffrable",),
    "déchiffreur": ("déchiffreur",),
    "déchiffreurs": ("déchiffreur",),
    "déchiffreuse": ("déchiffreur",),
    "déchiffreuses": ("déchiffreur",),
    "décidable": ("décidable",),
    "décidables": ("décidable",),
    "déciduale": ("décidual",),
    "déciduales": ("décidual",),
    "décidual": ("décidual",),
    "déciduaux": ("décidual",),
    "décimable": ("décimable",),
    "décimables": ("décimable",),
    "décimale": ("décimal",),
    "décimales": ("décimal",),
    "décimal": ("décimal",),
    "décimaux": ("décimal",),
    "décimétrique": ("décimétrique",),
    "décimétriques": ("décimétrique",),
    "décinormale": ("décinormal",),
    "décinormales": ("décinormal",),
    "décinormal": ("décinormal",),
    "décinormaux": ("décinormal",),
    "décisif": ("décisif",),
    "décisifs": ("décisif",),
    "décisive": ("décisif",),
    "décisives": ("décisif",),
    "décisionnaire": ("décisionnaire",),
    "décisionnaires": ("décisionnaire",),
    "décisionnelle": ("décisionnel",),
    "décisionnelles": ("décisionnel",),
    "décisionnel": ("décisionnel",),
    "décisionnels": ("décisionnel",),
    "décisoire": ("décisoire",),
    "décisoires": ("décisoire",),
    "déclamateur": ("déclamateur",),
    "déclamateurs": ("déclamateur",),
    "déclamatrice": ("déclamateur",),
    "déclamatrices": ("déclamateur",),
    "déclamatoire": ("déclamatoire",),
    "déclamatoires": ("déclamatoire",),
    "déclarable": ("déclarable",),
    "déclarables": ("déclarable",),
    "déclaratif": ("déclaratif",),
    "déclaratifs": ("déclaratif",),
    "déclarative": ("déclaratif",),
    "déclaratives": ("déclaratif",),
    "déclaratoire": ("déclaratoire",),
    "déclaratoires": ("déclaratoire",),
    "déclencheur": ("déclencheur",),
    "déclencheurs": ("déclencheur",),
    "déclencheuse": ("déclencheur",),
    "déclencheuses": ("déclencheur",),
    "déclinable": ("déclinable",),
    "déclinables": ("déclinable",),
    "déclinatoire": ("déclinatoire",),
    "déclinatoires": ("déclinatoire",),
    "déclive": ("déclive",),
    "déclives": ("déclive",),
    "déco": ("déco",),
    "décos": ("déco",),
    "décodeur": ("décodeur",),
    "décodeurs": ("décodeur",),
    "décodeuse": ("décodeur",),
    "décodeuses": ("décodeur",),
    "décolonisateur": ("décolonisateur",),
    "décolonisateurs": ("décolonisateur",),
    "décolonisatrice": ("décolonisateur",),
    "décolonisatrices": ("décolonisateur",),
    "décomposable": ("décomposable",),
    "décomposables": ("décomposable",),
    "décompresseur": ("décompresseur",),
    "décompresseurs": ("décompresseur",),
    "décompresseuse": ("décompresseur",),
    "décompresseuses": ("décompresseur",),
    "décongestif": ("décongestif",),
    "décongestifs": ("décongestif",),
    "décongestive": ("décongestif",),
    "décongestives": ("décongestif",),
    "décorable": ("décorable",),
    "décorables": ("décorable",),
    "décorateur": ("décorateur",),
    "décorateurs": ("décorateur",),
    "décoratrice": ("décorateur",),
    "décoratrices": ("décorateur",),
    "décoratif": ("décoratif",),
    "décoratifs": ("décoratif",),
    "décorative": ("décoratif",),
    "décoratives": ("décoratif",),
    "découvrable": ("découvrable",),
    "découvrables": ("découvrable",),
    "décrémentielle": ("décrémentiel",),
    "décrémentielles": ("décrémentiel",),
    "décrémentiel": ("décrémentiel",),
    "décrémentiels": ("décrémentiel",),
    "décrochable": ("décrochable",),
    "décrochables": ("décrochable",),
    "décryptable": ("décryptable",),
    "décryptables": ("décryptable",),
    "décuple": ("décuple",),
    "décuples": ("décuple",),
    "décurionale": ("décurional",),
    "décurionales": ("décurional",),
    "décurional": ("décurional",),
    "décurionaux": ("décurional",),
    "décylique": ("décylique",),
    "décyliques": ("décylique",),
    "dédaignable": ("dédaignable",),
    "dédaignables": ("dédaignable",),
    "dédaigneuse": ("dédaigneux",),
    "dédaigneuses": ("dédaigneux",),
    "dédaigneux": ("dédaigneux",),
    "dédaléen": ("dédaléen",),
    "dédaléenne": ("dédaléen",),
    "dédaléennes": ("dédaléen",),
    "dédaléens": ("dédaléen",),
    "dédalien": ("dédalien",),
    "dédalienne": ("dédalien",),
    "dédaliennes": ("dédalien",),
    "dédaliens": ("dédalien",),
    "dédicatoire": ("dédicatoire",),
    "dédicatoires": ("dédicatoire",),
    "dédommageable": ("dédommageable",),
    "dédommageables": ("dédommageable",),
    "dédoublable": ("dédoublable",),
    "dédoublables": ("dédoublable",),
    "déductible": ("déductible",),
    "déductibles": ("déductible",),
    "déductif": ("déductif",),
    "déductifs": ("déductif",),
    "déductive": ("déductif",),
    "déductives": ("déductif",),
    "défaisable": ("défaisable",),
    "défaisables": ("défaisable",),
    "défaitiste": ("défaitiste",),
    "défaitistes": ("défaitiste",),
    "défavorable": ("défavorable",),
    "défavorables": ("défavorable",),
    "défectif": ("défectif",),
    "défectifs": ("défectif",),
    "défective": ("défectif",),
    "défectives": ("défectif",),
    "défectologique": ("défectologique",),
    "défectologiques": ("défectologique",),
    "défectueuse": ("défectueux",),
    "défectueuses": ("défectueux",),
    "défectueux": ("défectueux",),
    "défendable": ("défendable",),
    "défendables": ("défendable",),
    "défensable": ("défensable",),
    "défensables": ("défensable",),
    "défensif": ("défensif",),
    "défensifs": ("défensif",),
    "défensive": ("défensif",),
    "défensives": ("défensif",),
    "déférentielle": ("déférentiel",),
    "déférentielles": ("déférentiel",),
    "déférentiel": ("déférentiel",),
    "déférentiels": ("déférentiel",),
    "défibreur": ("défibreur",),
    "défibreurs": ("défibreur",),
    "défibreuse": ("défibreur",),
    "défibreuses": ("défibreur",),
    "défibrillateur": ("défibrillateur",),
    "défibrillateurs": ("défibrillateur",),
    "défibrillatrice": ("défibrillateur",),
    "défibrillatrices": ("défibrillateur",),
    "déficiens": ("déficiens",),
    "déficitaire": ("déficitaire",),
    "déficitaires": ("déficitaire",),
    "défilable": ("défilable",),
    "défilables": ("défilable",),
    "définissable": ("définissable",),
    "définissables": ("définissable",),
    "définitif": ("définitif",),
    "définitifs": ("définitif",),
    "définitive": ("définitif",),
    "définitives": ("définitif",),
    "définitionnelle": ("définitionnel",),
    "définitionnelles": ("définitionnel",),
    "définitionnel": ("définitionnel",),
    "définitionnels": ("définitionnel",),
    "définitoire": ("définitoire",),
    "définitoires": ("définitoire",),
    "déflationniste": ("déflationniste",),
    "déflationnistes": ("déflationniste",),
    "déflecteur": ("déflecteur",),
    "déflecteurs": ("déflecteur",),
    "déflectrice": ("déflecteur",),
    "déflectrices": ("déflecteur",),
    "déformable": ("déformable",),
    "déformables": ("déformable",),
    "déformateur": ("déformateur",),
    "déformateurs": ("déformateur",),
    "déformatrice": ("déformateur",),
    "déformatrices": ("déformateur",),
    "défrichable": ("défrichable",),
    "défrichables": ("défrichable",),
    "défroissable": ("défroissable",),
    "défroissables": ("défroissable",),
    "dégénératif": ("dégénératif",),
    "dégénératifs": ("dégénératif",),
    "dégénérative": ("dégénératif",),
    "dégénératives": ("dégénératif",),
    "dégradable": ("dégradable",),
    "dégradables": ("dégradable",),
    "dégressif": ("dégressif",),
    "dégressifs": ("dégressif",),
    "dégressive": ("dégressif",),
    "dégressives": ("dégressif",),
    "dégueulasse": ("dégueulasse",),
    "dégueulasses": ("dégueulasse",),
    "déhoussable": ("déhoussable",),
    "déhoussables": ("déhoussable",),
    "déhydroascorbique": ("déhydroascorbique",),
    "déhydroascorbiques": ("déhydroascorbique",),
    "déhydrocamphorique": ("déhydrocamphorique",),
    "déhydrocamphoriques": ("déhydrocamphorique",),
    "déhydrocholique": ("déhydrocholique",),
    "déhydrocholiques": ("déhydrocholique",),
    "déicide": ("déicide",),
    "déicides": ("déicide",),
    "déictique": ("déictique",),
    "déictiques": ("déictique",),
    "déiste": ("déiste",),
    "déistes": ("déiste",),
    "délateur": ("délateur",),
    "délateurs": ("délateur",),
    "délatrice": ("délateur",),
    "délatrices": ("délateur",),
    "délayable": ("délayable",),
    "délayables": ("délayable",),
    "délébile": ("délébile",),
    "délébiles": ("délébile",),
    "délectable": ("délectable",),
    "délectables": ("délectable",),
    "délégatif": ("délégatif",),
    "délégatifs": ("délégatif",),
    "délégative": ("délégatif",),
    "délégatives": ("délégatif",),
    "délétère": ("délétère",),
    "délétères": ("délétère",),
    "déliaque": ("déliaque",),
    "déliaques": ("déliaque",),
    "délibératif": ("délibératif",),
    "délibératifs": ("délibératif",),
    "délibérative": ("délibératif",),
    "délibératives": ("délibératif",),
    "délibératoire": ("délibératoire",),
    "délibératoires": ("délibératoire",),
    "délicieuse": ("délicieux",),
    "délicieuses": ("délicieux",),
    "délicieux": ("délicieux",),
    "délictuelle": ("délictuel",),
    "délictuelles": ("délictuel",),
    "délictuel": ("délictuel",),
    "délictuels": ("délictuel",),
    "délictueuse": ("délictueux",),
    "délictueuses": ("délictueux",),
    "délictueux": ("délictueux",),
    "délien": ("délien",),
    "délienne": ("délien",),
    "déliennes": ("délien",),
    "déliens": ("délien",),
    "délimitatif": ("délimitatif",),
    "délimitatifs": ("délimitatif",),
    "délimitative": ("délimitatif",),
    "délimitatives": ("délimitatif",),
    "délirogène": ("délirogène",),
    "délirogènes": ("délirogène",),
    "délocalisable": ("délocalisable",),
    "délocalisables": ("délocalisable",),
    "délogeable": ("délogeable",),
    "délogeables": ("délogeable",),
    "déloyale": ("déloyal",),
    "déloyales": ("déloyal",),
    "déloyal": ("déloyal",),
    "déloyaux": ("déloyal",),
    "delphien": ("delphien",),
    "delphienne": ("delphien",),
    "delphiennes": ("delphien",),
    "delphiens": ("delphien",),
    "delphinale": ("delphinal",),
    "delphinales": ("delphinal",),
    "delphinal": ("delphinal",),
    "delphinaux": ("delphinal",),
    "delphique": ("delphique",),
    "delphiques": ("delphique",),
    "deltaïque": ("deltaïque",),
    "deltaïques": ("deltaïque",),
    "deltidiale": ("deltidial",),
    "deltidiales": ("deltidial",),
    "deltidial": ("deltidial",),
    "deltidiaux": ("deltidial",),
    "deltoïde": ("deltoïde",),
    "deltoïdes": ("deltoïde",),
    "deltoïdien": ("deltoïdien",),
    "deltoïdienne": ("deltoïdien",),
    "deltoïdiennes": ("deltoïdien",),
    "deltoïdiens": ("deltoïdien",),
    "démagogique": ("démagogique",),
    "démagogiques": ("démagogique",),
    "démagogue": ("démagogue",),
    "démagogues": ("démagogue",),
    "demandable": ("demandable",),
    "demandables": ("demandable",),
    "démarcatif": ("démarcatif",),
    "démarcatifs": ("démarcatif",),
    "démarcative": ("démarcatif",),
    "démarcatives": ("démarcatif",),
    "démentielle": ("démentiel",),
    "démentielles": ("démentiel",),
    "démentiel": ("démentiel",),
    "démentiels": ("démentiel",),
    "démerdeur": ("démerdeur",),
    "démerdeurs": ("démerdeur",),
    "démerdeuse": ("démerdeur",),
    "démerdeuses": ("démerdeur",),
    "démersale": ("démersal",),
    "démersales": ("démersal",),
    "démersal": ("démersal",),
    "démersaux": ("démersal",),
    "démineur": ("démineur",),
    "démineurs": ("démineur",),
    "démineuse": ("démineur",),
    "démineuses": ("démineur",),
    "démise": ("démis",),
    "démises": ("démis",),
    "démis": ("démis",),
    "démissionnaire": ("démissionnaire",),
    "démissionnaires": ("démissionnaire",),
    "démiurgique": ("démiurgique",),
    "démiurgiques": ("démiurgique",),
    "démobilisable": ("démobilisable",),
    "démobilisables": ("démobilisable",),
    "démobilisateur": ("démobilisateur",),
    "démobilisateurs": ("démobilisateur",),
    "démobilisatrice": ("démobilisateur",),
    "démobilisatrices": ("démobilisateur",),
    "démochrétien": ("démochrétien",),
    "démochrétienne": ("démochrétien",),
    "démochrétiennes": ("démochrétien",),
    "démochrétiens": ("démochrétien",),
    "démocrate": ("démocrate",),
    "démocrates": ("démocrate",),
    "démocratique": ("démocratique",),
    "démocratiques": ("démocratique",),
    "démodécique": ("démodécique",),
    "démodéciques": ("démodécique",),
    "démographe": ("démographe",),
    "démographes": ("démographe",),
    "démographique": ("démographique",),
    "démographiques": ("démographique",),
    "démoniaque": ("démoniaque",),
    "démoniaques": ("démoniaque",),
    "démonique": ("démonique",),
    "démoniques": ("démonique",),
    "démoniste": ("démoniste",),
    "démonistes": ("démoniste",),
    "démonologique": ("démonologique",),
    "démonologiques": ("démonologique",),
    "démonstratif": ("démonstratif",),
    "démonstratifs": ("démonstratif",),
    "démonstrative": ("démonstratif",),
    "démonstratives": ("démonstratif",),
    "démontable": ("démontable",),
    "démontables": ("démontable",),
    "démontrable": ("démontrable",),
    "démontrables": ("démontrable",),
    "démoralisateur": ("démoralisateur",),
    "démoralisateurs": ("démoralisateur",),
    "démoralisatrice": ("démoralisateur",),
    "démoralisatrices": ("démoralisateur",),
    "démotique": ("démotique",),
    "démotiques": ("démotique",),
    "démultiplicateur": ("démultiplicateur",),
    "démultiplicateurs": ("démultiplicateur",),
    "démultiplicatrice": ("démultiplicateur",),
    "démultiplicatrices": ("démultiplicateur",),
    "démystificateur": ("démystificateur",),
    "démystificateurs": ("démystificateur",),
    "démystificatrice": ("démystificateur",),
    "démystificatrices": ("démystificateur",),
    "dendriforme": ("dendriforme",),
    "dendriformes": ("dendriforme",),
    "dendritique": ("dendritique",),
    "dendritiques": ("dendritique",),
    "dendrochronologique": ("dendrochronologique",),
    "dendrochronologiques": ("dendrochronologique",),
    "dendroïde": ("dendroïde",),
    "dendroïdes": ("dendroïde",),
    "dendrologique": ("dendrologique",),
    "dendrologiques": ("dendrologique",),
    "dendrométrique": ("dendrométrique",),
    "dendrométriques": ("dendrométrique",),
    "dénégatoire": ("dénégatoire",),
    "dénégatoires": ("dénégatoire",),
    "dénigreur": ("dénigreur",),
    "dénigreurs": ("dénigreur",),
    "dénigreuse": ("dénigreur",),
    "dénigreuses": ("dénigreur",),
    "dénombrable": ("dénombrable",),
    "dénombrables": ("dénombrable",),
    "dénominatif": ("dénominatif",),
    "dénominatifs": ("dénominatif",),
    "dénominative": ("dénominatif",),
    "dénominatives": ("dénominatif",),
    "dénonciateur": ("dénonciateur",),
    "dénonciateurs": ("dénonciateur",),
    "dénonciatrice": ("dénonciateur",),
    "dénonciatrices": ("dénonciateur",),
    "dénotatif": ("dénotatif",),
    "dénotatifs": ("dénotatif",),
    "dénotative": ("dénotatif",),
    "dénotatives": ("dénotatif",),
    "dénotationnelle": ("dénotationnel",),
    "dénotationnelles": ("dénotationnel",),
    "dénotationnel": ("dénotationnel",),
    "dénotationnels": ("dénotationnel",),
    "dense": ("dense",),
    "denses": ("dense",),
    "densimétrique": ("densimétrique",),
    "densimétriques": ("densimétrique",),
    "densitaire": ("densitaire",),
    "densitaires": ("densitaire",),
    "densitométrique": ("densitométrique",),
    "densitométriques": ("densitométrique",),
    "dentaire": ("dentaire",),
    "dentaires": ("dentaire",),
    "dentale": ("dental",),
    "dentales": ("dental",),
    "dental": ("dental",),
    "dentaux": ("dental",),
    "dentellière": ("dentellier",),
    "dentellières": ("dentellier",),
    "dentellier": ("dentellier",),
    "dentelliers": ("dentellier",),
    "dentifère": ("dentifère",),
    "dentifères": ("dentifère",),
    "dentifrice": ("dentifrice",),
    "dentifrices": ("dentifrice",),
    "dentigère": ("dentigère",),
    "dentigères": ("dentigère",),
    "dentinaire": ("dentinaire",),
    "dentinaires": ("dentinaire",),
    "dentoalvéolaire": ("dentoalvéolaire",),
    "dentoalvéolaires": ("dentoalvéolaire",),
    "dentoformateur": ("dentoformateur",),
    "dentoformateurs": ("dentoformateur",),
    "dentoformatrice": ("dentoformateur",),
    "dentoformatrices": ("dentoformateur",),
    "dentolabiale": ("dentolabial",),
    "dentolabiales": ("dentolabial",),
    "dentolabial": ("dentolabial",),
    "dentolabiaux": ("dentolabial",),
    "déontique": ("déontique",),
    "déontiques": ("déontique",),
    "déontologique": ("déontologique",),
    "déontologiques": ("déontologique",),
    "dépanneur": ("dépanneur",),
    "dépanneurs": ("dépanneur",),
    "dépanneuse": ("dépanneur",),
    "dépanneuses": ("dépanneur",),
    "départementale": ("départemental",),
    "départementales": ("départemental",),
    "départemental": ("départemental",),
    "départementaux": ("départemental",),
    "départementaliste": ("départementaliste",),
    "départementalistes": ("départementaliste",),
    "départiteur": ("départiteur",),
    "départiteurs": ("départiteur",),
    "départitrice": ("départiteur",),
    "départitrices": ("départiteur",),
    "dépensière": ("dépensier",),
    "dépensières": ("dépensier",),
    "dépensier": ("dépensier",),
    "dépensiers": ("dépensier",),
    "dépicatoire": ("dépicatoire",),
    "dépicatoires": ("dépicatoire",),
    "dépilatoire": ("dépilatoire",),
    "dépilatoires": ("dépilatoire",),
    "dépistable": ("dépistable",),
    "dépistables": ("dépistable",),
    "déplaçable": ("déplaçable",),
    "déplaçables": ("déplaçable",),
    "déplétif": ("déplétif",),
    "déplétifs": ("déplétif",),
    "déplétive": ("déplétif",),
    "déplétives": ("déplétif",),
    "dépliable": ("dépliable",),
    "dépliables": ("dépliable",),
    "déplisseur": ("déplisseur",),
    "déplisseurs": ("déplisseur",),
    "déplisseuse": ("déplisseur",),
    "déplisseuses": ("déplisseur",),
    "déplorable": ("déplorable",),
    "déplorables": ("déplorable",),
    "dépollueur": ("dépollueur",),
    "dépollueurs": ("dépollueur",),
    "dépollueuse": ("dépollueur",),
    "dépollueuses": ("dépollueur",),
    "déposable": ("déposable",),
    "déposables": ("déposable",),
    "dépoussiéreur": ("dépoussiéreur",),
    "dépoussiéreurs": ("dépoussiéreur",),
    "dépoussiéreuse": ("dépoussiéreur",),
    "dépoussiéreuses": ("dépoussiéreur",),
    "dépravateur": ("dépravateur",),
    "dépravateurs": ("dépravateur",),
    "dépravatrice": ("dépravateur",),
    "dépravatrices": ("dépravateur",),
    "déprécatif": ("déprécatif",),
    "déprécatifs": ("déprécatif",),
    "déprécative": ("déprécatif",),
    "déprécatives": ("déprécatif",),
    "déprécatoire": ("déprécatoire",),
    "déprécatoires": ("déprécatoire",),
    "dépréciateur": ("dépréciateur",),
    "dépréciateurs": ("dépréciateur",),
    "dépréciatrice": ("dépréciateur",),
    "dépréciatrices": ("dépréciateur",),
    "dépréciatif": ("dépréciatif",),
    "dépréciatifs": ("dépréciatif",),
    "dépréciative": ("dépréciatif",),
    "dépréciatives": ("dépréciatif",),
    "déprédateur": ("déprédateur",),
    "déprédateurs": ("déprédateur",),
    "déprédatrice": ("déprédateur",),
    "déprédatrices": ("déprédateur",),
    "dépresseur": ("dépresseur",),
    "dépresseurs": ("dépresseur",),
    "dépressif": ("dépressif",),
    "dépressifs": ("dépressif",),
    "dépressive": ("dépressif",),
    "dépressives": ("dépressif",),
    "dépressionnaire": ("dépressionnaire",),
    "dépressionnaires": ("dépressionnaire",),
    "dépressogène": ("dépressogène",),
    "dépressogènes": ("dépressogène",),
    "dépurateur": ("dépurateur",),
    "dépurateurs": ("dépurateur",),
    "dépuratrice": ("dépurateur",),
    "dépuratrices": ("dépurateur",),
    "dépuratif": ("dépuratif",),
    "dépuratifs": ("dépuratif",),
    "dépurative": ("dépuratif",),
    "dépuratives": ("dépuratif",),
    "déracinable": ("déracinable",),
    "déracinables": ("déracinable",),
    "déradelphe": ("déradelphe",),
    "déradelphes": ("déradelphe",),
    "der": ("der",),
    "déraillable": ("déraillable",),
    "déraillables": ("déraillable",),
    "dérailleur": ("dérailleur",),
    "dérailleurs": ("dérailleur",),
    "déraisonnable": ("déraisonnable",),
    "déraisonnables": ("déraisonnable",),
    "déréelle": ("déréel",),
    "déréelles": ("déréel",),
    "déréel": ("déréel",),
    "déréels": ("déréel",),
    "déréistique": ("déréistique",),
    "déréistiques": ("déréistique",),
    "dérisoire": ("dérisoire",),
    "dérisoires": ("dérisoire",),
    "dérivable": ("dérivable",),
    "dérivables": ("dérivable",),
    "dérivatif": ("dérivatif",),
    "dérivatifs": ("dérivatif",),
    "dérivative": ("dérivatif",),
    "dérivatives": ("dérivatif",),
    "dérivationnelle": ("dérivationnel",),
    "dérivationnelles": ("dérivationnel",),
    "dérivationnel": ("dérivationnel",),
    "dérivationnels": ("dérivationnel",),
    "dermanyssique": ("dermanyssique",),
    "dermanyssiques": ("dermanyssique",),
    "dermatologique": ("dermatologique",),
    "dermatologiques": ("dermatologique",),
    "dermatopathique": ("dermatopathique",),
    "dermatopathiques": ("dermatopathique",),
    "dermatoptique": ("dermatoptique",),
    "dermatoptiques": ("dermatoptique",),
    "dermatosparactique": ("dermatosparactique",),
    "dermatosparactiques": ("dermatosparactique",),
    "dermique": ("dermique",),
    "dermiques": ("dermique",),
    "dermoépidermique": ("dermoépidermique",),
    "dermoépidermiques": ("dermoépidermique",),
    "dermoïde": ("dermoïde",),
    "dermoïdes": ("dermoïde",),
    "dermotrope": ("dermotrope",),
    "dermotropes": ("dermotrope",),
    "dernière": ("dernier",),
    "dernières": ("dernier",),
    "dernier": ("dernier",),
    "derniers": ("dernier",),
    "dérobeur": ("dérobeur",),
    "dérobeurs": ("dérobeur",),
    "dérobeuse": ("dérobeur",),
    "dérobeuses": ("dérobeur",),
    "dérogataire": ("dérogataire",),
    "dérogataires": ("dérogataire",),
    "dérogatif": ("dérogatif",),
    "dérogatifs": ("dérogatif",),
    "dérogative": ("dérogatif",),
    "dérogatives": ("dérogatif",),
    "dérogatoire": ("dérogatoire",),
    "dérogatoires": ("dérogatoire",),
    "désactivateur": ("désactivateur",),
    "désactivateurs": ("désactivateur",),
    "désactivatrice": ("désactivateur",),
    "désactivatrices": ("désactivateur",),
    "désagréable": ("désagréable",),
    "désagréables": ("désagréable",),
    "désaliéniste": ("désaliéniste",),
    "désaliénistes": ("désaliéniste",),
    "désapprobateur": ("désapprobateur",),
    "désapprobateurs": ("désapprobateur",),
    "désapprobatrice": ("désapprobateur",),
    "désapprobatrices": ("désapprobateur",),
    "désastreuse": ("désastreux",),
    "désastreuses": ("désastreux",),
    "désastreux": ("désastreux",),
    "désavantageuse": ("désavantageux",),
    "désavantageuses": ("désavantageux",),
    "désavantageux": ("désavantageux",),
    "désavouable": ("désavouable",),
    "désavouables": ("désavouable",),
    "déschlammeur": ("déschlammeur",),
    "déschlammeurs": ("déschlammeur",),
    "descriptible": ("descriptible",),
    "descriptibles": ("descriptible",),
    "descriptif": ("descriptif",),
    "descriptifs": ("descriptif",),
    "descriptive": ("descriptif",),
    "descriptives": ("descriptif",),
    "descriptiviste": ("descriptiviste",),
    "descriptivistes": ("descriptiviste",),
    "désenchanteresse": ("désenchanteur",),
    "désenchanteresses": ("désenchanteur",),
    "désenchanteur": ("désenchanteur",),
    "désenchanteurs": ("désenchanteur",),
    "désenfumable": ("désenfumable",),
    "désenfumables": ("désenfumable",),
    "désensibilisateur": ("désensibilisateur",),
    "désensibilisateurs": ("désensibilisateur",),
    "désensibilisatrice": ("désensibilisateur",),
    "désensibilisatrices": ("désensibilisateur",),
    "déserticole": ("déserticole",),
    "déserticoles": ("déserticole",),
    "désertique": ("désertique",),
    "désertiques": ("désertique",),
    "désherbeur": ("désherbeur",),
    "désherbeurs": ("désherbeur",),
    "désherbeuse": ("désherbeur",),
    "désherbeuses": ("désherbeur",),
    "déshonnête": ("déshonnête",),
    "déshonnêtes": ("déshonnête",),
    "désidératif": ("désidératif",),
    "désidératifs": ("désidératif",),
    "désidérative": ("désidératif",),
    "désidératives": ("désidératif",),
    "design": ("design",),
    "désignatif": ("désignatif",),
    "désignatifs": ("désignatif",),
    "désignative": ("désignatif",),
    "désignatives": ("désignatif",),
    "désinentielle": ("désinentiel",),
    "désinentielles": ("désinentiel",),
    "désinentiel": ("désinentiel",),
    "désinentiels": ("désinentiel",),
    "désinfecteur": ("désinfecteur",),
    "désinfecteurs": ("désinfecteur",),
    "désinfectrice": ("désinfecteur",),
    "désinfectrices": ("désinfecteur",),
    "désinflationniste": ("désinflationniste",),
    "désinflationnistes": ("désinflationniste",),
    "désinformateur": ("désinformateur",),
    "désinformateurs": ("désinformateur",),
    "désinformatrice": ("désinformateur",),
    "désinformatrices": ("désinformateur",),
    "désinhibiteur": ("désinhibiteur",),
    "désinhibiteurs": ("désinhibiteur",),
    "désinhibitrice": ("désinhibiteur",),
    "désinhibitrices": ("désinhibiteur",),
    "désinvolte": ("désinvolte",),
    "désinvoltes": ("désinvolte",),
    "désirable": ("désirable",),
    "désirables": ("désirable",),
    "désireuse": ("désireux",),
    "désireuses": ("désireux",),
    "désireux": ("désireux",),
    "desmodromique": ("desmodromique",),
    "desmodromiques": ("desmodromique",),
    "desmoïde": ("desmoïde",),
    "desmoïdes": ("desmoïde",),
    "desmotrope": ("desmotrope",),
    "desmotropes": ("desmotrope",),
    "desmotropique": ("desmotropique",),
    "desmotropiques": ("desmotropique",),
    "désorganisateur": ("désorganisateur",),
    "désorganisateurs": ("désorganisateur",),
    "désorganisatrice": ("désorganisateur",),
    "désorganisatrices": ("désorganisateur",),
    "désoxycholique": ("désoxycholique",),
    "désoxycholiques": ("désoxycholique",),
    "désoxyribonucléique": ("désoxyribonucléique",),
    "désoxyribonucléiques": ("désoxyribonucléique",),
    "despiciens": ("despiciens",),
    "despote": ("despote",),
    "despotes": ("despote",),
    "despotique": ("despotique",),
    "despotiques": ("despotique",),
    "desquamatif": ("desquamatif",),
    "desquamatifs": ("desquamatif",),
    "desquamative": ("desquamatif",),
    "desquamatives": ("desquamatif",),
    "dessiccatif": ("dessiccatif",),
    "dessiccatifs": ("dessiccatif",),
    "dessiccative": ("dessiccatif",),
    "dessiccatives": ("dessiccatif",),
    "dessinable": ("dessinable",),
    "dessinables": ("dessinable",),
    "dessoucheur": ("dessoucheur",),
    "dessoucheurs": ("dessoucheur",),
    "dessoucheuse": ("dessoucheur",),
    "dessoucheuses": ("dessoucheur",),
    "déstabilisateur": ("déstabilisateur",),
    "déstabilisateurs": ("déstabilisateur",),
    "déstabilisatrice": ("déstabilisateur",),
    "déstabilisatrices": ("déstabilisateur",),
    "destinataire": ("destinataire",),
    "destinataires": ("destinataire",),
    "destituable": ("destituable",),
    "destituables": ("destituable",),
    "destructeur": ("destructeur",),
    "destructeurs": ("destructeur",),
    "destructrice": ("destructeur",),
    "destructrices": ("destructeur",),
    "destructible": ("destructible",),
    "destructibles": ("destructible",),
    "destructif": ("destructif",),
    "destructifs": ("destructif",),
    "destructive": ("destructif",),
    "destructives": ("destructif",),
    "désuète": ("désuet",),
    "désuètes": ("désuet",),
    "désuet": ("désuet",),
    "désuets": ("désuet",),
    "détachable": ("détachable",),
    "détachables": ("détachable",),
    "détartreur": ("détartreur",),
    "détartreurs": ("détartreur",),
    "détectable": ("détectable",),
    "détectables": ("détectable",),
    "détecteur": ("détecteur",),
    "détecteurs": ("détecteur",),
    "détectrice": ("détecteur",),
    "détectrices": ("détecteur",),
    "détenteur": ("détenteur",),
    "détenteurs": ("détenteur",),
    "détentrice": ("détenteur",),
    "détentrices": ("détenteur",),
    "détentionnaire": ("détentionnaire",),
    "détentionnaires": ("détentionnaire",),
    "détérioratif": ("détérioratif",),
    "détérioratifs": ("détérioratif",),
    "détériorative": ("détérioratif",),
    "détérioratives": ("détérioratif",),
    "déterminable": ("déterminable",),
    "déterminables": ("déterminable",),
    "déterminatif": ("déterminatif",),
    "déterminatifs": ("déterminatif",),
    "déterminative": ("déterminatif",),
    "déterminatives": ("déterminatif",),
    "déterministe": ("déterministe",),
    "déterministes": ("déterministe",),
    "détersif": ("détersif",),
    "détersifs": ("détersif",),
    "détersive": ("détersif",),
    "détersives": ("détersif",),
    "détestable": ("détestable",),
    "détestables": ("détestable",),
    "détorse": ("détors",),
    "détorses": ("détors",),
    "détors": ("détors",),
    "détracteur": ("détracteur",),
    "détracteurs": ("détracteur",),
    "détractrice": ("détracteur",),
    "détractrices": ("détracteur",),
    "détriticole": ("détriticole",),
    "détriticoles": ("détriticole",),
    "détritique": ("détritique",),
    "détritiques": ("détritique",),
    "détritivore": ("détritivore",),
    "détritivores": ("détritivore",),
    "deutéranope": ("deutéranope",),
    "deutéranopes": ("deutéranope",),
    "deutérique": ("deutérique",),
    "deutériques": ("deutérique",),
    "deutérocanonique": ("deutérocanonique",),
    "deutérocanoniques": ("deutérocanonique",),
    "deutérotoque": ("deutérotoque",),
    "deutérotoques": ("deutérotoque",),
    "deuxième": ("deuxième",),
    "deuxièmes": ("deuxième",),
    "dévaginable": ("dévaginable",),
    "dévaginables": ("dévaginable",),
    "devanâgari": ("devanâgari",),
    "devanâgaris": ("devanâgari",),
    "dévastateur": ("dévastateur",),
    "dévastateurs": ("dévastateur",),
    "dévastatrice": ("dévastateur",),
    "dévastatrices": ("dévastateur",),
    "développable": ("développable",),
    "développables": ("développable",),
    "développementaliste": ("développementaliste",),
    "développementalistes": ("développementaliste",),
    "déverbale": ("déverbal",),
    "déverbales": ("déverbal",),
    "déverbal": ("déverbal",),
    "déverbaux": ("déverbal",),
    "déverbatif": ("déverbatif",),
    "déverbatifs": ("déverbatif",),
    "déverbative": ("déverbatif",),
    "déverbatives": ("déverbatif",),
    "déverse": ("dévers",),
    "déverses": ("dévers",),
    "dévers": ("dévers",),
    "déviateur": ("déviateur",),
    "déviateurs": ("déviateur",),
    "déviatrice": ("déviateur",),
    "déviatrices": ("déviateur",),
    "déviationniste": ("déviationniste",),
    "déviationnistes": ("déviationniste",),
    "devinable": ("devinable",),
    "devinables": ("devinable",),
    "dévissable": ("dévissable",),
    "dévissables": ("dévissable",),
    "dévitrifiable": ("dévitrifiable",),
    "dévitrifiables": ("dévitrifiable",),
    "dévolutif": ("dévolutif",),
    "dévolutifs": ("dévolutif",),
    "dévolutive": ("dévolutif",),
    "dévolutives": ("dévolutif",),
    "dévonien": ("dévonien",),
    "dévonienne": ("dévonien",),
    "dévoniennes": ("dévonien",),
    "dévoniens": ("dévonien",),
    "dévorateur": ("dévorateur",),
    "dévorateurs": ("dévorateur",),
    "dévoratrice": ("dévorateur",),
    "dévoratrices": ("dévorateur",),
    "dévoreur": ("dévoreur",),
    "dévoreurs": ("dévoreur",),
    "dévoreuse": ("dévoreur",),
    "dévoreuses": ("dévoreur",),
    "dévotieuse": ("dévotieux",),
    "dévotieuses": ("dévotieux",),
    "dévotieux": ("dévotieux",),
    "dévotionnelle": ("dévotionnel",),
    "dévotionnelles": ("dévotionnel",),
    "dévotionnel": ("dévotionnel",),
    "dévotionnels": ("dévotionnel",),
    "dextre": ("dextre",),
    "dextres": ("dextre",),
    "dextrogyre": ("dextrogyre",),
    "dextrogyres": ("dextrogyre",),
    "dextrorsum": ("dextrorsum",),
    "diabétique": ("diabétique",),
    "diabétiques": ("diabétique",),
    "diabétogène": ("diabétogène",),
    "diabétogènes": ("diabétogène",),
    "diabétologique": ("diabétologique",),
    "diabétologiques": ("diabétologique",),
    "diable": ("diable",),
    "diables": ("diable",),
    "diabolique": ("diabolique",),
    "diaboliques": ("diabolique",),
    "diacétique": ("diacétique",),
    "diacétiques": ("diacétique",),
    "diacétylénique": ("diacétylénique",),
    "diacétyléniques": ("diacétylénique",),
    "diacétylsuccinique": ("diacétylsuccinique",),
    "diacétylsucciniques": ("diacétylsuccinique",),
    "diachronique": ("diachronique",),
    "diachroniques": ("diachronique",),
    "diacide": ("diacide",),
    "diacides": ("diacide",),
    "diacode": ("diacode",),
    "diacodes": ("diacode",),
    "diaconale": ("diaconal",),
    "diaconales": ("diaconal",),
    "diaconal": ("diaconal",),
    "diaconaux": ("diaconal",),
    "diacondylien": ("diacondylien",),
    "diacondylienne": ("diacondylien",),
    "diacondyliennes": ("diacondylien",),
    "diacondyliens": ("diacondylien",),
    "diacritique": ("diacritique",),
    "diacritiques": ("diacritique",),
    "diadelphe": ("diadelphe",),
    "diadelphes": ("diadelphe",),
    "diadique": ("diadique",),
    "diadiques": ("diadique",),
    "diadochique": ("diadochique",),
    "diadochiques": ("diadochique",),
    "diadrome": ("diadrome",),
    "diadromes": ("diadrome",),
    "diagénétique": ("diagénétique",),
    "diagénétiques": ("diagénétique",),
    "diagnostiquable": ("diagnostiquable",),
    "diagnostiquables": ("diagnostiquable",),
    "diagnostique": ("diagnostique",),
    "diagnostiques": ("diagnostique",),
    "diagométrique": ("diagométrique",),
    "diagométriques": ("diagométrique",),
    "diagonale": ("diagonal",),
    "diagonales": ("diagonal",),
    "diagonal": ("diagonal",),
    "diagonaux": ("diagonal",),
    "diagonalisable": ("diagonalisable",),
    "diagonalisables": ("diagonalisable",),
    "diagynique": ("diagynique",),
    "diagyniques": ("diagynique",),
    "diakène": ("diakène",),
    "diakènes": ("diakène",),
    "dialectale": ("dialectal",),
    "dialectales": ("dialectal",),
    "dialectal": ("dialectal",),
    "dialectaux": ("dialectal",),
    "dialectique": ("dialectique",),
    "dialectiques": ("dialectique",),
    "dialectisable": ("dialectisable",),
    "dialectisables": ("dialectisable",),
    "dialectologique": ("dialectologique",),
    "dialectologiques": ("dialectologique",),
    "dialectophone": ("dialectophone",),
    "dialectophones": ("dialectophone",),
    "dialegmatique": ("dialegmatique",),
    "dialegmatiques": ("dialegmatique",),
    "diallagique": ("diallagique",),
    "diallagiques": ("diallagique",),
    "dialogique": ("dialogique",),
    "dialogiques": ("dialogique",),
    "dialoguale": ("dialogual",),
    "dialoguales": ("dialogual",),
    "dialogual": ("dialogual",),
    "dialoguaux": ("dialogual",),
    "dialurique": ("dialurique",),
    "dialuriques": ("dialurique",),
    "dialycarpique": ("dialycarpique",),
    "dialycarpiques": ("dialycarpique",),
    "dialypétale": ("dialypétale",),
    "dialypétales": ("dialypétale",),
    "dialysable": ("dialysable",),
    "dialysables": ("dialysable",),
    "dialysépale": ("dialysépale",),
    "dialysépales": ("dialysépale",),
    "diamagnétique": ("diamagnétique",),
    "diamagnétiques": ("diamagnétique",),
    "diamantaire": ("diamantaire",),
    "diamantaires": ("diamantaire",),
    "diamantifère": ("diamantifère",),
    "diamantifères": ("diamantifère",),
    "diaméatique": ("diaméatique",),
    "diaméatiques": ("diaméatique",),
    "diamétrale": ("diamétral",),
    "diamétrales": ("diamétral",),
    "diamétral": ("diamétral",),
    "diamétraux": ("diamétral",),
    "diammonique": ("diammonique",),
    "diammoniques": ("diammonique",),
    "diamniotique": ("diamniotique",),
    "diamniotiques": ("diamniotique",),
    "diandrique": ("diandrique",),
    "diandriques": ("diandrique",),
    "dianétique": ("dianétique",),
    "dianétiques": ("dianétique",),
    "diaphane": ("diaphane",),
    "diaphanes": ("diaphane",),
    "diaphonique": ("diaphonique",),
    "diaphoniques": ("diaphonique",),
    "diaphonométrique": ("diaphonométrique",),
    "diaphonométriques": ("diaphonométrique",),
    "diaphorétique": ("diaphorétique",),
    "diaphorétiques": ("diaphorétique",),
    "diaphragmatique": ("diaphragmatique",),
    "diaphragmatiques": ("diaphragmatique",),
    "diaphysaire": ("diaphysaire",),
    "diaphysaires": ("diaphysaire",),
    "diapirique": ("diapirique",),
    "diapiriques": ("diapirique",),
    "diaporématique": ("diaporématique",),
    "diaporématiques": ("diaporématique",),
    "diarrhéique": ("diarrhéique",),
    "diarrhéiques": ("diarrhéique",),
    "diarthrodiale": ("diarthrodial",),
    "diarthrodiales": ("diarthrodial",),
    "diarthrodial": ("diarthrodial",),
    "diarthrodiaux": ("diarthrodial",),
    "diascopique": ("diascopique",),
    "diascopiques": ("diascopique",),
    "diasporique": ("diasporique",),
    "diasporiques": ("diasporique",),
    "diastasigène": ("diastasigène",),
    "diastasigènes": ("diastasigène",),
    "diastasique": ("diastasique",),
    "diastasiques": ("diastasique",),
    "diastématique": ("diastématique",),
    "diastématiques": ("diastématique",),
    "diastimométrique": ("diastimométrique",),
    "diastimométriques": ("diastimométrique",),
    "diastolique": ("diastolique",),
    "diastoliques": ("diastolique",),
    "diastrophique": ("diastrophique",),
    "diastrophiques": ("diastrophique",),
    "diathermane": ("diathermane",),
    "diathermanes": ("diathermane",),
    "diatherme": ("diatherme",),
    "diathermes": ("diatherme",),
    "diathermique": ("diathermique",),
    "diathermiques": ("diathermique",),
    "diathésique": ("diathésique",),
    "diathésiques": ("diathésique",),
    "diatomique": ("diatomique",),
    "diatomiques": ("diatomique",),
    "diatonique": ("diatonique",),
    "diatoniques": ("diatonique",),
    "diazoacétique": ("diazoacétique",),
    "diazoacétiques": ("diazoacétique",),
    "diazoïque": ("diazoïque",),
    "diazoïques": ("diazoïque",),
    "diazotypique": ("diazotypique",),
    "diazotypiques": ("diazotypique",),
    "dibasique": ("dibasique",),
    "dibasiques": ("dibasique",),
    "dibromosuccinique": ("dibromosuccinique",),
    "dibromosucciniques": ("dibromosuccinique",),
    "dicalcique": ("dicalcique",),
    "dicalciques": ("dicalcique",),
    "dicarboxylique": ("dicarboxylique",),
    "dicarboxyliques": ("dicarboxylique",),
    "dicaryotique": ("dicaryotique",),
    "dicaryotiques": ("dicaryotique",),
    "dicéphale": ("dicéphale",),
    "dicéphales": ("dicéphale",),
    "dicétonique": ("dicétonique",),
    "dicétoniques": ("dicétonique",),
    "dichloracétique": ("dichloracétique",),
    "dichloracétiques": ("dichloracétique",),
    "dichlorophénoxyacétique": ("dichlorophénoxyacétique",),
    "dichlorophénoxyacétiques": ("dichlorophénoxyacétique",),
    "dichogame": ("dichogame",),
    "dichogames": ("dichogame",),
    "dichorionique": ("dichorionique",),
    "dichorioniques": ("dichorionique",),
    "dichotique": ("dichotique",),
    "dichotiques": ("dichotique",),
    "dichotome": ("dichotome",),
    "dichotomes": ("dichotome",),
    "dichotomique": ("dichotomique",),
    "dichotomiques": ("dichotomique",),
    "dichroïque": ("dichroïque",),
    "dichroïques": ("dichroïque",),
    "dichromate": ("dichromate",),
    "dichromates": ("dichromate",),
    "dichromatique": ("dichromatique",),
    "dichromatiques": ("dichromatique",),
    "dichroscopique": ("dichroscopique",),
    "dichroscopiques": ("dichroscopique",),
    "dicible": ("dicible",),
    "dicibles": ("dicible",),
    "dickensien": ("dickensien",),
    "dickensienne": ("dickensien",),
    "dickensiennes": ("dickensien",),
    "dickensiens": ("dickensien",),
    "dicline": ("dicline",),
    "diclines": ("dicline",),
    "dicotylédonée": ("dicotylédoné",),
    "dicotylédonées": ("dicotylédoné",),
    "dicotylédoné": ("dicotylédoné",),
    "dicotylédone": ("dicotylédone",),
    "dicotylédonés": ("dicotylédoné",),
    "dicotylédones": ("dicotylédone",),
    "dicrote": ("dicrote",),
    "dicrotes": ("dicrote",),
    "dictatoriale": ("dictatorial",),
    "dictatoriales": ("dictatorial",),
    "dictatorial": ("dictatorial",),
    "dictatoriaux": ("dictatorial",),
    "dictionnairique": ("dictionnairique",),
    "dictionnairiques": ("dictionnairique",),
    "dictyocytaire": ("dictyocytaire",),
    "dictyocytaires": ("dictyocytaire",),
    "didactique": ("didactique",),
    "didactiques": ("didactique",),
    "didactyle": ("didactyle",),
    "didactyles": ("didactyle",),
    "didelphe": ("didelphe",),
    "didelphes": ("didelphe",),
    "didermique": ("didermique",),
    "didermiques": ("didermique",),
    "diducteur": ("diducteur",),
    "diducteurs": ("diducteur",),
    "diductrice": ("diducteur",),
    "diductrices": ("diducteur",),
    "didyme": ("didyme",),
    "didymes": ("didyme",),
    "diédrale": ("diédral",),
    "diédrales": ("diédral",),
    "diédral": ("diédral",),
    "diédraux": ("diédral",),
    "dièdre": ("dièdre",),
    "dièdres": ("dièdre",),
    "diédrique": ("diédrique",),
    "diédriques": ("diédrique",),
    "diégétique": ("diégétique",),
    "diégétiques": ("diégétique",),
    "diélectrique": ("diélectrique",),
    "diélectriques": ("diélectrique",),
    "diélectrophorétique": ("diélectrophorétique",),
    "diélectrophorétiques": ("diélectrophorétique",),
    "diencéphalique": ("diencéphalique",),
    "diencéphaliques": ("diencéphalique",),
    "diénique": ("diénique",),
    "diéniques": ("diénique",),
    "dieppoise": ("dieppois",),
    "dieppoises": ("dieppois",),
    "dieppois": ("dieppois",),
    "diésée": ("diésé",),
    "diésées": ("diésé",),
    "diésé": ("diésé",),
    "dièse": ("dièse",),
    "diésés": ("diésé",),
    "diesel": ("diesel",),
    "diététique": ("diététique",),
    "diététiques": ("diététique",),
    "diéthylbarbiturique": ("diéthylbarbiturique",),
    "diéthylbarbituriques": ("diéthylbarbiturique",),
    "diéthylénique": ("diéthylénique",),
    "diéthyléniques": ("diéthylénique",),
    "diéthylique": ("diéthylique",),
    "diéthyliques": ("diéthylique",),
    "diffamateur": ("diffamateur",),
    "diffamateurs": ("diffamateur",),
    "diffamatrice": ("diffamateur",),
    "diffamatrices": ("diffamateur",),
    "diffamatoire": ("diffamatoire",),
    "diffamatoires": ("diffamatoire",),
    "différenciable": ("différenciable",),
    "différenciables": ("différenciable",),
    "différenciateur": ("différenciateur",),
    "différenciateurs": ("différenciateur",),
    "différenciatrice": ("différenciateur",),
    "différenciatrices": ("différenciateur",),
    "différenciatif": ("différenciatif",),
    "différenciatifs": ("différenciatif",),
    "différenciative": ("différenciatif",),
    "différenciatives": ("différenciatif",),
    "différentiable": ("différentiable",),
    "différentiables": ("différentiable",),
    "différentielle": ("différentiel",),
    "différentielles": ("différentiel",),
    "différentiel": ("différentiel",),
    "différentiels": ("différentiel",),
    "difficile": ("difficile",),
    "difficiles": ("difficile",),
    "difficultueuse": ("difficultueux",),
    "difficultueuses": ("difficultueux",),
    "difficultueux": ("difficultueux",),
    "difforme": ("difforme",),
    "difformes": ("difforme",),
    "diffusable": ("diffusable",),
    "diffusables": ("diffusable",),
    "diffuse": ("diffus",),
    "diffuses": ("diffus",),
    "diffus": ("diffus",),
    "diffusible": ("diffusible",),
    "diffusibles": ("diffusible",),
    "diffusionniste": ("diffusionniste",),
    "diffusionnistes": ("diffusionniste",),
    "digallique": ("digallique",),
    "digalliques": ("digallique",),
    "digastrique": ("digastrique",),
    "digastriques": ("digastrique",),
    "digérable": ("digérable",),
    "digérables": ("digérable",),
    "digeste": ("digeste",),
    "digestes": ("digeste",),
    "digestible": ("digestible",),
    "digestibles": ("digestible",),
    "digestif": ("digestif",),
    "digestifs": ("digestif",),
    "digestive": ("digestif",),
    "digestives": ("digestif",),
    "digitale": ("digital",),
    "digitales": ("digital",),
    "digital": ("digital",),
    "digitaux": ("digital",),
    "digitalique": ("digitalique",),
    "digitaliques": ("digitalique",),
    "digitiforme": ("digitiforme",),
    "digitiformes": ("digitiforme",),
    "digitigrade": ("digitigrade",),
    "digitigrades": ("digitigrade",),
    "diglossique": ("diglossique",),
    "diglossiques": ("diglossique",),
    "diglycolique": ("diglycolique",),
    "diglycoliques": ("diglycolique",),
    "digne": ("digne",),
    "dignes": ("digne",),
    "dignitaire": ("dignitaire",),
    "dignitaires": ("dignitaire",),
    "digonale": ("digonal",),
    "digonales": ("digonal",),
    "digonal": ("digonal",),
    "digonaux": ("digonal",),
    "digressif": ("digressif",),
    "digressifs": ("digressif",),
    "digressive": ("digressif",),
    "digressives": ("digressif",),
    "dihydroxybenzoïque": ("dihydroxybenzoïque",),
    "dihydroxybenzoïques": ("dihydroxybenzoïque",),
    "dihydroxymalonique": ("dihydroxymalonique",),
    "dihydroxymaloniques": ("dihydroxymalonique",),
    "dijonnaise": ("dijonnais",),
    "dijonnaises": ("dijonnais",),
    "dijonnais": ("dijonnais",),
    "dilapidateur": ("dilapidateur",),
    "dilapidateurs": ("dilapidateur",),
    "dilapidatrice": ("dilapidateur",),
    "dilapidatrices": ("dilapidateur",),
    "dilatable": ("dilatable",),
    "dilatables": ("dilatable",),
    "dilatateur": ("dilatateur",),
    "dilatateurs": ("dilatateur",),
    "dilatatrice": ("dilatateur",),
    "dilatatrices": ("dilatateur",),
    "dilatoire": ("dilatoire",),
    "dilatoires": ("dilatoire",),
    "dilatométrique": ("dilatométrique",),
    "dilatométriques": ("dilatométrique",),
    "dilemmatique": ("dilemmatique",),
    "dilemmatiques": ("dilemmatique",),
    "dilettante": ("dilettante",),
    "dilettantes": ("dilettante",),
    "diluable": ("diluable",),
    "diluables": ("diluable",),
    "dilutif": ("dilutif",),
    "dilutifs": ("dilutif",),
    "dilutive": ("dilutif",),
    "dilutives": ("dilutif",),
    "diluviale": ("diluvial",),
    "diluviales": ("diluvial",),
    "diluvial": ("diluvial",),
    "diluviaux": ("diluvial",),
    "diluvien": ("diluvien",),
    "diluvienne": ("diluvien",),
    "diluviennes": ("diluvien",),
    "diluviens": ("diluvien",),
    "dimensionnelle": ("dimensionnel",),
    "dimensionnelles": ("dimensionnel",),
    "dimensionnel": ("dimensionnel",),
    "dimensionnels": ("dimensionnel",),
    "dimère": ("dimère",),
    "dimères": ("dimère",),
    "dimérique": ("dimérique",),
    "dimériques": ("dimérique",),
    "diméthylacétique": ("diméthylacétique",),
    "diméthylacétiques": ("diméthylacétique",),
    "diméthylallylique": ("diméthylallylique",),
    "diméthylallyliques": ("diméthylallylique",),
    "diméthylique": ("diméthylique",),
    "diméthyliques": ("diméthylique",),
    "dimètre": ("dimètre",),
    "dimètres": ("dimètre",),
    "dimictique": ("dimictique",),
    "dimictiques": ("dimictique",),
    "dîmière": ("dîmier",),
    "dîmières": ("dîmier",),
    "dîmier": ("dîmier",),
    "dîmiers": ("dîmier",),
    "diminutif": ("diminutif",),
    "diminutifs": ("diminutif",),
    "diminutive": ("diminutif",),
    "diminutives": ("diminutif",),
    "dimissoriale": ("dimissorial",),
    "dimissoriales": ("dimissorial",),
    "dimissorial": ("dimissorial",),
    "dimissoriaux": ("dimissorial",),
    "dimorphe": ("dimorphe",),
    "dimorphes": ("dimorphe",),
    "d'importance": ("d'importance",),
    "dinantien": ("dinantien",),
    "dinantienne": ("dinantien",),
    "dinantiennes": ("dinantien",),
    "dinantiens": ("dinantien",),
    "dinarique": ("dinarique",),
    "dinariques": ("dinarique",),
    "dînatoire": ("dînatoire",),
    "dînatoires": ("dînatoire",),
    "dingo": ("dingo",),
    "dingos": ("dingo",),
    "dingue": ("dingue",),
    "dingues": ("dingue",),
    "dioecique": ("dioecique",),
    "dioeciques": ("dioecique",),
    "dioïque": ("dioïque",),
    "dioïques": ("dioïque",),
    "dionysiaque": ("dionysiaque",),
    "dionysiaques": ("dionysiaque",),
    "dionysien": ("dionysien",),
    "dionysienne": ("dionysien",),
    "dionysiennes": ("dionysien",),
    "dionysiens": ("dionysien",),
    "diophantien": ("diophantien",),
    "diophantienne": ("diophantien",),
    "diophantiennes": ("diophantien",),
    "diophantiens": ("diophantien",),
    "dioptrique": ("dioptrique",),
    "dioptriques": ("dioptrique",),
    "dioramique": ("dioramique",),
    "dioramiques": ("dioramique",),
    "diotique": ("diotique",),
    "diotiques": ("diotique",),
    "dipétale": ("dipétale",),
    "dipétales": ("dipétale",),
    "diphasique": ("diphasique",),
    "diphasiques": ("diphasique",),
    "diphénique": ("diphénique",),
    "diphéniques": ("diphénique",),
    "diphénylacétique": ("diphénylacétique",),
    "diphénylacétiques": ("diphénylacétique",),
    "diphénylglyoxilique": ("diphénylglyoxilique",),
    "diphénylglyoxiliques": ("diphénylglyoxilique",),
    "diphosphorique": ("diphosphorique",),
    "diphosphoriques": ("diphosphorique",),
    "diphtérimorphe": ("diphtérimorphe",),
    "diphtérimorphes": ("diphtérimorphe",),
    "diphtérique": ("diphtérique",),
    "diphtériques": ("diphtérique",),
    "diphtéroïde": ("diphtéroïde",),
    "diphtéroïdes": ("diphtéroïde",),
    "diphyodonte": ("diphyodonte",),
    "diphyodontes": ("diphyodonte",),
    "diplex": ("diplex",),
    "diplobiontique": ("diplobiontique",),
    "diplobiontiques": ("diplobiontique",),
    "diploblastique": ("diploblastique",),
    "diploblastiques": ("diploblastique",),
    "diplocéphale": ("diplocéphale",),
    "diplocéphales": ("diplocéphale",),
    "diploïde": ("diploïde",),
    "diploïdes": ("diploïde",),
    "diploïque": ("diploïque",),
    "diploïques": ("diploïque",),
    "diplomate": ("diplomate",),
    "diplomates": ("diplomate",),
    "diplomatique": ("diplomatique",),
    "diplomatiques": ("diplomatique",),
    "dipneumonée": ("dipneumoné",),
    "dipneumonées": ("dipneumoné",),
    "dipneumoné": ("dipneumoné",),
    "dipneumone": ("dipneumone",),
    "dipneumonés": ("dipneumoné",),
    "dipneumones": ("dipneumone",),
    "dipode": ("dipode",),
    "dipodes": ("dipode",),
    "dipolaire": ("dipolaire",),
    "dipolaires": ("dipolaire",),
    "dipsomane": ("dipsomane",),
    "dipsomanes": ("dipsomane",),
    "dipsomaniaque": ("dipsomaniaque",),
    "dipsomaniaques": ("dipsomaniaque",),
    "diptère": ("diptère",),
    "diptères": ("diptère",),
    "diptérique": ("diptérique",),
    "diptériques": ("diptérique",),
    "dipyge": ("dipyge",),
    "dipyges": ("dipyge",),
    "directeur": ("directeur",),
    "directeurs": ("directeur",),
    "directrice": ("directeur",),
    "directrices": ("directeur",),
    "directif": ("directif",),
    "directifs": ("directif",),
    "directive": ("directif",),
    "directives": ("directif",),
    "directionnelle": ("directionnel",),
    "directionnelles": ("directionnel",),
    "directionnel": ("directionnel",),
    "directionnels": ("directionnel",),
    "directoriale": ("directorial",),
    "directoriales": ("directorial",),
    "directorial": ("directorial",),
    "directoriaux": ("directorial",),
    "dirigeable": ("dirigeable",),
    "dirigeables": ("dirigeable",),
    "dirigiste": ("dirigiste",),
    "dirigistes": ("dirigiste",),
    "disazoïque": ("disazoïque",),
    "disazoïques": ("disazoïque",),
    "discale": ("discal",),
    "discales": ("discal",),
    "discal": ("discal",),
    "discaux": ("discal",),
    "discernable": ("discernable",),
    "discernables": ("discernable",),
    "disciplinable": ("disciplinable",),
    "disciplinables": ("disciplinable",),
    "disciplinaire": ("disciplinaire",),
    "disciplinaires": ("disciplinaire",),
    "disco": ("disco",),
    "discobole": ("discobole",),
    "discoboles": ("discobole",),
    "discographique": ("discographique",),
    "discographiques": ("discographique",),
    "discoïdale": ("discoïdal",),
    "discoïdales": ("discoïdal",),
    "discoïdal": ("discoïdal",),
    "discoïdaux": ("discoïdal",),
    "discoïde": ("discoïde",),
    "discoïdes": ("discoïde",),
    "discophile": ("discophile",),
    "discophiles": ("discophile",),
    "discophilique": ("discophilique",),
    "discophiliques": ("discophilique",),
    "discoradiculaire": ("discoradiculaire",),
    "discoradiculaires": ("discoradiculaire",),
    "discourtoise": ("discourtois",),
    "discourtoises": ("discourtois",),
    "discourtois": ("discourtois",),
    "discrète": ("discret",),
    "discrètes": ("discret",),
    "discret": ("discret",),
    "discrets": ("discret",),
    "discrétionnaire": ("discrétionnaire",),
    "discrétionnaires": ("discrétionnaire",),
    "discriminatif": ("discriminatif",),
    "discriminatifs": ("discriminatif",),
    "discriminative": ("discriminatif",),
    "discriminatives": ("discriminatif",),
    "discriminatoire": ("discriminatoire",),
    "discriminatoires": ("discriminatoire",),
    "discursif": ("discursif",),
    "discursifs": ("discursif",),
    "discursive": ("discursif",),
    "discursives": ("discursif",),
    "discutable": ("discutable",),
    "discutables": ("discutable",),
    "discutailleur": ("discutailleur",),
    "discutailleurs": ("discutailleur",),
    "discutailleuse": ("discutailleur",),
    "discutailleuses": ("discutailleur",),
    "discuteur": ("discuteur",),
    "discuteurs": ("discuteur",),
    "discuteuse": ("discuteur",),
    "discuteuses": ("discuteur",),
    "disetteuse": ("disetteux",),
    "disetteuses": ("disetteux",),
    "disetteux": ("disetteux",),
    "disgracieuse": ("disgracieux",),
    "disgracieuses": ("disgracieux",),
    "disgracieux": ("disgracieux",),
    "disharmonique": ("disharmonique",),
    "disharmoniques": ("disharmonique",),
    "disjonctif": ("disjonctif",),
    "disjonctifs": ("disjonctif",),
    "disjonctive": ("disjonctif",),
    "disjonctives": ("disjonctif",),
    "dismutase": ("dismutase",),
    "dismutases": ("dismutase",),
    "disodique": ("disodique",),
    "disodiques": ("disodique",),
    "disparate": ("disparate",),
    "disparates": ("disparate",),
    "dispendieuse": ("dispendieux",),
    "dispendieuses": ("dispendieux",),
    "dispendieux": ("dispendieux",),
    "dispensable": ("dispensable",),
    "dispensables": ("dispensable",),
    "dispensateur": ("dispensateur",),
    "dispensateurs": ("dispensateur",),
    "dispensatrice": ("dispensateur",),
    "dispensatrices": ("dispensateur",),
    "dispersif": ("dispersif",),
    "dispersifs": ("dispersif",),
    "dispersive": ("dispersif",),
    "dispersives": ("dispersif",),
    "dispersoïde": ("dispersoïde",),
    "dispersoïdes": ("dispersoïde",),
    "dispondaïque": ("dispondaïque",),
    "dispondaïques": ("dispondaïque",),
    "disponible": ("disponible",),
    "disponibles": ("disponible",),
    "dispose": ("dispos",),
    "disposes": ("dispos",),
    "dispos": ("dispos",),
    "dispositif": ("dispositif",),
    "dispositifs": ("dispositif",),
    "dispositive": ("dispositif",),
    "dispositives": ("dispositif",),
    "dispositionnelle": ("dispositionnel",),
    "dispositionnelles": ("dispositionnel",),
    "dispositionnel": ("dispositionnel",),
    "dispositionnels": ("dispositionnel",),
    "disproportionnelle": ("disproportionnel",),
    "disproportionnelles": ("disproportionnel",),
    "disproportionnel": ("disproportionnel",),
    "disproportionnels": ("disproportionnel",),
    "disputable": ("disputable",),
    "disputables": ("disputable",),
    "disputailleur": ("disputailleur",),
    "disputailleurs": ("disputailleur",),
    "disputailleuse": ("disputailleur",),
    "disputailleuses": ("disputailleur",),
    "disruptif": ("disruptif",),
    "disruptifs": ("disruptif",),
    "disruptive": ("disruptif",),
    "disruptives": ("disruptif",),
    "dissécable": ("dissécable",),
    "dissécables": ("dissécable",),
    "dissemblable": ("dissemblable",),
    "dissemblables": ("dissemblable",),
    "dissimulateur": ("dissimulateur",),
    "dissimulateurs": ("dissimulateur",),
    "dissimulatrice": ("dissimulateur",),
    "dissimulatrices": ("dissimulateur",),
    "dissipateur": ("dissipateur",),
    "dissipateurs": ("dissipateur",),
    "dissipatrice": ("dissipateur",),
    "dissipatrices": ("dissipateur",),
    "dissipatif": ("dissipatif",),
    "dissipatifs": ("dissipatif",),
    "dissipative": ("dissipatif",),
    "dissipatives": ("dissipatif",),
    "dissociable": ("dissociable",),
    "dissociables": ("dissociable",),
    "dissociateur": ("dissociateur",),
    "dissociateurs": ("dissociateur",),
    "dissociatrice": ("dissociateur",),
    "dissociatrices": ("dissociateur",),
    "dissociatif": ("dissociatif",),
    "dissociatifs": ("dissociatif",),
    "dissociative": ("dissociatif",),
    "dissociatives": ("dissociatif",),
    "dissoluble": ("dissoluble",),
    "dissolubles": ("dissoluble",),
    "dissolutif": ("dissolutif",),
    "dissolutifs": ("dissolutif",),
    "dissolutive": ("dissolutif",),
    "dissolutives": ("dissolutif",),
    "dissuasif": ("dissuasif",),
    "dissuasifs": ("dissuasif",),
    "dissuasive": ("dissuasif",),
    "dissuasives": ("dissuasif",),
    "dissyllabe": ("dissyllabe",),
    "dissyllabes": ("dissyllabe",),
    "dissyllabique": ("dissyllabique",),
    "dissyllabiques": ("dissyllabique",),
    "dissymétrique": ("dissymétrique",),
    "dissymétriques": ("dissymétrique",),
    "distale": ("distal",),
    "distales": ("distal",),
    "distal": ("distal",),
    "distaux": ("distal",),
    "distanciable": ("distanciable",),
    "distanciables": ("distanciable",),
    "distensif": ("distensif",),
    "distensifs": ("distensif",),
    "distensive": ("distensif",),
    "distensives": ("distensif",),
    "disthénique": ("disthénique",),
    "disthéniques": ("disthénique",),
    "distillable": ("distillable",),
    "distillables": ("distillable",),
    "distillatoire": ("distillatoire",),
    "distillatoires": ("distillatoire",),
    "distinctif": ("distinctif",),
    "distinctifs": ("distinctif",),
    "distinctive": ("distinctif",),
    "distinctives": ("distinctif",),
    "distinguable": ("distinguable",),
    "distinguables": ("distinguable",),
    "distique": ("distique",),
    "distiques": ("distique",),
    "distorse": ("distors",),
    "distorses": ("distors",),
    "distors": ("distors",),
    "distractible": ("distractible",),
    "distractibles": ("distractible",),
    "distractif": ("distractif",),
    "distractifs": ("distractif",),
    "distractive": ("distractif",),
    "distractives": ("distractif",),
    "distribuable": ("distribuable",),
    "distribuables": ("distribuable",),
    "distributaire": ("distributaire",),
    "distributaires": ("distributaire",),
    "distributeur": ("distributeur",),
    "distributeurs": ("distributeur",),
    "distributrice": ("distributeur",),
    "distributrices": ("distributeur",),
    "distributif": ("distributif",),
    "distributifs": ("distributif",),
    "distributive": ("distributif",),
    "distributives": ("distributif",),
    "distributionnaliste": ("distributionnaliste",),
    "distributionnalistes": ("distributionnaliste",),
    "distributionnelle": ("distributionnel",),
    "distributionnelles": ("distributionnel",),
    "distributionnel": ("distributionnel",),
    "distributionnels": ("distributionnel",),
    "distyle": ("distyle",),
    "distyles": ("distyle",),
    "disulfonique": ("disulfonique",),
    "disulfoniques": ("disulfonique",),
    "disystolique": ("disystolique",),
    "disystoliques": ("disystolique",),
    "diterpénique": ("diterpénique",),
    "diterpéniques": ("diterpénique",),
    "dithéiste": ("dithéiste",),
    "dithéistes": ("dithéiste",),
    "ditherme": ("ditherme",),
    "dithermes": ("ditherme",),
    "dithiocarbamique": ("dithiocarbamique",),
    "dithiocarbamiques": ("dithiocarbamique",),
    "dithiocarbonique": ("dithiocarbonique",),
    "dithiocarboniques": ("dithiocarbonique",),
    "dithiocarboxylique": ("dithiocarboxylique",),
    "dithiocarboxyliques": ("dithiocarboxylique",),
    "dithionique": ("dithionique",),
    "dithioniques": ("dithionique",),
    "dithyrambique": ("dithyrambique",),
    "dithyrambiques": ("dithyrambique",),
    "diurétique": ("diurétique",),
    "diurétiques": ("diurétique",),
    "diurnale": ("diurnal",),
    "diurnales": ("diurnal",),
    "diurnal": ("diurnal",),
    "diurnaux": ("diurnal",),
    "diurne": ("diurne",),
    "diurnes": ("diurne",),
    "divagateur": ("divagateur",),
    "divagateurs": ("divagateur",),
    "divagatrice": ("divagateur",),
    "divagatrices": ("divagateur",),
    "dive": ("dive",),
    "dives": ("dive",),
    "diverse": ("divers",),
    "diverses": ("divers",),
    "divers": ("divers",),
    "diversifiable": ("diversifiable",),
    "diversifiables": ("diversifiable",),
    "diversiforme": ("diversiforme",),
    "diversiformes": ("diversiforme",),
    "diverticulaire": ("diverticulaire",),
    "diverticulaires": ("diverticulaire",),
    "dividuelle": ("dividuel",),
    "dividuelles": ("dividuel",),
    "dividuel": ("dividuel",),
    "dividuels": ("dividuel",),
    "divinateur": ("divinateur",),
    "divinateurs": ("divinateur",),
    "divinatrice": ("divinateur",),
    "divinatrices": ("divinateur",),
    "divinatoire": ("divinatoire",),
    "divinatoires": ("divinatoire",),
    "divinylique": ("divinylique",),
    "divinyliques": ("divinylique",),
    "divise": ("divis",),
    "divises": ("divis",),
    "divis": ("divis",),
    "diviseur": ("diviseur",),
    "diviseurs": ("diviseur",),
    "diviseuse": ("diviseur",),
    "diviseuses": ("diviseur",),
    "divisible": ("divisible",),
    "divisibles": ("divisible",),
    "divisionnaire": ("divisionnaire",),
    "divisionnaires": ("divisionnaire",),
    "divisionnelle": ("divisionnel",),
    "divisionnelles": ("divisionnel",),
    "divisionnel": ("divisionnel",),
    "divisionnels": ("divisionnel",),
    "divisionniste": ("divisionniste",),
    "divisionnistes": ("divisionniste",),
    "divortiale": ("divortial",),
    "divortiales": ("divortial",),
    "divortial": ("divortial",),
    "divortiaux": ("divortial",),
    "divulgateur": ("divulgateur",),
    "divulgateurs": ("divulgateur",),
    "divulgatrice": ("divulgateur",),
    "divulgatrices": ("divulgateur",),
    "dixième": ("dixième",),
    "dixièmes": ("dixième",),
    "dizygote": ("dizygote",),
    "dizygotes": ("dizygote",),
    "dizygotique": ("dizygotique",),
    "dizygotiques": ("dizygotique",),
    "djaïna": ("djaïna",),
    "djiboutien": ("djiboutien",),
    "djiboutienne": ("djiboutien",),
    "djiboutiennes": ("djiboutien",),
    "djiboutiens": ("djiboutien",),
    "docétique": ("docétique",),
    "docétiques": ("docétique",),
    "docile": ("docile",),
    "dociles": ("docile",),
    "docimologique": ("docimologique",),
    "docimologiques": ("docimologique",),
    "docte": ("docte",),
    "doctes": ("docte",),
    "doctissime": ("doctissime",),
    "doctissimes": ("doctissime",),
    "doctorale": ("doctoral",),
    "doctorales": ("doctoral",),
    "doctoral": ("doctoral",),
    "doctoraux": ("doctoral",),
    "doctrinaire": ("doctrinaire",),
    "doctrinaires": ("doctrinaire",),
    "doctrinale": ("doctrinal",),
    "doctrinales": ("doctrinal",),
    "doctrinal": ("doctrinal",),
    "doctrinaux": ("doctrinal",),
    "documentaire": ("documentaire",),
    "documentaires": ("documentaire",),
    "dodécaèdre": ("dodécaèdre",),
    "dodécaèdres": ("dodécaèdre",),
    "dodécaédrique": ("dodécaédrique",),
    "dodécaédriques": ("dodécaédrique",),
    "dodécagonale": ("dodécagonal",),
    "dodécagonales": ("dodécagonal",),
    "dodécagonal": ("dodécagonal",),
    "dodécagonaux": ("dodécagonal",),
    "dodécanoïque": ("dodécanoïque",),
    "dodécanoïques": ("dodécanoïque",),
    "dodécaphonique": ("dodécaphonique",),
    "dodécaphoniques": ("dodécaphonique",),
    "dodécastyle": ("dodécastyle",),
    "dodécastyles": ("dodécastyle",),
    "dodécasyllabe": ("dodécasyllabe",),
    "dodécasyllabes": ("dodécasyllabe",),
    "dodrantaire": ("dodrantaire",),
    "dodrantaires": ("dodrantaire",),
    "dogmatique": ("dogmatique",),
    "dogmatiques": ("dogmatique",),
    "dogmatiseur": ("dogmatiseur",),
    "dogmatiseurs": ("dogmatiseur",),
    "dogmatiseuse": ("dogmatiseur",),
    "dogmatiseuses": ("dogmatiseur",),
    "dogmatiste": ("dogmatiste",),
    "dogmatistes": ("dogmatiste",),
    "doisynolique": ("doisynolique",),
    "doisynoliques": ("doisynolique",),
    "dolby": ("dolby",),
    "dolichocéphale": ("dolichocéphale",),
    "dolichocéphales": ("dolichocéphale",),
    "dolichocrâne": ("dolichocrâne",),
    "dolichocrânes": ("dolichocrâne",),
    "dolichotypique": ("dolichotypique",),
    "dolichotypiques": ("dolichotypique",),
    "dolomitique": ("dolomitique",),
    "dolomitiques": ("dolomitique",),
    "doloriste": ("doloriste",),
    "doloristes": ("doloriste",),
    "dolosif": ("dolosif",),
    "dolosifs": ("dolosif",),
    "dolosive": ("dolosif",),
    "dolosives": ("dolosif",),
    "domaniale": ("domanial",),
    "domaniales": ("domanial",),
    "domanial": ("domanial",),
    "domaniaux": ("domanial",),
    "dombiste": ("dombiste",),
    "dombistes": ("dombiste",),
    "doméen": ("doméen",),
    "doméenne": ("doméen",),
    "doméennes": ("doméen",),
    "doméens": ("doméen",),
    "domesticable": ("domesticable",),
    "domesticables": ("domesticable",),
    "domestique": ("domestique",),
    "domestiques": ("domestique",),
    "domicale": ("domical",),
    "domicales": ("domical",),
    "domical": ("domical",),
    "domicaux": ("domical",),
    "domiciliaire": ("domiciliaire",),
    "domiciliaires": ("domiciliaire",),
    "dominateur": ("dominateur",),
    "dominateurs": ("dominateur",),
    "dominatrice": ("dominateur",),
    "dominatrices": ("dominateur",),
    "dominicale": ("dominical",),
    "dominicales": ("dominical",),
    "dominical": ("dominical",),
    "dominicaux": ("dominical",),
    "dommageable": ("dommageable",),
    "dommageables": ("dommageable",),
    "domptable": ("domptable",),
    "domptables": ("domptable",),
    "donateur": ("donateur",),
    "donateurs": ("donateur",),
    "donatrice": ("donateur",),
    "donatrices": ("donateur",),
    "donatiste": ("donatiste",),
    "donatistes": ("donatiste",),
    "donjuanesque": ("donjuanesque",),
    "donjuanesques": ("donjuanesque",),
    "donneur": ("donneur",),
    "donneurs": ("donneur",),
    "donneuse": ("donneur",),
    "donneuses": ("donneur",),
    "dopaminergique": ("dopaminergique",),
    "dopaminergiques": ("dopaminergique",),
    "dopaminomimétique": ("dopaminomimétique",),
    "dopaminomimétiques": ("dopaminomimétique",),
    "doreur": ("doreur",),
    "doreurs": ("doreur",),
    "doreuse": ("doreur",),
    "doreuses": ("doreur",),
    "dorien": ("dorien",),
    "dorienne": ("dorien",),
    "doriennes": ("dorien",),
    "doriens": ("dorien",),
    "dorique": ("dorique",),
    "doriques": ("dorique",),
    "dormeur": ("dormeur",),
    "dormeurs": ("dormeur",),
    "dormeuse": ("dormeur",),
    "dormeuses": ("dormeur",),
    "dormitif": ("dormitif",),
    "dormitifs": ("dormitif",),
    "dormitive": ("dormitif",),
    "dormitives": ("dormitif",),
    "dorsale": ("dorsal",),
    "dorsales": ("dorsal",),
    "dorsal": ("dorsal",),
    "dorsaux": ("dorsal",),
    "dorsiventrale": ("dorsiventral",),
    "dorsiventrales": ("dorsiventral",),
    "dorsiventral": ("dorsiventral",),
    "dorsiventraux": ("dorsiventral",),
    "dorsolombaire": ("dorsolombaire",),
    "dorsolombaires": ("dorsolombaire",),
    "dorso-palatal": ("dorso-palatal",),
    "dosable": ("dosable",),
    "dosables": ("dosable",),
    "doseur": ("doseur",),
    "doseurs": ("doseur",),
    "doseuse": ("doseur",),
    "doseuses": ("doseur",),
    "dotale": ("dotal",),
    "dotales": ("dotal",),
    "dotal": ("dotal",),
    "dotaux": ("dotal",),
    "douanière": ("douanier",),
    "douanières": ("douanier",),
    "douanier": ("douanier",),
    "douaniers": ("douanier",),
    "doublée": ("doublé",),
    "doublées": ("doublé",),
    "doublé": ("doublé",),
    "double": ("double",),
    "doublés": ("doublé",),
    "doubles": ("double",),
    "douceâtre": ("douceâtre",),
    "douceâtres": ("douceâtre",),
    "doucereuse": ("doucereux",),
    "doucereuses": ("doucereux",),
    "doucereux": ("doucereux",),
    "doucet": ("doucet",),
    "doucets": ("doucet",),
    "doucette": ("doucet",),
    "doucettes": ("doucet",),
    "douillet": ("douillet",),
    "douillets": ("douillet",),
    "douillette": ("douillet",),
    "douillettes": ("douillet",),
    "douloureuse": ("douloureux",),
    "douloureuses": ("douloureux",),
    "douloureux": ("douloureux",),
    "douteur": ("douteur",),
    "douteurs": ("douteur",),
    "douteuse": ("douteux",),
    "douteuses": ("douteux",),
    "douteux": ("douteux",),
    "douce": ("doux",),
    "douces": ("doux",),
    "doux": ("doux",),
    "douzième": ("douzième",),
    "douzièmes": ("douzième",),
    "doxologique": ("doxologique",),
    "doxologiques": ("doxologique",),
    "draconien": ("draconien",),
    "draconienne": ("draconien",),
    "draconiennes": ("draconien",),
    "draconiens": ("draconien",),
    "draconitique": ("draconitique",),
    "draconitiques": ("draconitique",),
    "dragueur": ("dragueur",),
    "dragueurs": ("dragueur",),
    "dragueuse": ("dragueur",),
    "dragueuses": ("dragueur",),
    "draineur": ("draineur",),
    "draineurs": ("draineur",),
    "draineuse": ("draineur",),
    "draineuses": ("draineur",),
    "dramatique": ("dramatique",),
    "dramatiques": ("dramatique",),
    "dramaturgique": ("dramaturgique",),
    "dramaturgiques": ("dramaturgique",),
    "drapière": ("drapier",),
    "drapières": ("drapier",),
    "drapier": ("drapier",),
    "drapiers": ("drapier",),
    "drastique": ("drastique",),
    "drastiques": ("drastique",),
    "dravidien": ("dravidien",),
    "dravidienne": ("dravidien",),
    "dravidiennes": ("dravidien",),
    "dravidiens": ("dravidien",),
    "drépanocytaire": ("drépanocytaire",),
    "drépanocytaires": ("drépanocytaire",),
    "driographique": ("driographique",),
    "driographiques": ("driographique",),
    "droitière": ("droitier",),
    "droitières": ("droitier",),
    "droitier": ("droitier",),
    "droitiers": ("droitier",),
    "droitiste": ("droitiste",),
    "droitistes": ("droitiste",),
    "drolatique": ("drolatique",),
    "drolatiques": ("drolatique",),
    "drôle": ("drôle",),
    "drôles": ("drôle",),
    "drôlet": ("drôlet",),
    "drôlets": ("drôlet",),
    "drôlette": ("drôlet",),
    "drôlettes": ("drôlet",),
    "dromochronique": ("dromochronique",),
    "dromochroniques": ("dromochronique",),
    "drômoise": ("drômois",),
    "drômoises": ("drômois",),
    "drômois": ("drômois",),
    "dromotrope": ("dromotrope",),
    "dromotropes": ("dromotrope",),
    "druidique": ("druidique",),
    "druidiques": ("druidique",),
    "druse": ("druse",),
    "druses": ("druse",),
    "drusillaire": ("drusillaire",),
    "drusillaires": ("drusillaire",),
    "druze": ("druze",),
    "druzes": ("druze",),
    "dry": ("dry",),
    "dualiste": ("dualiste",),
    "dualistes": ("dualiste",),
    "dubitatif": ("dubitatif",),
    "dubitatifs": ("dubitatif",),
    "dubitative": ("dubitatif",),
    "dubitatives": ("dubitatif",),
    "ducale": ("ducal",),
    "ducales": ("ducal",),
    "ducal": ("ducal",),
    "ducaux": ("ducal",),
    "ductile": ("ductile",),
    "ductiles": ("ductile",),
    "duhamélien": ("duhamélien",),
    "duhamélienne": ("duhamélien",),
    "duhaméliennes": ("duhamélien",),
    "duhaméliens": ("duhamélien",),
    "dulçaquicole": ("dulçaquicole",),
    "dulçaquicoles": ("dulçaquicole",),
    "dulcicole": ("dulcicole",),
    "dulcicoles": ("dulcicole",),
    "dunaire": ("dunaire",),
    "dunaires": ("dunaire",),
    "dunkerquoise": ("dunkerquois",),
    "dunkerquoises": ("dunkerquois",),
    "dunkerquois": ("dunkerquois",),
    "dunoise": ("dunois",),
    "dunoises": ("dunois",),
    "dunois": ("dunois",),
    "duodécennale": ("duodécennal",),
    "duodécennales": ("duodécennal",),
    "duodécennal": ("duodécennal",),
    "duodécennaux": ("duodécennal",),
    "duodécimale": ("duodécimal",),
    "duodécimales": ("duodécimal",),
    "duodécimal": ("duodécimal",),
    "duodécimaux": ("duodécimal",),
    "duodénale": ("duodénal",),
    "duodénales": ("duodénal",),
    "duodénal": ("duodénal",),
    "duodénaux": ("duodénal",),
    "duolocale": ("duolocal",),
    "duolocales": ("duolocal",),
    "duolocal": ("duolocal",),
    "duolocaux": ("duolocal",),
    "dupe": ("dupe",),
    "dupes": ("dupe",),
    "duplex": ("duplex",),
    "duplicatif": ("duplicatif",),
    "duplicatifs": ("duplicatif",),
    "duplicative": ("duplicatif",),
    "duplicatives": ("duplicatif",),
    "duplice": ("duplice",),
    "duplices": ("duplice",),
    "durable": ("durable",),
    "durables": ("durable",),
    "duraille": ("duraille",),
    "durailles": ("duraille",),
    "durale": ("dural",),
    "durales": ("dural",),
    "dural": ("dural",),
    "duraux": ("dural",),
    "duratif": ("duratif",),
    "duratifs": ("duratif",),
    "durative": ("duratif",),
    "duratives": ("duratif",),
    "durcissable": ("durcissable",),
    "durcissables": ("durcissable",),
    "durcisseur": ("durcisseur",),
    "durcisseurs": ("durcisseur",),
    "durcisseuse": ("durcisseur",),
    "durcisseuses": ("durcisseur",),
    "durham": ("durham",),
    "duumvirale": ("duumviral",),
    "duumvirales": ("duumviral",),
    "duumviral": ("duumviral",),
    "duumviraux": ("duumviral",),
    "duveteuse": ("duveteux",),
    "duveteuses": ("duveteux",),
    "duveteux": ("duveteux",),
    "dyadique": ("dyadique",),
    "dyadiques": ("dyadique",),
    "dynamique": ("dynamique",),
    "dynamiques": ("dynamique",),
    "dynamiste": ("dynamiste",),
    "dynamistes": ("dynamiste",),
    "dynamoélectrique": ("dynamoélectrique",),
    "dynamoélectriques": ("dynamoélectrique",),
    "dynamogène": ("dynamogène",),
    "dynamogènes": ("dynamogène",),
    "dynamogénique": ("dynamogénique",),
    "dynamogéniques": ("dynamogénique",),
    "dynamométrique": ("dynamométrique",),
    "dynamométriques": ("dynamométrique",),
    "dynastique": ("dynastique",),
    "dynastiques": ("dynastique",),
    "dyscalculique": ("dyscalculique",),
    "dyscalculiques": ("dyscalculique",),
    "dyscéphalique": ("dyscéphalique",),
    "dyscéphaliques": ("dyscéphalique",),
    "dyschromatopsique": ("dyschromatopsique",),
    "dyschromatopsiques": ("dyschromatopsique",),
    "dyscrasique": ("dyscrasique",),
    "dyscrasiques": ("dyscrasique",),
    "dysembryoplasique": ("dysembryoplasique",),
    "dysembryoplasiques": ("dysembryoplasique",),
    "dysendocrinien": ("dysendocrinien",),
    "dysendocrinienne": ("dysendocrinien",),
    "dysendocriniennes": ("dysendocrinien",),
    "dysendocriniens": ("dysendocrinien",),
    "dysentériforme": ("dysentériforme",),
    "dysentériformes": ("dysentériforme",),
    "dysentérique": ("dysentérique",),
    "dysentériques": ("dysentérique",),
    "dysérythropoïétique": ("dysérythropoïétique",),
    "dysérythropoïétiques": ("dysérythropoïétique",),
    "dysgénésique": ("dysgénésique",),
    "dysgénésiques": ("dysgénésique",),
    "dysgénique": ("dysgénique",),
    "dysgéniques": ("dysgénique",),
    "dysgraphique": ("dysgraphique",),
    "dysgraphiques": ("dysgraphique",),
    "dysgravidique": ("dysgravidique",),
    "dysgravidiques": ("dysgravidique",),
    "dysharmonieuse": ("dysharmonieux",),
    "dysharmonieuses": ("dysharmonieux",),
    "dysharmonieux": ("dysharmonieux",),
    "dysharmonique": ("dysharmonique",),
    "dysharmoniques": ("dysharmonique",),
    "dysidrosique": ("dysidrosique",),
    "dysidrosiques": ("dysidrosique",),
    "dysimmunitaire": ("dysimmunitaire",),
    "dysimmunitaires": ("dysimmunitaire",),
    "dyskératosique": ("dyskératosique",),
    "dyskératosiques": ("dyskératosique",),
    "dyskinétique": ("dyskinétique",),
    "dyskinétiques": ("dyskinétique",),
    "dysleptique": ("dysleptique",),
    "dysleptiques": ("dysleptique",),
    "dyslexique": ("dyslexique",),
    "dyslexiques": ("dyslexique",),
    "dyslipémique": ("dyslipémique",),
    "dyslipémiques": ("dyslipémique",),
    "dysmature": ("dysmature",),
    "dysmatures": ("dysmature",),
    "dysmélique": ("dysmélique",),
    "dysméliques": ("dysmélique",),
    "dysménorrhéique": ("dysménorrhéique",),
    "dysménorrhéiques": ("dysménorrhéique",),
    "dysmétabolique": ("dysmétabolique",),
    "dysmétaboliques": ("dysmétabolique",),
    "dysmétrique": ("dysmétrique",),
    "dysmétriques": ("dysmétrique",),
    "dysmorphique": ("dysmorphique",),
    "dysmorphiques": ("dysmorphique",),
    "dysontogénétique": ("dysontogénétique",),
    "dysontogénétiques": ("dysontogénétique",),
    "dysorique": ("dysorique",),
    "dysoriques": ("dysorique",),
    "dysorthographique": ("dysorthographique",),
    "dysorthographiques": ("dysorthographique",),
    "dyspepsique": ("dyspepsique",),
    "dyspepsiques": ("dyspepsique",),
    "dyspeptique": ("dyspeptique",),
    "dyspeptiques": ("dyspeptique",),
    "dysphorique": ("dysphorique",),
    "dysphoriques": ("dysphorique",),
    "dysplasique": ("dysplasique",),
    "dysplasiques": ("dysplasique",),
    "dysplastique": ("dysplastique",),
    "dysplastiques": ("dysplastique",),
    "dyspnéique": ("dyspnéique",),
    "dyspnéiques": ("dyspnéique",),
    "dysprosodique": ("dysprosodique",),
    "dysprosodiques": ("dysprosodique",),
    "dyssociale": ("dyssocial",),
    "dyssociales": ("dyssocial",),
    "dyssocial": ("dyssocial",),
    "dyssociaux": ("dyssocial",),
    "dysthymique": ("dysthymique",),
    "dysthymiques": ("dysthymique",),
    "dystocique": ("dystocique",),
    "dystociques": ("dystocique",),
    "dystrophique": ("dystrophique",),
    "dystrophiques": ("dystrophique",),
    "dysurique": ("dysurique",),
    "dysuriques": ("dysurique",),
    "éberthien": ("éberthien",),
    "éberthienne": ("éberthien",),
    "éberthiennes": ("éberthien",),
    "éberthiens": ("éberthien",),
    "ébionite": ("ébionite",),
    "ébionites": ("ébionite",),
    "ébouleuse": ("ébouleux",),
    "ébouleuses": ("ébouleux",),
    "ébouleux": ("ébouleux",),
    "ébranlable": ("ébranlable",),
    "ébranlables": ("ébranlable",),
    "ébrieuse": ("ébrieux",),
    "ébrieuses": ("ébrieux",),
    "ébrieux": ("ébrieux",),
    "ébroïcien": ("ébroïcien",),
    "ébroïcienne": ("ébroïcien",),
    "ébroïciennes": ("ébroïcien",),
    "ébroïciens": ("ébroïcien",),
    "ébroudeur": ("ébroudeur",),
    "ébroudeurs": ("ébroudeur",),
    "ébroudeuse": ("ébroudeur",),
    "ébroudeuses": ("ébroudeur",),
    "ébulliométrique": ("ébulliométrique",),
    "ébulliométriques": ("ébulliométrique",),
    "ébullioscopique": ("ébullioscopique",),
    "ébullioscopiques": ("ébullioscopique",),
    "éburnéen": ("éburnéen",),
    "éburnéenne": ("éburnéen",),
    "éburnéennes": ("éburnéen",),
    "éburnéens": ("éburnéen",),
    "écailleuse": ("écailleux",),
    "écailleuses": ("écailleux",),
    "écailleux": ("écailleux",),
    "écarlate": ("écarlate",),
    "écarlates": ("écarlate",),
    "écartable": ("écartable",),
    "écartables": ("écartable",),
    "ecbolique": ("ecbolique",),
    "ecboliques": ("ecbolique",),
    "ecchymotique": ("ecchymotique",),
    "ecchymotiques": ("ecchymotique",),
    "ecclésiale": ("ecclésial",),
    "ecclésiales": ("ecclésial",),
    "ecclésial": ("ecclésial",),
    "ecclésiaux": ("ecclésial",),
    "ecclésiastique": ("ecclésiastique",),
    "ecclésiastiques": ("ecclésiastique",),
    "ecclésiologique": ("ecclésiologique",),
    "ecclésiologiques": ("ecclésiologique",),
    "eccrine": ("eccrine",),
    "eccrines": ("eccrine",),
    "échampelée": ("échampelée",),
    "échampelées": ("échampelée",),
    "échangeable": ("échangeable",),
    "échangeables": ("échangeable",),
    "échangiste": ("échangiste",),
    "échangistes": ("échangiste",),
    "échardonneur": ("échardonneur",),
    "échardonneurs": ("échardonneur",),
    "échardonneuse": ("échardonneur",),
    "échardonneuses": ("échardonneur",),
    "échéant": ("échéant",),
    "échéants": ("échéant",),
    "échec": ("échec",),
    "échevinale": ("échevinal",),
    "échevinales": ("échevinal",),
    "échevinal": ("échevinal",),
    "échevinaux": ("échevinal",),
    "échinoïde": ("échinoïde",),
    "échinoïdes": ("échinoïde",),
    "échiquéen": ("échiquéen",),
    "échiquéenne": ("échiquéen",),
    "échiquéennes": ("échiquéen",),
    "échiquéens": ("échiquéen",),
    "échocardiographique": ("échocardiographique",),
    "échocardiographiques": ("échocardiographique",),
    "échoencéphalographique": ("échoencéphalographique",),
    "échoencéphalographiques": ("échoencéphalographique",),
    "échogène": ("échogène",),
    "échogènes": ("échogène",),
    "échographique": ("échographique",),
    "échographiques": ("échographique",),
    "échokinésique": ("échokinésique",),
    "échokinésiques": ("échokinésique",),
    "écholalique": ("écholalique",),
    "écholaliques": ("écholalique",),
    "écholocateur": ("écholocateur",),
    "écholocateurs": ("écholocateur",),
    "écholocateuse": ("écholocateur",),
    "écholocateuses": ("écholocateur",),
    "échométrique": ("échométrique",),
    "échométriques": ("échométrique",),
    "échopraxique": ("échopraxique",),
    "échopraxiques": ("échopraxique",),
    "échotière": ("échotier",),
    "échotières": ("échotier",),
    "échotier": ("échotier",),
    "échotiers": ("échotier",),
    "échotomographique": ("échotomographique",),
    "échotomographiques": ("échotomographique",),
    "écimable": ("écimable",),
    "écimables": ("écimable",),
    "éclaireur": ("éclaireur",),
    "éclaireurs": ("éclaireur",),
    "éclaireuse": ("éclaireur",),
    "éclaireuses": ("éclaireur",),
    "éclamptique": ("éclamptique",),
    "éclamptiques": ("éclamptique",),
    "éclectique": ("éclectique",),
    "éclectiques": ("éclectique",),
    "écliptique": ("écliptique",),
    "écliptiques": ("écliptique",),
    "éclosable": ("éclosable",),
    "éclosables": ("éclosable",),
    "éclusière": ("éclusier",),
    "éclusières": ("éclusier",),
    "éclusier": ("éclusier",),
    "éclusiers": ("éclusier",),
    "ecmnésique": ("ecmnésique",),
    "ecmnésiques": ("ecmnésique",),
    "ecmnétique": ("ecmnétique",),
    "ecmnétiques": ("ecmnétique",),
    "écobiocénotique": ("écobiocénotique",),
    "écobiocénotiques": ("écobiocénotique",),
    "écolière": ("écolier",),
    "écolières": ("écolier",),
    "écolier": ("écolier",),
    "écoliers": ("écolier",),
    "écolo": ("écolo",),
    "écolos": ("écolo",),
    "écologique": ("écologique",),
    "écologiques": ("écologique",),
    "écologiste": ("écologiste",),
    "écologistes": ("écologiste",),
    "économe": ("économe",),
    "économes": ("économe",),
    "économétrique": ("économétrique",),
    "économétriques": ("économétrique",),
    "economicus": ("economicus",),
    "économique": ("économique",),
    "économiques": ("économique",),
    "économiste": ("économiste",),
    "économistes": ("économiste",),
    "écossaise": ("écossais",),
    "écossaises": ("écossais",),
    "écossais": ("écossais",),
    "écoutable": ("écoutable",),
    "écoutables": ("écoutable",),
    "écrasable": ("écrasable",),
    "écrasables": ("écrasable",),
    "ectoblastique": ("ectoblastique",),
    "ectoblastiques": ("ectoblastique",),
    "ectocrine": ("ectocrine",),
    "ectocrines": ("ectocrine",),
    "ectodermique": ("ectodermique",),
    "ectodermiques": ("ectodermique",),
    "ectolécithe": ("ectolécithe",),
    "ectolécithes": ("ectolécithe",),
    "ectomorphe": ("ectomorphe",),
    "ectomorphes": ("ectomorphe",),
    "ectopage": ("ectopage",),
    "ectopages": ("ectopage",),
    "ectoparasite": ("ectoparasite",),
    "ectoparasites": ("ectoparasite",),
    "ectopique": ("ectopique",),
    "ectopiques": ("ectopique",),
    "ectoplasmique": ("ectoplasmique",),
    "ectoplasmiques": ("ectoplasmique",),
    "ectothrix": ("ectothrix",),
    "ectotrophe": ("ectotrophe",),
    "ectotrophes": ("ectotrophe",),
    "ectrodactyle": ("ectrodactyle",),
    "ectrodactyles": ("ectrodactyle",),
    "ectromèle": ("ectromèle",),
    "ectromèles": ("ectromèle",),
    "ectypale": ("ectypal",),
    "ectypales": ("ectypal",),
    "ectypal": ("ectypal",),
    "ectypaux": ("ectypal",),
    "écumeuse": ("écumeux",),
    "écumeuses": ("écumeux",),
    "écumeux": ("écumeux",),
    "écussonnable": ("écussonnable",),
    "écussonnables": ("écussonnable",),
    "eczémateuse": ("eczémateux",),
    "eczémateuses": ("eczémateux",),
    "eczémateux": ("eczémateux",),
    "eczématiforme": ("eczématiforme",),
    "eczématiformes": ("eczématiforme",),
    "eczématique": ("eczématique",),
    "eczématiques": ("eczématique",),
    "édaphique": ("édaphique",),
    "édaphiques": ("édaphique",),
    "édénique": ("édénique",),
    "édéniques": ("édénique",),
    "édificateur": ("édificateur",),
    "édificateurs": ("édificateur",),
    "édificatrice": ("édificateur",),
    "édificatrices": ("édificateur",),
    "édilitaire": ("édilitaire",),
    "édilitaires": ("édilitaire",),
    "éditeur": ("éditeur",),
    "éditeurs": ("éditeur",),
    "éditrice": ("éditeur",),
    "éditrices": ("éditeur",),
    "éditique": ("éditique",),
    "éditiques": ("éditique",),
    "éditoriale": ("éditorial",),
    "éditoriales": ("éditorial",),
    "éditorial": ("éditorial",),
    "éditoriaux": ("éditorial",),
    "édrique": ("édrique",),
    "édriques": ("édrique",),
    "éducable": ("éducable",),
    "éducables": ("éducable",),
    "éducateur": ("éducateur",),
    "éducateurs": ("éducateur",),
    "éducatrice": ("éducateur",),
    "éducatrices": ("éducateur",),
    "éducatif": ("éducatif",),
    "éducatifs": ("éducatif",),
    "éducative": ("éducatif",),
    "éducatives": ("éducatif",),
    "éducationnelle": ("éducationnel",),
    "éducationnelles": ("éducationnel",),
    "éducationnel": ("éducationnel",),
    "éducationnels": ("éducationnel",),
    "effaçable": ("effaçable",),
    "effaçables": ("effaçable",),
    "effaceur": ("effaceur",),
    "effaceurs": ("effaceur",),
    "effaceuse": ("effaceur",),
    "effaceuses": ("effaceur",),
    "effecteur": ("effecteur",),
    "effecteurs": ("effecteur",),
    "effectrice": ("effecteur",),
    "effectrices": ("effecteur",),
    "effectif": ("effectif",),
    "effectifs": ("effectif",),
    "effective": ("effectif",),
    "effectives": ("effectif",),
    "effectuable": ("effectuable",),
    "effectuables": ("effectuable",),
    "efficace": ("efficace",),
    "efficaces": ("efficace",),
    "effileur": ("effileur",),
    "effileurs": ("effileur",),
    "effileuse": ("effileur",),
    "effileuses": ("effileur",),
    "effilocheur": ("effilocheur",),
    "effilocheurs": ("effilocheur",),
    "effilocheuse": ("effilocheur",),
    "effilocheuses": ("effilocheur",),
    "effiloqueur": ("effiloqueur",),
    "effiloqueurs": ("effiloqueur",),
    "effiloqueuse": ("effiloqueur",),
    "effiloqueuses": ("effiloqueur",),
    "effractif": ("effractif",),
    "effractifs": ("effractif",),
    "effractive": ("effractif",),
    "effractives": ("effractif",),
    "effroyable": ("effroyable",),
    "effroyables": ("effroyable",),
    "effusif": ("effusif",),
    "effusifs": ("effusif",),
    "effusive": ("effusif",),
    "effusives": ("effusif",),
    "égalable": ("égalable",),
    "égalables": ("égalable",),
    "égale": ("égal",),
    "égales": ("égal",),
    "égal": ("égal",),
    "égaux": ("égal",),
    "égalisateur": ("égalisateur",),
    "égalisateurs": ("égalisateur",),
    "égalisatrice": ("égalisateur",),
    "égalisatrices": ("égalisateur",),
    "égalitaire": ("égalitaire",),
    "égalitaires": ("égalitaire",),
    "égalitariste": ("égalitariste",),
    "égalitaristes": ("égalitariste",),
    "égéen": ("égéen",),
    "égéenne": ("égéen",),
    "égéennes": ("égéen",),
    "égéens": ("égéen",),
    "égocentrique": ("égocentrique",),
    "égocentriques": ("égocentrique",),
    "égocentriste": ("égocentriste",),
    "égocentristes": ("égocentriste",),
    "égoïste": ("égoïste",),
    "égoïstes": ("égoïste",),
    "égophonique": ("égophonique",),
    "égophoniques": ("égophonique",),
    "égotique": ("égotique",),
    "égotiques": ("égotique",),
    "égotiste": ("égotiste",),
    "égotistes": ("égotiste",),
    "égoutteur": ("égoutteur",),
    "égoutteurs": ("égoutteur",),
    "égratigneur": ("égratigneur",),
    "égratigneurs": ("égratigneur",),
    "égratigneuse": ("égratigneur",),
    "égratigneuses": ("égratigneur",),
    "égreneur": ("égreneur",),
    "égreneurs": ("égreneur",),
    "égreneuse": ("égreneur",),
    "égreneuses": ("égreneur",),
    "égressif": ("égressif",),
    "égressifs": ("égressif",),
    "égressive": ("égressif",),
    "égressives": ("égressif",),
    "égyptien": ("égyptien",),
    "égyptienne": ("égyptien",),
    "égyptiennes": ("égyptien",),
    "égyptiens": ("égyptien",),
    "égypto-araméennes": ("égypto-araméen",),
    "égypto-israélien": ("égypto-israélien",),
    "égypto-israélienne": ("égypto-israélien",),
    "égyptologique": ("égyptologique",),
    "égyptologiques": ("égyptologique",),
    "eidétique": ("eidétique",),
    "eidétiques": ("eidétique",),
    "éjaculateur": ("éjaculateur",),
    "éjaculateurs": ("éjaculateur",),
    "éjaculatrice": ("éjaculateur",),
    "éjaculatrices": ("éjaculateur",),
    "éjaculatoire": ("éjaculatoire",),
    "éjaculatoires": ("éjaculatoire",),
    "éjectable": ("éjectable",),
    "éjectables": ("éjectable",),
    "éjecteur": ("éjecteur",),
    "éjecteurs": ("éjecteur",),
    "éjectif": ("éjectif",),
    "éjectifs": ("éjectif",),
    "éjective": ("éjectif",),
    "éjectives": ("éjectif",),
    "ekphonétique": ("ekphonétique",),
    "ekphonétiques": ("ekphonétique",),
    "élaborateur": ("élaborateur",),
    "élaborateurs": ("élaborateur",),
    "élaboratrice": ("élaborateur",),
    "élaboratrices": ("élaborateur",),
    "élaïdique": ("élaïdique",),
    "élaïdiques": ("élaïdique",),
    "élamite": ("élamite",),
    "élamites": ("élamite",),
    "élastique": ("élastique",),
    "élastiques": ("élastique",),
    "élastoplastique": ("élastoplastique",),
    "élastoplastiques": ("élastoplastique",),
    "élatif": ("élatif",),
    "élatifs": ("élatif",),
    "élative": ("élatif",),
    "élatives": ("élatif",),
    "éléate": ("éléate",),
    "éléates": ("éléate",),
    "éléatique": ("éléatique",),
    "éléatiques": ("éléatique",),
    "électif": ("électif",),
    "électifs": ("électif",),
    "élective": ("électif",),
    "électives": ("électif",),
    "électorale": ("électoral",),
    "électorales": ("électoral",),
    "électoral": ("électoral",),
    "électoraux": ("électoral",),
    "électoraliste": ("électoraliste",),
    "électoralistes": ("électoraliste",),
    "électrique": ("électrique",),
    "électriques": ("électrique",),
    "électrisable": ("électrisable",),
    "électrisables": ("électrisable",),
    "électroacoustique": ("électroacoustique",),
    "électroacoustiques": ("électroacoustique",),
    "électrobiologique": ("électrobiologique",),
    "électrobiologiques": ("électrobiologique",),
    "électrocapillaire": ("électrocapillaire",),
    "électrocapillaires": ("électrocapillaire",),
    "électrocardiographique": ("électrocardiographique",),
    "électrocardiographiques": ("électrocardiographique",),
    "électrochimique": ("électrochimique",),
    "électrochimiques": ("électrochimique",),
    "électrocinétique": ("électrocinétique",),
    "électrocinétiques": ("électrocinétique",),
    "électrocorticale": ("électrocortical",),
    "électrocorticales": ("électrocortical",),
    "électrocortical": ("électrocortical",),
    "électrocorticaux": ("électrocortical",),
    "électrocuteur": ("électrocuteur",),
    "électrocuteurs": ("électrocuteur",),
    "électrocutrice": ("électrocuteur",),
    "électrocutrices": ("électrocuteur",),
    "électrodermale": ("électrodermal",),
    "électrodermales": ("électrodermal",),
    "électrodermal": ("électrodermal",),
    "électrodermaux": ("électrodermal",),
    "électrodomestique": ("électrodomestique",),
    "électrodomestiques": ("électrodomestique",),
    "électrodynamique": ("électrodynamique",),
    "électrodynamiques": ("électrodynamique",),
    "électroencéphalographique": ("électroencéphalographique",),
    "électroencéphalographiques": ("électroencéphalographique",),
    "électrofaible": ("électrofaible",),
    "électrofaibles": ("électrofaible",),
    "électrogalvanique": ("électrogalvanique",),
    "électrogalvaniques": ("électrogalvanique",),
    "électrogène": ("électrogène",),
    "électrogènes": ("électrogène",),
    "électrographitique": ("électrographitique",),
    "électrographitiques": ("électrographitique",),
    "électrolysable": ("électrolysable",),
    "électrolysables": ("électrolysable",),
    "électrolytique": ("électrolytique",),
    "électrolytiques": ("électrolytique",),
    "électromagnétique": ("électromagnétique",),
    "électromagnétiques": ("électromagnétique",),
    "électro-mécanique": ("électromécanique",),
    "électromécanique": ("électromécanique",),
    "électro-mécaniques": ("électromécanique",),
    "électromécaniques": ("électromécanique",),
    "électromédicale": ("électromédical",),
    "électromédicales": ("électromédical",),
    "électromédical": ("électromédical",),
    "électromédicaux": ("électromédical",),
    "électroménagère": ("électroménager",),
    "électroménagères": ("électroménager",),
    "électroménager": ("électroménager",),
    "électroménagers": ("électroménager",),
    "électrométallurgique": ("électrométallurgique",),
    "électrométallurgiques": ("électrométallurgique",),
    "électrométrique": ("électrométrique",),
    "électrométriques": ("électrométrique",),
    "électromoteur": ("électromoteur",),
    "électromoteurs": ("électromoteur",),
    "électromotrice": ("électromoteur",),
    "électromotrices": ("électromoteur",),
    "électromusculaire": ("électromusculaire",),
    "électromusculaires": ("électromusculaire",),
    "électromyographique": ("électromyographique",),
    "électromyographiques": ("électromyographique",),
    "électronégatif": ("électronégatif",),
    "électronégatifs": ("électronégatif",),
    "électronégative": ("électronégatif",),
    "électronégatives": ("électronégatif",),
    "électronique": ("électronique",),
    "électroniques": ("électronique",),
    "électronucléaire": ("électronucléaire",),
    "électronucléaires": ("électronucléaire",),
    "électro-optique": ("électro-optique",),
    "électrophile": ("électrophile",),
    "électrophiles": ("électrophile",),
    "électrophorétique": ("électrophorétique",),
    "électrophorétiques": ("électrophorétique",),
    "électrophysiologique": ("électrophysiologique",),
    "électrophysiologiques": ("électrophysiologique",),
    "électropneumatique": ("électropneumatique",),
    "électropneumatiques": ("électropneumatique",),
    "électroportatif": ("électroportatif",),
    "électroportatifs": ("électroportatif",),
    "électroportative": ("électroportatif",),
    "électroportatives": ("électroportatif",),
    "électroporteur": ("électroporteur",),
    "électroporteurs": ("électroporteur",),
    "électroporteuse": ("électroporteur",),
    "électroporteuses": ("électroporteur",),
    "électropositif": ("électropositif",),
    "électropositifs": ("électropositif",),
    "électropositive": ("électropositif",),
    "électropositives": ("électropositif",),
    "électrorhéologique": ("électrorhéologique",),
    "électrorhéologiques": ("électrorhéologique",),
    "électrosensible": ("électrosensible",),
    "électrosensibles": ("électrosensible",),
    "électrostatique": ("électrostatique",),
    "électrostatiques": ("électrostatique",),
    "électrosystolique": ("électrosystolique",),
    "électrosystoliques": ("électrosystolique",),
    "électrotechnique": ("électrotechnique",),
    "électrotechniques": ("électrotechnique",),
    "électrothérapique": ("électrothérapique",),
    "électrothérapiques": ("électrothérapique",),
    "électrothermique": ("électrothermique",),
    "électrothermiques": ("électrothermique",),
    "électrotonique": ("électrotonique",),
    "électrotoniques": ("électrotonique",),
    "éléen": ("éléen",),
    "éléenne": ("éléen",),
    "éléennes": ("éléen",),
    "éléens": ("éléen",),
    "élégïambique": ("élégïambique",),
    "élégïambiques": ("élégïambique",),
    "élégiaque": ("élégiaque",),
    "élégiaques": ("élégiaque",),
    "élémentaire": ("élémentaire",),
    "élémentaires": ("élémentaire",),
    "éléostéarique": ("éléostéarique",),
    "éléostéariques": ("éléostéarique",),
    "éléphantesque": ("éléphantesque",),
    "éléphantesques": ("éléphantesque",),
    "éléphantiasique": ("éléphantiasique",),
    "éléphantiasiques": ("éléphantiasique",),
    "élevable": ("élevable",),
    "élevables": ("élevable",),
    "élévateur": ("élévateur",),
    "élévateurs": ("élévateur",),
    "élévatrice": ("élévateur",),
    "élévatrices": ("élévateur",),
    "élévatoire": ("élévatoire",),
    "élévatoires": ("élévatoire",),
    "elfique": ("elfique",),
    "elfiques": ("elfique",),
    "élicite": ("élicite",),
    "élicites": ("élicite",),
    "éligible": ("éligible",),
    "éligibles": ("éligible",),
    "éliminable": ("éliminable",),
    "éliminables": ("éliminable",),
    "éliminateur": ("éliminateur",),
    "éliminateurs": ("éliminateur",),
    "éliminatrice": ("éliminateur",),
    "éliminatrices": ("éliminateur",),
    "éliminatoire": ("éliminatoire",),
    "éliminatoires": ("éliminatoire",),
    "élitaire": ("élitaire",),
    "élitaires": ("élitaire",),
    "élitiste": ("élitiste",),
    "élitistes": ("élitiste",),
    "ellagique": ("ellagique",),
    "ellagiques": ("ellagique",),
    "ellagotannique": ("ellagotannique",),
    "ellagotanniques": ("ellagotannique",),
    "ellipsoïdale": ("ellipsoïdal",),
    "ellipsoïdales": ("ellipsoïdal",),
    "ellipsoïdal": ("ellipsoïdal",),
    "ellipsoïdaux": ("ellipsoïdal",),
    "ellipsoïde": ("ellipsoïde",),
    "ellipsoïdes": ("ellipsoïde",),
    "ellipsoïdique": ("ellipsoïdique",),
    "ellipsoïdiques": ("ellipsoïdique",),
    "elliptique": ("elliptique",),
    "elliptiques": ("elliptique",),
    "élogieuse": ("élogieux",),
    "élogieuses": ("élogieux",),
    "élogieux": ("élogieux",),
    "élohiste": ("élohiste",),
    "élohistes": ("élohiste",),
    "éloïste": ("éloïste",),
    "éloïstes": ("éloïste",),
    "élusif": ("élusif",),
    "élusifs": ("élusif",),
    "élusive": ("élusif",),
    "élusives": ("élusif",),
    "éluviale": ("éluvial",),
    "éluviales": ("éluvial",),
    "éluvial": ("éluvial",),
    "éluviaux": ("éluvial",),
    "éluvionnaire": ("éluvionnaire",),
    "éluvionnaires": ("éluvionnaire",),
    "élyséen": ("élyséen",),
    "élyséenne": ("élyséen",),
    "élyséennes": ("élyséen",),
    "élyséens": ("élyséen",),
    "élytrale": ("élytral",),
    "élytrales": ("élytral",),
    "élytral": ("élytral",),
    "élytraux": ("élytral",),
    "elzévirien": ("elzévirien",),
    "elzévirienne": ("elzévirien",),
    "elzéviriennes": ("elzévirien",),
    "elzéviriens": ("elzévirien",),
    "émanateur": ("émanateur",),
    "émanateurs": ("émanateur",),
    "émanatrice": ("émanateur",),
    "émanatrices": ("émanateur",),
    "émancipateur": ("émancipateur",),
    "émancipateurs": ("émancipateur",),
    "émancipatrice": ("émancipateur",),
    "émancipatrices": ("émancipateur",),
    "emberlificoteur": ("emberlificoteur",),
    "emberlificoteurs": ("emberlificoteur",),
    "emberlificoteuse": ("emberlificoteur",),
    "emberlificoteuses": ("emberlificoteur",),
    "emblématique": ("emblématique",),
    "emblématiques": ("emblématique",),
    "emboîtable": ("emboîtable",),
    "emboîtables": ("emboîtable",),
    "emboligène": ("emboligène",),
    "emboligènes": ("emboligène",),
    "embolique": ("embolique",),
    "emboliques": ("embolique",),
    "embolismique": ("embolismique",),
    "embolismiques": ("embolismique",),
    "emboutissable": ("emboutissable",),
    "emboutissables": ("emboutissable",),
    "emboutisseur": ("emboutisseur",),
    "emboutisseurs": ("emboutisseur",),
    "emboutisseuse": ("emboutisseur",),
    "emboutisseuses": ("emboutisseur",),
    "embrasseur": ("embrasseur",),
    "embrasseurs": ("embrasseur",),
    "embrasseuse": ("embrasseur",),
    "embrasseuses": ("embrasseur",),
    "embryogène": ("embryogène",),
    "embryogènes": ("embryogène",),
    "embryogénique": ("embryogénique",),
    "embryogéniques": ("embryogénique",),
    "embryoïde": ("embryoïde",),
    "embryoïdes": ("embryoïde",),
    "embryologique": ("embryologique",),
    "embryologiques": ("embryologique",),
    "embryonnaire": ("embryonnaire",),
    "embryonnaires": ("embryonnaire",),
    "embryoplastique": ("embryoplastique",),
    "embryoplastiques": ("embryoplastique",),
    "embryospécifique": ("embryospécifique",),
    "embryospécifiques": ("embryospécifique",),
    "embryotrophe": ("embryotrophe",),
    "embryotrophes": ("embryotrophe",),
    "embryotrophique": ("embryotrophique",),
    "embryotrophiques": ("embryotrophique",),
    "émeraude": ("émeraude",),
    "émérite": ("émérite",),
    "émérites": ("émérite",),
    "émétique": ("émétique",),
    "émétiques": ("émétique",),
    "émetteur": ("émetteur",),
    "émetteurs": ("émetteur",),
    "émettrice": ("émetteur",),
    "émettrices": ("émetteur",),
    "émilien": ("émilien",),
    "émilienne": ("émilien",),
    "émiliennes": ("émilien",),
    "émiliens": ("émilien",),
    "éminentissime": ("éminentissime",),
    "éminentissimes": ("éminentissime",),
    "émissaire": ("émissaire",),
    "émissaires": ("émissaire",),
    "émissif": ("émissif",),
    "émissifs": ("émissif",),
    "émissive": ("émissif",),
    "émissives": ("émissif",),
    "emménagogue": ("emménagogue",),
    "emménagogues": ("emménagogue",),
    "emmerdeur": ("emmerdeur",),
    "emmerdeurs": ("emmerdeur",),
    "emmerdeuse": ("emmerdeur",),
    "emmerdeuses": ("emmerdeur",),
    "emmétrope": ("emmétrope",),
    "emmétropes": ("emmétrope",),
    "émolumentaire": ("émolumentaire",),
    "émolumentaires": ("émolumentaire",),
    "émotif": ("émotif",),
    "émotifs": ("émotif",),
    "émotive": ("émotif",),
    "émotives": ("émotif",),
    "émotionnable": ("émotionnable",),
    "émotionnables": ("émotionnable",),
    "émotionnelle": ("émotionnel",),
    "émotionnelles": ("émotionnel",),
    "émotionnel": ("émotionnel",),
    "émotionnels": ("émotionnel",),
    "empathique": ("empathique",),
    "empathiques": ("empathique",),
    "emphatique": ("emphatique",),
    "emphatiques": ("emphatique",),
    "emphysémateuse": ("emphysémateux",),
    "emphysémateuses": ("emphysémateux",),
    "emphysémateux": ("emphysémateux",),
    "emphytéotique": ("emphytéotique",),
    "emphytéotiques": ("emphytéotique",),
    "empilable": ("empilable",),
    "empilables": ("empilable",),
    "empire": ("empire",),
    "empiriocriticiste": ("empiriocriticiste",),
    "empiriocriticistes": ("empiriocriticiste",),
    "empiriomoniste": ("empiriomoniste",),
    "empiriomonistes": ("empiriomoniste",),
    "empirique": ("empirique",),
    "empiriques": ("empirique",),
    "empiriste": ("empiriste",),
    "empiristes": ("empiriste",),
    "emplastique": ("emplastique",),
    "emplastiques": ("emplastique",),
    "employable": ("employable",),
    "employables": ("employable",),
    "empoisonneur": ("empoisonneur",),
    "empoisonneurs": ("empoisonneur",),
    "empoisonneuse": ("empoisonneur",),
    "empoisonneuses": ("empoisonneur",),
    "emprunteur": ("emprunteur",),
    "emprunteurs": ("emprunteur",),
    "emprunteuse": ("emprunteur",),
    "emprunteuses": ("emprunteur",),
    "empyreumatique": ("empyreumatique",),
    "empyreumatiques": ("empyreumatique",),
    "émulsif": ("émulsif",),
    "émulsifs": ("émulsif",),
    "émulsive": ("émulsif",),
    "émulsives": ("émulsif",),
    "émulsifiable": ("émulsifiable",),
    "émulsifiables": ("émulsifiable",),
    "émulsificateur": ("émulsificateur",),
    "émulsificateurs": ("émulsificateur",),
    "émulsificatrice": ("émulsificateur",),
    "émulsificatrices": ("émulsificateur",),
    "émulsionnable": ("émulsionnable",),
    "émulsionnables": ("émulsionnable",),
    "énantiomorphe": ("énantiomorphe",),
    "énantiomorphes": ("énantiomorphe",),
    "énantiotrope": ("énantiotrope",),
    "énantiotropes": ("énantiotrope",),
    "énarchique": ("énarchique",),
    "énarchiques": ("énarchique",),
    "énarque": ("énarque",),
    "énarques": ("énarque",),
    "encaissable": ("encaissable",),
    "encaissables": ("encaissable",),
    "encastrable": ("encastrable",),
    "encastrables": ("encastrable",),
    "enceinte": ("enceinte",),
    "enceintes": ("enceinte",),
    "encéphalique": ("encéphalique",),
    "encéphaliques": ("encéphalique",),
    "encéphalographique": ("encéphalographique",),
    "encéphalographiques": ("encéphalographique",),
    "encéphaloïde": ("encéphaloïde",),
    "encéphaloïdes": ("encéphaloïde",),
    "encéphalopathique": ("encéphalopathique",),
    "encéphalopathiques": ("encéphalopathique",),
    "enchanteresse": ("enchanteur",),
    "enchanteresses": ("enchanteur",),
    "enchanteur": ("enchanteur",),
    "enchanteurs": ("enchanteur",),
    "enchondrale": ("enchondral",),
    "enchondrales": ("enchondral",),
    "enchondral": ("enchondral",),
    "enchondraux": ("enchondral",),
    "enclitique": ("enclitique",),
    "enclitiques": ("enclitique",),
    "encodeur": ("encodeur",),
    "encodeurs": ("encodeur",),
    "encodeuse": ("encodeur",),
    "encodeuses": ("encodeur",),
    "encolleur": ("encolleur",),
    "encolleurs": ("encolleur",),
    "encolleuse": ("encolleur",),
    "encolleuses": ("encolleur",),
    "encoprésique": ("encoprésique",),
    "encoprésiques": ("encoprésique",),
    "encoprétique": ("encoprétique",),
    "encoprétiques": ("encoprétique",),
    "encreur": ("encreur",),
    "encreurs": ("encreur",),
    "encreuse": ("encreur",),
    "encreuses": ("encreur",),
    "encyclopédique": ("encyclopédique",),
    "encyclopédiques": ("encyclopédique",),
    "endapexien": ("endapexien",),
    "endapexienne": ("endapexien",),
    "endapexiennes": ("endapexien",),
    "endapexiens": ("endapexien",),
    "endémique": ("endémique",),
    "endémiques": ("endémique",),
    "endémosporadique": ("endémosporadique",),
    "endémo-sporadiques": ("endémosporadique",),
    "endémosporadiques": ("endémosporadique",),
    "endermique": ("endermique",),
    "endermiques": ("endermique",),
    "endoblastique": ("endoblastique",),
    "endoblastiques": ("endoblastique",),
    "endobronchique": ("endobronchique",),
    "endobronchiques": ("endobronchique",),
    "endobuccale": ("endobuccal",),
    "endobuccales": ("endobuccal",),
    "endobuccal": ("endobuccal",),
    "endobuccaux": ("endobuccal",),
    "endocardiaque": ("endocardiaque",),
    "endocardiaques": ("endocardiaque",),
    "endocardique": ("endocardique",),
    "endocardiques": ("endocardique",),
    "endocarditique": ("endocarditique",),
    "endocarditiques": ("endocarditique",),
    "endocavitaire": ("endocavitaire",),
    "endocavitaires": ("endocavitaire",),
    "endocellulaire": ("endocellulaire",),
    "endocellulaires": ("endocellulaire",),
    "endocentrique": ("endocentrique",),
    "endocentriques": ("endocentrique",),
    "endocervicale": ("endocervical",),
    "endocervicales": ("endocervical",),
    "endocervical": ("endocervical",),
    "endocervicaux": ("endocervical",),
    "endochondrale": ("endochondral",),
    "endochondrales": ("endochondral",),
    "endochondral": ("endochondral",),
    "endochondraux": ("endochondral",),
    "endochoriale": ("endochorial",),
    "endochoriales": ("endochorial",),
    "endochorial": ("endochorial",),
    "endochoriaux": ("endochorial",),
    "endocorporelle": ("endocorporel",),
    "endocorporelles": ("endocorporel",),
    "endocorporel": ("endocorporel",),
    "endocorporels": ("endocorporel",),
    "endocrânien": ("endocrânien",),
    "endocrânienne": ("endocrânien",),
    "endocrâniennes": ("endocrânien",),
    "endocrâniens": ("endocrânien",),
    "endocrine": ("endocrine",),
    "endocrines": ("endocrine",),
    "endocrinien": ("endocrinien",),
    "endocrinienne": ("endocrinien",),
    "endocriniennes": ("endocrinien",),
    "endocriniens": ("endocrinien",),
    "endocrinocardiaque": ("endocrinocardiaque",),
    "endocrinocardiaques": ("endocrinocardiaque",),
    "endocrinologique": ("endocrinologique",),
    "endocrinologiques": ("endocrinologique",),
    "endocrino-musculaire": ("endocrino-musculaire",),
    "endocrinotrope": ("endocrinotrope",),
    "endocrinotropes": ("endocrinotrope",),
    "endodermique": ("endodermique",),
    "endodermiques": ("endodermique",),
    "endogame": ("endogame",),
    "endogames": ("endogame",),
    "endogastrique": ("endogastrique",),
    "endogastriques": ("endogastrique",),
    "endogène": ("endogène",),
    "endogènes": ("endogène",),
    "endoglobulaire": ("endoglobulaire",),
    "endoglobulaires": ("endoglobulaire",),
    "endolabyrinthique": ("endolabyrinthique",),
    "endolabyrinthiques": ("endolabyrinthique",),
    "endoluminale": ("endoluminal",),
    "endoluminales": ("endoluminal",),
    "endoluminal": ("endoluminal",),
    "endoluminaux": ("endoluminal",),
    "endolymphatique": ("endolymphatique",),
    "endolymphatiques": ("endolymphatique",),
    "endométriale": ("endométrial",),
    "endométriales": ("endométrial",),
    "endométrial": ("endométrial",),
    "endométriaux": ("endométrial",),
    "endométrioïde": ("endométrioïde",),
    "endométrioïdes": ("endométrioïde",),
    "endométriosique": ("endométriosique",),
    "endométriosiques": ("endométriosique",),
    "endomorphe": ("endomorphe",),
    "endomorphes": ("endomorphe",),
    "endomyocardique": ("endomyocardique",),
    "endomyocardiques": ("endomyocardique",),
    "endonasale": ("endonasal",),
    "endonasales": ("endonasal",),
    "endonasal": ("endonasal",),
    "endonasaux": ("endonasal",),
    "endoplasmique": ("endoplasmique",),
    "endoplasmiques": ("endoplasmique",),
    "endoréique": ("endoréique",),
    "endoréiques": ("endoréique",),
    "endormeur": ("endormeur",),
    "endormeurs": ("endormeur",),
    "endormeuse": ("endormeur",),
    "endormeuses": ("endormeur",),
    "endorphinergique": ("endorphinergique",),
    "endorphinergiques": ("endorphinergique",),
    "endorphinique": ("endorphinique",),
    "endorphiniques": ("endorphinique",),
    "endosacculaire": ("endosacculaire",),
    "endosacculaires": ("endosacculaire",),
    "endoscopique": ("endoscopique",),
    "endoscopiques": ("endoscopique",),
    "endosomique": ("endosomique",),
    "endosomiques": ("endosomique",),
    "endosquelettique": ("endosquelettique",),
    "endosquelettiques": ("endosquelettique",),
    "endossable": ("endossable",),
    "endossables": ("endossable",),
    "endothéliale": ("endothélial",),
    "endothéliales": ("endothélial",),
    "endothélial": ("endothélial",),
    "endothéliaux": ("endothélial",),
    "endothéliochoriale": ("endothéliochorial",),
    "endothéliochoriales": ("endothéliochorial",),
    "endothéliochorial": ("endothéliochorial",),
    "endothéliochoriaux": ("endothéliochorial",),
    "endothérapique": ("endothérapique",),
    "endothérapiques": ("endothérapique",),
    "endothermique": ("endothermique",),
    "endothermiques": ("endothermique",),
    "endothoracique": ("endothoracique",),
    "endothoraciques": ("endothoracique",),
    "endothrix": ("endothrix",),
    "endotoxinique": ("endotoxinique",),
    "endotoxiniques": ("endotoxinique",),
    "endotrachéale": ("endotrachéal",),
    "endotrachéales": ("endotrachéal",),
    "endotrachéal": ("endotrachéal",),
    "endotrachéaux": ("endotrachéal",),
    "endotrophe": ("endotrophe",),
    "endotrophes": ("endotrophe",),
    "endo-urétrale": ("endo-urétral",),
    "endovaginale": ("endovaginal",),
    "endovaginales": ("endovaginal",),
    "endovaginal": ("endovaginal",),
    "endovaginaux": ("endovaginal",),
    "endovasculaire": ("endovasculaire",),
    "endovasculaires": ("endovasculaire",),
    "endoveineuse": ("endoveineux",),
    "endoveineuses": ("endoveineux",),
    "endoveineux": ("endoveineux",),
    "endroit": ("endroit",),
    "endurable": ("endurable",),
    "endurables": ("endurable",),
    "énéolithique": ("énéolithique",),
    "énéolithiques": ("énéolithique",),
    "énergétique": ("énergétique",),
    "énergétiques": ("énergétique",),
    "énergétiste": ("énergétiste",),
    "énergétistes": ("énergétiste",),
    "énergique": ("énergique",),
    "énergiques": ("énergique",),
    "énergivore": ("énergivore",),
    "énergivores": ("énergivore",),
    "enfichable": ("enfichable",),
    "enfichables": ("enfichable",),
    "enfichiste": ("enfichiste",),
    "enfichistes": ("enfichiste",),
    "enfoutiste": ("enfoutiste",),
    "enfoutistes": ("enfoutiste",),
    "enfumable": ("enfumable",),
    "enfumables": ("enfumable",),
    "engageable": ("engageable",),
    "engageables": ("engageable",),
    "enharmonique": ("enharmonique",),
    "enharmoniques": ("enharmonique",),
    "enhydre": ("enhydre",),
    "enhydres": ("enhydre",),
    "énième": ("énième",),
    "énièmes": ("énième",),
    "énigmatique": ("énigmatique",),
    "énigmatiques": ("énigmatique",),
    "enjôleur": ("enjôleur",),
    "enjôleurs": ("enjôleur",),
    "enjôleuse": ("enjôleur",),
    "enjôleuses": ("enjôleur",),
    "enképhalinergique": ("enképhalinergique",),
    "enképhalinergiques": ("enképhalinergique",),
    "ennéagonale": ("ennéagonal",),
    "ennéagonales": ("ennéagonal",),
    "ennéagonal": ("ennéagonal",),
    "ennéagonaux": ("ennéagonal",),
    "ennéagone": ("ennéagone",),
    "ennéagones": ("ennéagone",),
    "ennuyeuse": ("ennuyeux",),
    "ennuyeuses": ("ennuyeux",),
    "ennuyeux": ("ennuyeux",),
    "énolique": ("énolique",),
    "énoliques": ("énolique",),
    "énolisable": ("énolisable",),
    "énolisables": ("énolisable",),
    "énonçable": ("énonçable",),
    "énonçables": ("énonçable",),
    "énonciateur": ("énonciateur",),
    "énonciateurs": ("énonciateur",),
    "énonciatrice": ("énonciateur",),
    "énonciatrices": ("énonciateur",),
    "énonciatif": ("énonciatif",),
    "énonciatifs": ("énonciatif",),
    "énonciative": ("énonciatif",),
    "énonciatives": ("énonciatif",),
    "énorme": ("énorme",),
    "énormes": ("énorme",),
    "enquêteur": ("enquêteur",),
    "enquêteurs": ("enquêteur",),
    "enquêteuse": ("enquêteur",),
    "enquêteuses": ("enquêteur",),
    "enquiquineur": ("enquiquineur",),
    "enquiquineurs": ("enquiquineur",),
    "enquiquineuse": ("enquiquineur",),
    "enquiquineuses": ("enquiquineur",),
    "enregistrable": ("enregistrable",),
    "enregistrables": ("enregistrable",),
    "enregistreur": ("enregistreur",),
    "enregistreurs": ("enregistreur",),
    "enregistreuse": ("enregistreur",),
    "enregistreuses": ("enregistreur",),
    "enrhumable": ("enrhumable",),
    "enrhumables": ("enrhumable",),
    "enroulable": ("enroulable",),
    "enroulables": ("enroulable",),
    "enrouleur": ("enrouleur",),
    "enrouleurs": ("enrouleur",),
    "enrouleuse": ("enrouleur",),
    "enrouleuses": ("enrouleur",),
    "enseignable": ("enseignable",),
    "enseignables": ("enseignable",),
    "ensembliste": ("ensembliste",),
    "ensemblistes": ("ensembliste",),
    "ensiforme": ("ensiforme",),
    "ensiformes": ("ensiforme",),
    "ensorceleur": ("ensorceleur",),
    "ensorceleurs": ("ensorceleur",),
    "ensorceleuse": ("ensorceleur",),
    "ensorceleuses": ("ensorceleur",),
    "entérale": ("entéral",),
    "entérales": ("entéral",),
    "entéral": ("entéral",),
    "entéraux": ("entéral",),
    "entérique": ("entérique",),
    "entériques": ("entérique",),
    "entéritique": ("entéritique",),
    "entéritiques": ("entéritique",),
    "entérocélien": ("entérocélien",),
    "entérocélienne": ("entérocélien",),
    "entérocéliennes": ("entérocélien",),
    "entérocéliens": ("entérocélien",),
    "entérohépatique": ("entérohépatique",),
    "entéro-hépatiques": ("entéro-hépatique",),
    "entérohépatiques": ("entérohépatique",),
    "entérologique": ("entérologique",),
    "entérologiques": ("entérologique",),
    "entéropathogène": ("entéropathogène",),
    "entéropathogènes": ("entéropathogène",),
    "entérorénale": ("entérorénal",),
    "entérorénales": ("entérorénal",),
    "entérorénal": ("entérorénal",),
    "entérorénaux": ("entérorénal",),
    "entérosoluble": ("entérosoluble",),
    "entérosolubles": ("entérosoluble",),
    "entérotoxinogène": ("entérotoxinogène",),
    "entérotoxinogènes": ("entérotoxinogène",),
    "entérotrope": ("entérotrope",),
    "entérotropes": ("entérotrope",),
    "enthalpique": ("enthalpique",),
    "enthalpiques": ("enthalpique",),
    "enthousiaste": ("enthousiaste",),
    "enthousiastes": ("enthousiaste",),
    "entière": ("entier",),
    "entières": ("entier",),
    "entier": ("entier",),
    "entiers": ("entier",),
    "entomogame": ("entomogame",),
    "entomogames": ("entomogame",),
    "entomologique": ("entomologique",),
    "entomologiques": ("entomologique",),
    "entomophage": ("entomophage",),
    "entomophages": ("entomophage",),
    "entomophile": ("entomophile",),
    "entomophiles": ("entomophile",),
    "entoptique": ("entoptique",),
    "entoptiques": ("entoptique",),
    "entotique": ("entotique",),
    "entotiques": ("entotique",),
    "entraînable": ("entraînable",),
    "entraînables": ("entraînable",),
    "entreposable": ("entreposable",),
    "entreposables": ("entreposable",),
    "entrepositaire": ("entrepositaire",),
    "entrepositaires": ("entrepositaire",),
    "entrepreneuriale": ("entrepreneurial",),
    "entrepreneuriales": ("entrepreneurial",),
    "entrepreneurial": ("entrepreneurial",),
    "entrepreneuriaux": ("entrepreneurial",),
    "entriste": ("entriste",),
    "entristes": ("entriste",),
    "entropique": ("entropique",),
    "entropiques": ("entropique",),
    "énumérable": ("énumérable",),
    "énumérables": ("énumérable",),
    "énumérateur": ("énumérateur",),
    "énumérateurs": ("énumérateur",),
    "énumératrice": ("énumérateur",),
    "énumératrices": ("énumérateur",),
    "énumératif": ("énumératif",),
    "énumératifs": ("énumératif",),
    "énumérative": ("énumératif",),
    "énumératives": ("énumératif",),
    "énurétique": ("énurétique",),
    "énurétiques": ("énurétique",),
    "envahisseur": ("envahisseur",),
    "envahisseurs": ("envahisseur",),
    "envahisseuse": ("envahisseur",),
    "envahisseuses": ("envahisseur",),
    "envers": ("envers",),
    "enviable": ("enviable",),
    "enviables": ("enviable",),
    "envieuse": ("envieux",),
    "envieuses": ("envieux",),
    "envieux": ("envieux",),
    "environnementale": ("environnemental",),
    "environnementales": ("environnemental",),
    "environnemental": ("environnemental",),
    "environnementaux": ("environnemental",),
    "envisageable": ("envisageable",),
    "envisageables": ("envisageable",),
    "enzootique": ("enzootique",),
    "enzootiques": ("enzootique",),
    "enzymatique": ("enzymatique",),
    "enzymatiques": ("enzymatique",),
    "enzymologique": ("enzymologique",),
    "enzymologiques": ("enzymologique",),
    "enzymoprive": ("enzymoprive",),
    "enzymoprives": ("enzymoprive",),
    "éocambrien": ("éocambrien",),
    "éocambrienne": ("éocambrien",),
    "éocambriennes": ("éocambrien",),
    "éocambriens": ("éocambrien",),
    "éocène": ("éocène",),
    "éocènes": ("éocène",),
    "éolien": ("éolien",),
    "éolienne": ("éolien",),
    "éoliennes": ("éolien",),
    "éoliens": ("éolien",),
    "éolique": ("éolique",),
    "éoliques": ("éolique",),
    "éolithique": ("éolithique",),
    "éolithiques": ("éolithique",),
    "éosinophile": ("éosinophile",),
    "éosinophiles": ("éosinophile",),
    "éosinophilique": ("éosinophilique",),
    "éosinophiliques": ("éosinophilique",),
    "épactale": ("épactal",),
    "épactales": ("épactal",),
    "épactal": ("épactal",),
    "épactaux": ("épactal",),
    "épagogique": ("épagogique",),
    "épagogiques": ("épagogique",),
    "épagomène": ("épagomène",),
    "épagomènes": ("épagomène",),
    "épais": ("épais",),
    "épaisse": ("épais",),
    "épaisses": ("épais",),
    "épaississeur": ("épaississeur",),
    "épaississeurs": ("épaississeur",),
    "épaississeuse": ("épaississeur",),
    "épaississeuses": ("épaississeur",),
    "éparse": ("épars",),
    "éparses": ("épars",),
    "épars": ("épars",),
    "épateur": ("épateur",),
    "épateurs": ("épateur",),
    "épateuse": ("épateur",),
    "épateuses": ("épateur",),
    "épeirogénique": ("épeirogénique",),
    "épeirogéniques": ("épeirogénique",),
    "épéiste": ("épéiste",),
    "épéistes": ("épéiste",),
    "épendymaire": ("épendymaire",),
    "épendymaires": ("épendymaire",),
    "épenthétique": ("épenthétique",),
    "épenthétiques": ("épenthétique",),
    "épexégétique": ("épexégétique",),
    "épexégétiques": ("épexégétique",),
    "épharmonique": ("épharmonique",),
    "épharmoniques": ("épharmonique",),
    "éphébique": ("éphébique",),
    "éphébiques": ("éphébique",),
    "éphectique": ("éphectique",),
    "éphectiques": ("éphectique",),
    "éphelcystique": ("éphelcystique",),
    "éphelcystiques": ("éphelcystique",),
    "éphémère": ("éphémère",),
    "éphémères": ("éphémère",),
    "éphémérophyte": ("éphémérophyte",),
    "éphémérophytes": ("éphémérophyte",),
    "éphésien": ("éphésien",),
    "éphésienne": ("éphésien",),
    "éphésiennes": ("éphésien",),
    "éphésiens": ("éphésien",),
    "éphestien": ("éphestien",),
    "éphestienne": ("éphestien",),
    "éphestiennes": ("éphestien",),
    "éphestiens": ("éphestien",),
    "épiblastique": ("épiblastique",),
    "épiblastiques": ("épiblastique",),
    "épibranchiale": ("épibranchial",),
    "épibranchiales": ("épibranchial",),
    "épibranchial": ("épibranchial",),
    "épibranchiaux": ("épibranchial",),
    "épicanthique": ("épicanthique",),
    "épicanthiques": ("épicanthique",),
    "épicardique": ("épicardique",),
    "épicardiques": ("épicardique",),
    "épicellulaire": ("épicellulaire",),
    "épicellulaires": ("épicellulaire",),
    "épicène": ("épicène",),
    "épicènes": ("épicène",),
    "épicentrale": ("épicentral",),
    "épicentrales": ("épicentral",),
    "épicentral": ("épicentral",),
    "épicentraux": ("épicentral",),
    "épicentrique": ("épicentrique",),
    "épicentriques": ("épicentrique",),
    "épichérématique": ("épichérématique",),
    "épichérématiques": ("épichérématique",),
    "épichoriale": ("épichorial",),
    "épichoriales": ("épichorial",),
    "épichorial": ("épichorial",),
    "épichoriaux": ("épichorial",),
    "épicondylien": ("épicondylien",),
    "épicondylienne": ("épicondylien",),
    "épicondyliennes": ("épicondylien",),
    "épicondyliens": ("épicondylien",),
    "épicontinentale": ("épicontinental",),
    "épicontinentales": ("épicontinental",),
    "épicontinental": ("épicontinental",),
    "épicontinentaux": ("épicontinental",),
    "épicrânien": ("épicrânien",),
    "épicrânienne": ("épicrânien",),
    "épicrâniennes": ("épicrânien",),
    "épicrâniens": ("épicrânien",),
    "épicritique": ("épicritique",),
    "épicritiques": ("épicritique",),
    "épicurien": ("épicurien",),
    "épicurienne": ("épicurien",),
    "épicuriennes": ("épicurien",),
    "épicuriens": ("épicurien",),
    "épicycloïdale": ("épicycloïdal",),
    "épicycloïdales": ("épicycloïdal",),
    "épicycloïdal": ("épicycloïdal",),
    "épicycloïdaux": ("épicycloïdal",),
    "épidéictique": ("épidéictique",),
    "épidéictiques": ("épidéictique",),
    "épidémiologique": ("épidémiologique",),
    "épidémiologiques": ("épidémiologique",),
    "épidémique": ("épidémique",),
    "épidémiques": ("épidémique",),
    "épidermique": ("épidermique",),
    "épidermiques": ("épidermique",),
    "épidermoïde": ("épidermoïde",),
    "épidermoïdes": ("épidermoïde",),
    "épidiascopique": ("épidiascopique",),
    "épidiascopiques": ("épidiascopique",),
    "épididymaire": ("épididymaire",),
    "épididymaires": ("épididymaire",),
    "épidurale": ("épidural",),
    "épidurales": ("épidural",),
    "épidural": ("épidural",),
    "épiduraux": ("épidural",),
    "épigame": ("épigame",),
    "épigames": ("épigame",),
    "épigamique": ("épigamique",),
    "épigamiques": ("épigamique",),
    "épigastrique": ("épigastrique",),
    "épigastriques": ("épigastrique",),
    "épigénésique": ("épigénésique",),
    "épigénésiques": ("épigénésique",),
    "épigénétique": ("épigénétique",),
    "épigénétiques": ("épigénétique",),
    "épigénique": ("épigénique",),
    "épigéniques": ("épigénique",),
    "épiglottique": ("épiglottique",),
    "épiglottiques": ("épiglottique",),
    "épignathe": ("épignathe",),
    "épignathes": ("épignathe",),
    "épigrammatique": ("épigrammatique",),
    "épigrammatiques": ("épigrammatique",),
    "épigraphique": ("épigraphique",),
    "épigraphiques": ("épigraphique",),
    "épigyne": ("épigyne",),
    "épigynes": ("épigyne",),
    "épilatoire": ("épilatoire",),
    "épilatoires": ("épilatoire",),
    "épileptiforme": ("épileptiforme",),
    "épileptiformes": ("épileptiforme",),
    "épileptique": ("épileptique",),
    "épileptiques": ("épileptique",),
    "épileptogène": ("épileptogène",),
    "épileptogènes": ("épileptogène",),
    "épileptoïde": ("épileptoïde",),
    "épileptoïdes": ("épileptoïde",),
    "épileur": ("épileur",),
    "épileurs": ("épileur",),
    "épileuse": ("épileur",),
    "épileuses": ("épileur",),
    "épimastigote": ("épimastigote",),
    "épimastigotes": ("épimastigote",),
    "épimère": ("épimère",),
    "épimères": ("épimère",),
    "épineurien": ("épineurien",),
    "épineurienne": ("épineurien",),
    "épineuriennes": ("épineurien",),
    "épineuriens": ("épineurien",),
    "épineuse": ("épineux",),
    "épineuses": ("épineux",),
    "épineux": ("épineux",),
    "épinière": ("épinière",),
    "épinières": ("épinière",),
    "épipaléolithique": ("épipaléolithique",),
    "épipaléolithiques": ("épipaléolithique",),
    "épipélagique": ("épipélagique",),
    "épipélagiques": ("épipélagique",),
    "épiphane": ("épiphane",),
    "épiphanes": ("épiphane",),
    "épiphénoméniste": ("épiphénoméniste",),
    "épiphénoménistes": ("épiphénoméniste",),
    "épiphrénique": ("épiphrénique",),
    "épiphréniques": ("épiphrénique",),
    "épiphylle": ("épiphylle",),
    "épiphylles": ("épiphylle",),
    "épiphysaire": ("épiphysaire",),
    "épiphysaires": ("épiphysaire",),
    "épiphyte": ("épiphyte",),
    "épiphytes": ("épiphyte",),
    "épiphytique": ("épiphytique",),
    "épiphytiques": ("épiphytique",),
    "épiploïque": ("épiploïque",),
    "épiploïques": ("épiploïque",),
    "épique": ("épique",),
    "épiques": ("épique",),
    "épirogénique": ("épirogénique",),
    "épirogéniques": ("épirogénique",),
    "épirote": ("épirote",),
    "épirotes": ("épirote",),
    "épisclérale": ("épiscléral",),
    "épisclérales": ("épiscléral",),
    "épiscléral": ("épiscléral",),
    "épiscléraux": ("épiscléral",),
    "épiscopale": ("épiscopal",),
    "épiscopales": ("épiscopal",),
    "épiscopal": ("épiscopal",),
    "épiscopaux": ("épiscopal",),
    "épiscopalien": ("épiscopalien",),
    "épiscopalienne": ("épiscopalien",),
    "épiscopaliennes": ("épiscopalien",),
    "épiscopaliens": ("épiscopalien",),
    "épiscopaliste": ("épiscopaliste",),
    "épiscopalistes": ("épiscopaliste",),
    "épisodique": ("épisodique",),
    "épisodiques": ("épisodique",),
    "épispastique": ("épispastique",),
    "épispastiques": ("épispastique",),
    "épistatique": ("épistatique",),
    "épistatiques": ("épistatique",),
    "épistémique": ("épistémique",),
    "épistémiques": ("épistémique",),
    "épistémologique": ("épistémologique",),
    "épistémologiques": ("épistémologique",),
    "épistolaire": ("épistolaire",),
    "épistolaires": ("épistolaire",),
    "épitaxiale": ("épitaxial",),
    "épitaxiales": ("épitaxial",),
    "épitaxial": ("épitaxial",),
    "épitaxiaux": ("épitaxial",),
    "épithéliale": ("épithélial",),
    "épithéliales": ("épithélial",),
    "épithélial": ("épithélial",),
    "épithéliaux": ("épithélial",),
    "épithéliochoriale": ("épithéliochorial",),
    "épithéliochoriales": ("épithéliochorial",),
    "épithéliochorial": ("épithéliochorial",),
    "épithéliochoriaux": ("épithéliochorial",),
    "épithélioïde": ("épithélioïde",),
    "épithélioïdes": ("épithélioïde",),
    "épithéliomateuse": ("épithéliomateux",),
    "épithéliomateuses": ("épithéliomateux",),
    "épithéliomateux": ("épithéliomateux",),
    "épithéliomusculaire": ("épithéliomusculaire",),
    "épithéliomusculaires": ("épithéliomusculaire",),
    "épithermale": ("épithermal",),
    "épithermales": ("épithermal",),
    "épithermal": ("épithermal",),
    "épithermaux": ("épithermal",),
    "épithermique": ("épithermique",),
    "épithermiques": ("épithermique",),
    "épithète": ("épithète",),
    "épithètes": ("épithète",),
    "épithétique": ("épithétique",),
    "épithétiques": ("épithétique",),
    "épitrochléen": ("épitrochléen",),
    "épitrochléenne": ("épitrochléen",),
    "épitrochléennes": ("épitrochléen",),
    "épitrochléens": ("épitrochléen",),
    "épizonale": ("épizonal",),
    "épizonales": ("épizonal",),
    "épizonal": ("épizonal",),
    "épizonaux": ("épizonal",),
    "épizootique": ("épizootique",),
    "épizootiques": ("épizootique",),
    "éplucheur": ("éplucheur",),
    "éplucheurs": ("éplucheur",),
    "éplucheuse": ("éplucheur",),
    "éplucheuses": ("éplucheur",),
    "épongeable": ("épongeable",),
    "épongeables": ("épongeable",),
    "éponyme": ("éponyme",),
    "éponymes": ("éponyme",),
    "épouvantable": ("épouvantable",),
    "épouvantables": ("épouvantable",),
    "époxy": ("époxy",),
    "époxyde": ("époxyde",),
    "époxydes": ("époxyde",),
    "époxydique": ("époxydique",),
    "époxydiques": ("époxydique",),
    "éprise": ("épris",),
    "éprises": ("épris",),
    "épris": ("épris",),
    "épuisable": ("épuisable",),
    "épuisables": ("épuisable",),
    "épurateur": ("épurateur",),
    "épurateurs": ("épurateur",),
    "épurateuse": ("épurateur",),
    "épurateuses": ("épurateur",),
    "épuratif": ("épuratif",),
    "épuratifs": ("épuratif",),
    "épurative": ("épuratif",),
    "épuratives": ("épuratif",),
    "épuratoire": ("épuratoire",),
    "épuratoires": ("épuratoire",),
    "équanime": ("équanime",),
    "équanimes": ("équanime",),
    "équationnelle": ("équationnel",),
    "équationnelles": ("équationnel",),
    "équationnel": ("équationnel",),
    "équationnels": ("équationnel",),
    "équatoriale": ("équatorial",),
    "équatoriales": ("équatorial",),
    "équatorial": ("équatorial",),
    "équatoriaux": ("équatorial",),
    "équatorien": ("équatorien",),
    "équatorienne": ("équatorien",),
    "équatoriennes": ("équatorien",),
    "équatoriens": ("équatorien",),
    "équestre": ("équestre",),
    "équestres": ("équestre",),
    "équiangle": ("équiangle",),
    "équiangles": ("équiangle",),
    "équiaxe": ("équiaxe",),
    "équiaxes": ("équiaxe",),
    "équiconcave": ("équiconcave",),
    "équiconcaves": ("équiconcave",),
    "équiconvexe": ("équiconvexe",),
    "équiconvexes": ("équiconvexe",),
    "équidirectif": ("équidirectif",),
    "équidirectifs": ("équidirectif",),
    "équidirective": ("équidirectif",),
    "équidirectives": ("équidirectif",),
    "équienne": ("équienne",),
    "équiennes": ("équienne",),
    "équilatérale": ("équilatéral",),
    "équilatérales": ("équilatéral",),
    "équilatéral": ("équilatéral",),
    "équilatéraux": ("équilatéral",),
    "équilatère": ("équilatère",),
    "équilatères": ("équilatère",),
    "équilibreur": ("équilibreur",),
    "équilibreurs": ("équilibreur",),
    "équilibreuse": ("équilibreur",),
    "équilibreuses": ("équilibreur",),
    "équimoléculaire": ("équimoléculaire",),
    "équimoléculaires": ("équimoléculaire",),
    "équimultiple": ("équimultiple",),
    "équimultiples": ("équimultiple",),
    "équinoxiale": ("équinoxial",),
    "équinoxiales": ("équinoxial",),
    "équinoxial": ("équinoxial",),
    "équinoxiaux": ("équinoxial",),
    "équipossible": ("équipossible",),
    "équipossibles": ("équipossible",),
    "équipotentielle": ("équipotentiel",),
    "équipotentielles": ("équipotentiel",),
    "équipotentiel": ("équipotentiel",),
    "équipotentiels": ("équipotentiel",),
    "équiprobable": ("équiprobable",),
    "équiprobables": ("équiprobable",),
    "équitable": ("équitable",),
    "équitables": ("équitable",),
    "équivoquée": ("équivoqué",),
    "équivoquées": ("équivoqué",),
    "équivoqué": ("équivoqué",),
    "équivoque": ("équivoque",),
    "équivoqués": ("équivoqué",),
    "équivoques": ("équivoque",),
    "éradicateur": ("éradicateur",),
    "éradicateurs": ("éradicateur",),
    "éradicatrice": ("éradicateur",),
    "éradicatrices": ("éradicateur",),
    "érasmien": ("érasmien",),
    "érasmienne": ("érasmien",),
    "érasmiennes": ("érasmien",),
    "érasmiens": ("érasmien",),
    "erbique": ("erbique",),
    "erbiques": ("erbique",),
    "érecteur": ("érecteur",),
    "érecteurs": ("érecteur",),
    "érectrice": ("érecteur",),
    "érectrices": ("érecteur",),
    "érectile": ("érectile",),
    "érectiles": ("érectile",),
    "erectus": ("erectus",),
    "éreinteur": ("éreinteur",),
    "éreinteurs": ("éreinteur",),
    "éreinteuse": ("éreinteur",),
    "éreinteuses": ("éreinteur",),
    "érémitique": ("érémitique",),
    "érémitiques": ("érémitique",),
    "érémophile": ("érémophile",),
    "érémophiles": ("érémophile",),
    "érésipélateuse": ("érésipélateux",),
    "érésipélateuses": ("érésipélateux",),
    "érésipélateux": ("érésipélateux",),
    "ergastulaire": ("ergastulaire",),
    "ergastulaires": ("ergastulaire",),
    "ergatif": ("ergatif",),
    "ergatifs": ("ergatif",),
    "ergatogyne": ("ergatogyne",),
    "ergatogynes": ("ergatogyne",),
    "ergodique": ("ergodique",),
    "ergodiques": ("ergodique",),
    "ergographique": ("ergographique",),
    "ergographiques": ("ergographique",),
    "ergométrique": ("ergométrique",),
    "ergométriques": ("ergométrique",),
    "ergonomique": ("ergonomique",),
    "ergonomiques": ("ergonomique",),
    "ergoteur": ("ergoteur",),
    "ergoteurs": ("ergoteur",),
    "ergoteuse": ("ergoteur",),
    "ergoteuses": ("ergoteur",),
    "ergothérapique": ("ergothérapique",),
    "ergothérapiques": ("ergothérapique",),
    "éristique": ("éristique",),
    "éristiques": ("éristique",),
    "érodable": ("érodable",),
    "érodables": ("érodable",),
    "érogène": ("érogène",),
    "érogènes": ("érogène",),
    "érosif": ("érosif",),
    "érosifs": ("érosif",),
    "érosive": ("érosif",),
    "érosives": ("érosif",),
    "érotique": ("érotique",),
    "érotiques": ("érotique",),
    "érotogène": ("érotogène",),
    "érotogènes": ("érotogène",),
    "érotologique": ("érotologique",),
    "érotologiques": ("érotologique",),
    "érotologue": ("érotologue",),
    "érotologues": ("érotologue",),
    "érotomane": ("érotomane",),
    "érotomanes": ("érotomane",),
    "érotomaniaque": ("érotomaniaque",),
    "érotomaniaques": ("érotomaniaque",),
    "erpétologique": ("erpétologique",),
    "erpétologiques": ("erpétologique",),
    "erratique": ("erratique",),
    "erratiques": ("erratique",),
    "erse": ("erse",),
    "erses": ("erse",),
    "éruciforme": ("éruciforme",),
    "éruciformes": ("éruciforme",),
    "érucique": ("érucique",),
    "éruciques": ("érucique",),
    "érugineuse": ("érugineux",),
    "érugineuses": ("érugineux",),
    "érugineux": ("érugineux",),
    "éruptif": ("éruptif",),
    "éruptifs": ("éruptif",),
    "éruptive": ("éruptif",),
    "éruptives": ("éruptif",),
    "érysipélateuse": ("érysipélateux",),
    "érysipélateuses": ("érysipélateux",),
    "érysipélateux": ("érysipélateux",),
    "érythémateuse": ("érythémateux",),
    "érythémateuses": ("érythémateux",),
    "érythémateux": ("érythémateux",),
    "érythématoïde": ("érythématoïde",),
    "érythématoïdes": ("érythématoïde",),
    "érythréen": ("érythréen",),
    "érythréenne": ("érythréen",),
    "érythréennes": ("érythréen",),
    "érythréens": ("érythréen",),
    "érythrémique": ("érythrémique",),
    "érythrémiques": ("érythrémique",),
    "érythroblastique": ("érythroblastique",),
    "érythroblastiques": ("érythroblastique",),
    "érythrocitaire": ("érythrocitaire",),
    "érythrocitaires": ("érythrocitaire",),
    "érythrocytaire": ("érythrocytaire",),
    "érythrocytaires": ("érythrocytaire",),
    "érythrodermique": ("érythrodermique",),
    "érythrodermiques": ("érythrodermique",),
    "érythrogène": ("érythrogène",),
    "érythrogènes": ("érythrogène",),
    "érythroïde": ("érythroïde",),
    "érythroïdes": ("érythroïde",),
    "érythromyéloïde": ("érythromyéloïde",),
    "érythromyéloïdes": ("érythromyéloïde",),
    "érythronique": ("érythronique",),
    "érythroniques": ("érythronique",),
    "érythropoïétique": ("érythropoïétique",),
    "érythropoïétiques": ("érythropoïétique",),
    "esbroufeur": ("esbroufeur",),
    "esbroufeurs": ("esbroufeur",),
    "esbroufeuse": ("esbroufeur",),
    "esbroufeuses": ("esbroufeur",),
    "escamotable": ("escamotable",),
    "escamotables": ("escamotable",),
    "escarrotique": ("escarrotique",),
    "escarrotiques": ("escarrotique",),
    "escharrotique": ("escharrotique",),
    "escharrotiques": ("escharrotique",),
    "eschatologique": ("eschatologique",),
    "eschatologiques": ("eschatologique",),
    "esclavagiste": ("esclavagiste",),
    "esclavagistes": ("esclavagiste",),
    "esclave": ("esclave",),
    "esclaves": ("esclave",),
    "esclavon": ("esclavon",),
    "esclavonne": ("esclavon",),
    "esclavonnes": ("esclavon",),
    "esclavons": ("esclavon",),
    "escomptable": ("escomptable",),
    "escomptables": ("escomptable",),
    "escompteur": ("escompteur",),
    "escompteurs": ("escompteur",),
    "escompteuse": ("escompteur",),
    "escompteuses": ("escompteur",),
    "escorteur": ("escorteur",),
    "escorteurs": ("escorteur",),
    "eskimo": ("eskimo",),
    "eskimos": ("eskimo",),
    "eskuarien": ("eskuarien",),
    "eskuarienne": ("eskuarien",),
    "eskuariennes": ("eskuarien",),
    "eskuariens": ("eskuarien",),
    "ésopique": ("ésopique",),
    "ésopiques": ("ésopique",),
    "ésotérique": ("ésotérique",),
    "ésotériques": ("ésotérique",),
    "espérable": ("espérable",),
    "espérables": ("espérable",),
    "espérantiste": ("espérantiste",),
    "espérantistes": ("espérantiste",),
    "espéranto": ("espéranto",),
    "espérantophone": ("espérantophone",),
    "espérantophones": ("espérantophone",),
    "espiègle": ("espiègle",),
    "espiègles": ("espiègle",),
    "espion": ("espion",),
    "espionne": ("espion",),
    "espionnes": ("espion",),
    "espions": ("espion",),
    "espressivo": ("espressivo",),
    "esquilleuse": ("esquilleux",),
    "esquilleuses": ("esquilleux",),
    "esquilleux": ("esquilleux",),
    "esquimaude": ("esquimau",),
    "esquimaudes": ("esquimau",),
    "esquimau": ("esquimau",),
    "esquimaux": ("esquimau",),
    "essénien": ("essénien",),
    "essénienne": ("essénien",),
    "esséniennes": ("essénien",),
    "esséniens": ("essénien",),
    "esséniste": ("esséniste",),
    "essénistes": ("esséniste",),
    "essentialiste": ("essentialiste",),
    "essentialistes": ("essentialiste",),
    "essentielle": ("essentiel",),
    "essentielles": ("essentiel",),
    "essentiel": ("essentiel",),
    "essentiels": ("essentiel",),
    "essoucheur": ("essoucheur",),
    "essoucheurs": ("essoucheur",),
    "essoucheuse": ("essoucheur",),
    "essoucheuses": ("essoucheur",),
    "est": ("est",),
    "est-africaines": ("est-africain",),
    "est-africain": ("est-africain",),
    "est-allemande": ("est-allemand",),
    "est-allemandes": ("est-allemand",),
    "est-allemand": ("est-allemand",),
    "est-allemands": ("est-allemand",),
    "estampeur": ("estampeur",),
    "estampeurs": ("estampeur",),
    "estampeuse": ("estampeur",),
    "estampeuses": ("estampeur",),
    "este": ("este",),
    "estes": ("este",),
    "est-européen": ("est-européen",),
    "est-européenne": ("est-européen",),
    "est-européens": ("est-européen",),
    "esthésiogène": ("esthésiogène",),
    "esthésiogènes": ("esthésiogène",),
    "esthésiométrique": ("esthésiométrique",),
    "esthésiométriques": ("esthésiométrique",),
    "esthète": ("esthète",),
    "esthètes": ("esthète",),
    "esthétique": ("esthétique",),
    "esthétiques": ("esthétique",),
    "estimable": ("estimable",),
    "estimables": ("estimable",),
    "estimatif": ("estimatif",),
    "estimatifs": ("estimatif",),
    "estimative": ("estimatif",),
    "estimatives": ("estimatif",),
    "estimatoire": ("estimatoire",),
    "estimatoires": ("estimatoire",),
    "estivale": ("estival",),
    "estivales": ("estival",),
    "estival": ("estival",),
    "estivaux": ("estival",),
    "estompable": ("estompable",),
    "estompables": ("estompable",),
    "estonien": ("estonien",),
    "estonienne": ("estonien",),
    "estoniennes": ("estonien",),
    "estoniens": ("estonien",),
    "estrogénique": ("estrogénique",),
    "estrogéniques": ("estrogénique",),
    "estroprogestatif": ("estroprogestatif",),
    "estroprogestatifs": ("estroprogestatif",),
    "estroprogestative": ("estroprogestatif",),
    "estroprogestatives": ("estroprogestatif",),
    "estuarien": ("estuarien",),
    "estuarienne": ("estuarien",),
    "estuariennes": ("estuarien",),
    "estuariens": ("estuarien",),
    "étale": ("étale",),
    "étales": ("étale",),
    "étalière": ("étalier",),
    "étalières": ("étalier",),
    "étalier": ("étalier",),
    "étaliers": ("étalier",),
    "étalonnière": ("étalonnier",),
    "étalonnières": ("étalonnier",),
    "étalonnier": ("étalonnier",),
    "étalonniers": ("étalonnier",),
    "étanche": ("étanche",),
    "étanches": ("étanche",),
    "étarque": ("étarque",),
    "étarques": ("étarque",),
    "étasunien": ("étasunien",),
    "étasunienne": ("étasunien",),
    "étasuniennes": ("étasunien",),
    "étasuniens": ("étasunien",),
    "étatique": ("étatique",),
    "étatiques": ("étatique",),
    "étatiste": ("étatiste",),
    "étatistes": ("étatiste",),
    "éternelle": ("éternel",),
    "éternelles": ("éternel",),
    "éternel": ("éternel",),
    "éternels": ("éternel",),
    "éternitaire": ("éternitaire",),
    "éternitaires": ("éternitaire",),
    "étésien": ("étésien",),
    "étésienne": ("étésien",),
    "étésiennes": ("étésien",),
    "étésiens": ("étésien",),
    "éthanoïque": ("éthanoïque",),
    "éthanoïques": ("éthanoïque",),
    "éthérique": ("éthérique",),
    "éthériques": ("éthérique",),
    "éthéromane": ("éthéromane",),
    "éthéromanes": ("éthéromane",),
    "éthiopien": ("éthiopien",),
    "éthiopienne": ("éthiopien",),
    "éthiopiennes": ("éthiopien",),
    "éthiopiens": ("éthiopien",),
    "éthique": ("éthique",),
    "éthiques": ("éthique",),
    "ethmoïdale": ("ethmoïdal",),
    "ethmoïdales": ("ethmoïdal",),
    "ethmoïdal": ("ethmoïdal",),
    "ethmoïdaux": ("ethmoïdal",),
    "ethmoïde": ("ethmoïde",),
    "ethmoïdes": ("ethmoïde",),
    "ethnique": ("ethnique",),
    "ethniques": ("ethnique",),
    "ethnobiologique": ("ethnobiologique",),
    "ethnobiologiques": ("ethnobiologique",),
    "ethnobotanique": ("ethnobotanique",),
    "ethnobotaniques": ("ethnobotanique",),
    "ethnocentrique": ("ethnocentrique",),
    "ethnocentriques": ("ethnocentrique",),
    "ethnographique": ("ethnographique",),
    "ethnographiques": ("ethnographique",),
    "ethnohistorique": ("ethnohistorique",),
    "ethnohistoriques": ("ethnohistorique",),
    "ethnolinguistique": ("ethnolinguistique",),
    "ethnolinguistiques": ("ethnolinguistique",),
    "ethnologique": ("ethnologique",),
    "ethnologiques": ("ethnologique",),
    "ethnométhodologique": ("ethnométhodologique",),
    "ethnométhodologiques": ("ethnométhodologique",),
    "ethnomusicologique": ("ethnomusicologique",),
    "ethnomusicologiques": ("ethnomusicologique",),
    "ethnophysiologique": ("ethnophysiologique",),
    "ethnophysiologiques": ("ethnophysiologique",),
    "ethnophysique": ("ethnophysique",),
    "ethnophysiques": ("ethnophysique",),
    "ethnopsychiatrique": ("ethnopsychiatrique",),
    "ethnopsychiatriques": ("ethnopsychiatrique",),
    "ethnopsychologique": ("ethnopsychologique",),
    "ethnopsychologiques": ("ethnopsychologique",),
    "ethnozoologique": ("ethnozoologique",),
    "ethnozoologiques": ("ethnozoologique",),
    "ethnozootechnique": ("ethnozootechnique",),
    "ethnozootechniques": ("ethnozootechnique",),
    "éthologique": ("éthologique",),
    "éthologiques": ("éthologique",),
    "éthoxalique": ("éthoxalique",),
    "éthoxaliques": ("éthoxalique",),
    "éthylénique": ("éthylénique",),
    "éthyléniques": ("éthylénique",),
    "éthylique": ("éthylique",),
    "éthyliques": ("éthylique",),
    "éthylsulfurique": ("éthylsulfurique",),
    "éthylsulfuriques": ("éthylsulfurique",),
    "étiologique": ("étiologique",),
    "étiologiques": ("étiologique",),
    "étiopathogénique": ("étiopathogénique",),
    "étiopathogéniques": ("étiopathogénique",),
    "étique": ("étique",),
    "étiques": ("étique",),
    "étiquetable": ("étiquetable",),
    "étiquetables": ("étiquetable",),
    "étirable": ("étirable",),
    "étirables": ("étirable",),
    "étireur": ("étireur",),
    "étireurs": ("étireur",),
    "étireuse": ("étireur",),
    "étireuses": ("étireur",),
    "étolien": ("étolien",),
    "étolienne": ("étolien",),
    "étoliennes": ("étolien",),
    "étoliens": ("étolien",),
    "étrange": ("étrange",),
    "étranges": ("étrange",),
    "étrangère": ("étranger",),
    "étrangères": ("étranger",),
    "étranger": ("étranger",),
    "étrangers": ("étranger",),
    "étrangleur": ("étrangleur",),
    "étrangleurs": ("étrangleur",),
    "étrangleuse": ("étrangleur",),
    "étrangleuses": ("étrangleur",),
    "étrière": ("étrier",),
    "étrières": ("étrier",),
    "étrier": ("étrier",),
    "étriers": ("étrier",),
    "étruscologique": ("étruscologique",),
    "étruscologiques": ("étruscologique",),
    "étrusque": ("étrusque",),
    "étrusques": ("étrusque",),
    "étudiable": ("étudiable",),
    "étudiables": ("étudiable",),
    "étymologique": ("étymologique",),
    "étymologiques": ("étymologique",),
    "eubéen": ("eubéen",),
    "eubéenne": ("eubéen",),
    "eubéennes": ("eubéen",),
    "eubéens": ("eubéen",),
    "euboïque": ("euboïque",),
    "euboïques": ("euboïque",),
    "eucaryote": ("eucaryote",),
    "eucaryotes": ("eucaryote",),
    "eucéphale": ("eucéphale",),
    "eucéphales": ("eucéphale",),
    "eucharistique": ("eucharistique",),
    "eucharistiques": ("eucharistique",),
    "euclidien": ("euclidien",),
    "euclidienne": ("euclidien",),
    "euclidiennes": ("euclidien",),
    "euclidiens": ("euclidien",),
    "eudémonique": ("eudémonique",),
    "eudémoniques": ("eudémonique",),
    "eudémoniste": ("eudémoniste",),
    "eudémonistes": ("eudémoniste",),
    "eudiométrique": ("eudiométrique",),
    "eudiométriques": ("eudiométrique",),
    "eugénique": ("eugénique",),
    "eugéniques": ("eugénique",),
    "eugonadotrophique": ("eugonadotrophique",),
    "eugonadotrophiques": ("eugonadotrophique",),
    "eulérien": ("eulérien",),
    "eulérienne": ("eulérien",),
    "eulériennes": ("eulérien",),
    "eulériens": ("eulérien",),
    "eunuchoïde": ("eunuchoïde",),
    "eunuchoïdes": ("eunuchoïde",),
    "eupepsique": ("eupepsique",),
    "eupepsiques": ("eupepsique",),
    "eupeptique": ("eupeptique",),
    "eupeptiques": ("eupeptique",),
    "euphémique": ("euphémique",),
    "euphémiques": ("euphémique",),
    "euphonique": ("euphonique",),
    "euphoniques": ("euphonique",),
    "euphorique": ("euphorique",),
    "euphoriques": ("euphorique",),
    "euphotique": ("euphotique",),
    "euphotiques": ("euphotique",),
    "euphuiste": ("euphuiste",),
    "euphuistes": ("euphuiste",),
    "euploïde": ("euploïde",),
    "euploïdes": ("euploïde",),
    "eupnéique": ("eupnéique",),
    "eupnéiques": ("eupnéique",),
    "eupraxique": ("eupraxique",),
    "eupraxiques": ("eupraxique",),
    "eurasiatique": ("eurasiatique",),
    "eurasiatiques": ("eurasiatique",),
    "eurasien": ("eurasien",),
    "eurasienne": ("eurasien",),
    "eurasiennes": ("eurasien",),
    "eurasiens": ("eurasien",),
    "euristique": ("euristique",),
    "euristiques": ("euristique",),
    "eurocommuniste": ("eurocommuniste",),
    "eurocommunistes": ("eurocommuniste",),
    "européaniste": ("européaniste",),
    "européanistes": ("européaniste",),
    "européen": ("européen",),
    "européenne": ("européen",),
    "européennes": ("européen",),
    "européens": ("européen",),
    "européiste": ("européiste",),
    "européistes": ("européiste",),
    "europeuse": ("europeux",),
    "europeuses": ("europeux",),
    "europeux": ("europeux",),
    "europhile": ("europhile",),
    "europhiles": ("europhile",),
    "europhobe": ("europhobe",),
    "europhobes": ("europhobe",),
    "europique": ("europique",),
    "europiques": ("europique",),
    "eurosceptique": ("eurosceptique",),
    "eurosceptiques": ("eurosceptique",),
    "euryalique": ("euryalique",),
    "euryaliques": ("euryalique",),
    "euryionique": ("euryionique",),
    "euryioniques": ("euryionique",),
    "euryphotique": ("euryphotique",),
    "euryphotiques": ("euryphotique",),
    "eurytherme": ("eurytherme",),
    "eurythermes": ("eurytherme",),
    "eurythmique": ("eurythmique",),
    "eurythmiques": ("eurythmique",),
    "euscarien": ("euscarien",),
    "euscarienne": ("euscarien",),
    "euscariennes": ("euscarien",),
    "euscariens": ("euscarien",),
    "euskarien": ("euskarien",),
    "euskarienne": ("euskarien",),
    "euskariennes": ("euskarien",),
    "euskariens": ("euskarien",),
    "euskarophone": ("euskarophone",),
    "euskarophones": ("euskarophone",),
    "euskérien": ("euskérien",),
    "euskérienne": ("euskérien",),
    "euskériennes": ("euskérien",),
    "euskériens": ("euskérien",),
    "eusomphalien": ("eusomphalien",),
    "eusomphalienne": ("eusomphalien",),
    "eusomphaliennes": ("eusomphalien",),
    "eusomphaliens": ("eusomphalien",),
    "eustasique": ("eustasique",),
    "eustasiques": ("eustasique",),
    "eustatique": ("eustatique",),
    "eustatiques": ("eustatique",),
    "eutectique": ("eutectique",),
    "eutectiques": ("eutectique",),
    "eutectoïde": ("eutectoïde",),
    "eutectoïdes": ("eutectoïde",),
    "euthanasique": ("euthanasique",),
    "euthanasiques": ("euthanasique",),
    "euthyroïdien": ("euthyroïdien",),
    "euthyroïdienne": ("euthyroïdien",),
    "euthyroïdiennes": ("euthyroïdien",),
    "euthyroïdiens": ("euthyroïdien",),
    "eutocique": ("eutocique",),
    "eutociques": ("eutocique",),
    "eutrophe": ("eutrophe",),
    "eutrophes": ("eutrophe",),
    "eutrophique": ("eutrophique",),
    "eutrophiques": ("eutrophique",),
    "euxinique": ("euxinique",),
    "euxiniques": ("euxinique",),
    "évacuateur": ("évacuateur",),
    "évacuateurs": ("évacuateur",),
    "évacuatrice": ("évacuateur",),
    "évacuatrices": ("évacuateur",),
    "évaluable": ("évaluable",),
    "évaluables": ("évaluable",),
    "évaluateur": ("évaluateur",),
    "évaluateurs": ("évaluateur",),
    "évaluatrice": ("évaluateur",),
    "évaluatrices": ("évaluateur",),
    "évaluatif": ("évaluatif",),
    "évaluatifs": ("évaluatif",),
    "évaluative": ("évaluatif",),
    "évaluatives": ("évaluatif",),
    "évangélique": ("évangélique",),
    "évangéliques": ("évangélique",),
    "évangélisateur": ("évangélisateur",),
    "évangélisateurs": ("évangélisateur",),
    "évangélisatrice": ("évangélisateur",),
    "évangélisatrices": ("évangélisateur",),
    "évangéliste": ("évangéliste",),
    "évangélistes": ("évangéliste",),
    "évaporable": ("évaporable",),
    "évaporables": ("évaporable",),
    "évaporatoire": ("évaporatoire",),
    "évaporatoires": ("évaporatoire",),
    "évaporitique": ("évaporitique",),
    "évaporitiques": ("évaporitique",),
    "évasif": ("évasif",),
    "évasifs": ("évasif",),
    "évasive": ("évasif",),
    "évasives": ("évasif",),
    "événementielle": ("événementiel",),
    "événementielles": ("événementiel",),
    "événementiel": ("événementiel",),
    "événementiels": ("événementiel",),
    "éventuelle": ("éventuel",),
    "éventuelles": ("éventuel",),
    "éventuel": ("éventuel",),
    "éventuels": ("éventuel",),
    "évergète": ("évergète",),
    "évergètes": ("évergète",),
    "evhémériste": ("evhémériste",),
    "evhéméristes": ("evhémériste",),
    "évitable": ("évitable",),
    "évitables": ("évitable",),
    "évocable": ("évocable",),
    "évocables": ("évocable",),
    "évocateur": ("évocateur",),
    "évocateurs": ("évocateur",),
    "évocatrice": ("évocateur",),
    "évocatrices": ("évocateur",),
    "évocatif": ("évocatif",),
    "évocatifs": ("évocatif",),
    "évocative": ("évocatif",),
    "évocatives": ("évocatif",),
    "évocatoire": ("évocatoire",),
    "évocatoires": ("évocatoire",),
    "évolutif": ("évolutif",),
    "évolutifs": ("évolutif",),
    "évolutive": ("évolutif",),
    "évolutives": ("évolutif",),
    "évolutionniste": ("évolutionniste",),
    "évolutionnistes": ("évolutionniste",),
    "exagérateur": ("exagérateur",),
    "exagérateurs": ("exagérateur",),
    "exagératrice": ("exagérateur",),
    "exagératrices": ("exagérateur",),
    "exaltable": ("exaltable",),
    "exaltables": ("exaltable",),
    "examinable": ("examinable",),
    "examinables": ("examinable",),
    "exanthémateuse": ("exanthémateux",),
    "exanthémateuses": ("exanthémateux",),
    "exanthémateux": ("exanthémateux",),
    "exanthématique": ("exanthématique",),
    "exanthématiques": ("exanthématique",),
    "excavatrice": ("excavatrice",),
    "excavatrices": ("excavatrice",),
    "excédentaire": ("excédentaire",),
    "excédentaires": ("excédentaire",),
    "excellentissime": ("excellentissime",),
    "excellentissimes": ("excellentissime",),
    "excentrique": ("excentrique",),
    "excentriques": ("excentrique",),
    "exceptionnelle": ("exceptionnel",),
    "exceptionnelles": ("exceptionnel",),
    "exceptionnel": ("exceptionnel",),
    "exceptionnels": ("exceptionnel",),
    "excessif": ("excessif",),
    "excessifs": ("excessif",),
    "excessive": ("excessif",),
    "excessives": ("excessif",),
    "excimère": ("excimère",),
    "excimères": ("excimère",),
    "excitable": ("excitable",),
    "excitables": ("excitable",),
    "excitateur": ("excitateur",),
    "excitateurs": ("excitateur",),
    "excitatrice": ("excitateur",),
    "excitatrices": ("excitateur",),
    "excitomoteur": ("excitomoteur",),
    "excitomoteurs": ("excitomoteur",),
    "excito-motrice": ("excito-moteur",),
    "excitomotrice": ("excitomoteur",),
    "excitomotrices": ("excitomoteur",),
    "excitosécrétoire": ("excitosécrétoire",),
    "excitosécrétoires": ("excitosécrétoire",),
    "excitotoxique": ("excitotoxique",),
    "excitotoxiques": ("excitotoxique",),
    "exclamatif": ("exclamatif",),
    "exclamatifs": ("exclamatif",),
    "exclamative": ("exclamatif",),
    "exclamatives": ("exclamatif",),
    "exclusif": ("exclusif",),
    "exclusifs": ("exclusif",),
    "exclusive": ("exclusif",),
    "exclusives": ("exclusif",),
    "exclusiviste": ("exclusiviste",),
    "exclusivistes": ("exclusiviste",),
    "excrémenteuse": ("excrémenteux",),
    "excrémenteuses": ("excrémenteux",),
    "excrémenteux": ("excrémenteux",),
    "excrémentielle": ("excrémentiel",),
    "excrémentielles": ("excrémentiel",),
    "excrémentiel": ("excrémentiel",),
    "excrémentiels": ("excrémentiel",),
    "excréteur": ("excréteur",),
    "excréteurs": ("excréteur",),
    "excrétrice": ("excréteur",),
    "excrétrices": ("excréteur",),
    "excrétoire": ("excrétoire",),
    "excrétoires": ("excrétoire",),
    "excusable": ("excusable",),
    "excusables": ("excusable",),
    "exécrable": ("exécrable",),
    "exécrables": ("exécrable",),
    "exécratoire": ("exécratoire",),
    "exécratoires": ("exécratoire",),
    "exécutable": ("exécutable",),
    "exécutables": ("exécutable",),
    "exécuteur": ("exécuteur",),
    "exécuteurs": ("exécuteur",),
    "exécutrice": ("exécuteur",),
    "exécutrices": ("exécuteur",),
    "exécutif": ("exécutif",),
    "exécutifs": ("exécutif",),
    "exécutive": ("exécutif",),
    "exécutives": ("exécutif",),
    "exécutoire": ("exécutoire",),
    "exécutoires": ("exécutoire",),
    "exégétique": ("exégétique",),
    "exégétiques": ("exégétique",),
    "exemplaire": ("exemplaire",),
    "exemplaires": ("exemplaire",),
    "exemplatif": ("exemplatif",),
    "exemplatifs": ("exemplatif",),
    "exemplative": ("exemplatif",),
    "exemplatives": ("exemplatif",),
    "exencéphale": ("exencéphale",),
    "exencéphales": ("exencéphale",),
    "exfoliateur": ("exfoliateur",),
    "exfoliateurs": ("exfoliateur",),
    "exfoliatrice": ("exfoliateur",),
    "exfoliatrices": ("exfoliateur",),
    "exfoliatif": ("exfoliatif",),
    "exfoliatifs": ("exfoliatif",),
    "exfoliative": ("exfoliatif",),
    "exfoliatives": ("exfoliatif",),
    "exhaustif": ("exhaustif",),
    "exhaustifs": ("exhaustif",),
    "exhaustive": ("exhaustif",),
    "exhaustives": ("exhaustif",),
    "exhibitionniste": ("exhibitionniste",),
    "exhibitionnistes": ("exhibitionniste",),
    "exigentielle": ("exigentiel",),
    "exigentielles": ("exigentiel",),
    "exigentiel": ("exigentiel",),
    "exigentiels": ("exigentiel",),
    "exigible": ("exigible",),
    "exigibles": ("exigible",),
    "exiguë": ("exigu",),
    "exiguës": ("exigu",),
    "exigu": ("exigu",),
    "exigus": ("exigu",),
    "exilien": ("exilien",),
    "exilienne": ("exilien",),
    "exiliennes": ("exilien",),
    "exiliens": ("exilien",),
    "exilique": ("exilique",),
    "exiliques": ("exilique",),
    "exinique": ("exinique",),
    "exiniques": ("exinique",),
    "existentiale": ("existential",),
    "existentiales": ("existential",),
    "existential": ("existential",),
    "existentiaux": ("existential",),
    "existentialiste": ("existentialiste",),
    "existentialistes": ("existentialiste",),
    "existentielle": ("existentiel",),
    "existentielles": ("existentiel",),
    "existentiel": ("existentiel",),
    "existentiels": ("existentiel",),
    "exobiologique": ("exobiologique",),
    "exobiologiques": ("exobiologique",),
    "exocardiaque": ("exocardiaque",),
    "exocardiaques": ("exocardiaque",),
    "exocentrique": ("exocentrique",),
    "exocentriques": ("exocentrique",),
    "exocervicale": ("exocervical",),
    "exocervicales": ("exocervical",),
    "exocervical": ("exocervical",),
    "exocervicaux": ("exocervical",),
    "exocrânien": ("exocrânien",),
    "exocrânienne": ("exocrânien",),
    "exocrâniennes": ("exocrânien",),
    "exocrâniens": ("exocrânien",),
    "exocrine": ("exocrine",),
    "exocrines": ("exocrine",),
    "exoérythrocytaire": ("exoérythrocytaire",),
    "exoérythrocytaires": ("exoérythrocytaire",),
    "exogame": ("exogame",),
    "exogames": ("exogame",),
    "exogamique": ("exogamique",),
    "exogamiques": ("exogamique",),
    "exogène": ("exogène",),
    "exogènes": ("exogène",),
    "exonératoire": ("exonératoire",),
    "exonératoires": ("exonératoire",),
    "exophtalmique": ("exophtalmique",),
    "exophtalmiques": ("exophtalmique",),
    "exoplasmique": ("exoplasmique",),
    "exoplasmiques": ("exoplasmique",),
    "exorable": ("exorable",),
    "exorables": ("exorable",),
    "exoréique": ("exoréique",),
    "exoréiques": ("exoréique",),
    "exosmotique": ("exosmotique",),
    "exosmotiques": ("exosmotique",),
    "exosphérique": ("exosphérique",),
    "exosphériques": ("exosphérique",),
    "exostosique": ("exostosique",),
    "exostosiques": ("exostosique",),
    "exotérique": ("exotérique",),
    "exotériques": ("exotérique",),
    "exothermique": ("exothermique",),
    "exothermiques": ("exothermique",),
    "exotique": ("exotique",),
    "exotiques": ("exotique",),
    "expansible": ("expansible",),
    "expansibles": ("expansible",),
    "expansif": ("expansif",),
    "expansifs": ("expansif",),
    "expansive": ("expansif",),
    "expansives": ("expansif",),
    "expansionniste": ("expansionniste",),
    "expansionnistes": ("expansionniste",),
    "expectatif": ("expectatif",),
    "expectatifs": ("expectatif",),
    "expectative": ("expectatif",),
    "expectatives": ("expectatif",),
    "expéditeur": ("expéditeur",),
    "expéditeurs": ("expéditeur",),
    "expéditrice": ("expéditeur",),
    "expéditrices": ("expéditeur",),
    "expéditif": ("expéditif",),
    "expéditifs": ("expéditif",),
    "expéditive": ("expéditif",),
    "expéditives": ("expéditif",),
    "expéditionnaire": ("expéditionnaire",),
    "expéditionnaires": ("expéditionnaire",),
    "expérimentable": ("expérimentable",),
    "expérimentables": ("expérimentable",),
    "expérimentale": ("expérimental",),
    "expérimentales": ("expérimental",),
    "expérimental": ("expérimental",),
    "expérimentaux": ("expérimental",),
    "expiable": ("expiable",),
    "expiables": ("expiable",),
    "expiateur": ("expiateur",),
    "expiateurs": ("expiateur",),
    "expiatrice": ("expiateur",),
    "expiatrices": ("expiateur",),
    "expiatoire": ("expiatoire",),
    "expiatoires": ("expiatoire",),
    "expirateur": ("expirateur",),
    "expirateurs": ("expirateur",),
    "expiratrice": ("expirateur",),
    "expiratrices": ("expirateur",),
    "expiratoire": ("expiratoire",),
    "expiratoires": ("expiratoire",),
    "explétif": ("explétif",),
    "explétifs": ("explétif",),
    "explétive": ("explétif",),
    "explétives": ("explétif",),
    "explicable": ("explicable",),
    "explicables": ("explicable",),
    "explicatif": ("explicatif",),
    "explicatifs": ("explicatif",),
    "explicative": ("explicatif",),
    "explicatives": ("explicatif",),
    "explicitable": ("explicitable",),
    "explicitables": ("explicitable",),
    "explicite": ("explicite",),
    "explicites": ("explicite",),
    "exploitable": ("exploitable",),
    "exploitables": ("exploitable",),
    "exploiteur": ("exploiteur",),
    "exploiteurs": ("exploiteur",),
    "exploiteuse": ("exploiteur",),
    "exploiteuses": ("exploiteur",),
    "explorable": ("explorable",),
    "explorables": ("explorable",),
    "explorateur": ("explorateur",),
    "explorateurs": ("explorateur",),
    "exploratrice": ("explorateur",),
    "exploratrices": ("explorateur",),
    "exploratoire": ("exploratoire",),
    "exploratoires": ("exploratoire",),
    "explosible": ("explosible",),
    "explosibles": ("explosible",),
    "explosif": ("explosif",),
    "explosifs": ("explosif",),
    "explosive": ("explosif",),
    "explosives": ("explosif",),
    "explosophore": ("explosophore",),
    "explosophores": ("explosophore",),
    "exponentielle": ("exponentiel",),
    "exponentielles": ("exponentiel",),
    "exponentiel": ("exponentiel",),
    "exponentiels": ("exponentiel",),
    "exportable": ("exportable",),
    "exportables": ("exportable",),
    "exportateur": ("exportateur",),
    "exportateurs": ("exportateur",),
    "exportatrice": ("exportateur",),
    "exportatrices": ("exportateur",),
    "exprès": ("exprès",),
    "expresse": ("exprès",),
    "expresses": ("exprès",),
    "express": ("express",),
    "expressif": ("expressif",),
    "expressifs": ("expressif",),
    "expressive": ("expressif",),
    "expressives": ("expressif",),
    "expressionniste": ("expressionniste",),
    "expressionnistes": ("expressionniste",),
    "exprimable": ("exprimable",),
    "exprimables": ("exprimable",),
    "expropriateur": ("expropriateur",),
    "expropriateurs": ("expropriateur",),
    "expropriatrice": ("expropriateur",),
    "expropriatrices": ("expropriateur",),
    "expugnable": ("expugnable",),
    "expugnables": ("expugnable",),
    "expulsif": ("expulsif",),
    "expulsifs": ("expulsif",),
    "expulsive": ("expulsif",),
    "expulsives": ("expulsif",),
    "expulteur": ("expulteur",),
    "expulteurs": ("expulteur",),
    "expultrice": ("expulteur",),
    "expultrices": ("expulteur",),
    "expurgatoire": ("expurgatoire",),
    "expurgatoires": ("expurgatoire",),
    "exquise": ("exquis",),
    "exquises": ("exquis",),
    "exquis": ("exquis",),
    "exsangue": ("exsangue",),
    "exsangues": ("exsangue",),
    "exsudatif": ("exsudatif",),
    "exsudatifs": ("exsudatif",),
    "exsudative": ("exsudatif",),
    "exsudatives": ("exsudatif",),
    "extatique": ("extatique",),
    "extatiques": ("extatique",),
    "extenseur": ("extenseur",),
    "extenseurs": ("extenseur",),
    "extensible": ("extensible",),
    "extensibles": ("extensible",),
    "extensif": ("extensif",),
    "extensifs": ("extensif",),
    "extensive": ("extensif",),
    "extensives": ("extensif",),
    "extensionnelle": ("extensionnel",),
    "extensionnelles": ("extensionnel",),
    "extensionnel": ("extensionnel",),
    "extensionnels": ("extensionnel",),
    "extensométrique": ("extensométrique",),
    "extensométriques": ("extensométrique",),
    "extériorisable": ("extériorisable",),
    "extériorisables": ("extériorisable",),
    "exterminateur": ("exterminateur",),
    "exterminateurs": ("exterminateur",),
    "exterminatrice": ("exterminateur",),
    "exterminatrices": ("exterminateur",),
    "externe": ("externe",),
    "externes": ("externe",),
    "extérocepteur": ("extérocepteur",),
    "extérocepteurs": ("extérocepteur",),
    "extéroceptrice": ("extérocepteur",),
    "extéroceptrices": ("extérocepteur",),
    "extéroceptif": ("extéroceptif",),
    "extéroceptifs": ("extéroceptif",),
    "extéroceptive": ("extéroceptif",),
    "extéroceptives": ("extéroceptif",),
    "extérorécepteur": ("extérorécepteur",),
    "extérorécepteurs": ("extérorécepteur",),
    "extéroréceptrice": ("extérorécepteur",),
    "extéroréceptrices": ("extérorécepteur",),
    "extincteur": ("extincteur",),
    "extincteurs": ("extincteur",),
    "extinctrice": ("extincteur",),
    "extinctrices": ("extincteur",),
    "extinctif": ("extinctif",),
    "extinctifs": ("extinctif",),
    "extinctive": ("extinctif",),
    "extinctives": ("extinctif",),
    "extinguible": ("extinguible",),
    "extinguibles": ("extinguible",),
    "extirpable": ("extirpable",),
    "extirpables": ("extirpable",),
    "extra": ("extra",),
    "extra-atmosphérique": ("extra-atmosphérique",),
    "extrabudgétaire": ("extrabudgétaire",),
    "extrabudgétaires": ("extrabudgétaire",),
    "extracapsulaire": ("extracapsulaire",),
    "extracapsulaires": ("extracapsulaire",),
    "extracardiaque": ("extracardiaque",),
    "extracardiaques": ("extracardiaque",),
    "extracellulaire": ("extracellulaire",),
    "extracellulaires": ("extracellulaire",),
    "extracérébrale": ("extracérébral",),
    "extracérébrales": ("extracérébral",),
    "extracérébral": ("extracérébral",),
    "extracérébraux": ("extracérébral",),
    "extracommunautaire": ("extracommunautaire",),
    "extracommunautaires": ("extracommunautaire",),
    "extraconjugale": ("extraconjugal",),
    "extraconjugales": ("extraconjugal",),
    "extraconjugal": ("extraconjugal",),
    "extraconjugaux": ("extraconjugal",),
    "extraconstitutionnelle": ("extraconstitutionnel",),
    "extraconstitutionnelles": ("extraconstitutionnel",),
    "extraconstitutionnel": ("extraconstitutionnel",),
    "extraconstitutionnels": ("extraconstitutionnel",),
    "extracontractuelle": ("extracontractuel",),
    "extracontractuelles": ("extracontractuel",),
    "extracontractuel": ("extracontractuel",),
    "extracontractuels": ("extracontractuel",),
    "extracorporelle": ("extracorporel",),
    "extracorporelles": ("extracorporel",),
    "extracorporel": ("extracorporel",),
    "extracorporels": ("extracorporel",),
    "extracrânien": ("extracrânien",),
    "extracrânienne": ("extracrânien",),
    "extracrâniennes": ("extracrânien",),
    "extracrâniens": ("extracrânien",),
    "extracteur": ("extracteur",),
    "extracteurs": ("extracteur",),
    "extractrice": ("extracteur",),
    "extractrices": ("extracteur",),
    "extractible": ("extractible",),
    "extractibles": ("extractible",),
    "extractif": ("extractif",),
    "extractifs": ("extractif",),
    "extractive": ("extractif",),
    "extractives": ("extractif",),
    "extra-curriculaires": ("extra-curriculaire",),
    "extradable": ("extradable",),
    "extradables": ("extradable",),
    "extraditionnelle": ("extraditionnel",),
    "extraditionnelles": ("extraditionnel",),
    "extraditionnel": ("extraditionnel",),
    "extraditionnels": ("extraditionnel",),
    "extradurale": ("extradural",),
    "extradurales": ("extradural",),
    "extradural": ("extradural",),
    "extraduraux": ("extradural",),
    "extraeuropéen": ("extraeuropéen",),
    "extraeuropéenne": ("extraeuropéen",),
    "extraeuropéennes": ("extraeuropéen",),
    "extraeuropéens": ("extraeuropéen",),
    "extrafusoriale": ("extrafusorial",),
    "extrafusoriales": ("extrafusorial",),
    "extrafusorial": ("extrafusorial",),
    "extrafusoriaux": ("extrafusorial",),
    "extragalactique": ("extragalactique",),
    "extragalactiques": ("extragalactique",),
    "extragénétique": ("extragénétique",),
    "extragénétiques": ("extragénétique",),
    "extragénitale": ("extragénital",),
    "extragénitales": ("extragénital",),
    "extragénital": ("extragénital",),
    "extragénitaux": ("extragénital",),
    "extrahépatique": ("extrahépatique",),
    "extrahépatiques": ("extrahépatique",),
    "extrahospitalière": ("extrahospitalier",),
    "extrahospitalières": ("extrahospitalier",),
    "extrahospitalier": ("extrahospitalier",),
    "extrahospitaliers": ("extrahospitalier",),
    "extrajudiciaire": ("extrajudiciaire",),
    "extrajudiciaires": ("extrajudiciaire",),
    "extralégale": ("extralégal",),
    "extralégales": ("extralégal",),
    "extralégal": ("extralégal",),
    "extralégaux": ("extralégal",),
    "extralemniscale": ("extralemniscal",),
    "extralemniscales": ("extralemniscal",),
    "extralemniscal": ("extralemniscal",),
    "extralemniscaux": ("extralemniscal",),
    "extralinguistique": ("extralinguistique",),
    "extralinguistiques": ("extralinguistique",),
    "extralucide": ("extralucide",),
    "extralucides": ("extralucide",),
    "extramédullaire": ("extramédullaire",),
    "extramédullaires": ("extramédullaire",),
    "extramélique": ("extramélique",),
    "extraméliques": ("extramélique",),
    "extramembraneuse": ("extramembraneux",),
    "extramembraneuses": ("extramembraneux",),
    "extramembraneux": ("extramembraneux",),
    "extraménagère": ("extraménager",),
    "extraménagères": ("extraménager",),
    "extraménager": ("extraménager",),
    "extraménagers": ("extraménager",),
    "extramuqueuse": ("extramuqueux",),
    "extramuqueuses": ("extramuqueux",),
    "extramuqueux": ("extramuqueux",),
    "extraneurologique": ("extraneurologique",),
    "extraneurologiques": ("extraneurologique",),
    "extranucléaire": ("extranucléaire",),
    "extranucléaires": ("extranucléaire",),
    "extraordinaire": ("extraordinaire",),
    "extraordinaires": ("extraordinaire",),
    "extraorganique": ("extraorganique",),
    "extraorganiques": ("extraorganique",),
    "extrapalléale": ("extrapalléal",),
    "extrapalléales": ("extrapalléal",),
    "extrapalléal": ("extrapalléal",),
    "extrapalléaux": ("extrapalléal",),
    "extraparlementaire": ("extraparlementaire",),
    "extraparlementaires": ("extraparlementaire",),
    "extrapatrimoniale": ("extrapatrimonial",),
    "extrapatrimoniales": ("extrapatrimonial",),
    "extrapatrimonial": ("extrapatrimonial",),
    "extrapatrimoniaux": ("extrapatrimonial",),
    "extrapéritonéale": ("extrapéritonéal",),
    "extrapéritonéales": ("extrapéritonéal",),
    "extrapéritonéal": ("extrapéritonéal",),
    "extrapéritonéaux": ("extrapéritonéal",),
    "extrapleurale": ("extrapleural",),
    "extrapleurales": ("extrapleural",),
    "extrapleural": ("extrapleural",),
    "extrapleuraux": ("extrapleural",),
    "extrapolable": ("extrapolable",),
    "extrapolables": ("extrapolable",),
    "extrapolatif": ("extrapolatif",),
    "extrapolatifs": ("extrapolatif",),
    "extrapolative": ("extrapolatif",),
    "extrapolatives": ("extrapolatif",),
    "extraposable": ("extraposable",),
    "extraposables": ("extraposable",),
    "extraprofessionnelle": ("extraprofessionnel",),
    "extraprofessionnelles": ("extraprofessionnel",),
    "extraprofessionnel": ("extraprofessionnel",),
    "extraprofessionnels": ("extraprofessionnel",),
    "extrapyramidale": ("extrapyramidal",),
    "extrapyramidales": ("extrapyramidal",),
    "extrapyramidal": ("extrapyramidal",),
    "extrapyramidaux": ("extrapyramidal",),
    "extrarénale": ("extrarénal",),
    "extrarénales": ("extrarénal",),
    "extrarénal": ("extrarénal",),
    "extrarénaux": ("extrarénal",),
    "extrascolaire": ("extrascolaire",),
    "extrascolaires": ("extrascolaire",),
    "extrasensible": ("extrasensible",),
    "extrasensibles": ("extrasensible",),
    "extrasensorielle": ("extrasensoriel",),
    "extrasensorielles": ("extrasensoriel",),
    "extrasensoriel": ("extrasensoriel",),
    "extrasensoriels": ("extrasensoriel",),
    "extrastatutaire": ("extrastatutaire",),
    "extrastatutaires": ("extrastatutaire",),
    "extraterrestre": ("extraterrestre",),
    "extraterrestres": ("extraterrestre",),
    "extraterritoriale": ("extraterritorial",),
    "extraterritoriales": ("extraterritorial",),
    "extraterritorial": ("extraterritorial",),
    "extraterritoriaux": ("extraterritorial",),
    "extratropicale": ("extratropical",),
    "extratropicales": ("extratropical",),
    "extratropical": ("extratropical",),
    "extratropicaux": ("extratropical",),
    "extravasculaire": ("extravasculaire",),
    "extravasculaires": ("extravasculaire",),
    "extraversif": ("extraversif",),
    "extraversifs": ("extraversif",),
    "extraversive": ("extraversif",),
    "extraversives": ("extraversif",),
    "extrémale": ("extrémal",),
    "extrémales": ("extrémal",),
    "extrémal": ("extrémal",),
    "extrémaux": ("extrémal",),
    "extrême": ("extrême",),
    "extrêmes": ("extrême",),
    "extrême-orientale": ("extrême-oriental",),
    "extrême-oriental": ("extrême-oriental",),
    "extrême-orientaux": ("extrême-oriental",),
    "extrémiste": ("extrémiste",),
    "extrémistes": ("extrémiste",),
    "extrinsèque": ("extrinsèque",),
    "extrinsèques": ("extrinsèque",),
    "extrorse": ("extrorse",),
    "extrorses": ("extrorse",),
    "extrusif": ("extrusif",),
    "extrusifs": ("extrusif",),
    "extrusive": ("extrusif",),
    "extrusives": ("extrusif",),
    "exuviale": ("exuvial",),
    "exuviales": ("exuvial",),
    "exuvial": ("exuvial",),
    "exuviaux": ("exuvial",),
    "faber": ("faber",),
    "fabien": ("fabien",),
    "fabienne": ("fabien",),
    "fabiennes": ("fabien",),
    "fabiens": ("fabien",),
    "fabricant": ("fabricant",),
    "fabricants": ("fabricant",),
    "fabriste": ("fabriste",),
    "fabristes": ("fabriste",),
    "fabulateur": ("fabulateur",),
    "fabulateurs": ("fabulateur",),
    "fabulatrice": ("fabulateur",),
    "fabulatrices": ("fabulateur",),
    "fabuleuse": ("fabuleux",),
    "fabuleuses": ("fabuleux",),
    "fabuleux": ("fabuleux",),
    "facétieuse": ("facétieux",),
    "facétieuses": ("facétieux",),
    "facétieux": ("facétieux",),
    "fâcheuse": ("fâcheux",),
    "fâcheuses": ("fâcheux",),
    "fâcheux": ("fâcheux",),
    "facho": ("facho",),
    "fachos": ("facho",),
    "faciale": ("facial",),
    "faciales": ("facial",),
    "facial": ("facial",),
    "faciaux": ("facial",),
    "facile": ("facile",),
    "faciles": ("facile",),
    "facilitateur": ("facilitateur",),
    "facilitateurs": ("facilitateur",),
    "facilitatrice": ("facilitateur",),
    "facilitatrices": ("facilitateur",),
    "façonnière": ("façonnier",),
    "façonnières": ("façonnier",),
    "façonnier": ("façonnier",),
    "façonniers": ("façonnier",),
    "factice": ("factice",),
    "factices": ("factice",),
    "factieuse": ("factieux",),
    "factieuses": ("factieux",),
    "factieux": ("factieux",),
    "factitif": ("factitif",),
    "factitifs": ("factitif",),
    "factitive": ("factitif",),
    "factitives": ("factitif",),
    "factorielle": ("factoriel",),
    "factorielles": ("factoriel",),
    "factoriel": ("factoriel",),
    "factoriels": ("factoriel",),
    "factuelle": ("factuel",),
    "factuelles": ("factuel",),
    "factuel": ("factuel",),
    "factuels": ("factuel",),
    "faculaire": ("faculaire",),
    "faculaires": ("faculaire",),
    "facultaire": ("facultaire",),
    "facultaires": ("facultaire",),
    "facultatif": ("facultatif",),
    "facultatifs": ("facultatif",),
    "facultative": ("facultatif",),
    "facultatives": ("facultatif",),
    "fada": ("fada",),
    "fadasse": ("fadasse",),
    "fadasses": ("fadasse",),
    "fadée": ("fadé",),
    "fadées": ("fadé",),
    "fadé": ("fadé",),
    "fade": ("fade",),
    "fadés": ("fadé",),
    "fades": ("fade",),
    "faible": ("faible",),
    "faibles": ("faible",),
    "faiblissime": ("faiblissime",),
    "faiblissimes": ("faiblissime",),
    "faïencière": ("faïencier",),
    "faïencières": ("faïencier",),
    "faïencier": ("faïencier",),
    "faïenciers": ("faïencier",),
    "failleuse": ("failleux",),
    "failleuses": ("failleux",),
    "failleux": ("failleux",),
    "faillible": ("faillible",),
    "faillibles": ("faillible",),
    "fair-play": ("fair-play",),
    "faisable": ("faisable",),
    "faisables": ("faisable",),
    "faisane": ("faisane",),
    "faisanes": ("faisane",),
    "faîtière": ("faîtière",),
    "faîtières": ("faîtière",),
    "falciforme": ("falciforme",),
    "falciformes": ("falciforme",),
    "falisque": ("falisque",),
    "falisques": ("falisque",),
    "fallacieuse": ("fallacieux",),
    "fallacieuses": ("fallacieux",),
    "fallacieux": ("fallacieux",),
    "falsifiable": ("falsifiable",),
    "falsifiables": ("falsifiable",),
    "famélique": ("famélique",),
    "faméliques": ("famélique",),
    "fameuse": ("fameux",),
    "fameuses": ("fameux",),
    "fameux": ("fameux",),
    "familiale": ("familial",),
    "familiales": ("familial",),
    "familial": ("familial",),
    "familiaux": ("familial",),
    "familière": ("familier",),
    "familières": ("familier",),
    "familier": ("familier",),
    "familiers": ("familier",),
    "familleux": ("familleux",),
    "fana": ("fana",),
    "fanas": ("fana",),
    "fanatique": ("fanatique",),
    "fanatiques": ("fanatique",),
    "fanfaron": ("fanfaron",),
    "fanfaronne": ("fanfaron",),
    "fanfaronnes": ("fanfaron",),
    "fanfarons": ("fanfaron",),
    "fangeuse": ("fangeux",),
    "fangeuses": ("fangeux",),
    "fangeux": ("fangeux",),
    "fantaisie": ("fantaisie",),
    "fantaisiste": ("fantaisiste",),
    "fantaisistes": ("fantaisiste",),
    "fantasmagorique": ("fantasmagorique",),
    "fantasmagoriques": ("fantasmagorique",),
    "fantasmatique": ("fantasmatique",),
    "fantasmatiques": ("fantasmatique",),
    "fantasque": ("fantasque",),
    "fantasques": ("fantasque",),
    "fantastique": ("fantastique",),
    "fantastiques": ("fantastique",),
    "fantoche": ("fantoche",),
    "fantoches": ("fantoche",),
    "fantomale": ("fantomal",),
    "fantomales": ("fantomal",),
    "fantomal": ("fantomal",),
    "fantomaux": ("fantomal",),
    "fantomatique": ("fantomatique",),
    "fantomatiques": ("fantomatique",),
    "faradique": ("faradique",),
    "faradiques": ("faradique",),
    "faramineuse": ("faramineux",),
    "faramineuses": ("faramineux",),
    "faramineux": ("faramineux",),
    "farce": ("farce",),
    "farcesque": ("farcesque",),
    "farcesques": ("farcesque",),
    "farceur": ("farceur",),
    "farceurs": ("farceur",),
    "farceuse": ("farceur",),
    "farceuses": ("farceur",),
    "fareiniste": ("fareiniste",),
    "fareinistes": ("fareiniste",),
    "farineuse": ("farineux",),
    "farineuses": ("farineux",),
    "farineux": ("farineux",),
    "fario": ("fario",),
    "farios": ("fario",),
    "farnésien": ("farnésien",),
    "farnésienne": ("farnésien",),
    "farnésiennes": ("farnésien",),
    "farnésiens": ("farnésien",),
    "farnésique": ("farnésique",),
    "farnésiques": ("farnésique",),
    "farouche": ("farouche",),
    "farouches": ("farouche",),
    "fasciculaire": ("fasciculaire",),
    "fasciculaires": ("fasciculaire",),
    "fascinateur": ("fascinateur",),
    "fascinateurs": ("fascinateur",),
    "fascinatrice": ("fascinateur",),
    "fascinatrices": ("fascinateur",),
    "fasciste": ("fasciste",),
    "fascistes": ("fasciste",),
    "fashionable": ("fashionable",),
    "fashionables": ("fashionable",),
    "faste": ("faste",),
    "fastes": ("faste",),
    "fastidieuse": ("fastidieux",),
    "fastidieuses": ("fastidieux",),
    "fastidieux": ("fastidieux",),
    "fastoche": ("fastoche",),
    "fastoches": ("fastoche",),
    "fastueuse": ("fastueux",),
    "fastueuses": ("fastueux",),
    "fastueux": ("fastueux",),
    "fataliste": ("fataliste",),
    "fatalistes": ("fataliste",),
    "fatidique": ("fatidique",),
    "fatidiques": ("fatidique",),
    "fatigable": ("fatigable",),
    "fatigables": ("fatigable",),
    "faubourien": ("faubourien",),
    "faubourienne": ("faubourien",),
    "faubouriennes": ("faubourien",),
    "faubouriens": ("faubourien",),
    "fauchable": ("fauchable",),
    "fauchables": ("fauchable",),
    "faunesque": ("faunesque",),
    "faunesques": ("faunesque",),
    "faunique": ("faunique",),
    "fauniques": ("faunique",),
    "faunistique": ("faunistique",),
    "faunistiques": ("faunistique",),
    "fauréen": ("fauréen",),
    "fauréenne": ("fauréen",),
    "fauréennes": ("fauréen",),
    "fauréens": ("fauréen",),
    "faustien": ("faustien",),
    "faustienne": ("faustien",),
    "faustiennes": ("faustien",),
    "faustiens": ("faustien",),
    "fautif": ("fautif",),
    "fautifs": ("fautif",),
    "fautive": ("fautif",),
    "fautives": ("fautif",),
    "fauve": ("fauve",),
    "fauves": ("fauve",),
    "fausse": ("faux",),
    "fausses": ("faux",),
    "faux": ("faux",),
    "faveuse": ("faveux",),
    "faveuses": ("faveux",),
    "faveux": ("faveux",),
    "favique": ("favique",),
    "faviques": ("favique",),
    "favorable": ("favorable",),
    "favorables": ("favorable",),
    "favori": ("favori",),
    "favoris": ("favori",),
    "favorite": ("favori",),
    "favorites": ("favori",),
    "féale": ("féal",),
    "féales": ("féal",),
    "féal": ("féal",),
    "féaux": ("féal",),
    "fébrifuge": ("fébrifuge",),
    "fébrifuges": ("fébrifuge",),
    "fébrile": ("fébrile",),
    "fébriles": ("fébrile",),
    "fébronien": ("fébronien",),
    "fébronienne": ("fébronien",),
    "fébroniennes": ("fébronien",),
    "fébroniens": ("fébronien",),
    "fécale": ("fécal",),
    "fécales": ("fécal",),
    "fécal": ("fécal",),
    "fécaux": ("fécal",),
    "fécaloïde": ("fécaloïde",),
    "fécaloïdes": ("fécaloïde",),
    "féciale": ("fécial",),
    "féciales": ("fécial",),
    "fécial": ("fécial",),
    "féciaux": ("fécial",),
    "fécondable": ("fécondable",),
    "fécondables": ("fécondable",),
    "fécondateur": ("fécondateur",),
    "fécondateurs": ("fécondateur",),
    "fécondatrice": ("fécondateur",),
    "fécondatrices": ("fécondateur",),
    "féculeuse": ("féculeux",),
    "féculeuses": ("féculeux",),
    "féculeux": ("féculeux",),
    "féculière": ("féculier",),
    "féculières": ("féculier",),
    "féculier": ("féculier",),
    "féculiers": ("féculier",),
    "fédérale": ("fédéral",),
    "fédérales": ("fédéral",),
    "fédéral": ("fédéral",),
    "fédéraux": ("fédéral",),
    "fédéraliste": ("fédéraliste",),
    "fédéralistes": ("fédéraliste",),
    "fédérateur": ("fédérateur",),
    "fédérateurs": ("fédérateur",),
    "fédératrice": ("fédérateur",),
    "fédératrices": ("fédérateur",),
    "fédératif": ("fédératif",),
    "fédératifs": ("fédératif",),
    "fédérative": ("fédératif",),
    "fédératives": ("fédératif",),
    "féerique": ("féerique",),
    "féeriques": ("féerique",),
    "feldspathique": ("feldspathique",),
    "feldspathiques": ("feldspathique",),
    "félibréen": ("félibréen",),
    "félibréenne": ("félibréen",),
    "félibréennes": ("félibréen",),
    "félibréens": ("félibréen",),
    "fellateur": ("fellateur",),
    "fellateurs": ("fellateur",),
    "fellatrice": ("fellateur",),
    "fellatrices": ("fellateur",),
    "fellinien": ("fellinien",),
    "fellinienne": ("fellinien",),
    "felliniennes": ("fellinien",),
    "felliniens": ("fellinien",),
    "félon": ("félon",),
    "félonne": ("félon",),
    "félonnes": ("félon",),
    "félons": ("félon",),
    "femelle": ("femelle",),
    "femelles": ("femelle",),
    "féminissime": ("féminissime",),
    "féminissimes": ("féminissime",),
    "féministe": ("féministe",),
    "féministes": ("féministe",),
    "féminoïde": ("féminoïde",),
    "féminoïdes": ("féminoïde",),
    "fémorale": ("fémoral",),
    "fémorales": ("fémoral",),
    "fémoral": ("fémoral",),
    "fémoraux": ("fémoral",),
    "fémoro-cutanée": ("fémoro-cutané",),
    "fémoro-cutané": ("fémoro-cutané",),
    "fencholique": ("fencholique",),
    "fencholiques": ("fencholique",),
    "fenchylique": ("fenchylique",),
    "fenchyliques": ("fenchylique",),
    "fendard": ("fendard",),
    "fendards": ("fendard",),
    "féodale": ("féodal",),
    "féodales": ("féodal",),
    "féodal": ("féodal",),
    "féodaux": ("féodal",),
    "fériale": ("férial",),
    "fériales": ("férial",),
    "férial": ("férial",),
    "fériaux": ("férial",),
    "féringien": ("féringien",),
    "féringienne": ("féringien",),
    "féringiennes": ("féringien",),
    "féringiens": ("féringien",),
    "fermée": ("fermé",),
    "fermées": ("fermé",),
    "fermé": ("fermé",),
    "ferme": ("ferme",),
    "fermés": ("fermé",),
    "fermes": ("ferme",),
    "fermentable": ("fermentable",),
    "fermentables": ("fermentable",),
    "fermentaire": ("fermentaire",),
    "fermentaires": ("fermentaire",),
    "fermentatif": ("fermentatif",),
    "fermentatifs": ("fermentatif",),
    "fermentative": ("fermentatif",),
    "fermentatives": ("fermentatif",),
    "fermentescible": ("fermentescible",),
    "fermentescibles": ("fermentescible",),
    "fermeur": ("fermeur",),
    "fermeurs": ("fermeur",),
    "fermeuse": ("fermeur",),
    "fermeuses": ("fermeur",),
    "fermière": ("fermier",),
    "fermières": ("fermier",),
    "fermier": ("fermier",),
    "fermiers": ("fermier",),
    "fermionique": ("fermionique",),
    "fermioniques": ("fermionique",),
    "féroce": ("féroce",),
    "féroces": ("féroce",),
    "féroïen": ("féroïen",),
    "féroïenne": ("féroïen",),
    "féroïennes": ("féroïen",),
    "féroïens": ("féroïen",),
    "ferrallitique": ("ferrallitique",),
    "ferrallitiques": ("ferrallitique",),
    "ferrandaise": ("ferrandais",),
    "ferrandaises": ("ferrandais",),
    "ferrandais": ("ferrandais",),
    "ferrant": ("ferrant",),
    "ferrants": ("ferrant",),
    "ferraraise": ("ferrarais",),
    "ferraraises": ("ferrarais",),
    "ferrarais": ("ferrarais",),
    "ferreuse": ("ferreux",),
    "ferreuses": ("ferreux",),
    "ferreux": ("ferreux",),
    "ferricyanhydrique": ("ferricyanhydrique",),
    "ferricyanhydriques": ("ferricyanhydrique",),
    "ferrifère": ("ferrifère",),
    "ferrifères": ("ferrifère",),
    "ferrimagnétique": ("ferrimagnétique",),
    "ferrimagnétiques": ("ferrimagnétique",),
    "ferriprive": ("ferriprive",),
    "ferriprives": ("ferriprive",),
    "ferrique": ("ferrique",),
    "ferriques": ("ferrique",),
    "ferritique": ("ferritique",),
    "ferritiques": ("ferritique",),
    "ferrocyanhydrique": ("ferrocyanhydrique",),
    "ferrocyanhydriques": ("ferrocyanhydrique",),
    "ferrodynamique": ("ferrodynamique",),
    "ferrodynamiques": ("ferrodynamique",),
    "ferroélectrique": ("ferroélectrique",),
    "ferroélectriques": ("ferroélectrique",),
    "ferromagnétique": ("ferromagnétique",),
    "ferromagnétiques": ("ferromagnétique",),
    "ferromanganique": ("ferromanganique",),
    "ferromanganiques": ("ferromanganique",),
    "ferrotypique": ("ferrotypique",),
    "ferrotypiques": ("ferrotypique",),
    "ferroutière": ("ferroutier",),
    "ferroutières": ("ferroutier",),
    "ferroutier": ("ferroutier",),
    "ferroutiers": ("ferroutier",),
    "ferroviaire": ("ferroviaire",),
    "ferroviaires": ("ferroviaire",),
    "ferrugineuse": ("ferrugineux",),
    "ferrugineuses": ("ferrugineux",),
    "ferrugineux": ("ferrugineux",),
    "fersiallitique": ("fersiallitique",),
    "fersiallitiques": ("fersiallitique",),
    "fertile": ("fertile",),
    "fertiles": ("fertile",),
    "fertilisable": ("fertilisable",),
    "fertilisables": ("fertilisable",),
    "férulique": ("férulique",),
    "féruliques": ("férulique",),
    "fessière": ("fessier",),
    "fessières": ("fessier",),
    "fessier": ("fessier",),
    "fessiers": ("fessier",),
    "festif": ("festif",),
    "festifs": ("festif",),
    "festive": ("festif",),
    "festives": ("festif",),
    "festivalière": ("festivalier",),
    "festivalières": ("festivalier",),
    "festivalier": ("festivalier",),
    "festivaliers": ("festivalier",),
    "fétiale": ("fétial",),
    "fétiales": ("fétial",),
    "fétial": ("fétial",),
    "fétiaux": ("fétial",),
    "fétiche": ("fétiche",),
    "fétiches": ("fétiche",),
    "fétichiste": ("fétichiste",),
    "fétichistes": ("fétichiste",),
    "fétide": ("fétide",),
    "fétides": ("fétide",),
    "feudataire": ("feudataire",),
    "feudataires": ("feudataire",),
    "feuilletonesque": ("feuilletonesque",),
    "feuilletonesques": ("feuilletonesque",),
    "feuilletonnesque": ("feuilletonnesque",),
    "feuilletonnesques": ("feuilletonnesque",),
    "feutrable": ("feutrable",),
    "feutrables": ("feutrable",),
    "feutrière": ("feutrier",),
    "feutrières": ("feutrier",),
    "feutrier": ("feutrier",),
    "feutriers": ("feutrier",),
    "fiable": ("fiable",),
    "fiables": ("fiable",),
    "fibreuse": ("fibreux",),
    "fibreuses": ("fibreux",),
    "fibreux": ("fibreux",),
    "fibrillaire": ("fibrillaire",),
    "fibrillaires": ("fibrillaire",),
    "fibrineuse": ("fibrineux",),
    "fibrineuses": ("fibrineux",),
    "fibrineux": ("fibrineux",),
    "fibrinoïde": ("fibrinoïde",),
    "fibrinoïdes": ("fibrinoïde",),
    "fibrinolytique": ("fibrinolytique",),
    "fibrinolytiques": ("fibrinolytique",),
    "fibrinoplastique": ("fibrinoplastique",),
    "fibrinoplastiques": ("fibrinoplastique",),
    "fibroblastique": ("fibroblastique",),
    "fibroblastiques": ("fibroblastique",),
    "fibrocartilagineuse": ("fibrocartilagineux",),
    "fibrocartilagineuses": ("fibrocartilagineux",),
    "fibro-cartilagineux": ("fibrocartilagineux",),
    "fibrocartilagineux": ("fibrocartilagineux",),
    "fibrogène": ("fibrogène",),
    "fibrogènes": ("fibrogène",),
    "fibroïde": ("fibroïde",),
    "fibroïdes": ("fibroïde",),
    "fibrokystique": ("fibrokystique",),
    "fibrokystiques": ("fibrokystique",),
    "fibrolamellaire": ("fibrolamellaire",),
    "fibrolamellaires": ("fibrolamellaire",),
    "fibromateuse": ("fibromateux",),
    "fibromateuses": ("fibromateux",),
    "fibromateux": ("fibromateux",),
    "fibromucinoïde": ("fibromucinoïde",),
    "fibromucinoïdes": ("fibromucinoïde",),
    "fibroplastique": ("fibroplastique",),
    "fibroplastiques": ("fibroplastique",),
    "fibroscopique": ("fibroscopique",),
    "fibroscopiques": ("fibroscopique",),
    "fibrovasculaire": ("fibrovasculaire",),
    "fibrovasculaires": ("fibrovasculaire",),
    "fictif": ("fictif",),
    "fictifs": ("fictif",),
    "fictive": ("fictif",),
    "fictives": ("fictif",),
    "fictionnelle": ("fictionnel",),
    "fictionnelles": ("fictionnel",),
    "fictionnel": ("fictionnel",),
    "fictionnels": ("fictionnel",),
    "fidéicommissaire": ("fidéicommissaire",),
    "fidéicommissaires": ("fidéicommissaire",),
    "fidéiste": ("fidéiste",),
    "fidéistes": ("fidéiste",),
    "fidéjussoire": ("fidéjussoire",),
    "fidéjussoires": ("fidéjussoire",),
    "fidèle": ("fidèle",),
    "fidèles": ("fidèle",),
    "fidéliste": ("fidéliste",),
    "fidélistes": ("fidéliste",),
    "fidjien": ("fidjien",),
    "fidjienne": ("fidjien",),
    "fidjiennes": ("fidjien",),
    "fidjiens": ("fidjien",),
    "fiduciaire": ("fiduciaire",),
    "fiduciaires": ("fiduciaire",),
    "fielleuse": ("fielleux",),
    "fielleuses": ("fielleux",),
    "fielleux": ("fielleux",),
    "fière": ("fier",),
    "fières": ("fier",),
    "fier": ("fier",),
    "fiers": ("fier",),
    "fiévreuse": ("fiévreux",),
    "fiévreuses": ("fiévreux",),
    "fiévreux": ("fiévreux",),
    "fignoleur": ("fignoleur",),
    "fignoleurs": ("fignoleur",),
    "fignoleuse": ("fignoleur",),
    "fignoleuses": ("fignoleur",),
    "figue": ("figue",),
    "figuratif": ("figuratif",),
    "figuratifs": ("figuratif",),
    "figurative": ("figuratif",),
    "figuratives": ("figuratif",),
    "figuriste": ("figuriste",),
    "figuristes": ("figuriste",),
    "filable": ("filable",),
    "filables": ("filable",),
    "filaire": ("filaire",),
    "filaires": ("filaire",),
    "filamenteuse": ("filamenteux",),
    "filamenteuses": ("filamenteux",),
    "filamenteux": ("filamenteux",),
    "filandière": ("filandière",),
    "filandières": ("filandière",),
    "filandreuse": ("filandreux",),
    "filandreuses": ("filandreux",),
    "filandreux": ("filandreux",),
    "filarien": ("filarien",),
    "filarienne": ("filarien",),
    "filariennes": ("filarien",),
    "filariens": ("filarien",),
    "filasse": ("filasse",),
    "fileur": ("fileur",),
    "fileurs": ("fileur",),
    "fileuse": ("fileur",),
    "fileuses": ("fileur",),
    "filiale": ("filial",),
    "filiales": ("filial",),
    "filial": ("filial",),
    "filiaux": ("filial",),
    "filicique": ("filicique",),
    "filiciques": ("filicique",),
    "filiforme": ("filiforme",),
    "filiformes": ("filiforme",),
    "filigraneur": ("filigraneur",),
    "filigraneurs": ("filigraneur",),
    "filigraneuse": ("filigraneur",),
    "filigraneuses": ("filigraneur",),
    "filmique": ("filmique",),
    "filmiques": ("filmique",),
    "filmographique": ("filmographique",),
    "filmographiques": ("filmographique",),
    "filmologique": ("filmologique",),
    "filmologiques": ("filmologique",),
    "filonien": ("filonien",),
    "filonienne": ("filonien",),
    "filoniennes": ("filonien",),
    "filoniens": ("filonien",),
    "filou": ("filou",),
    "filtrable": ("filtrable",),
    "filtrables": ("filtrable",),
    "filtreur": ("filtreur",),
    "filtreurs": ("filtreur",),
    "filtreuse": ("filtreur",),
    "filtreuses": ("filtreur",),
    "fimicole": ("fimicole",),
    "fimicoles": ("fimicole",),
    "finaliste": ("finaliste",),
    "finalistes": ("finaliste",),
    "finalitaire": ("finalitaire",),
    "finalitaires": ("finalitaire",),
    "finançable": ("finançable",),
    "finançables": ("finançable",),
    "financeur": ("financeur",),
    "financeurs": ("financeur",),
    "financeuse": ("financeur",),
    "financeuses": ("financeur",),
    "financière": ("financier",),
    "financières": ("financier",),
    "financier": ("financier",),
    "financiers": ("financier",),
    "finasseur": ("finasseur",),
    "finasseurs": ("finasseur",),
    "finasseuse": ("finasseur",),
    "finasseuses": ("finasseur",),
    "finassière": ("finassier",),
    "finassières": ("finassier",),
    "finassier": ("finassier",),
    "finassiers": ("finassier",),
    "finitiste": ("finitiste",),
    "finitistes": ("finitiste",),
    "finlandaise": ("finlandais",),
    "finlandaises": ("finlandais",),
    "finlandais": ("finlandais",),
    "finnoise": ("finnois",),
    "finnoises": ("finnois",),
    "finnois": ("finnois",),
    "finno-ougrienne": ("finno-ougrien",),
    "finno-ougriennes": ("finno-ougrien",),
    "finno-ougriens": ("finno-ougrien",),
    "fiscale": ("fiscal",),
    "fiscales": ("fiscal",),
    "fiscal": ("fiscal",),
    "fiscaux": ("fiscal",),
    "fissible": ("fissible",),
    "fissibles": ("fissible",),
    "fissile": ("fissile",),
    "fissiles": ("fissile",),
    "fissilingue": ("fissilingue",),
    "fissilingues": ("fissilingue",),
    "fissipare": ("fissipare",),
    "fissipares": ("fissipare",),
    "fissipède": ("fissipède",),
    "fissipèdes": ("fissipède",),
    "fissirostre": ("fissirostre",),
    "fissirostres": ("fissirostre",),
    "fissuraire": ("fissuraire",),
    "fissuraires": ("fissuraire",),
    "fissurale": ("fissural",),
    "fissurales": ("fissural",),
    "fissural": ("fissural",),
    "fissuraux": ("fissural",),
    "fistulaire": ("fistulaire",),
    "fistulaires": ("fistulaire",),
    "fistuleuse": ("fistuleux",),
    "fistuleuses": ("fistuleux",),
    "fistuleux": ("fistuleux",),
    "fixable": ("fixable",),
    "fixables": ("fixable",),
    "fixateur": ("fixateur",),
    "fixateurs": ("fixateur",),
    "fixatrice": ("fixateur",),
    "fixatrices": ("fixateur",),
    "fixée": ("fixé",),
    "fixées": ("fixé",),
    "fixé": ("fixé",),
    "fixe": ("fixe",),
    "fixés": ("fixé",),
    "fixes": ("fixe",),
    "fixiste": ("fixiste",),
    "fixistes": ("fixiste",),
    "flabelliforme": ("flabelliforme",),
    "flabelliformes": ("flabelliforme",),
    "flaccide": ("flaccide",),
    "flaccides": ("flaccide",),
    "flache": ("flache",),
    "flaches": ("flache",),
    "flacheuse": ("flacheux",),
    "flacheuses": ("flacheux",),
    "flacheux": ("flacheux",),
    "flagada": ("flagada",),
    "flagellaire": ("flagellaire",),
    "flagellaires": ("flagellaire",),
    "flagellateur": ("flagellateur",),
    "flagellateurs": ("flagellateur",),
    "flagellatrice": ("flagellateur",),
    "flagellatrices": ("flagellateur",),
    "flagorneur": ("flagorneur",),
    "flagorneurs": ("flagorneur",),
    "flagorneuse": ("flagorneur",),
    "flagorneuses": ("flagorneur",),
    "flaireur": ("flaireur",),
    "flaireurs": ("flaireur",),
    "flaireuse": ("flaireur",),
    "flaireuses": ("flaireur",),
    "flambeur": ("flambeur",),
    "flambeurs": ("flambeur",),
    "flambeuse": ("flambeur",),
    "flambeuses": ("flambeur",),
    "flamenca": ("flamenco",),
    "flamencas": ("flamenco",),
    "flamenco": ("flamenco",),
    "flamencos": ("flamenco",),
    "flaminien": ("flaminien",),
    "flaminienne": ("flaminien",),
    "flaminiennes": ("flaminien",),
    "flaminiens": ("flaminien",),
    "flandresque": ("flandresque",),
    "flandresques": ("flandresque",),
    "flandrien": ("flandrien",),
    "flandrienne": ("flandrien",),
    "flandriennes": ("flandrien",),
    "flandriens": ("flandrien",),
    "flanellaire": ("flanellaire",),
    "flanellaires": ("flanellaire",),
    "flash": ("flash",),
    "flashy": ("flashy",),
    "flasque": ("flasque",),
    "flasques": ("flasque",),
    "flat": ("flat",),
    "flats": ("flat",),
    "flatteur": ("flatteur",),
    "flatteurs": ("flatteur",),
    "flatteuse": ("flatteur",),
    "flatteuses": ("flatteur",),
    "flavéole": ("flavéole",),
    "flavéoles": ("flavéole",),
    "flavianique": ("flavianique",),
    "flavianiques": ("flavianique",),
    "flavien": ("flavien",),
    "flaviens": ("flavien",),
    "flavocobaltique": ("flavocobaltique",),
    "flavocobaltiques": ("flavocobaltique",),
    "fléchisseur": ("fléchisseur",),
    "fléchisseurs": ("fléchisseur",),
    "flegmatique": ("flegmatique",),
    "flegmatiques": ("flegmatique",),
    "fleur": ("fleur",),
    "fleurette": ("fleurette",),
    "fleurettes": ("fleurette",),
    "fleuriste": ("fleuriste",),
    "fleuristes": ("fleuriste",),
    "fleuve": ("fleuve",),
    "fleuves": ("fleuve",),
    "flexible": ("flexible",),
    "flexibles": ("flexible",),
    "flexionnelle": ("flexionnel",),
    "flexionnelles": ("flexionnel",),
    "flexionnel": ("flexionnel",),
    "flexionnels": ("flexionnel",),
    "flexueuse": ("flexueux",),
    "flexueuses": ("flexueux",),
    "flexueux": ("flexueux",),
    "flirteur": ("flirteur",),
    "flirteurs": ("flirteur",),
    "flirteuse": ("flirteur",),
    "flirteuses": ("flirteur",),
    "floche": ("floche",),
    "floches": ("floche",),
    "floconneuse": ("floconneux",),
    "floconneuses": ("floconneux",),
    "floconneux": ("floconneux",),
    "floculeuse": ("floculeux",),
    "floculeuses": ("floculeux",),
    "floculeux": ("floculeux",),
    "florale": ("floral",),
    "florales": ("floral",),
    "floral": ("floral",),
    "floraux": ("floral",),
    "floricole": ("floricole",),
    "floricoles": ("floricole",),
    "floridien": ("floridien",),
    "floridienne": ("floridien",),
    "floridiennes": ("floridien",),
    "floridiens": ("floridien",),
    "florifère": ("florifère",),
    "florifères": ("florifère",),
    "florigène": ("florigène",),
    "florigènes": ("florigène",),
    "floristique": ("floristique",),
    "floristiques": ("floristique",),
    "flosculeuse": ("flosculeux",),
    "flosculeuses": ("flosculeux",),
    "flosculeux": ("flosculeux",),
    "flottable": ("flottable",),
    "flottables": ("flottable",),
    "fluctueuse": ("fluctueux",),
    "fluctueuses": ("fluctueux",),
    "fluctueux": ("fluctueux",),
    "fluet": ("fluet",),
    "fluets": ("fluet",),
    "fluette": ("fluet",),
    "fluettes": ("fluet",),
    "fluidale": ("fluidal",),
    "fluidales": ("fluidal",),
    "fluidal": ("fluidal",),
    "fluidaux": ("fluidal",),
    "fluide": ("fluide",),
    "fluides": ("fluide",),
    "fluidique": ("fluidique",),
    "fluidiques": ("fluidique",),
    "fluidissime": ("fluidissime",),
    "fluidissimes": ("fluidissime",),
    "fluo": ("fluo",),
    "fluoborique": ("fluoborique",),
    "fluoboriques": ("fluoborique",),
    "fluogermanique": ("fluogermanique",),
    "fluogermaniques": ("fluogermanique",),
    "fluophosphorique": ("fluophosphorique",),
    "fluophosphoriques": ("fluophosphorique",),
    "fluoracétique": ("fluoracétique",),
    "fluoracétiques": ("fluoracétique",),
    "fluor": ("fluor",),
    "fluorescéinique": ("fluorescéinique",),
    "fluorescéiniques": ("fluorescéinique",),
    "fluorhydrique": ("fluorhydrique",),
    "fluorhydriques": ("fluorhydrique",),
    "fluorique": ("fluorique",),
    "fluoriques": ("fluorique",),
    "fluoritique": ("fluoritique",),
    "fluoritiques": ("fluoritique",),
    "fluosilicique": ("fluosilicique",),
    "fluosiliciques": ("fluosilicique",),
    "fluosulfonique": ("fluosulfonique",),
    "fluosulfoniques": ("fluosulfonique",),
    "fluviale": ("fluvial",),
    "fluviales": ("fluvial",),
    "fluvial": ("fluvial",),
    "fluviaux": ("fluvial",),
    "fluviatile": ("fluviatile",),
    "fluviatiles": ("fluviatile",),
    "fluvio-deltaïques": ("fluvio-deltaïque",),
    "fluvio-lacustre": ("fluvio-lacustre",),
    "fluvio-marine": ("fluvio-marin",),
    "fluvio-maritime": ("fluvio-maritime",),
    "fluviométrique": ("fluviométrique",),
    "fluviométriques": ("fluviométrique",),
    "fluxionnaire": ("fluxionnaire",),
    "fluxionnaires": ("fluxionnaire",),
    "fob": ("fob",),
    "focale": ("focal",),
    "focales": ("focal",),
    "focal": ("focal",),
    "focaux": ("focal",),
    "focalisable": ("focalisable",),
    "focalisables": ("focalisable",),
    "focométrique": ("focométrique",),
    "focométriques": ("focométrique",),
    "focus": ("focus",),
    "foetale": ("foetal",),
    "foetales": ("foetal",),
    "foetal": ("foetal",),
    "foetaux": ("foetal",),
    "foeticide": ("foeticide",),
    "foeticides": ("foeticide",),
    "foireuse": ("foireux",),
    "foireuses": ("foireux",),
    "foireux": ("foireux",),
    "fol": ("fol",),
    "folasse": ("folasse",),
    "folasses": ("folasse",),
    "folâtre": ("folâtre",),
    "folâtres": ("folâtre",),
    "foldingue": ("foldingue",),
    "foldingues": ("foldingue",),
    "foliaire": ("foliaire",),
    "foliaires": ("foliaire",),
    "folichon": ("folichon",),
    "folichonne": ("folichon",),
    "folichonnes": ("folichon",),
    "folichons": ("folichon",),
    "folique": ("folique",),
    "foliques": ("folique",),
    "folk": ("folk",),
    "folks": ("folk",),
    "folklo": ("folklo",),
    "folklorique": ("folklorique",),
    "folkloriques": ("folklorique",),
    "follet": ("follet",),
    "follets": ("follet",),
    "follette": ("follet",),
    "follettes": ("follet",),
    "folliculaire": ("folliculaire",),
    "folliculaires": ("folliculaire",),
    "folliculostimulante": ("folliculostimulant",),
    "folliculostimulantes": ("folliculostimulant",),
    "folliculo-stimulant": ("folliculo-stimulant",),
    "folliculostimulant": ("folliculostimulant",),
    "folliculostimulants": ("folliculostimulant",),
    "fonceur": ("fonceur",),
    "fonceurs": ("fonceur",),
    "fonceuse": ("fonceur",),
    "fonceuses": ("fonceur",),
    "foncière": ("foncier",),
    "foncières": ("foncier",),
    "foncier": ("foncier",),
    "fonciers": ("foncier",),
    "fonctionnaliste": ("fonctionnaliste",),
    "fonctionnalistes": ("fonctionnaliste",),
    "fonctionnelle": ("fonctionnel",),
    "fonctionnelles": ("fonctionnel",),
    "fonctionnel": ("fonctionnel",),
    "fonctionnels": ("fonctionnel",),
    "fondamentale": ("fondamental",),
    "fondamentales": ("fondamental",),
    "fondamental": ("fondamental",),
    "fondamentaux": ("fondamental",),
    "fondamentaliste": ("fondamentaliste",),
    "fondamentalistes": ("fondamentaliste",),
    "fondateur": ("fondateur",),
    "fondateurs": ("fondateur",),
    "fondatrice": ("fondateur",),
    "fondatrices": ("fondateur",),
    "fondationnelle": ("fondationnel",),
    "fondationnelles": ("fondationnel",),
    "fondationnel": ("fondationnel",),
    "fondationnels": ("fondationnel",),
    "fongible": ("fongible",),
    "fongibles": ("fongible",),
    "fongicide": ("fongicide",),
    "fongicides": ("fongicide",),
    "fongicole": ("fongicole",),
    "fongicoles": ("fongicole",),
    "fongiforme": ("fongiforme",),
    "fongiformes": ("fongiforme",),
    "fongique": ("fongique",),
    "fongiques": ("fongique",),
    "fongistatique": ("fongistatique",),
    "fongistatiques": ("fongistatique",),
    "fongoïde": ("fongoïde",),
    "fongoïdes": ("fongoïde",),
    "fongueuse": ("fongueux",),
    "fongueuses": ("fongueux",),
    "fongueux": ("fongueux",),
    "fontinale": ("fontinal",),
    "fontinales": ("fontinal",),
    "fontinal": ("fontinal",),
    "fontinaux": ("fontinal",),
    "footballistique": ("footballistique",),
    "footballistiques": ("footballistique",),
    "forable": ("forable",),
    "forables": ("forable",),
    "forclose": ("forclos",),
    "forcloses": ("forclos",),
    "forclos": ("forclos",),
    "forestière": ("forestier",),
    "forestières": ("forestier",),
    "forestier": ("forestier",),
    "forestiers": ("forestier",),
    "forézien": ("forézien",),
    "forézienne": ("forézien",),
    "foréziennes": ("forézien",),
    "foréziens": ("forézien",),
    "forfaitaire": ("forfaitaire",),
    "forfaitaires": ("forfaitaire",),
    "forgeable": ("forgeable",),
    "forgeables": ("forgeable",),
    "formalisable": ("formalisable",),
    "formalisables": ("formalisable",),
    "formalisateur": ("formalisateur",),
    "formalisateurs": ("formalisateur",),
    "formalisatrice": ("formalisateur",),
    "formalisatrices": ("formalisateur",),
    "formaliste": ("formaliste",),
    "formalistes": ("formaliste",),
    "formantique": ("formantique",),
    "formantiques": ("formantique",),
    "formateur": ("formateur",),
    "formateurs": ("formateur",),
    "formatrice": ("formateur",),
    "formatrices": ("formateur",),
    "formatif": ("formatif",),
    "formatifs": ("formatif",),
    "formative": ("formatif",),
    "formatives": ("formatif",),
    "formelle": ("formel",),
    "formelles": ("formel",),
    "formel": ("formel",),
    "formels": ("formel",),
    "formidable": ("formidable",),
    "formidables": ("formidable",),
    "formiminoglutamique": ("formiminoglutamique",),
    "formiminoglutamiques": ("formiminoglutamique",),
    "formique": ("formique",),
    "formiques": ("formique",),
    "formogène": ("formogène",),
    "formogènes": ("formogène",),
    "formophénolique": ("formophénolique",),
    "formophénoliques": ("formophénolique",),
    "formulable": ("formulable",),
    "formulables": ("formulable",),
    "formulaire": ("formulaire",),
    "formulaires": ("formulaire",),
    "formylacétique": ("formylacétique",),
    "formylacétiques": ("formylacétique",),
    "fortiche": ("fortiche",),
    "fortiches": ("fortiche",),
    "fortifiable": ("fortifiable",),
    "fortifiables": ("fortifiable",),
    "fossile": ("fossile",),
    "fossiles": ("fossile",),
    "fossilifère": ("fossilifère",),
    "fossilifères": ("fossilifère",),
    "folle": ("fou",),
    "folles": ("fou",),
    "fou": ("fou",),
    "fous": ("fou",),
    "fofolle": ("foufou",),
    "fofolles": ("foufou",),
    "foufou": ("foufou",),
    "foufous": ("foufou",),
    "fougueuse": ("fougueux",),
    "fougueuses": ("fougueux",),
    "fougueux": ("fougueux",),
    "fouillis": ("fouillis",),
    "fouineur": ("fouineur",),
    "fouineurs": ("fouineur",),
    "fouineuse": ("fouineur",),
    "fouineuses": ("fouineur",),
    "fouisseur": ("fouisseur",),
    "fouisseurs": ("fouisseur",),
    "fouisseuse": ("fouisseur",),
    "fouisseuses": ("fouisseur",),
    "fourbe": ("fourbe",),
    "fourbes": ("fourbe",),
    "fouriériste": ("fouriériste",),
    "fouriéristes": ("fouriériste",),
    "fourragère": ("fourrager",),
    "fourragères": ("fourrager",),
    "fourrager": ("fourrager",),
    "fourragers": ("fourrager",),
    "foutraque": ("foutraque",),
    "foutraques": ("foutraque",),
    "fovéale": ("fovéal",),
    "fovéales": ("fovéal",),
    "fovéal": ("fovéal",),
    "fovéaux": ("fovéal",),
    "fovéolaire": ("fovéolaire",),
    "fovéolaires": ("fovéolaire",),
    "foyère": ("foyer",),
    "foyères": ("foyer",),
    "foyer": ("foyer",),
    "foyers": ("foyer",),
    "fractionnable": ("fractionnable",),
    "fractionnables": ("fractionnable",),
    "fractionnaire": ("fractionnaire",),
    "fractionnaires": ("fractionnaire",),
    "fractionnelle": ("fractionnel",),
    "fractionnelles": ("fractionnel",),
    "fractionnel": ("fractionnel",),
    "fractionnels": ("fractionnel",),
    "fractionniste": ("fractionniste",),
    "fractionnistes": ("fractionniste",),
    "fracturable": ("fracturable",),
    "fracturables": ("fracturable",),
    "fracturaire": ("fracturaire",),
    "fracturaires": ("fracturaire",),
    "fragile": ("fragile",),
    "fragiles": ("fragile",),
    "fragmentable": ("fragmentable",),
    "fragmentables": ("fragmentable",),
    "fragmentaire": ("fragmentaire",),
    "fragmentaires": ("fragmentaire",),
    "fraîche": ("frais",),
    "fraîches": ("frais",),
    "frais": ("frais",),
    "fraise": ("fraise",),
    "fraisière": ("fraisière",),
    "fraisières": ("fraisière",),
    "framboisée": ("framboisé",),
    "framboisées": ("framboisé",),
    "framboisé": ("framboisé",),
    "framboise": ("framboise",),
    "framboisés": ("framboisé",),
    "franche": ("franc",),
    "franches": ("franc",),
    "franc": ("franc",),
    "francs": ("franc",),
    "franque": ("franc",),
    "franques": ("franc",),
    "française": ("français",),
    "françaises": ("français",),
    "français": ("français",),
    "francfortoise": ("francfortois",),
    "francfortoises": ("francfortois",),
    "francfortois": ("francfortois",),
    "franchiseur": ("franchiseur",),
    "franchiseurs": ("franchiseur",),
    "franchiseuse": ("franchiseur",),
    "franchiseuses": ("franchiseur",),
    "franchissable": ("franchissable",),
    "franchissables": ("franchissable",),
    "francien": ("francien",),
    "francienne": ("francien",),
    "franciennes": ("francien",),
    "franciens": ("francien",),
    "francilien": ("francilien",),
    "francilienne": ("francilien",),
    "franciliennes": ("francilien",),
    "franciliens": ("francilien",),
    "francique": ("francique",),
    "franciques": ("francique",),
    "franco": ("franco",),
    "franco-allemande": ("franco-allemand",),
    "franco-allemand": ("franco-allemand",),
    "franco-allemands": ("franco-allemand",),
    "franco-américaine": ("franco-américain",),
    "franco-américaines": ("franco-américain",),
    "franco-américain": ("franco-américain",),
    "franco-américains": ("franco-américain",),
    "franco-britannique": ("franco-britannique",),
    "franco-britanniques": ("franco-britannique",),
    "franco-canadien": ("franco-canadien",),
    "franco-canadiens": ("franco-canadien",),
    "franco-flamande": ("franco-flamand",),
    "franco-flamand": ("franco-flamand",),
    "franco-françaises": ("franco-français",),
    "franco-français": ("franco-français",),
    "franco-italien": ("franco-italien",),
    "franco-italienne": ("franco-italien",),
    "franco-italiennes": ("franco-italien",),
    "franco-italiens": ("franco-italien",),
    "franconien": ("franconien",),
    "franconienne": ("franconien",),
    "franconiennes": ("franconien",),
    "franconiens": ("franconien",),
    "francophile": ("francophile",),
    "francophiles": ("francophile",),
    "francophobe": ("francophobe",),
    "francophobes": ("francophobe",),
    "francophone": ("francophone",),
    "francophones": ("francophone",),
    "franco-provençale": ("franco-provençal",),
    "franco-russe": ("franco-russe",),
    "franglaise": ("franglais",),
    "franglaises": ("franglais",),
    "franglais": ("franglais",),
    "franquiste": ("franquiste",),
    "franquistes": ("franquiste",),
    "frappeur": ("frappeur",),
    "frappeurs": ("frappeur",),
    "frappeuse": ("frappeur",),
    "frappeuses": ("frappeur",),
    "fraternelle": ("fraternel",),
    "fraternelles": ("fraternel",),
    "fraternel": ("fraternel",),
    "fraternels": ("fraternel",),
    "fratricide": ("fratricide",),
    "fratricides": ("fratricide",),
    "fraudatoire": ("fraudatoire",),
    "fraudatoires": ("fraudatoire",),
    "fraudeur": ("fraudeur",),
    "fraudeurs": ("fraudeur",),
    "fraudeuse": ("fraudeur",),
    "fraudeuses": ("fraudeur",),
    "frauduleuse": ("frauduleux",),
    "frauduleuses": ("frauduleux",),
    "frauduleux": ("frauduleux",),
    "frêle": ("frêle",),
    "frêles": ("frêle",),
    "frénateur": ("frénateur",),
    "frénateurs": ("frénateur",),
    "frénatrice": ("frénateur",),
    "frénatrices": ("frénateur",),
    "frénétique": ("frénétique",),
    "frénétiques": ("frénétique",),
    "fréquentable": ("fréquentable",),
    "fréquentables": ("fréquentable",),
    "fréquentatif": ("fréquentatif",),
    "fréquentatifs": ("fréquentatif",),
    "fréquentative": ("fréquentatif",),
    "fréquentatives": ("fréquentatif",),
    "fréquentielle": ("fréquentiel",),
    "fréquentielles": ("fréquentiel",),
    "fréquentiel": ("fréquentiel",),
    "fréquentiels": ("fréquentiel",),
    "freudien": ("freudien",),
    "freudienne": ("freudien",),
    "freudiennes": ("freudien",),
    "freudiens": ("freudien",),
    "friable": ("friable",),
    "friables": ("friable",),
    "fribronoïde": ("fribronoïde",),
    "fribronoïdes": ("fribronoïde",),
    "fricatif": ("fricatif",),
    "fricatifs": ("fricatif",),
    "fricative": ("fricatif",),
    "fricatives": ("fricatif",),
    "fricoteur": ("fricoteur",),
    "fricoteurs": ("fricoteur",),
    "fricoteuse": ("fricoteur",),
    "fricoteuses": ("fricoteur",),
    "frictionnelle": ("frictionnel",),
    "frictionnelles": ("frictionnel",),
    "frictionnel": ("frictionnel",),
    "frictionnels": ("frictionnel",),
    "frictionneur": ("frictionneur",),
    "frictionneurs": ("frictionneur",),
    "frigide": ("frigide",),
    "frigides": ("frigide",),
    "frigoporteur": ("frigoporteur",),
    "frigoporteurs": ("frigoporteur",),
    "frigoporteuse": ("frigoporteur",),
    "frigoporteuses": ("frigoporteur",),
    "frigorifique": ("frigorifique",),
    "frigorifiques": ("frigorifique",),
    "frigorigène": ("frigorigène",),
    "frigorigènes": ("frigorigène",),
    "frigoriste": ("frigoriste",),
    "frigoristes": ("frigoriste",),
    "frileuse": ("frileux",),
    "frileuses": ("frileux",),
    "frileux": ("frileux",),
    "frimeur": ("frimeur",),
    "frimeurs": ("frimeur",),
    "frimeuse": ("frimeur",),
    "frimeuses": ("frimeur",),
    "frioulien": ("frioulien",),
    "frioulienne": ("frioulien",),
    "friouliennes": ("frioulien",),
    "friouliens": ("frioulien",),
    "fripon": ("fripon",),
    "friponne": ("fripon",),
    "friponnes": ("fripon",),
    "fripons": ("fripon",),
    "frison": ("frison",),
    "frisonne": ("frison",),
    "frisonnes": ("frison",),
    "frisons": ("frison",),
    "frisquet": ("frisquet",),
    "frisquets": ("frisquet",),
    "frisquette": ("frisquet",),
    "frisquettes": ("frisquet",),
    "frivole": ("frivole",),
    "frivoles": ("frivole",),
    "fröbélien": ("fröbélien",),
    "fröbélienne": ("fröbélien",),
    "fröbéliennes": ("fröbélien",),
    "fröbéliens": ("fröbélien",),
    "froissable": ("froissable",),
    "froissables": ("froissable",),
    "frôleur": ("frôleur",),
    "frôleurs": ("frôleur",),
    "frôleuse": ("frôleur",),
    "frôleuses": ("frôleur",),
    "fromagère": ("fromager",),
    "fromagères": ("fromager",),
    "fromager": ("fromager",),
    "fromagers": ("fromager",),
    "froment": ("froment",),
    "fromentale": ("fromental",),
    "fromentales": ("fromental",),
    "fromental": ("fromental",),
    "fromentaux": ("fromental",),
    "fromentée": ("fromentée",),
    "fromentées": ("fromentée",),
    "fronceur": ("fronceur",),
    "fronceurs": ("fronceur",),
    "fronceuse": ("fronceur",),
    "fronceuses": ("fronceur",),
    "frondeur": ("frondeur",),
    "frondeurs": ("frondeur",),
    "frondeuse": ("frondeur",),
    "frondeuses": ("frondeur",),
    "frondicole": ("frondicole",),
    "frondicoles": ("frondicole",),
    "frontale": ("frontal",),
    "frontales": ("frontal",),
    "frontal": ("frontal",),
    "frontaux": ("frontal",),
    "frontalière": ("frontalier",),
    "frontalières": ("frontalier",),
    "frontalier": ("frontalier",),
    "frontaliers": ("frontalier",),
    "frontiste": ("frontiste",),
    "frontistes": ("frontiste",),
    "frontogénétique": ("frontogénétique",),
    "frontogénétiques": ("frontogénétique",),
    "frontologique": ("frontologique",),
    "frontologiques": ("frontologique",),
    "fructifère": ("fructifère",),
    "fructifères": ("fructifère",),
    "fructueuse": ("fructueux",),
    "fructueuses": ("fructueux",),
    "fructueux": ("fructueux",),
    "frugale": ("frugal",),
    "frugales": ("frugal",),
    "frugal": ("frugal",),
    "frugaux": ("frugal",),
    "frugivore": ("frugivore",),
    "frugivores": ("frugivore",),
    "fruitière": ("fruitier",),
    "fruitières": ("fruitier",),
    "fruitier": ("fruitier",),
    "fruitiers": ("fruitier",),
    "frumentaire": ("frumentaire",),
    "frumentaires": ("frumentaire",),
    "fruste": ("fruste",),
    "frustes": ("fruste",),
    "frustratoire": ("frustratoire",),
    "frustratoires": ("frustratoire",),
    "fruticuleuse": ("fruticuleux",),
    "fruticuleuses": ("fruticuleux",),
    "fruticuleux": ("fruticuleux",),
    "fuchsia": ("fuchsia",),
    "fuchsien": ("fuchsien",),
    "fuchsienne": ("fuchsien",),
    "fuchsiennes": ("fuchsien",),
    "fuchsiens": ("fuchsien",),
    "fuégien": ("fuégien",),
    "fuégienne": ("fuégien",),
    "fuégiennes": ("fuégien",),
    "fuégiens": ("fuégien",),
    "fuériste": ("fuériste",),
    "fuéristes": ("fuériste",),
    "fugace": ("fugace",),
    "fugaces": ("fugace",),
    "fugitif": ("fugitif",),
    "fugitifs": ("fugitif",),
    "fugitive": ("fugitif",),
    "fugitives": ("fugitif",),
    "fugueur": ("fugueur",),
    "fugueurs": ("fugueur",),
    "fugueuse": ("fugueur",),
    "fugueuses": ("fugueur",),
    "fulgurale": ("fulgural",),
    "fulgurales": ("fulgural",),
    "fulgural": ("fulgural",),
    "fulguraux": ("fulgural",),
    "fuligineuse": ("fuligineux",),
    "fuligineuses": ("fuligineux",),
    "fuligineux": ("fuligineux",),
    "fulminatoire": ("fulminatoire",),
    "fulminatoires": ("fulminatoire",),
    "fulminique": ("fulminique",),
    "fulminiques": ("fulminique",),
    "fulvique": ("fulvique",),
    "fulviques": ("fulvique",),
    "fumable": ("fumable",),
    "fumables": ("fumable",),
    "fumarique": ("fumarique",),
    "fumariques": ("fumarique",),
    "fumasse": ("fumasse",),
    "fumasses": ("fumasse",),
    "fumeur": ("fumeur",),
    "fumeurs": ("fumeur",),
    "fumeuse": ("fumeux",),
    "fumeuses": ("fumeux",),
    "fumeux": ("fumeux",),
    "fumigatoire": ("fumigatoire",),
    "fumigatoires": ("fumigatoire",),
    "fumigène": ("fumigène",),
    "fumigènes": ("fumigène",),
    "fumiste": ("fumiste",),
    "fumistes": ("fumiste",),
    "fumivore": ("fumivore",),
    "fumivores": ("fumivore",),
    "fun": ("fun",),
    "funambulesque": ("funambulesque",),
    "funambulesques": ("funambulesque",),
    "fundique": ("fundique",),
    "fundiques": ("fundique",),
    "fundoscopique": ("fundoscopique",),
    "fundoscopiques": ("fundoscopique",),
    "funèbre": ("funèbre",),
    "funèbres": ("funèbre",),
    "funéraire": ("funéraire",),
    "funéraires": ("funéraire",),
    "funeste": ("funeste",),
    "funestes": ("funeste",),
    "funiculaire": ("funiculaire",),
    "funiculaires": ("funiculaire",),
    "funk": ("funk",),
    "funks": ("funk",),
    "funky": ("funky",),
    "furannique": ("furannique",),
    "furanniques": ("furannique",),
    "furax": ("furax",),
    "fureteur": ("fureteur",),
    "fureteurs": ("fureteur",),
    "fureteuse": ("fureteur",),
    "fureteuses": ("fureteur",),
    "furfurylique": ("furfurylique",),
    "furfuryliques": ("furfurylique",),
    "furieuse": ("furieux",),
    "furieuses": ("furieux",),
    "furieux": ("furieux",),
    "furioso": ("furioso",),
    "furoïque": ("furoïque",),
    "furoïques": ("furoïque",),
    "furonculeuse": ("furonculeux",),
    "furonculeuses": ("furonculeux",),
    "furonculeux": ("furonculeux",),
    "furonculoïde": ("furonculoïde",),
    "furonculoïdes": ("furonculoïde",),
    "furtif": ("furtif",),
    "furtifs": ("furtif",),
    "furtive": ("furtif",),
    "furtives": ("furtif",),
    "fusible": ("fusible",),
    "fusibles": ("fusible",),
    "fusidique": ("fusidique",),
    "fusidiques": ("fusidique",),
    "fusiforme": ("fusiforme",),
    "fusiformes": ("fusiforme",),
    "fusionnelle": ("fusionnel",),
    "fusionnelles": ("fusionnel",),
    "fusionnel": ("fusionnel",),
    "fusionnels": ("fusionnel",),
    "fusocellulaire": ("fusocellulaire",),
    "fusocellulaires": ("fusocellulaire",),
    "fusoriale": ("fusorial",),
    "fusoriales": ("fusorial",),
    "fusorial": ("fusorial",),
    "fusoriaux": ("fusorial",),
    "futile": ("futile",),
    "futiles": ("futile",),
    "futurible": ("futurible",),
    "futuribles": ("futurible",),
    "futuriste": ("futuriste",),
    "futuristes": ("futuriste",),
    "futurologique": ("futurologique",),
    "futurologiques": ("futurologique",),
    "fuvélien": ("fuvélien",),
    "fuvélienne": ("fuvélien",),
    "fuvéliennes": ("fuvélien",),
    "fuvéliens": ("fuvélien",),
    "gabaminergique": ("gabaminergique",),
    "gabaminergiques": ("gabaminergique",),
    "gabbroïque": ("gabbroïque",),
    "gabbroïques": ("gabbroïque",),
    "gabonaise": ("gabonais",),
    "gabonaises": ("gabonais",),
    "gabonais": ("gabonais",),
    "gâcheur": ("gâcheur",),
    "gâcheurs": ("gâcheur",),
    "gâcheuse": ("gâcheur",),
    "gâcheuses": ("gâcheur",),
    "gaélique": ("gaélique",),
    "gaéliques": ("gaélique",),
    "gaffeur": ("gaffeur",),
    "gaffeurs": ("gaffeur",),
    "gaffeuse": ("gaffeur",),
    "gaffeuses": ("gaffeur",),
    "gaga": ("gaga",),
    "gagesque": ("gagesque",),
    "gagesques": ("gagesque",),
    "gagiste": ("gagiste",),
    "gagistes": ("gagiste",),
    "gagnable": ("gagnable",),
    "gagnables": ("gagnable",),
    "gagneur": ("gagneur",),
    "gagneurs": ("gagneur",),
    "gagneuse": ("gagneur",),
    "gagneuses": ("gagneur",),
    "galactagogue": ("galactagogue",),
    "galactagogues": ("galactagogue",),
    "galactarique": ("galactarique",),
    "galactariques": ("galactarique",),
    "galactique": ("galactique",),
    "galactiques": ("galactique",),
    "galactobolique": ("galactobolique",),
    "galactoboliques": ("galactobolique",),
    "galactocentrique": ("galactocentrique",),
    "galactocentriques": ("galactocentrique",),
    "galactogène": ("galactogène",),
    "galactogènes": ("galactogène",),
    "galactonique": ("galactonique",),
    "galactoniques": ("galactonique",),
    "galactophore": ("galactophore",),
    "galactophores": ("galactophore",),
    "galactopoïétique": ("galactopoïétique",),
    "galactopoïétiques": ("galactopoïétique",),
    "galactosique": ("galactosique",),
    "galactosiques": ("galactosique",),
    "galacturonique": ("galacturonique",),
    "galacturoniques": ("galacturonique",),
    "galate": ("galate",),
    "galates": ("galate",),
    "galénique": ("galénique",),
    "galéniques": ("galénique",),
    "galéniste": ("galéniste",),
    "galénistes": ("galéniste",),
    "galetteuse": ("galetteux",),
    "galetteuses": ("galetteux",),
    "galetteux": ("galetteux",),
    "galeuse": ("galeux",),
    "galeuses": ("galeux",),
    "galeux": ("galeux",),
    "galicien": ("galicien",),
    "galicienne": ("galicien",),
    "galiciennes": ("galicien",),
    "galiciens": ("galicien",),
    "galiléen": ("galiléen",),
    "galiléenne": ("galiléen",),
    "galiléennes": ("galiléen",),
    "galiléens": ("galiléen",),
    "galleuse": ("galleux",),
    "galleuses": ("galleux",),
    "galleux": ("galleux",),
    "gallicole": ("gallicole",),
    "gallicoles": ("gallicole",),
    "galligène": ("galligène",),
    "galligènes": ("galligène",),
    "gallique": ("gallique",),
    "galliques": ("gallique",),
    "gallo": ("gallo",),
    "gallos": ("gallo",),
    "galloise": ("gallois",),
    "galloises": ("gallois",),
    "gallois": ("gallois",),
    "gallo-romaine": ("gallo-romain",),
    "gallo-romaines": ("gallo-romain",),
    "gallo-romain": ("gallo-romain",),
    "gallo-romains": ("gallo-romain",),
    "gallo-romans": ("gallo-roman",),
    "galoisien": ("galoisien",),
    "galoisienne": ("galoisien",),
    "galoisiennes": ("galoisien",),
    "galoisiens": ("galoisien",),
    "galonnière": ("galonnier",),
    "galonnières": ("galonnier",),
    "galonnier": ("galonnier",),
    "galonniers": ("galonnier",),
    "galopeur": ("galopeur",),
    "galopeurs": ("galopeur",),
    "galopeuse": ("galopeur",),
    "galopeuses": ("galopeur",),
    "galtonien": ("galtonien",),
    "galtonienne": ("galtonien",),
    "galtoniennes": ("galtonien",),
    "galtoniens": ("galtonien",),
    "galvanique": ("galvanique",),
    "galvaniques": ("galvanique",),
    "galvanomagnétique": ("galvanomagnétique",),
    "galvanomagnétiques": ("galvanomagnétique",),
    "galvanométrique": ("galvanométrique",),
    "galvanométriques": ("galvanométrique",),
    "galvanoplaste": ("galvanoplaste",),
    "galvanoplastes": ("galvanoplaste",),
    "galvanoplastique": ("galvanoplastique",),
    "galvanoplastiques": ("galvanoplastique",),
    "galvanotonique": ("galvanotonique",),
    "galvanotoniques": ("galvanotonique",),
    "gambardière": ("gambardière",),
    "gambardières": ("gambardière",),
    "gambien": ("gambien",),
    "gambienne": ("gambien",),
    "gambiennes": ("gambien",),
    "gambiens": ("gambien",),
    "gaméticide": ("gaméticide",),
    "gaméticides": ("gaméticide",),
    "gamétique": ("gamétique",),
    "gamétiques": ("gamétique",),
    "gamétocytaire": ("gamétocytaire",),
    "gamétocytaires": ("gamétocytaire",),
    "gamétophytique": ("gamétophytique",),
    "gamétophytiques": ("gamétophytique",),
    "gamma": ("gamma",),
    "gammagraphique": ("gammagraphique",),
    "gammagraphiques": ("gammagraphique",),
    "gammée": ("gammée",),
    "gammées": ("gammée",),
    "gamocarpique": ("gamocarpique",),
    "gamocarpiques": ("gamocarpique",),
    "gamopétale": ("gamopétale",),
    "gamopétales": ("gamopétale",),
    "gamosépale": ("gamosépale",),
    "gamosépales": ("gamosépale",),
    "ganache": ("ganache",),
    "ganaches": ("ganache",),
    "gangétique": ("gangétique",),
    "gangétiques": ("gangétique",),
    "ganglionnaire": ("ganglionnaire",),
    "ganglionnaires": ("ganglionnaire",),
    "ganglioplégique": ("ganglioplégique",),
    "ganglioplégiques": ("ganglioplégique",),
    "gangreneuse": ("gangreneux",),
    "gangréneuse": ("gangréneux",),
    "gangreneuses": ("gangreneux",),
    "gangréneuses": ("gangréneux",),
    "gangreneux": ("gangreneux",),
    "gangréneux": ("gangréneux",),
    "ganoïde": ("ganoïde",),
    "ganoïdes": ("ganoïde",),
    "gantière": ("gantier",),
    "gantières": ("gantier",),
    "gantier": ("gantier",),
    "gantiers": ("gantier",),
    "gantoise": ("gantois",),
    "gantoises": ("gantois",),
    "gantois": ("gantois",),
    "gapançaise": ("gapançais",),
    "gapançaises": ("gapançais",),
    "gapançais": ("gapançais",),
    "garance": ("garance",),
    "garçon": ("garçon",),
    "garçons": ("garçon",),
    "garçonnière": ("garçonnier",),
    "garçonnières": ("garçonnier",),
    "garçonnier": ("garçonnier",),
    "garçonniers": ("garçonnier",),
    "gardable": ("gardable",),
    "gardables": ("gardable",),
    "gardien": ("gardien",),
    "gardienne": ("gardien",),
    "gardiennes": ("gardien",),
    "gardiens": ("gardien",),
    "gardiste": ("gardiste",),
    "gardistes": ("gardiste",),
    "gardoise": ("gardois",),
    "gardoises": ("gardois",),
    "gardois": ("gardois",),
    "gargantuesque": ("gargantuesque",),
    "gargantuesques": ("gargantuesque",),
    "gargasien": ("gargasien",),
    "gargasienne": ("gargasien",),
    "gargasiennes": ("gargasien",),
    "gargasiens": ("gargasien",),
    "garibaldien": ("garibaldien",),
    "garibaldienne": ("garibaldien",),
    "garibaldiennes": ("garibaldien",),
    "garibaldiens": ("garibaldien",),
    "garonnaise": ("garonnais",),
    "garonnaises": ("garonnais",),
    "garonnais": ("garonnais",),
    "gascon": ("gascon",),
    "gasconne": ("gascon",),
    "gasconnes": ("gascon",),
    "gascons": ("gascon",),
    "gaspésien": ("gaspésien",),
    "gaspésienne": ("gaspésien",),
    "gaspésiennes": ("gaspésien",),
    "gaspésiens": ("gaspésien",),
    "gaspilleur": ("gaspilleur",),
    "gaspilleurs": ("gaspilleur",),
    "gaspilleuse": ("gaspilleur",),
    "gaspilleuses": ("gaspilleur",),
    "gassendiste": ("gassendiste",),
    "gassendistes": ("gassendiste",),
    "gastralgique": ("gastralgique",),
    "gastralgiques": ("gastralgique",),
    "gastrique": ("gastrique",),
    "gastriques": ("gastrique",),
    "gastro-colique": ("gastro-colique",),
    "gastroduodénale": ("gastroduodénal",),
    "gastroduodénales": ("gastroduodénal",),
    "gastroduodénal": ("gastroduodénal",),
    "gastroduodénaux": ("gastroduodénal",),
    "gastro-entéritiques": ("gastro-entéritique",),
    "gastro-épiploïque": ("gastro-épiploïque",),
    "gastro-hépatiques": ("gastro-hépatique",),
    "gastro-intestinale": ("gastro-intestinal",),
    "gastro-intestinales": ("gastro-intestinal",),
    "gastro-intestinal": ("gastro-intestinal",),
    "gastro-intestinaux": ("gastro-intestinal",),
    "gastronomique": ("gastronomique",),
    "gastronomiques": ("gastronomique",),
    "gastro-oesophagienne": ("gastro-oesophagien",),
    "gastroprive": ("gastroprive",),
    "gastroprives": ("gastroprive",),
    "gastro-pylorique": ("gastro-pylorique",),
    "gâteau": ("gâteau",),
    "gâteaux": ("gâteau",),
    "gâteuse": ("gâteux",),
    "gâteuses": ("gâteux",),
    "gâteux": ("gâteux",),
    "gauche": ("gauche",),
    "gauches": ("gauche",),
    "gauchère": ("gaucher",),
    "gauchères": ("gaucher",),
    "gaucher": ("gaucher",),
    "gauchers": ("gaucher",),
    "gauchiste": ("gauchiste",),
    "gauchistes": ("gauchiste",),
    "gaullien": ("gaullien",),
    "gaullienne": ("gaullien",),
    "gaulliennes": ("gaullien",),
    "gaulliens": ("gaullien",),
    "gaulliste": ("gaulliste",),
    "gaullistes": ("gaulliste",),
    "gauloise": ("gaulois",),
    "gauloises": ("gaulois",),
    "gaulois": ("gaulois",),
    "gavache": ("gavache",),
    "gavaches": ("gavache",),
    "gavroche": ("gavroche",),
    "gavroches": ("gavroche",),
    "gay": ("gay",),
    "gazéifiable": ("gazéifiable",),
    "gazéifiables": ("gazéifiable",),
    "gazeuse": ("gazeux",),
    "gazeuses": ("gazeux",),
    "gazeux": ("gazeux",),
    "gazière": ("gazier",),
    "gazières": ("gazier",),
    "gazier": ("gazier",),
    "gaziers": ("gazier",),
    "gaziste": ("gaziste",),
    "gazistes": ("gaziste",),
    "gazométrique": ("gazométrique",),
    "gazométriques": ("gazométrique",),
    "gazonneuse": ("gazonneux",),
    "gazonneuses": ("gazonneux",),
    "gazonneux": ("gazonneux",),
    "gazouilleur": ("gazouilleur",),
    "gazouilleurs": ("gazouilleur",),
    "gazouilleuse": ("gazouilleur",),
    "gazouilleuses": ("gazouilleur",),
    "gélatineuse": ("gélatineux",),
    "gélatineuses": ("gélatineux",),
    "gélatineux": ("gélatineux",),
    "gélatiniforme": ("gélatiniforme",),
    "gélatiniformes": ("gélatiniforme",),
    "géléophysique": ("géléophysique",),
    "géléophysiques": ("géléophysique",),
    "gélif": ("gélif",),
    "gélifs": ("gélif",),
    "gélive": ("gélif",),
    "gélives": ("gélif",),
    "gélogène": ("gélogène",),
    "gélogènes": ("gélogène",),
    "gélosique": ("gélosique",),
    "gélosiques": ("gélosique",),
    "gemarique": ("gemarique",),
    "gemariques": ("gemarique",),
    "gémeau": ("gémeau",),
    "gémeaux": ("gémeau",),
    "gémelle": ("gémeau",),
    "gémelles": ("gémeau",),
    "gémellaire": ("gémellaire",),
    "gémellaires": ("gémellaire",),
    "gémellipare": ("gémellipare",),
    "gémellipares": ("gémellipare",),
    "gemmée": ("gemmé",),
    "gemmées": ("gemmé",),
    "gemmé": ("gemmé",),
    "gemme": ("gemme",),
    "gemmés": ("gemmé",),
    "gemmes": ("gemme",),
    "gemmeur": ("gemmeur",),
    "gemmeurs": ("gemmeur",),
    "gemmeuse": ("gemmeur",),
    "gemmeuses": ("gemmeur",),
    "gemmifère": ("gemmifère",),
    "gemmifères": ("gemmifère",),
    "gemmipare": ("gemmipare",),
    "gemmipares": ("gemmipare",),
    "gemmologique": ("gemmologique",),
    "gemmologiques": ("gemmologique",),
    "gemmologiste": ("gemmologiste",),
    "gemmologistes": ("gemmologiste",),
    "génale": ("génal",),
    "génales": ("génal",),
    "génal": ("génal",),
    "génaux": ("génal",),
    "généalogique": ("généalogique",),
    "généalogiques": ("généalogique",),
    "générale": ("général",),
    "générales": ("général",),
    "général": ("général",),
    "généraux": ("général",),
    "généralisable": ("généralisable",),
    "généralisables": ("généralisable",),
    "généralisateur": ("généralisateur",),
    "généralisateurs": ("généralisateur",),
    "généralisatrice": ("généralisateur",),
    "généralisatrices": ("généralisateur",),
    "généraliste": ("généraliste",),
    "généralistes": ("généraliste",),
    "générateur": ("générateur",),
    "générateurs": ("générateur",),
    "génératrice": ("générateur",),
    "génératrices": ("générateur",),
    "génératif": ("génératif",),
    "génératifs": ("génératif",),
    "générative": ("génératif",),
    "génératives": ("génératif",),
    "générationnelle": ("générationnel",),
    "générationnelles": ("générationnel",),
    "générationnel": ("générationnel",),
    "générationnels": ("générationnel",),
    "générativiste": ("générativiste",),
    "générativistes": ("générativiste",),
    "généreuse": ("généreux",),
    "généreuses": ("généreux",),
    "généreux": ("généreux",),
    "générique": ("générique",),
    "génériques": ("générique",),
    "génésiaque": ("génésiaque",),
    "génésiaques": ("génésiaque",),
    "génésique": ("génésique",),
    "génésiques": ("génésique",),
    "généthliaque": ("généthliaque",),
    "généthliaques": ("généthliaque",),
    "génétique": ("génétique",),
    "génétiques": ("génétique",),
    "genevoise": ("genevois",),
    "genevoises": ("genevois",),
    "genevois": ("genevois",),
    "géni": ("géni",),
    "géniale": ("génial",),
    "géniales": ("génial",),
    "génial": ("génial",),
    "géniaux": ("génial",),
    "génien": ("génien",),
    "génienne": ("génien",),
    "géniennes": ("génien",),
    "géniens": ("génien",),
    "génio-hyoïdiennes": ("génio-hyoïdien",),
    "génique": ("génique",),
    "géniques": ("génique",),
    "génitale": ("génital",),
    "génitales": ("génital",),
    "génital": ("génital",),
    "génitaux": ("génital",),
    "génitif": ("génitif",),
    "génitifs": ("génitif",),
    "génitive": ("génitif",),
    "génitives": ("génitif",),
    "génito-crurale": ("génito-crural",),
    "génito-crural": ("génito-crural",),
    "génito-spinale": ("génito-spinal",),
    "génitosurrénale": ("génitosurrénal",),
    "génitosurrénales": ("génitosurrénal",),
    "génitosurrénal": ("génitosurrénal",),
    "génitosurrénaux": ("génitosurrénal",),
    "génito-urinaire": ("génito-urinaire",),
    "génito-urinaires": ("génito-urinaire",),
    "génoise": ("génois",),
    "génoises": ("génois",),
    "génois": ("génois",),
    "génomique": ("génomique",),
    "génomiques": ("génomique",),
    "génotoxique": ("génotoxique",),
    "génotoxiques": ("génotoxique",),
    "génotypique": ("génotypique",),
    "génotypiques": ("génotypique",),
    "gentille": ("gentil",),
    "gentilles": ("gentil",),
    "gentil": ("gentil",),
    "gentils": ("gentil",),
    "gentilice": ("gentilice",),
    "gentilices": ("gentilice",),
    "gentillet": ("gentillet",),
    "gentillets": ("gentillet",),
    "gentillette": ("gentillet",),
    "gentillettes": ("gentillet",),
    "gentisique": ("gentisique",),
    "gentisiques": ("gentisique",),
    "géoacoustique": ("géoacoustique",),
    "géoacoustiques": ("géoacoustique",),
    "géobotanique": ("géobotanique",),
    "géobotaniques": ("géobotanique",),
    "géocentrique": ("géocentrique",),
    "géocentriques": ("géocentrique",),
    "géocentriste": ("géocentriste",),
    "géocentristes": ("géocentriste",),
    "géochimique": ("géochimique",),
    "géochimiques": ("géochimique",),
    "géochronologique": ("géochronologique",),
    "géochronologiques": ("géochronologique",),
    "géocoronale": ("géocoronal",),
    "géocoronales": ("géocoronal",),
    "géocoronal": ("géocoronal",),
    "géocoronaux": ("géocoronal",),
    "géodésique": ("géodésique",),
    "géodésiques": ("géodésique",),
    "géodique": ("géodique",),
    "géodiques": ("géodique",),
    "géodynamique": ("géodynamique",),
    "géodynamiques": ("géodynamique",),
    "géographique": ("géographique",),
    "géographiques": ("géographique",),
    "géoïdique": ("géoïdique",),
    "géoïdiques": ("géoïdique",),
    "géolinguistique": ("géolinguistique",),
    "géolinguistiques": ("géolinguistique",),
    "géologique": ("géologique",),
    "géologiques": ("géologique",),
    "géomagnétique": ("géomagnétique",),
    "géomagnétiques": ("géomagnétique",),
    "géomatique": ("géomatique",),
    "géomatiques": ("géomatique",),
    "géomécanique": ("géomécanique",),
    "géomécaniques": ("géomécanique",),
    "géométrale": ("géométral",),
    "géométrales": ("géométral",),
    "géométral": ("géométral",),
    "géométraux": ("géométral",),
    "géométrique": ("géométrique",),
    "géométriques": ("géométrique",),
    "géomorphogénique": ("géomorphogénique",),
    "géomorphogéniques": ("géomorphogénique",),
    "géomorphologique": ("géomorphologique",),
    "géomorphologiques": ("géomorphologique",),
    "géophage": ("géophage",),
    "géophages": ("géophage",),
    "géophysique": ("géophysique",),
    "géophysiques": ("géophysique",),
    "géopolitique": ("géopolitique",),
    "géopolitiques": ("géopolitique",),
    "géopotentielle": ("géopotentiel",),
    "géopotentielles": ("géopotentiel",),
    "géopotentiel": ("géopotentiel",),
    "géopotentiels": ("géopotentiel",),
    "géorgien": ("géorgien",),
    "géorgienne": ("géorgien",),
    "géorgiennes": ("géorgien",),
    "géorgiens": ("géorgien",),
    "géorgique": ("géorgique",),
    "géorgiques": ("géorgique",),
    "géosismique": ("géosismique",),
    "géosismiques": ("géosismique",),
    "géostationnaire": ("géostationnaire",),
    "géostationnaires": ("géostationnaire",),
    "géostatique": ("géostatique",),
    "géostatiques": ("géostatique",),
    "géostatistique": ("géostatistique",),
    "géostatistiques": ("géostatistique",),
    "géostratégique": ("géostratégique",),
    "géostratégiques": ("géostratégique",),
    "géostrophique": ("géostrophique",),
    "géostrophiques": ("géostrophique",),
    "géosynchrone": ("géosynchrone",),
    "géosynchrones": ("géosynchrone",),
    "géotactique": ("géotactique",),
    "géotactiques": ("géotactique",),
    "géotechnique": ("géotechnique",),
    "géotechniques": ("géotechnique",),
    "géotectonique": ("géotectonique",),
    "géotectoniques": ("géotectonique",),
    "géothermale": ("géothermal",),
    "géothermales": ("géothermal",),
    "géothermal": ("géothermal",),
    "géothermaux": ("géothermal",),
    "géothermique": ("géothermique",),
    "géothermiques": ("géothermique",),
    "géotrope": ("géotrope",),
    "géotropes": ("géotrope",),
    "géotropique": ("géotropique",),
    "géotropiques": ("géotropique",),
    "gérable": ("gérable",),
    "gérables": ("gérable",),
    "géranique": ("géranique",),
    "géraniques": ("géranique",),
    "gerbable": ("gerbable",),
    "gerbables": ("gerbable",),
    "gerbeur": ("gerbeur",),
    "gerbeurs": ("gerbeur",),
    "gerbeuse": ("gerbeur",),
    "gerbeuses": ("gerbeur",),
    "gériatrique": ("gériatrique",),
    "gériatriques": ("gériatrique",),
    "germaneuse": ("germaneux",),
    "germaneuses": ("germaneux",),
    "germaneux": ("germaneux",),
    "germanifluorhydrique": ("germanifluorhydrique",),
    "germanifluorhydriques": ("germanifluorhydrique",),
    "germanique": ("germanique",),
    "germaniques": ("germanique",),
    "germaniste": ("germaniste",),
    "germanistes": ("germaniste",),
    "germano-britannique": ("germano-britannique",),
    "germano-britanniques": ("germano-britannique",),
    "germanophile": ("germanophile",),
    "germanophiles": ("germanophile",),
    "germanophobe": ("germanophobe",),
    "germanophobes": ("germanophobe",),
    "germanophone": ("germanophone",),
    "germanophones": ("germanophone",),
    "germano-soviétique": ("germano-soviétique",),
    "germicide": ("germicide",),
    "germicides": ("germicide",),
    "germinale": ("germinal",),
    "germinales": ("germinal",),
    "germinal": ("germinal",),
    "germinaux": ("germinal",),
    "germinateur": ("germinateur",),
    "germinateurs": ("germinateur",),
    "germinatrice": ("germinateur",),
    "germinatrices": ("germinateur",),
    "germinatif": ("germinatif",),
    "germinatifs": ("germinatif",),
    "germinative": ("germinatif",),
    "germinatives": ("germinatif",),
    "gérontocratique": ("gérontocratique",),
    "gérontocratiques": ("gérontocratique",),
    "gérontologique": ("gérontologique",),
    "gérontologiques": ("gérontologique",),
    "gérontophile": ("gérontophile",),
    "gérontophiles": ("gérontophile",),
    "gersoise": ("gersois",),
    "gersoises": ("gersois",),
    "gersois": ("gersois",),
    "gestagène": ("gestagène",),
    "gestagènes": ("gestagène",),
    "gestaltiste": ("gestaltiste",),
    "gestaltistes": ("gestaltiste",),
    "gestatif": ("gestatif",),
    "gestatifs": ("gestatif",),
    "gestative": ("gestatif",),
    "gestatives": ("gestatif",),
    "gestationnelle": ("gestationnel",),
    "gestationnelles": ("gestationnel",),
    "gestationnel": ("gestationnel",),
    "gestationnels": ("gestationnel",),
    "gestatoire": ("gestatoire",),
    "gestatoires": ("gestatoire",),
    "gestionnaire": ("gestionnaire",),
    "gestionnaires": ("gestionnaire",),
    "gestuelle": ("gestuel",),
    "gestuelles": ("gestuel",),
    "gestuel": ("gestuel",),
    "gestuels": ("gestuel",),
    "ghanéen": ("ghanéen",),
    "ghanéenne": ("ghanéen",),
    "ghanéennes": ("ghanéen",),
    "ghanéens": ("ghanéen",),
    "gibbérellique": ("gibbérellique",),
    "gibbérelliques": ("gibbérellique",),
    "gibbeuse": ("gibbeux",),
    "gibbeuses": ("gibbeux",),
    "gibbeux": ("gibbeux",),
    "giboyeuse": ("giboyeux",),
    "giboyeuses": ("giboyeux",),
    "giboyeux": ("giboyeux",),
    "gigantesque": ("gigantesque",),
    "gigantesques": ("gigantesque",),
    "gigantocellulaire": ("gigantocellulaire",),
    "gigantocellulaires": ("gigantocellulaire",),
    "gigantofolliculaire": ("gigantofolliculaire",),
    "gigantofolliculaires": ("gigantofolliculaire",),
    "gigantopyramidale": ("gigantopyramidal",),
    "gigantopyramidales": ("gigantopyramidal",),
    "gigantopyramidal": ("gigantopyramidal",),
    "gigantopyramidaux": ("gigantopyramidal",),
    "gigogne": ("gigogne",),
    "gigognes": ("gigogne",),
    "gingivale": ("gingival",),
    "gingivales": ("gingival",),
    "gingival": ("gingival",),
    "gingivaux": ("gingival",),
    "ginguet": ("ginguet",),
    "ginguets": ("ginguet",),
    "giottesque": ("giottesque",),
    "giottesques": ("giottesque",),
    "giratoire": ("giratoire",),
    "giratoires": ("giratoire",),
    "giscardien": ("giscardien",),
    "giscardienne": ("giscardien",),
    "giscardiennes": ("giscardien",),
    "giscardiens": ("giscardien",),
    "gîtologique": ("gîtologique",),
    "gîtologiques": ("gîtologique",),
    "givreuse": ("givreux",),
    "givreuses": ("givreux",),
    "givreux": ("givreux",),
    "glabre": ("glabre",),
    "glabres": ("glabre",),
    "glaceur": ("glaceur",),
    "glaceurs": ("glaceur",),
    "glaceuse": ("glaceux",),
    "glaceuses": ("glaceux",),
    "glaceux": ("glaceux",),
    "glaciaire": ("glaciaire",),
    "glaciaires": ("glaciaire",),
    "glacielle": ("glaciel",),
    "glacielles": ("glaciel",),
    "glaciel": ("glaciel",),
    "glaciels": ("glaciel",),
    "glaciologique": ("glaciologique",),
    "glaciologiques": ("glaciologique",),
    "glagolitique": ("glagolitique",),
    "glagolitiques": ("glagolitique",),
    "glaireuse": ("glaireux",),
    "glaireuses": ("glaireux",),
    "glaireux": ("glaireux",),
    "glaise": ("glaise",),
    "glaises": ("glaise",),
    "glaiseuse": ("glaiseux",),
    "glaiseuses": ("glaiseux",),
    "glaiseux": ("glaiseux",),
    "glamourous": ("glamourous",),
    "glandulaire": ("glandulaire",),
    "glandulaires": ("glandulaire",),
    "glanduleuse": ("glanduleux",),
    "glanduleuses": ("glanduleux",),
    "glanduleux": ("glanduleux",),
    "glaucomateuse": ("glaucomateux",),
    "glaucomateuses": ("glaucomateux",),
    "glaucomateux": ("glaucomateux",),
    "glauconieuse": ("glauconieux",),
    "glauconieuses": ("glauconieux",),
    "glauconieux": ("glauconieux",),
    "glauque": ("glauque",),
    "glauques": ("glauque",),
    "glénoïdale": ("glénoïdale",),
    "glénoïdales": ("glénoïdale",),
    "glénoïdal": ("glénoïdal",),
    "glénoïdaux": ("glénoïdal",),
    "glénoïde": ("glénoïde",),
    "glénoïdes": ("glénoïde",),
    "glénoïdien": ("glénoïdien",),
    "glénoïdienne": ("glénoïdien",),
    "glénoïdiennes": ("glénoïdien",),
    "glénoïdiens": ("glénoïdien",),
    "gliale": ("glial",),
    "gliales": ("glial",),
    "glial": ("glial",),
    "gliaux": ("glial",),
    "glischroïde": ("glischroïde",),
    "glischroïdes": ("glischroïde",),
    "glisseur": ("glisseur",),
    "glisseurs": ("glisseur",),
    "glisseuse": ("glisseur",),
    "glisseuses": ("glisseur",),
    "globale": ("global",),
    "globales": ("global",),
    "global": ("global",),
    "globaux": ("global",),
    "globalisateur": ("globalisateur",),
    "globalisateurs": ("globalisateur",),
    "globalisatrice": ("globalisateur",),
    "globalisatrices": ("globalisateur",),
    "globaliste": ("globaliste",),
    "globalistes": ("globaliste",),
    "globique": ("globique",),
    "globiques": ("globique",),
    "globocellulaire": ("globocellulaire",),
    "globocellulaires": ("globocellulaire",),
    "globulaire": ("globulaire",),
    "globulaires": ("globulaire",),
    "globuleuse": ("globuleux",),
    "globuleuses": ("globuleux",),
    "globuleux": ("globuleux",),
    "glomérulaire": ("glomérulaire",),
    "glomérulaires": ("glomérulaire",),
    "glomique": ("glomique",),
    "glomiques": ("glomique",),
    "glorieuse": ("glorieux",),
    "glorieuses": ("glorieux",),
    "glorieux": ("glorieux",),
    "glorificateur": ("glorificateur",),
    "glorificateurs": ("glorificateur",),
    "glorificatrice": ("glorificateur",),
    "glorificatrices": ("glorificateur",),
    "glossolabiée": ("glossolabié",),
    "glosso-labiées": ("glosso-labié",),
    "glossolabiées": ("glossolabié",),
    "glossolabié": ("glossolabié",),
    "glossolabiés": ("glossolabié",),
    "glossopharyngien": ("glossopharyngien",),
    "glossopharyngienne": ("glossopharyngien",),
    "glossopharyngiennes": ("glossopharyngien",),
    "glossopharyngiens": ("glossopharyngien",),
    "glosso-staphylins": ("glosso-staphylin",),
    "glottale": ("glottal",),
    "glottales": ("glottal",),
    "glottal": ("glottal",),
    "glottaux": ("glottal",),
    "glottique": ("glottique",),
    "glottiques": ("glottique",),
    "glouton": ("glouton",),
    "gloutonne": ("glouton",),
    "gloutonnes": ("glouton",),
    "gloutons": ("glouton",),
    "glucarique": ("glucarique",),
    "glucariques": ("glucarique",),
    "glucidique": ("glucidique",),
    "glucidiques": ("glucidique",),
    "glucido-lipidique": ("glucido-lipidique",),
    "glucido-protidiques": ("glucido-protidique",),
    "glucocorticoïde": ("glucocorticoïde",),
    "glucocorticoïdes": ("glucocorticoïde",),
    "glucoformateur": ("glucoformateur",),
    "glucoformateurs": ("glucoformateur",),
    "glucoformatrice": ("glucoformateur",),
    "glucoformatrices": ("glucoformateur",),
    "gluconique": ("gluconique",),
    "gluconiques": ("gluconique",),
    "glucosidasique": ("glucosidasique",),
    "glucosidasiques": ("glucosidasique",),
    "glucuronique": ("glucuronique",),
    "glucuroniques": ("glucuronique",),
    "glutamique": ("glutamique",),
    "glutamiques": ("glutamique",),
    "glutarique": ("glutarique",),
    "glutariques": ("glutarique",),
    "glutéale": ("glutéal",),
    "glutéales": ("glutéal",),
    "glutéal": ("glutéal",),
    "glutéaux": ("glutéal",),
    "glutineuse": ("glutineux",),
    "glutineuses": ("glutineux",),
    "glutineux": ("glutineux",),
    "glycémique": ("glycémique",),
    "glycémiques": ("glycémique",),
    "glycérique": ("glycérique",),
    "glycériques": ("glycérique",),
    "glycérophosphorique": ("glycérophosphorique",),
    "glycérophosphoriques": ("glycérophosphorique",),
    "glycérophtalique": ("glycérophtalique",),
    "glycérophtaliques": ("glycérophtalique",),
    "glycidique": ("glycidique",),
    "glycidiques": ("glycidique",),
    "glycocholique": ("glycocholique",),
    "glycocholiques": ("glycocholique",),
    "glycogénique": ("glycogénique",),
    "glycogéniques": ("glycogénique",),
    "glycogénolytique": ("glycogénolytique",),
    "glycogénolytiques": ("glycogénolytique",),
    "glycolique": ("glycolique",),
    "glycoliques": ("glycolique",),
    "glycolurique": ("glycolurique",),
    "glycoluriques": ("glycolurique",),
    "glycolytique": ("glycolytique",),
    "glycolytiques": ("glycolytique",),
    "glyconien": ("glyconien",),
    "glyconienne": ("glyconien",),
    "glyconiennes": ("glyconien",),
    "glyconiens": ("glyconien",),
    "glycopénique": ("glycopénique",),
    "glycopéniques": ("glycopénique",),
    "glycoprotéique": ("glycoprotéique",),
    "glycoprotéiques": ("glycoprotéique",),
    "glycorégulateur": ("glycorégulateur",),
    "glycorégulateurs": ("glycorégulateur",),
    "glycorégulatrice": ("glycorégulateur",),
    "glycorégulatrices": ("glycorégulateur",),
    "glycosidique": ("glycosidique",),
    "glycosidiques": ("glycosidique",),
    "glycostatique": ("glycostatique",),
    "glycostatiques": ("glycostatique",),
    "glycosurique": ("glycosurique",),
    "glycosuriques": ("glycosurique",),
    "glycotrope": ("glycotrope",),
    "glycotropes": ("glycotrope",),
    "glycuronique": ("glycuronique",),
    "glycuroniques": ("glycuronique",),
    "glycyrrhétinique": ("glycyrrhétinique",),
    "glycyrrhétiniques": ("glycyrrhétinique",),
    "glycyrrhizique": ("glycyrrhizique",),
    "glycyrrhiziques": ("glycyrrhizique",),
    "glyoxylique": ("glyoxylique",),
    "glyoxyliques": ("glyoxylique",),
    "gnangnan": ("gnangnan",),
    "gnangnans": ("gnangnan",),
    "gneisseuse": ("gneisseux",),
    "gneisseuses": ("gneisseux",),
    "gneisseux": ("gneisseux",),
    "gneissique": ("gneissique",),
    "gneissiques": ("gneissique",),
    "gniangnian": ("gniangnian",),
    "gniangnians": ("gniangnian",),
    "gnomique": ("gnomique",),
    "gnomiques": ("gnomique",),
    "gnomonique": ("gnomonique",),
    "gnomoniques": ("gnomonique",),
    "gnoséologique": ("gnoséologique",),
    "gnoséologiques": ("gnoséologique",),
    "gnosique": ("gnosique",),
    "gnosiques": ("gnosique",),
    "gnostique": ("gnostique",),
    "gnostiques": ("gnostique",),
    "gnotobiotique": ("gnotobiotique",),
    "gnotobiotiques": ("gnotobiotique",),
    "gnotoxénique": ("gnotoxénique",),
    "gnotoxéniques": ("gnotoxénique",),
    "godiche": ("godiche",),
    "godiches": ("godiche",),
    "godichon": ("godichon",),
    "godichonne": ("godichon",),
    "godichonnes": ("godichon",),
    "godichons": ("godichon",),
    "goémonière": ("goémonier",),
    "goémonières": ("goémonier",),
    "goémonier": ("goémonier",),
    "goémoniers": ("goémonier",),
    "goétique": ("goétique",),
    "goétiques": ("goétique",),
    "goï": ("goï",),
    "goinfre": ("goinfre",),
    "goinfres": ("goinfre",),
    "goitreuse": ("goitreux",),
    "goitreuses": ("goitreux",),
    "goitreux": ("goitreux",),
    "goitrigène": ("goitrigène",),
    "goitrigènes": ("goitrigène",),
    "gold": ("gold",),
    "golden": ("golden",),
    "golfique": ("golfique",),
    "golfiques": ("golfique",),
    "golfiste": ("golfiste",),
    "golfistes": ("golfiste",),
    "goliardique": ("goliardique",),
    "goliardiques": ("goliardique",),
    "gomariste": ("gomariste",),
    "gomaristes": ("gomariste",),
    "gommeuse": ("gommeux",),
    "gommeuses": ("gommeux",),
    "gommeux": ("gommeux",),
    "gommifère": ("gommifère",),
    "gommifères": ("gommifère",),
    "gomorrhéen": ("gomorrhéen",),
    "gomorrhéenne": ("gomorrhéen",),
    "gomorrhéennes": ("gomorrhéen",),
    "gomorrhéens": ("gomorrhéen",),
    "gonadique": ("gonadique",),
    "gonadiques": ("gonadique",),
    "gonadophorique": ("gonadophorique",),
    "gonadophoriques": ("gonadophorique",),
    "gonadothérapique": ("gonadothérapique",),
    "gonadothérapiques": ("gonadothérapique",),
    "gonadotrope": ("gonadotrope",),
    "gonadotropes": ("gonadotrope",),
    "gonalgique": ("gonalgique",),
    "gonalgiques": ("gonalgique",),
    "gonflable": ("gonflable",),
    "gonflables": ("gonflable",),
    "gongoriste": ("gongoriste",),
    "gongoristes": ("gongoriste",),
    "goniaque": ("goniaque",),
    "goniaques": ("goniaque",),
    "gonidiale": ("gonidial",),
    "gonidiales": ("gonidial",),
    "gonidial": ("gonidial",),
    "gonidiaux": ("gonidial",),
    "goniométrique": ("goniométrique",),
    "goniométriques": ("goniométrique",),
    "gonochorique": ("gonochorique",),
    "gonochoriques": ("gonochorique",),
    "gonococcique": ("gonococcique",),
    "gonococciques": ("gonococcique",),
    "gonocytaire": ("gonocytaire",),
    "gonocytaires": ("gonocytaire",),
    "gonosomique": ("gonosomique",),
    "gonosomiques": ("gonosomique",),
    "gordien": ("gordien",),
    "gordiens": ("gordien",),
    "gore": ("gore",),
    "gosse": ("gosse",),
    "gosses": ("gosse",),
    "gothique": ("gothique",),
    "gothiques": ("gothique",),
    "gotique": ("gotique",),
    "gotiques": ("gotique",),
    "gouailleur": ("gouailleur",),
    "gouailleurs": ("gouailleur",),
    "gouailleuse": ("gouailleur",),
    "gouailleuses": ("gouailleur",),
    "gouape": ("gouape",),
    "gouapes": ("gouape",),
    "goudronneuse": ("goudronneux",),
    "goudronneuses": ("goudronneux",),
    "goudronneux": ("goudronneux",),
    "goujonnière": ("goujonnière",),
    "goujonnières": ("goujonnière",),
    "goulafre": ("goulafre",),
    "goulafres": ("goulafre",),
    "gourde": ("gourde",),
    "gourdes": ("gourde",),
    "goûteuse": ("goûteux",),
    "goûteuses": ("goûteux",),
    "goûteux": ("goûteux",),
    "gouttereau": ("gouttereau",),
    "gouttereaux": ("gouttereau",),
    "goutteuse": ("goutteux",),
    "goutteuses": ("goutteux",),
    "goutteux": ("goutteux",),
    "gouvernable": ("gouvernable",),
    "gouvernables": ("gouvernable",),
    "gouvernementale": ("gouvernemental",),
    "gouvernementales": ("gouvernemental",),
    "gouvernemental": ("gouvernemental",),
    "gouvernementaux": ("gouvernemental",),
    "goy": ("goy",),
    "grabataire": ("grabataire",),
    "grabataires": ("grabataire",),
    "graciable": ("graciable",),
    "graciables": ("graciable",),
    "gracieuse": ("gracieux",),
    "gracieuses": ("gracieux",),
    "gracieux": ("gracieux",),
    "gracile": ("gracile",),
    "graciles": ("gracile",),
    "gradualiste": ("gradualiste",),
    "gradualistes": ("gradualiste",),
    "graduelle": ("graduel",),
    "graduelles": ("graduel",),
    "graduel": ("graduel",),
    "graduels": ("graduel",),
    "grainetière": ("grainetier",),
    "grainetières": ("grainetier",),
    "grainetier": ("grainetier",),
    "grainetiers": ("grainetier",),
    "graisseur": ("graisseur",),
    "graisseurs": ("graisseur",),
    "graisseuse": ("graisseux",),
    "graisseuses": ("graisseux",),
    "graisseux": ("graisseux",),
    "graminée": ("graminée",),
    "graminées": ("graminée",),
    "grammaticale": ("grammatical",),
    "grammaticales": ("grammatical",),
    "grammatical": ("grammatical",),
    "grammaticaux": ("grammatical",),
    "gram-négatif": ("gram-négatif",),
    "gram-négatives": ("gram-négatif",),
    "gram-positive": ("gram-positif",),
    "granaire": ("granaire",),
    "granaires": ("granaire",),
    "grand-ducale": ("grand-ducal",),
    "grand-ducales": ("grand-ducal",),
    "grand-ducal": ("grand-ducal",),
    "grand-ducaux": ("grand-ducal",),
    "grandelet": ("grandelet",),
    "grandelets": ("grandelet",),
    "grandelette": ("grandelet",),
    "grandelettes": ("grandelet",),
    "grandet": ("grandet",),
    "grandets": ("grandet",),
    "grandette": ("grandet",),
    "grandettes": ("grandet",),
    "grand-guignolesque": ("grand-guignolesque",),
    "grand-guignolesques": ("grand-guignolesque",),
    "grandiose": ("grandiose",),
    "grandioses": ("grandiose",),
    "grandissime": ("grandissime",),
    "grandissimes": ("grandissime",),
    "graniteuse": ("graniteux",),
    "graniteuses": ("graniteux",),
    "graniteux": ("graniteux",),
    "granitique": ("granitique",),
    "granitiques": ("granitique",),
    "granitoïde": ("granitoïde",),
    "granitoïdes": ("granitoïde",),
    "granivore": ("granivore",),
    "granivores": ("granivore",),
    "granoblastique": ("granoblastique",),
    "granoblastiques": ("granoblastique",),
    "granodioritique": ("granodioritique",),
    "granodioritiques": ("granodioritique",),
    "granophyrique": ("granophyrique",),
    "granophyriques": ("granophyrique",),
    "granulaire": ("granulaire",),
    "granulaires": ("granulaire",),
    "granuleuse": ("granuleux",),
    "granuleuses": ("granuleux",),
    "granuleux": ("granuleux",),
    "granulique": ("granulique",),
    "granuliques": ("granulique",),
    "granulitique": ("granulitique",),
    "granulitiques": ("granulitique",),
    "granulocytaire": ("granulocytaire",),
    "granulocytaires": ("granulocytaire",),
    "granulocytotoxique": ("granulocytotoxique",),
    "granulocytotoxiques": ("granulocytotoxique",),
    "granulomateuse": ("granulomateux",),
    "granulomateuses": ("granulomateux",),
    "granulomateux": ("granulomateux",),
    "granulométrique": ("granulométrique",),
    "granulométriques": ("granulométrique",),
    "granulopexique": ("granulopexique",),
    "granulopexiques": ("granulopexique",),
    "graphique": ("graphique",),
    "graphiques": ("graphique",),
    "graphiteuse": ("graphiteux",),
    "graphiteuses": ("graphiteux",),
    "graphiteux": ("graphiteux",),
    "graphitique": ("graphitique",),
    "graphitiques": ("graphitique",),
    "graphocinétique": ("graphocinétique",),
    "graphocinétiques": ("graphocinétique",),
    "graphologique": ("graphologique",),
    "graphologiques": ("graphologique",),
    "graphométrique": ("graphométrique",),
    "graphométriques": ("graphométrique",),
    "graphomoteur": ("graphomoteur",),
    "graphomoteurs": ("graphomoteur",),
    "graphomotrice": ("graphomoteur",),
    "graphomotrices": ("graphomoteur",),
    "grappilleur": ("grappilleur",),
    "grappilleurs": ("grappilleur",),
    "grappilleuse": ("grappilleur",),
    "grappilleuses": ("grappilleur",),
    "gras": ("gras",),
    "grasse": ("gras",),
    "grasses": ("gras",),
    "grassouillet": ("grassouillet",),
    "grassouillets": ("grassouillet",),
    "grassouillette": ("grassouillet",),
    "grassouillettes": ("grassouillet",),
    "gratteur": ("gratteur",),
    "gratteurs": ("gratteur",),
    "gratteuse": ("gratteur",),
    "gratteuses": ("gratteur",),
    "gravatif": ("gravatif",),
    "gravatifs": ("gravatif",),
    "gravative": ("gravatif",),
    "gravatives": ("gravatif",),
    "grave": ("grave",),
    "graves": ("grave",),
    "gravelée": ("gravelée",),
    "gravelées": ("gravelée",),
    "graveleuse": ("graveleux",),
    "graveleuses": ("graveleux",),
    "graveleux": ("graveleux",),
    "gravettien": ("gravettien",),
    "gravettienne": ("gravettien",),
    "gravettiennes": ("gravettien",),
    "gravettiens": ("gravettien",),
    "graveur": ("graveur",),
    "graveurs": ("graveur",),
    "graveuse": ("graveur",),
    "graveuses": ("graveur",),
    "gravide": ("gravide",),
    "gravides": ("gravide",),
    "gravidique": ("gravidique",),
    "gravidiques": ("gravidique",),
    "gravidocardiaque": ("gravidocardiaque",),
    "gravidocardiaques": ("gravidocardiaque",),
    "gravidotoxique": ("gravidotoxique",),
    "gravidotoxiques": ("gravidotoxique",),
    "gravifique": ("gravifique",),
    "gravifiques": ("gravifique",),
    "gravimétrique": ("gravimétrique",),
    "gravimétriques": ("gravimétrique",),
    "gravissime": ("gravissime",),
    "gravissimes": ("gravissime",),
    "gravitaire": ("gravitaire",),
    "gravitaires": ("gravitaire",),
    "gravitationnelle": ("gravitationnel",),
    "gravitationnelles": ("gravitationnel",),
    "gravitationnel": ("gravitationnel",),
    "gravitationnels": ("gravitationnel",),
    "grec": ("grec",),
    "grecque": ("grec",),
    "grecques": ("grec",),
    "grecs": ("grec",),
    "gréco-latine": ("gréco-latin",),
    "gréco-latin": ("gréco-latin",),
    "gréco-latins": ("gréco-latin",),
    "gréco-romaine": ("gréco-romain",),
    "gréco-romaines": ("gréco-romain",),
    "gréco-romain": ("gréco-romain",),
    "gréco-romains": ("gréco-romain",),
    "gréco-turc": ("gréco-turc",),
    "gréco-turque": ("gréco-turc",),
    "gréco-turques": ("gréco-turc",),
    "greffable": ("greffable",),
    "greffables": ("greffable",),
    "grégaire": ("grégaire",),
    "grégaires": ("grégaire",),
    "grégarigène": ("grégarigène",),
    "grégarigènes": ("grégarigène",),
    "grège": ("grège",),
    "grèges": ("grège",),
    "grégeoise": ("grégeois",),
    "grégeoises": ("grégeois",),
    "grégeois": ("grégeois",),
    "grégorien": ("grégorien",),
    "grégorienne": ("grégorien",),
    "grégoriennes": ("grégorien",),
    "grégoriens": ("grégorien",),
    "grêlée": ("grêlé",),
    "grêlées": ("grêlé",),
    "grêlé": ("grêlé",),
    "grêle": ("grêle",),
    "grêlés": ("grêlé",),
    "grêles": ("grêle",),
    "grêleuse": ("grêleux",),
    "grêleuses": ("grêleux",),
    "grêleux": ("grêleux",),
    "grenat": ("grenat",),
    "grenobloise": ("grenoblois",),
    "grenobloises": ("grenoblois",),
    "grenoblois": ("grenoblois",),
    "gréseuse": ("gréseux",),
    "gréseuses": ("gréseux",),
    "gréseux": ("gréseux",),
    "gribiche": ("gribiche",),
    "gribiches": ("gribiche",),
    "gribouilleur": ("gribouilleur",),
    "gribouilleurs": ("gribouilleur",),
    "gribouilleuse": ("gribouilleur",),
    "gribouilleuses": ("gribouilleur",),
    "grièche": ("grièche",),
    "grièches": ("grièche",),
    "griffeur": ("griffeur",),
    "griffeurs": ("griffeur",),
    "griffeuse": ("griffeur",),
    "griffeuses": ("griffeur",),
    "grignoteur": ("grignoteur",),
    "grignoteurs": ("grignoteur",),
    "grignoteuse": ("grignoteur",),
    "grignoteuses": ("grignoteur",),
    "grimacière": ("grimacier",),
    "grimacières": ("grimacier",),
    "grimacier": ("grimacier",),
    "grimaciers": ("grimacier",),
    "grimpeur": ("grimpeur",),
    "grimpeurs": ("grimpeur",),
    "grimpeuse": ("grimpeur",),
    "grimpeuses": ("grimpeur",),
    "grincheuse": ("grincheux",),
    "grincheuses": ("grincheux",),
    "grincheux": ("grincheux",),
    "gringalet": ("gringalet",),
    "gringalets": ("gringalet",),
    "gringalette": ("gringalet",),
    "gringalettes": ("gringalet",),
    "gringe": ("gringe",),
    "gringes": ("gringe",),
    "grippale": ("grippal",),
    "grippales": ("grippal",),
    "grippal": ("grippal",),
    "grippaux": ("grippal",),
    "grise": ("gris",),
    "grises": ("gris",),
    "gris": ("gris",),
    "grisâtre": ("grisâtre",),
    "grisâtres": ("grisâtre",),
    "grison": ("grison",),
    "grisonne": ("grison",),
    "grisonnes": ("grison",),
    "grisons": ("grison",),
    "grisouteuse": ("grisouteux",),
    "grisouteuses": ("grisouteux",),
    "grisouteux": ("grisouteux",),
    "grivoise": ("grivois",),
    "grivoises": ("grivois",),
    "grivois": ("grivois",),
    "groenlandaise": ("groenlandais",),
    "groenlandaises": ("groenlandais",),
    "groenlandais": ("groenlandais",),
    "groggy": ("groggy",),
    "grogneur": ("grogneur",),
    "grogneurs": ("grogneur",),
    "grogneuse": ("grogneur",),
    "grogneuses": ("grogneur",),
    "grognon": ("grognon",),
    "grognonne": ("grognon",),
    "grognonnes": ("grognon",),
    "grognons": ("grognon",),
    "grondable": ("grondable",),
    "grondables": ("grondable",),
    "grondeur": ("grondeur",),
    "grondeurs": ("grondeur",),
    "grondeuse": ("grondeur",),
    "grondeuses": ("grondeur",),
    "gros": ("gros",),
    "grosse": ("gros",),
    "grosses": ("gros",),
    "groseille": ("groseille",),
    "grossière": ("grossier",),
    "grossières": ("grossier",),
    "grossier": ("grossier",),
    "grossiers": ("grossier",),
    "grotesque": ("grotesque",),
    "grotesques": ("grotesque",),
    "groupusculaire": ("groupusculaire",),
    "groupusculaires": ("groupusculaire",),
    "grumeleuse": ("grumeleux",),
    "grumeleuses": ("grumeleux",),
    "grumeleux": ("grumeleux",),
    "grumifère": ("grumifère",),
    "grumifères": ("grumifère",),
    "grunge": ("grunge",),
    "gruyer": ("gruyer",),
    "gruyers": ("gruyer",),
    "guadeloupéen": ("guadeloupéen",),
    "guadeloupéenne": ("guadeloupéen",),
    "guadeloupéennes": ("guadeloupéen",),
    "guadeloupéens": ("guadeloupéen",),
    "guai": ("guai",),
    "guais": ("guais",),
    "guanidique": ("guanidique",),
    "guanidiques": ("guanidique",),
    "guarani": ("guarani",),
    "guaranis": ("guarani",),
    "guatemaltèque": ("guatemaltèque",),
    "guatémaltèque": ("guatémaltèque",),
    "guatemaltèques": ("guatemaltèque",),
    "guatémaltèques": ("guatémaltèque",),
    "guéable": ("guéable",),
    "guéables": ("guéable",),
    "guèbre": ("guèbre",),
    "guèbres": ("guèbre",),
    "guelfe": ("guelfe",),
    "guelfes": ("guelfe",),
    "guenilleuse": ("guenilleux",),
    "guenilleuses": ("guenilleux",),
    "guenilleux": ("guenilleux",),
    "guérissable": ("guérissable",),
    "guérissables": ("guérissable",),
    "guérisseur": ("guérisseur",),
    "guérisseurs": ("guérisseur",),
    "guérisseuse": ("guérisseur",),
    "guérisseuses": ("guérisseur",),
    "guernesiaise": ("guernesiais",),
    "guernesiaises": ("guernesiais",),
    "guernesiais": ("guernesiais",),
    "guerrière": ("guerrier",),
    "guerrières": ("guerrier",),
    "guerrier": ("guerrier",),
    "guerriers": ("guerrier",),
    "guesdiste": ("guesdiste",),
    "guesdistes": ("guesdiste",),
    "gueuse": ("gueux",),
    "gueuses": ("gueux",),
    "gueux": ("gueux",),
    "guévariste": ("guévariste",),
    "guévaristes": ("guévariste",),
    "guèze": ("guèze",),
    "guèzes": ("guèze",),
    "guignolesque": ("guignolesque",),
    "guignolesques": ("guignolesque",),
    "guilleret": ("guilleret",),
    "guillerets": ("guilleret",),
    "guillerette": ("guilleret",),
    "guillerettes": ("guilleret",),
    "guinéen": ("guinéen",),
    "guinéenne": ("guinéen",),
    "guinéennes": ("guinéen",),
    "guinéens": ("guinéen",),
    "gulaire": ("gulaire",),
    "gulaires": ("gulaire",),
    "gummifère": ("gummifère",),
    "gummifères": ("gummifère",),
    "gustatif": ("gustatif",),
    "gustatifs": ("gustatif",),
    "gustative": ("gustatif",),
    "gustatives": ("gustatif",),
    "gutturale": ("guttural",),
    "gutturales": ("guttural",),
    "guttural": ("guttural",),
    "gutturaux": ("guttural",),
    "guyanaise": ("guyanais",),
    "guyanaises": ("guyanais",),
    "guyanais": ("guyanais",),
    "gymnastique": ("gymnastique",),
    "gymnastiques": ("gymnastique",),
    "gymnique": ("gymnique",),
    "gymniques": ("gymnique",),
    "gymnocarpe": ("gymnocarpe",),
    "gymnocarpes": ("gymnocarpe",),
    "gymnopile": ("gymnopile",),
    "gymnopiles": ("gymnopile",),
    "gymnosperme": ("gymnosperme",),
    "gymnospermes": ("gymnosperme",),
    "gynandre": ("gynandre",),
    "gynandres": ("gynandre",),
    "gynandroïde": ("gynandroïde",),
    "gynandroïdes": ("gynandroïde",),
    "gynécologique": ("gynécologique",),
    "gynécologiques": ("gynécologique",),
    "gynobasique": ("gynobasique",),
    "gynobasiques": ("gynobasique",),
    "gynocardique": ("gynocardique",),
    "gynocardiques": ("gynocardique",),
    "gynogénétique": ("gynogénétique",),
    "gynogénétiques": ("gynogénétique",),
    "gynoïde": ("gynoïde",),
    "gynoïdes": ("gynoïde",),
    "gypseuse": ("gypseux",),
    "gypseuses": ("gypseux",),
    "gypseux": ("gypseux",),
    "gypsifère": ("gypsifère",),
    "gypsifères": ("gypsifère",),
    "gypsitique": ("gypsitique",),
    "gypsitiques": ("gypsitique",),
    "gyromagnétique": ("gyromagnétique",),
    "gyromagnétiques": ("gyromagnétique",),
    "gyroscopique": ("gyroscopique",),
    "gyroscopiques": ("gyroscopique",),
    "gyrostatique": ("gyrostatique",),
    "gyrostatiques": ("gyrostatique",),
    "gyrovague": ("gyrovague",),
    "gyrovagues": ("gyrovague",),
    "habile": ("habile",),
    "habiles": ("habile",),
    "habilis": ("habilis",),
    "habilitateur": ("habilitateur",),
    "habilitateurs": ("habilitateur",),
    "habilitatrice": ("habilitateur",),
    "habilitatrices": ("habilitateur",),
    "habillable": ("habillable",),
    "habillables": ("habillable",),
    "habitable": ("habitable",),
    "habitables": ("habitable",),
    "habituelle": ("habituel",),
    "habituelles": ("habituel",),
    "habituel": ("habituel",),
    "habituels": ("habituel",),
    "hâbleur": ("hâbleur",),
    "hâbleurs": ("hâbleur",),
    "hâbleuse": ("hâbleur",),
    "hâbleuses": ("hâbleur",),
    "haboku": ("haboku",),
    "hachémite": ("hachémite",),
    "hachémites": ("hachémite",),
    "hadale": ("hadal",),
    "hadales": ("hadal",),
    "hadal": ("hadal",),
    "hadaux": ("hadal",),
    "hadronique": ("hadronique",),
    "hadroniques": ("hadronique",),
    "hafside": ("hafside",),
    "hafsides": ("hafside",),
    "hagiographe": ("hagiographe",),
    "hagiographes": ("hagiographe",),
    "hagiographique": ("hagiographique",),
    "hagiographiques": ("hagiographique",),
    "hagiologique": ("hagiologique",),
    "hagiologiques": ("hagiologique",),
    "hagiorite": ("hagiorite",),
    "hagiorites": ("hagiorite",),
    "haguaise": ("haguais",),
    "haguaises": ("haguais",),
    "haguais": ("haguais",),
    "haillonneuse": ("haillonneux",),
    "haillonneuses": ("haillonneux",),
    "haillonneux": ("haillonneux",),
    "haineuse": ("haineux",),
    "haineuses": ("haineux",),
    "haineux": ("haineux",),
    "hainuyère": ("hainuyer",),
    "hainuyères": ("hainuyer",),
    "hainuyer": ("hainuyer",),
    "hainuyers": ("hainuyer",),
    "haïssable": ("haïssable",),
    "haïssables": ("haïssable",),
    "haïsseur": ("haïsseur",),
    "haïsseurs": ("haïsseur",),
    "haïsseuse": ("haïsseur",),
    "haïsseuses": ("haïsseur",),
    "haïtien": ("haïtien",),
    "haïtienne": ("haïtien",),
    "haïtiennes": ("haïtien",),
    "haïtiens": ("haïtien",),
    "halal": ("halal",),
    "halieutique": ("halieutique",),
    "halieutiques": ("halieutique",),
    "halistérique": ("halistérique",),
    "halistériques": ("halistérique",),
    "halitueuse": ("halitueux",),
    "halitueuses": ("halitueux",),
    "halitueux": ("halitueux",),
    "hallstattien": ("hallstattien",),
    "hallstattienne": ("hallstattien",),
    "hallstattiennes": ("hallstattien",),
    "hallstattiens": ("hallstattien",),
    "hallucinatoire": ("hallucinatoire",),
    "hallucinatoires": ("hallucinatoire",),
    "hallucinogène": ("hallucinogène",),
    "hallucinogènes": ("hallucinogène",),
    "hallucinolytique": ("hallucinolytique",),
    "hallucinolytiques": ("hallucinolytique",),
    "halogénée": ("halogéné",),
    "halogénées": ("halogéné",),
    "halogéné": ("halogéné",),
    "halogène": ("halogène",),
    "halogénés": ("halogéné",),
    "halogènes": ("halogène",),
    "haloïde": ("haloïde",),
    "haloïdes": ("haloïde",),
    "halomorphe": ("halomorphe",),
    "halomorphes": ("halomorphe",),
    "halophile": ("halophile",),
    "halophiles": ("halophile",),
    "halophyte": ("halophyte",),
    "halophytes": ("halophyte",),
    "haltérophile": ("haltérophile",),
    "haltérophiles": ("haltérophile",),
    "hambourgeoise": ("hambourgeois",),
    "hambourgeoises": ("hambourgeois",),
    "hambourgeois": ("hambourgeois",),
    "hambourgien": ("hambourgien",),
    "hambourgienne": ("hambourgien",),
    "hambourgiennes": ("hambourgien",),
    "hambourgiens": ("hambourgien",),
    "hamiltonien": ("hamiltonien",),
    "hamiltonienne": ("hamiltonien",),
    "hamiltoniennes": ("hamiltonien",),
    "hamiltoniens": ("hamiltonien",),
    "hamitique": ("hamitique",),
    "hamitiques": ("hamitique",),
    "hamlétien": ("hamlétien",),
    "hamlétienne": ("hamlétien",),
    "hamlétiennes": ("hamlétien",),
    "hamlétiens": ("hamlétien",),
    "hanafite": ("hanafite",),
    "hanafites": ("hanafite",),
    "hanbalite": ("hanbalite",),
    "hanbalites": ("hanbalite",),
    "handisport": ("handisport",),
    "hanifite": ("hanifite",),
    "hanifites": ("hanifite",),
    "hannemannien": ("hannemannien",),
    "hannemannienne": ("hannemannien",),
    "hannemanniennes": ("hannemannien",),
    "hannemanniens": ("hannemannien",),
    "hanovrien": ("hanovrien",),
    "hanovrienne": ("hanovrien",),
    "hanovriennes": ("hanovrien",),
    "hanovriens": ("hanovrien",),
    "hanséate": ("hanséate",),
    "hanséates": ("hanséate",),
    "hanséatique": ("hanséatique",),
    "hanséatiques": ("hanséatique",),
    "hansénien": ("hansénien",),
    "hansénienne": ("hansénien",),
    "hanséniennes": ("hansénien",),
    "hanséniens": ("hansénien",),
    "haoussa": ("haoussa",),
    "haoussas": ("haoussa",),
    "haphémétrique": ("haphémétrique",),
    "haphémétriques": ("haphémétrique",),
    "haplobiontique": ("haplobiontique",),
    "haplobiontiques": ("haplobiontique",),
    "haplodiplobiontique": ("haplodiplobiontique",),
    "haplodiplobiontiques": ("haplodiplobiontique",),
    "haploïde": ("haploïde",),
    "haploïdes": ("haploïde",),
    "happeur": ("happeur",),
    "happeurs": ("happeur",),
    "hapténique": ("hapténique",),
    "hapténiques": ("hapténique",),
    "haptique": ("haptique",),
    "haptiques": ("haptique",),
    "haptophore": ("haptophore",),
    "haptophores": ("haptophore",),
    "harappéen": ("harappéen",),
    "harappéenne": ("harappéen",),
    "harappéennes": ("harappéen",),
    "harappéens": ("harappéen",),
    "harceleur": ("harceleur",),
    "harceleurs": ("harceleur",),
    "harceleuse": ("harceleur",),
    "harceleuses": ("harceleur",),
    "hard": ("hard",),
    "hardcore": ("hardcore",),
    "hardé": ("hardé",),
    "hardés": ("hardé",),
    "haret": ("haret",),
    "harets": ("haret",),
    "hargneuse": ("hargneux",),
    "hargneuses": ("hargneux",),
    "hargneux": ("hargneux",),
    "harmonieuse": ("harmonieux",),
    "harmonieuses": ("harmonieux",),
    "harmonieux": ("harmonieux",),
    "harmonique": ("harmonique",),
    "harmoniques": ("harmonique",),
    "harmonisateur": ("harmonisateur",),
    "harmonisateurs": ("harmonisateur",),
    "harmonisatrice": ("harmonisateur",),
    "harmonisatrices": ("harmonisateur",),
    "hasardeuse": ("hasardeux",),
    "hasardeuses": ("hasardeux",),
    "hasardeux": ("hasardeux",),
    "hassidique": ("hassidique",),
    "hassidiques": ("hassidique",),
    "hathorique": ("hathorique",),
    "hathoriques": ("hathorique",),
    "hâtif": ("hâtif",),
    "hâtifs": ("hâtif",),
    "hâtive": ("hâtif",),
    "hâtives": ("hâtif",),
    "haugianiste": ("haugianiste",),
    "haugianistes": ("haugianiste",),
    "hauranaise": ("hauranais",),
    "hauranaises": ("hauranais",),
    "hauranais": ("hauranais",),
    "haussière": ("haussier",),
    "haussières": ("haussier",),
    "haussier": ("haussier",),
    "haussiers": ("haussier",),
    "haustrale": ("haustral",),
    "haustrales": ("haustral",),
    "haustral": ("haustral",),
    "haustraux": ("haustral",),
    "hauterivien": ("hauterivien",),
    "hauterivienne": ("hauterivien",),
    "hauteriviennes": ("hauterivien",),
    "hauteriviens": ("hauterivien",),
    "hauturière": ("hauturier",),
    "hauturières": ("hauturier",),
    "hauturier": ("hauturier",),
    "hauturiers": ("hauturier",),
    "havanaise": ("havanais",),
    "havanaises": ("havanais",),
    "havanais": ("havanais",),
    "havane": ("havane",),
    "hâve": ("hâve",),
    "hâves": ("hâve",),
    "haveur": ("haveur",),
    "haveurs": ("haveur",),
    "haveuse": ("haveur",),
    "haveuses": ("haveur",),
    "havraise": ("havrais",),
    "havraises": ("havrais",),
    "havrais": ("havrais",),
    "hawaïen": ("hawaïen",),
    "hawaïenne": ("hawaïen",),
    "hawaïennes": ("hawaïen",),
    "hawaïens": ("hawaïen",),
    "hawaiien": ("hawaiien",),
    "hawaiienne": ("hawaiien",),
    "hawaiiennes": ("hawaiien",),
    "hawaiiens": ("hawaiien",),
    "hawiyé": ("hawiyé",),
    "hawiyés": ("hawiyé",),
    "hebdomadaire": ("hebdomadaire",),
    "hebdomadaires": ("hebdomadaire",),
    "hébéphrène": ("hébéphrène",),
    "hébéphrènes": ("hébéphrène",),
    "hébéphrénique": ("hébéphrénique",),
    "hébéphréniques": ("hébéphrénique",),
    "hébertiste": ("hébertiste",),
    "hébertistes": ("hébertiste",),
    "héboïdophrène": ("héboïdophrène",),
    "héboïdophrènes": ("héboïdophrène",),
    "hébraïque": ("hébreu",),
    "hébraïques": ("hébreu",),
    "hébréophone": ("hébréophone",),
    "hébréophones": ("hébréophone",),
    "hébreu": ("hébreu",),
    "hébreux": ("hébreu",),
    "hécatomère": ("hécatomère",),
    "hécatomères": ("hécatomère",),
    "hécatonstyle": ("hécatonstyle",),
    "hécatonstyles": ("hécatonstyle",),
    "hectique": ("hectique",),
    "hectiques": ("hectique",),
    "hectographique": ("hectographique",),
    "hectographiques": ("hectographique",),
    "hectométrique": ("hectométrique",),
    "hectométriques": ("hectométrique",),
    "hédonique": ("hédonique",),
    "hédoniques": ("hédonique",),
    "hédoniste": ("hédoniste",),
    "hédonistes": ("hédoniste",),
    "hédonistique": ("hédonistique",),
    "hédonistiques": ("hédonistique",),
    "hégélien": ("hégélien",),
    "hégélienne": ("hégélien",),
    "hégéliennes": ("hégélien",),
    "hégéliens": ("hégélien",),
    "hégémonique": ("hégémonique",),
    "hégémoniques": ("hégémonique",),
    "hégémoniste": ("hégémoniste",),
    "hégémonistes": ("hégémoniste",),
    "heideggérien": ("heideggérien",),
    "heideggérienne": ("heideggérien",),
    "heideggériennes": ("heideggérien",),
    "heideggériens": ("heideggérien",),
    "heimatlos": ("heimatlos",),
    "héliaque": ("héliaque",),
    "héliaques": ("héliaque",),
    "héliciforme": ("héliciforme",),
    "héliciformes": ("héliciforme",),
    "hélicitique": ("hélicitique",),
    "hélicitiques": ("hélicitique",),
    "hélicocentrifuge": ("hélicocentrifuge",),
    "hélicocentrifuges": ("hélicocentrifuge",),
    "hélicocentripète": ("hélicocentripète",),
    "hélicocentripètes": ("hélicocentripète",),
    "hélicoïdale": ("hélicoïdal",),
    "hélicoïdales": ("hélicoïdal",),
    "hélicoïdal": ("hélicoïdal",),
    "hélicoïdaux": ("hélicoïdal",),
    "hélicoïde": ("hélicoïde",),
    "hélicoïdes": ("hélicoïde",),
    "hélicopode": ("hélicopode",),
    "hélicopodes": ("hélicopode",),
    "héliocentrique": ("héliocentrique",),
    "héliocentriques": ("héliocentrique",),
    "héliocentriste": ("héliocentriste",),
    "héliocentristes": ("héliocentriste",),
    "hélioélectrique": ("hélioélectrique",),
    "hélioélectriques": ("hélioélectrique",),
    "héliofuge": ("héliofuge",),
    "héliofuges": ("héliofuge",),
    "héliographique": ("héliographique",),
    "héliographiques": ("héliographique",),
    "héliophile": ("héliophile",),
    "héliophiles": ("héliophile",),
    "héliophobe": ("héliophobe",),
    "héliophobes": ("héliophobe",),
    "héliophysique": ("héliophysique",),
    "héliophysiques": ("héliophysique",),
    "héliosynchrone": ("héliosynchrone",),
    "héliosynchrones": ("héliosynchrone",),
    "héliotechnique": ("héliotechnique",),
    "héliotechniques": ("héliotechnique",),
    "héliothérapique": ("héliothérapique",),
    "héliothérapiques": ("héliothérapique",),
    "héliothermique": ("héliothermique",),
    "héliothermiques": ("héliothermique",),
    "héliothermodynamique": ("héliothermodynamique",),
    "héliothermodynamiques": ("héliothermodynamique",),
    "héliotropique": ("héliotropique",),
    "héliotropiques": ("héliotropique",),
    "helladique": ("helladique",),
    "helladiques": ("helladique",),
    "hellène": ("hellène",),
    "hellènes": ("hellène",),
    "hellénique": ("hellénique",),
    "helléniques": ("hellénique",),
    "hellénistique": ("hellénistique",),
    "hellénistiques": ("hellénistique",),
    "hellénophone": ("hellénophone",),
    "hellénophones": ("hellénophone",),
    "helminthique": ("helminthique",),
    "helminthiques": ("helminthique",),
    "helminthoïde": ("helminthoïde",),
    "helminthoïdes": ("helminthoïde",),
    "helvéolée": ("helvéolée",),
    "helvéolées": ("helvéolée",),
    "helvète": ("helvète",),
    "helvètes": ("helvète",),
    "helvétien": ("helvétien",),
    "helvétienne": ("helvétien",),
    "helvétiennes": ("helvétien",),
    "helvétiens": ("helvétien",),
    "helvétique": ("helvétique",),
    "helvétiques": ("helvétique",),
    "hémale": ("hémal",),
    "hémales": ("hémal",),
    "hémal": ("hémal",),
    "hémaux": ("hémal",),
    "hématimétrique": ("hématimétrique",),
    "hématimétriques": ("hématimétrique",),
    "hématique": ("hématique",),
    "hématiques": ("hématique",),
    "hématoblastique": ("hématoblastique",),
    "hématoblastiques": ("hématoblastique",),
    "hématode": ("hématode",),
    "hématodes": ("hématode",),
    "hématogène": ("hématogène",),
    "hématogènes": ("hématogène",),
    "hématologique": ("hématologique",),
    "hématologiques": ("hématologique",),
    "hématophage": ("hématophage",),
    "hématophages": ("hématophage",),
    "hématopoïétique": ("hématopoïétique",),
    "hématopoïétiques": ("hématopoïétique",),
    "hématurique": ("hématurique",),
    "hématuriques": ("hématurique",),
    "héméralope": ("héméralope",),
    "héméralopes": ("héméralope",),
    "héméralopique": ("héméralopique",),
    "héméralopiques": ("héméralopique",),
    "hémérologique": ("hémérologique",),
    "hémérologiques": ("hémérologique",),
    "héméropériodique": ("héméropériodique",),
    "héméropériodiques": ("héméropériodique",),
    "hémiangiocarpe": ("hémiangiocarpe",),
    "hémiangiocarpes": ("hémiangiocarpe",),
    "hémianopsique": ("hémianopsique",),
    "hémianopsiques": ("hémianopsique",),
    "hémiballique": ("hémiballique",),
    "hémiballiques": ("hémiballique",),
    "hémicéphale": ("hémicéphale",),
    "hémicéphales": ("hémicéphale",),
    "hémicylindrique": ("hémicylindrique",),
    "hémicylindriques": ("hémicylindrique",),
    "hémièdre": ("hémièdre",),
    "hémièdres": ("hémièdre",),
    "hémiédrique": ("hémiédrique",),
    "hémiédriques": ("hémiédrique",),
    "hémifaciale": ("hémifacial",),
    "hémifaciales": ("hémifacial",),
    "hémifacial": ("hémifacial",),
    "hémifaciaux": ("hémifacial",),
    "hémimellitique": ("hémimellitique",),
    "hémimellitiques": ("hémimellitique",),
    "héminique": ("héminique",),
    "héminiques": ("héminique",),
    "hémiopique": ("hémiopique",),
    "hémiopiques": ("hémiopique",),
    "hémiparétique": ("hémiparétique",),
    "hémiparétiques": ("hémiparétique",),
    "hémiparkinsonien": ("hémiparkinsonien",),
    "hémiparkinsonienne": ("hémiparkinsonien",),
    "hémiparkinsoniennes": ("hémiparkinsonien",),
    "hémiparkinsoniens": ("hémiparkinsonien",),
    "hémiperméable": ("hémiperméable",),
    "hémiperméables": ("hémiperméable",),
    "hémiphone": ("hémiphone",),
    "hémiphones": ("hémiphone",),
    "hémiplégique": ("hémiplégique",),
    "hémiplégiques": ("hémiplégique",),
    "hémipneustique": ("hémipneustique",),
    "hémipneustiques": ("hémipneustique",),
    "hémisphérique": ("hémisphérique",),
    "hémisphériques": ("hémisphérique",),
    "hémizygote": ("hémizygote",),
    "hémizygotes": ("hémizygote",),
    "hémochoriale": ("hémochorial",),
    "hémochoriales": ("hémochorial",),
    "hémochorial": ("hémochorial",),
    "hémochoriaux": ("hémochorial",),
    "hémochromogène": ("hémochromogène",),
    "hémochromogènes": ("hémochromogène",),
    "hémocompatible": ("hémocompatible",),
    "hémocompatibles": ("hémocompatible",),
    "hémodynamique": ("hémodynamique",),
    "hémodynamiques": ("hémodynamique",),
    "hémoendothéliale": ("hémoendothélial",),
    "hémoendothéliales": ("hémoendothélial",),
    "hémoendothélial": ("hémoendothélial",),
    "hémoendothéliaux": ("hémoendothélial",),
    "hémoglobinique": ("hémoglobinique",),
    "hémoglobiniques": ("hémoglobinique",),
    "hémoglobinurique": ("hémoglobinurique",),
    "hémoglobinuriques": ("hémoglobinurique",),
    "hémohistioblastique": ("hémohistioblastique",),
    "hémohistioblastiques": ("hémohistioblastique",),
    "hémoleucocytaire": ("hémoleucocytaire",),
    "hémoleucocytaires": ("hémoleucocytaire",),
    "hémolysinique": ("hémolysinique",),
    "hémolysiniques": ("hémolysinique",),
    "hémolytique": ("hémolytique",),
    "hémolytiques": ("hémolytique",),
    "hémopathique": ("hémopathique",),
    "hémopathiques": ("hémopathique",),
    "hémophagocytaire": ("hémophagocytaire",),
    "hémophagocytaires": ("hémophagocytaire",),
    "hémophile": ("hémophile",),
    "hémophiles": ("hémophile",),
    "hémophilique": ("hémophilique",),
    "hémophiliques": ("hémophilique",),
    "hémophiloïde": ("hémophiloïde",),
    "hémophiloïdes": ("hémophiloïde",),
    "hémopiésique": ("hémopiésique",),
    "hémopiésiques": ("hémopiésique",),
    "hémopoïétique": ("hémopoïétique",),
    "hémopoïétiques": ("hémopoïétique",),
    "hémoptoïque": ("hémoptoïque",),
    "hémoptoïques": ("hémoptoïque",),
    "hémoptysique": ("hémoptysique",),
    "hémoptysiques": ("hémoptysique",),
    "hémorragipare": ("hémorragipare",),
    "hémorragipares": ("hémorragipare",),
    "hémorragique": ("hémorragique",),
    "hémorragiques": ("hémorragique",),
    "hémorroïdaire": ("hémorroïdaire",),
    "hémorroïdaires": ("hémorroïdaire",),
    "hémorroïdale": ("hémorroïdal",),
    "hémorroïdales": ("hémorroïdal",),
    "hémorroïdal": ("hémorroïdal",),
    "hémorroïdaux": ("hémorroïdal",),
    "hémostatique": ("hémostatique",),
    "hémostatiques": ("hémostatique",),
    "hémotrope": ("hémotrope",),
    "hémotropes": ("hémotrope",),
    "hémotypologique": ("hémotypologique",),
    "hémotypologiques": ("hémotypologique",),
    "hendécagonale": ("hendécagonal",),
    "hendécagonales": ("hendécagonal",),
    "hendécagonal": ("hendécagonal",),
    "hendécagonaux": ("hendécagonal",),
    "hendécasyllabe": ("hendécasyllabe",),
    "hendécasyllabes": ("hendécasyllabe",),
    "hennuyère": ("hennuyer",),
    "hennuyères": ("hennuyer",),
    "hennuyer": ("hennuyer",),
    "hennuyers": ("hennuyer",),
    "hépatique": ("hépatique",),
    "hépatiques": ("hépatique",),
    "hépatitique": ("hépatitique",),
    "hépatitiques": ("hépatitique",),
    "hépato-biliaire": ("hépato-biliaire",),
    "hépatobiliaire": ("hépatobiliaire",),
    "hépato-biliaires": ("hépato-biliaire",),
    "hépatobiliaires": ("hépatobiliaire",),
    "hépatocellulaire": ("hépatocellulaire",),
    "hépatocellulaires": ("hépatocellulaire",),
    "hépatocytaire": ("hépatocytaire",),
    "hépatocytaires": ("hépatocytaire",),
    "hépatodiaphragmatique": ("hépatodiaphragmatique",),
    "hépatodiaphragmatiques": ("hépatodiaphragmatique",),
    "hépatogène": ("hépatogène",),
    "hépatogènes": ("hépatogène",),
    "hépatolenticulaire": ("hépatolenticulaire",),
    "hépatolenticulaires": ("hépatolenticulaire",),
    "hépatolytique": ("hépatolytique",),
    "hépatolytiques": ("hépatolytique",),
    "hépatorénale": ("hépatorénal",),
    "hépatorénales": ("hépatorénal",),
    "hépatorénal": ("hépatorénal",),
    "hépatorénaux": ("hépatorénal",),
    "hépatosplénomégalique": ("hépatosplénomégalique",),
    "hépatosplénomégaliques": ("hépatosplénomégalique",),
    "hépato-toxique": ("hépato-toxique",),
    "hépatotoxique": ("hépatotoxique",),
    "hépatotoxiques": ("hépatotoxique",),
    "hépatotrope": ("hépatotrope",),
    "hépatotropes": ("hépatotrope",),
    "hépato-vésiculaires": ("hépato-vésiculaire",),
    "hephthémimère": ("hephthémimère",),
    "hephthémimères": ("hephthémimère",),
    "heptacorde": ("heptacorde",),
    "heptacordes": ("heptacorde",),
    "heptaèdre": ("heptaèdre",),
    "heptaèdres": ("heptaèdre",),
    "heptaédrique": ("heptaédrique",),
    "heptaédriques": ("heptaédrique",),
    "heptagonale": ("heptagonal",),
    "heptagonales": ("heptagonal",),
    "heptagonal": ("heptagonal",),
    "heptagonaux": ("heptagonal",),
    "heptamètre": ("heptamètre",),
    "heptamètres": ("heptamètre",),
    "heptanoïque": ("heptanoïque",),
    "heptanoïques": ("heptanoïque",),
    "heptarchique": ("heptarchique",),
    "heptarchiques": ("heptarchique",),
    "heptasyllabe": ("heptasyllabe",),
    "heptasyllabes": ("heptasyllabe",),
    "heptatubulaire": ("heptatubulaire",),
    "heptatubulaires": ("heptatubulaire",),
    "heptylique": ("heptylique",),
    "heptyliques": ("heptylique",),
    "heptynecarboxylique": ("heptynecarboxylique",),
    "heptynecarboxyliques": ("heptynecarboxylique",),
    "héraldique": ("héraldique",),
    "héraldiques": ("héraldique",),
    "herbagère": ("herbager",),
    "herbagères": ("herbager",),
    "herbager": ("herbager",),
    "herbagers": ("herbager",),
    "herbeuse": ("herbeux",),
    "herbeuses": ("herbeux",),
    "herbeux": ("herbeux",),
    "herbicide": ("herbicide",),
    "herbicides": ("herbicide",),
    "herbivore": ("herbivore",),
    "herbivores": ("herbivore",),
    "herculéen": ("herculéen",),
    "herculéenne": ("herculéen",),
    "herculéennes": ("herculéen",),
    "herculéens": ("herculéen",),
    "hercynien": ("hercynien",),
    "hercynienne": ("hercynien",),
    "hercyniennes": ("hercynien",),
    "hercyniens": ("hercynien",),
    "héréditaire": ("héréditaire",),
    "héréditaires": ("héréditaire",),
    "héréditariste": ("héréditariste",),
    "héréditaristes": ("héréditariste",),
    "hérédo": ("hérédo",),
    "hérédos": ("hérédo",),
    "hérédosyphilitique": ("hérédosyphilitique",),
    "hérédosyphilitiques": ("hérédosyphilitique",),
    "hereford": ("hereford",),
    "hérétique": ("hérétique",),
    "hérétiques": ("hérétique",),
    "hérissonne": ("hérissonne",),
    "hérissonnes": ("hérissonne",),
    "héritable": ("héritable",),
    "héritables": ("héritable",),
    "héritière": ("héritier",),
    "héritières": ("héritier",),
    "héritier": ("héritier",),
    "héritiers": ("héritier",),
    "hermaphrodite": ("hermaphrodite",),
    "hermaphrodites": ("hermaphrodite",),
    "herméneutique": ("herméneutique",),
    "herméneutiques": ("herméneutique",),
    "hermétique": ("hermétique",),
    "hermétiques": ("hermétique",),
    "hermétiste": ("hermétiste",),
    "hermétistes": ("hermétiste",),
    "hermitien": ("hermitien",),
    "hermitienne": ("hermitien",),
    "hermitiennes": ("hermitien",),
    "hermitiens": ("hermitien",),
    "hermitique": ("hermitique",),
    "hermitiques": ("hermitique",),
    "herniaire": ("herniaire",),
    "herniaires": ("herniaire",),
    "hernieuse": ("hernieux",),
    "hernieuses": ("hernieux",),
    "hernieux": ("hernieux",),
    "héroïnomane": ("héroïnomane",),
    "héroïnomanes": ("héroïnomane",),
    "héroïque": ("héroïque",),
    "héroïques": ("héroïque",),
    "héronnière": ("héronnier",),
    "héronnières": ("héronnier",),
    "héronnier": ("héronnier",),
    "héronniers": ("héronnier",),
    "herpétiforme": ("herpétiforme",),
    "herpétiformes": ("herpétiforme",),
    "herpétique": ("herpétique",),
    "herpétiques": ("herpétique",),
    "herpétologique": ("herpétologique",),
    "herpétologiques": ("herpétologique",),
    "herseur": ("herseur",),
    "herseurs": ("herseur",),
    "herseuse": ("herseur",),
    "herseuses": ("herseur",),
    "hertzien": ("hertzien",),
    "hertzienne": ("hertzien",),
    "hertziennes": ("hertzien",),
    "hertziens": ("hertzien",),
    "hespérétinique": ("hespérétinique",),
    "hespérétiniques": ("hespérétinique",),
    "hessoise": ("hessois",),
    "hessoises": ("hessois",),
    "hessois": ("hessois",),
    "hésychaste": ("hésychaste",),
    "hésychastes": ("hésychaste",),
    "hétéradelphe": ("hétéradelphe",),
    "hétéradelphes": ("hétéradelphe",),
    "hétéralien": ("hétéralien",),
    "hétéralienne": ("hétéralien",),
    "hétéraliennes": ("hétéralien",),
    "hétéraliens": ("hétéralien",),
    "hétéro": ("hétéro",),
    "hétéros": ("hétéro",),
    "hétéroatomique": ("hétéroatomique",),
    "hétéroatomiques": ("hétéroatomique",),
    "hétéroblastique": ("hétéroblastique",),
    "hétéroblastiques": ("hétéroblastique",),
    "hétérocaryote": ("hétérocaryote",),
    "hétérocaryotes": ("hétérocaryote",),
    "hétérocentrique": ("hétérocentrique",),
    "hétérocentriques": ("hétérocentrique",),
    "hétérocerque": ("hétérocerque",),
    "hétérocerques": ("hétérocerque",),
    "hétérochromatique": ("hétérochromatique",),
    "hétérochromatiques": ("hétérochromatique",),
    "hétérochrome": ("hétérochrome",),
    "hétérochromes": ("hétérochrome",),
    "hétérochrone": ("hétérochrone",),
    "hétérochrones": ("hétérochrone",),
    "hétéroclite": ("hétéroclite",),
    "hétéroclites": ("hétéroclite",),
    "hétérocyclique": ("hétérocyclique",),
    "hétérocycliques": ("hétérocyclique",),
    "hétérocytotrope": ("hétérocytotrope",),
    "hétérocytotropes": ("hétérocytotrope",),
    "hétérodonte": ("hétérodonte",),
    "hétérodontes": ("hétérodonte",),
    "hétérodoxe": ("hétérodoxe",),
    "hétérodoxes": ("hétérodoxe",),
    "hétérodrome": ("hétérodrome",),
    "hétérodromes": ("hétérodrome",),
    "hétérodyme": ("hétérodyme",),
    "hétérodymes": ("hétérodyme",),
    "hétérodyname": ("hétérodyname",),
    "hétérodynames": ("hétérodyname",),
    "hétérodyne": ("hétérodyne",),
    "hétérodynes": ("hétérodyne",),
    "hétérofibre": ("hétérofibre",),
    "hétérofibres": ("hétérofibre",),
    "hétérogamétique": ("hétérogamétique",),
    "hétérogamétiques": ("hétérogamétique",),
    "hétérogène": ("hétérogène",),
    "hétérogènes": ("hétérogène",),
    "hétérograde": ("hétérograde",),
    "hétérogrades": ("hétérograde",),
    "hétérogyne": ("hétérogyne",),
    "hétérogynes": ("hétérogyne",),
    "hétéroïque": ("hétéroïque",),
    "hétéroïques": ("hétéroïque",),
    "hétérolécithe": ("hétérolécithe",),
    "hétérolécithes": ("hétérolécithe",),
    "hétérologique": ("hétérologique",),
    "hétérologiques": ("hétérologique",),
    "hétérologue": ("hétérologue",),
    "hétérologues": ("hétérologue",),
    "hétérolytique": ("hétérolytique",),
    "hétérolytiques": ("hétérolytique",),
    "hétéromère": ("hétéromère",),
    "hétéromères": ("hétéromère",),
    "hétérométabole": ("hétérométabole",),
    "hétérométaboles": ("hétérométabole",),
    "hétérométrique": ("hétérométrique",),
    "hétérométriques": ("hétérométrique",),
    "hétéromorphe": ("hétéromorphe",),
    "hétéromorphes": ("hétéromorphe",),
    "hétéronome": ("hétéronome",),
    "hétéronomes": ("hétéronome",),
    "hétéronucléaire": ("hétéronucléaire",),
    "hétéronucléaires": ("hétéronucléaire",),
    "hétéronyme": ("hétéronyme",),
    "hétéronymes": ("hétéronyme",),
    "hétéropage": ("hétéropage",),
    "hétéropages": ("hétéropage",),
    "hétérophasique": ("hétérophasique",),
    "hétérophasiques": ("hétérophasique",),
    "hétérophile": ("hétérophile",),
    "hétérophiles": ("hétérophile",),
    "hétérophone": ("hétérophone",),
    "hétérophones": ("hétérophone",),
    "hétérophonique": ("hétérophonique",),
    "hétérophoniques": ("hétérophonique",),
    "hétérophytique": ("hétérophytique",),
    "hétérophytiques": ("hétérophytique",),
    "hétéropique": ("hétéropique",),
    "hétéropiques": ("hétéropique",),
    "hétéroplastique": ("hétéroplastique",),
    "hétéroplastiques": ("hétéroplastique",),
    "hétéroploïde": ("hétéroploïde",),
    "hétéroploïdes": ("hétéroploïde",),
    "hétéropolaire": ("hétéropolaire",),
    "hétéropolaires": ("hétéropolaire",),
    "hétéropycnotique": ("hétéropycnotique",),
    "hétéropycnotiques": ("hétéropycnotique",),
    "hétérorgane": ("hétérorgane",),
    "hétérorganes": ("hétérorgane",),
    "hétérorganique": ("hétérorganique",),
    "hétérorganiques": ("hétérorganique",),
    "hétérorythmique": ("hétérorythmique",),
    "hétérorythmiques": ("hétérorythmique",),
    "hétérosensorielle": ("hétérosensoriel",),
    "hétérosensorielles": ("hétérosensoriel",),
    "hétérosensoriel": ("hétérosensoriel",),
    "hétérosensoriels": ("hétérosensoriel",),
    "hétérosexuelle": ("hétérosexuel",),
    "hétérosexuelles": ("hétérosexuel",),
    "hétérosexuel": ("hétérosexuel",),
    "hétérosexuels": ("hétérosexuel",),
    "hétérospécifique": ("hétérospécifique",),
    "hétérospécifiques": ("hétérospécifique",),
    "hétérosynaptique": ("hétérosynaptique",),
    "hétérosynaptiques": ("hétérosynaptique",),
    "hétérothallique": ("hétérothallique",),
    "hétérothalliques": ("hétérothallique",),
    "hétérotherme": ("hétérotherme",),
    "hétérothermes": ("hétérotherme",),
    "hétérotope": ("hétérotope",),
    "hétérotopes": ("hétérotope",),
    "hétérotopique": ("hétérotopique",),
    "hétérotopiques": ("hétérotopique",),
    "hétérotrophe": ("hétérotrophe",),
    "hétérotrophes": ("hétérotrophe",),
    "hétérotype": ("hétérotype",),
    "hétérotypes": ("hétérotype",),
    "hétérotypien": ("hétérotypien",),
    "hétérotypienne": ("hétérotypien",),
    "hétérotypiennes": ("hétérotypien",),
    "hétérotypiens": ("hétérotypien",),
    "hétérotypique": ("hétérotypique",),
    "hétérotypiques": ("hétérotypique",),
    "hétéroxène": ("hétéroxène",),
    "hétéroxènes": ("hétéroxène",),
    "hétérozygote": ("hétérozygote",),
    "hétérozygotes": ("hétérozygote",),
    "heureuse": ("heureux",),
    "heureuses": ("heureux",),
    "heureux": ("heureux",),
    "heuristique": ("heuristique",),
    "heuristiques": ("heuristique",),
    "hexadactyle": ("hexadactyle",),
    "hexadactyles": ("hexadactyle",),
    "hexadécanoïque": ("hexadécanoïque",),
    "hexadécanoïques": ("hexadécanoïque",),
    "hexadécimale": ("hexadécimal",),
    "hexadécimales": ("hexadécimal",),
    "hexadécimal": ("hexadécimal",),
    "hexadécimaux": ("hexadécimal",),
    "hexadentate": ("hexadentate",),
    "hexadentates": ("hexadentate",),
    "hexadiénoïque": ("hexadiénoïque",),
    "hexadiénoïques": ("hexadiénoïque",),
    "hexaèdre": ("hexaèdre",),
    "hexaèdres": ("hexaèdre",),
    "hexaédrique": ("hexaédrique",),
    "hexaédriques": ("hexaédrique",),
    "hexagonale": ("hexagonal",),
    "hexagonales": ("hexagonal",),
    "hexagonal": ("hexagonal",),
    "hexagonaux": ("hexagonal",),
    "hexamètre": ("hexamètre",),
    "hexamètres": ("hexamètre",),
    "hexamoteur": ("hexamoteur",),
    "hexamoteurs": ("hexamoteur",),
    "hexamotrice": ("hexamoteur",),
    "hexamotrices": ("hexamoteur",),
    "hexanedioïque": ("hexanedioïque",),
    "hexanedioïques": ("hexanedioïque",),
    "hexanoïque": ("hexanoïque",),
    "hexanoïques": ("hexanoïque",),
    "hexapode": ("hexapode",),
    "hexapodes": ("hexapode",),
    "hexaprocesseur": ("hexaprocesseur",),
    "hexaréacteur": ("hexaréacteur",),
    "hexaréacteurs": ("hexaréacteur",),
    "hexastyle": ("hexastyle",),
    "hexastyles": ("hexastyle",),
    "hexasyllabe": ("hexasyllabe",),
    "hexasyllabes": ("hexasyllabe",),
    "hexathionique": ("hexathionique",),
    "hexathioniques": ("hexathionique",),
    "hexatomique": ("hexatomique",),
    "hexatomiques": ("hexatomique",),
    "hexonique": ("hexonique",),
    "hexoniques": ("hexonique",),
    "hexuronique": ("hexuronique",),
    "hexuroniques": ("hexuronique",),
    "hexylique": ("hexylique",),
    "hexyliques": ("hexylique",),
    "hiatale": ("hiatal",),
    "hiatales": ("hiatal",),
    "hiatal": ("hiatal",),
    "hiataux": ("hiatal",),
    "hibernale": ("hibernal",),
    "hibernales": ("hibernal",),
    "hibernal": ("hibernal",),
    "hibernaux": ("hibernal",),
    "hideuse": ("hideux",),
    "hideuses": ("hideux",),
    "hideux": ("hideux",),
    "hiémale": ("hiémal",),
    "hiémales": ("hiémal",),
    "hiémal": ("hiémal",),
    "hiémaux": ("hiémal",),
    "hiéracocéphale": ("hiéracocéphale",),
    "hiéracocéphales": ("hiéracocéphale",),
    "hiérarchique": ("hiérarchique",),
    "hiérarchiques": ("hiérarchique",),
    "hiérarchisable": ("hiérarchisable",),
    "hiérarchisables": ("hiérarchisable",),
    "hiératique": ("hiératique",),
    "hiératiques": ("hiératique",),
    "hiérocratique": ("hiérocratique",),
    "hiérocratiques": ("hiérocratique",),
    "hiérogamique": ("hiérogamique",),
    "hiérogamiques": ("hiérogamique",),
    "hiéroglyphique": ("hiéroglyphique",),
    "hiéroglyphiques": ("hiéroglyphique",),
    "hiérographique": ("hiérographique",),
    "hiérographiques": ("hiérographique",),
    "hiéronymien": ("hiéronymien",),
    "hiéronymienne": ("hiéronymien",),
    "hiéronymiennes": ("hiéronymien",),
    "hiéronymiens": ("hiéronymien",),
    "highland": ("highland",),
    "highlands": ("highland",),
    "hilaire": ("hilaire",),
    "hilaires": ("hilaire",),
    "hilare": ("hilare",),
    "hilares": ("hilare",),
    "hilbertien": ("hilbertien",),
    "hilbertienne": ("hilbertien",),
    "hilbertiennes": ("hilbertien",),
    "hilbertiens": ("hilbertien",),
    "himalayen": ("himalayen",),
    "himalayenne": ("himalayen",),
    "himalayennes": ("himalayen",),
    "himalayens": ("himalayen",),
    "hindi": ("hindi",),
    "hindouiste": ("hindouiste",),
    "hindouistes": ("hindouiste",),
    "hindoustani": ("hindoustani",),
    "hinschiste": ("hinschiste",),
    "hinschistes": ("hinschiste",),
    "hippiatrique": ("hippiatrique",),
    "hippiatriques": ("hippiatrique",),
    "hippie": ("hippie",),
    "hippies": ("hippie",),
    "hippique": ("hippique",),
    "hippiques": ("hippique",),
    "hippocampique": ("hippocampique",),
    "hippocampiques": ("hippocampique",),
    "hippocratique": ("hippocratique",),
    "hippocratiques": ("hippocratique",),
    "hippologique": ("hippologique",),
    "hippologiques": ("hippologique",),
    "hippomobile": ("hippomobile",),
    "hippomobiles": ("hippomobile",),
    "hippophage": ("hippophage",),
    "hippophages": ("hippophage",),
    "hippophagique": ("hippophagique",),
    "hippophagiques": ("hippophagique",),
    "hippopotamesque": ("hippopotamesque",),
    "hippopotamesques": ("hippopotamesque",),
    "hippurique": ("hippurique",),
    "hippuriques": ("hippurique",),
    "hippy": ("hippy",),
    "hirsute": ("hirsute",),
    "hirsutes": ("hirsute",),
    "hispanique": ("hispanique",),
    "hispaniques": ("hispanique",),
    "hispaniste": ("hispaniste",),
    "hispanistes": ("hispaniste",),
    "hispano-arabes": ("hispano-arabe",),
    "hispano-mexicaines": ("hispano-mexicain",),
    "hispano-moresques": ("hispano-moresque",),
    "hispanophone": ("hispanophone",),
    "hispanophones": ("hispanophone",),
    "hispide": ("hispide",),
    "hispides": ("hispide",),
    "hissien": ("hissien",),
    "hissienne": ("hissien",),
    "hissiennes": ("hissien",),
    "hissiens": ("hissien",),
    "histadroutique": ("histadroutique",),
    "histadroutiques": ("histadroutique",),
    "histaminergique": ("histaminergique",),
    "histaminergiques": ("histaminergique",),
    "histaminique": ("histaminique",),
    "histaminiques": ("histaminique",),
    "histaminolytique": ("histaminolytique",),
    "histaminolytiques": ("histaminolytique",),
    "histaminopexique": ("histaminopexique",),
    "histaminopexiques": ("histaminopexique",),
    "histiocytaire": ("histiocytaire",),
    "histiocytaires": ("histiocytaire",),
    "histiocytoprolifératif": ("histiocytoprolifératif",),
    "histiocytoprolifératifs": ("histiocytoprolifératif",),
    "histiocytoproliférative": ("histiocytoprolifératif",),
    "histiocytoprolifératives": ("histiocytoprolifératif",),
    "histioïde": ("histioïde",),
    "histioïdes": ("histioïde",),
    "histiolymphocytaire": ("histiolymphocytaire",),
    "histiolymphocytaires": ("histiolymphocytaire",),
    "histiomonocytaire": ("histiomonocytaire",),
    "histiomonocytaires": ("histiomonocytaire",),
    "histochimique": ("histochimique",),
    "histochimiques": ("histochimique",),
    "histocompatible": ("histocompatible",),
    "histocompatibles": ("histocompatible",),
    "histogène": ("histogène",),
    "histogènes": ("histogène",),
    "histogénétique": ("histogénétique",),
    "histogénétiques": ("histogénétique",),
    "histo-incompatible": ("histo-incompatible",),
    "histologique": ("histologique",),
    "histologiques": ("histologique",),
    "historiciste": ("historiciste",),
    "historicistes": ("historiciste",),
    "historiographique": ("historiographique",),
    "historiographiques": ("historiographique",),
    "historique": ("historique",),
    "historiques": ("historique",),
    "histotoxique": ("histotoxique",),
    "histotoxiques": ("histotoxique",),
    "histrionique": ("histrionique",),
    "histrioniques": ("histrionique",),
    "hitchcockien": ("hitchcockien",),
    "hitchcockienne": ("hitchcockien",),
    "hitchcockiennes": ("hitchcockien",),
    "hitchcockiens": ("hitchcockien",),
    "hitlérien": ("hitlérien",),
    "hitlérienne": ("hitlérien",),
    "hitlériennes": ("hitlérien",),
    "hitlériens": ("hitlérien",),
    "hittite": ("hittite",),
    "hittites": ("hittite",),
    "hivernale": ("hivernal",),
    "hivernales": ("hivernal",),
    "hivernal": ("hivernal",),
    "hivernaux": ("hivernal",),
    "hodgkinien": ("hodgkinien",),
    "hodgkinienne": ("hodgkinien",),
    "hodgkiniennes": ("hodgkinien",),
    "hodgkiniens": ("hodgkinien",),
    "hodochrone": ("hodochrone",),
    "hodochrones": ("hodochrone",),
    "holandrique": ("holandrique",),
    "holandriques": ("holandrique",),
    "holantarctique": ("holantarctique",),
    "holantarctiques": ("holantarctique",),
    "holarctique": ("holarctique",),
    "holarctiques": ("holarctique",),
    "holiste": ("holiste",),
    "holistes": ("holiste",),
    "holistique": ("holistique",),
    "holistiques": ("holistique",),
    "hollandaise": ("hollandais",),
    "hollandaises": ("hollandais",),
    "hollandais": ("hollandais",),
    "hollandée": ("hollandée",),
    "hollandées": ("hollandée",),
    "hollywoodien": ("hollywoodien",),
    "hollywoodienne": ("hollywoodien",),
    "hollywoodiennes": ("hollywoodien",),
    "hollywoodiens": ("hollywoodien",),
    "holoblastique": ("holoblastique",),
    "holoblastiques": ("holoblastique",),
    "holocène": ("holocène",),
    "holocènes": ("holocène",),
    "holocrine": ("holocrine",),
    "holocrines": ("holocrine",),
    "holodiastolique": ("holodiastolique",),
    "holodiastoliques": ("holodiastolique",),
    "holognathe": ("holognathe",),
    "holognathes": ("holognathe",),
    "holographe": ("holographe",),
    "holographes": ("holographe",),
    "holographique": ("holographique",),
    "holographiques": ("holographique",),
    "hologynique": ("hologynique",),
    "hologyniques": ("hologynique",),
    "hololeucocrate": ("hololeucocrate",),
    "hololeucocrates": ("hololeucocrate",),
    "holomagnétique": ("holomagnétique",),
    "holomagnétiques": ("holomagnétique",),
    "holomélanocrate": ("holomélanocrate",),
    "holomélanocrates": ("holomélanocrate",),
    "holométabole": ("holométabole",),
    "holométaboles": ("holométabole",),
    "holométrique": ("holométrique",),
    "holométriques": ("holométrique",),
    "holomictique": ("holomictique",),
    "holomictiques": ("holomictique",),
    "holomorphe": ("holomorphe",),
    "holomorphes": ("holomorphe",),
    "holonome": ("holonome",),
    "holonomes": ("holonome",),
    "holophrastique": ("holophrastique",),
    "holophrastiques": ("holophrastique",),
    "holophtalme": ("holophtalme",),
    "holophtalmes": ("holophtalme",),
    "holopneustique": ("holopneustique",),
    "holopneustiques": ("holopneustique",),
    "holorime": ("holorime",),
    "holorimes": ("holorime",),
    "holostome": ("holostome",),
    "holostomes": ("holostome",),
    "holosystolique": ("holosystolique",),
    "holosystoliques": ("holosystolique",),
    "holothymique": ("holothymique",),
    "holothymiques": ("holothymique",),
    "holoxénique": ("holoxénique",),
    "holoxéniques": ("holoxénique",),
    "homale": ("homal",),
    "homales": ("homal",),
    "homal": ("homal",),
    "homaux": ("homal",),
    "homéen": ("homéen",),
    "homéenne": ("homéen",),
    "homéennes": ("homéen",),
    "homéens": ("homéen",),
    "homéomère": ("homéomère",),
    "homéomères": ("homéomère",),
    "homéomorphe": ("homéomorphe",),
    "homéomorphes": ("homéomorphe",),
    "homéopathique": ("homéopathique",),
    "homéopathiques": ("homéopathique",),
    "homéopolaire": ("homéopolaire",),
    "homéopolaires": ("homéopolaire",),
    "homéostatique": ("homéostatique",),
    "homéostatiques": ("homéostatique",),
    "homéotherme": ("homéotherme",),
    "homéothermes": ("homéotherme",),
    "homéotique": ("homéotique",),
    "homéotiques": ("homéotique",),
    "homéotypique": ("homéotypique",),
    "homéotypiques": ("homéotypique",),
    "homéousien": ("homéousien",),
    "homéousienne": ("homéousien",),
    "homéousiennes": ("homéousien",),
    "homéousiens": ("homéousien",),
    "homérique": ("homérique",),
    "homériques": ("homérique",),
    "homicide": ("homicide",),
    "homicides": ("homicide",),
    "hommasse": ("hommasse",),
    "hommasses": ("hommasse",),
    "homo": ("homo",),
    "homos": ("homo",),
    "homocamphorique": ("homocamphorique",),
    "homocamphoriques": ("homocamphorique",),
    "homocentrique": ("homocentrique",),
    "homocentriques": ("homocentrique",),
    "homocerque": ("homocerque",),
    "homocerques": ("homocerque",),
    "homochrome": ("homochrome",),
    "homochromes": ("homochrome",),
    "homochromique": ("homochromique",),
    "homochromiques": ("homochromique",),
    "homochrone": ("homochrone",),
    "homochrones": ("homochrone",),
    "homocinétique": ("homocinétique",),
    "homocinétiques": ("homocinétique",),
    "homocyclique": ("homocyclique",),
    "homocycliques": ("homocyclique",),
    "homocytotrope": ("homocytotrope",),
    "homocytotropes": ("homocytotrope",),
    "homodonte": ("homodonte",),
    "homodontes": ("homodonte",),
    "homodyname": ("homodyname",),
    "homodynames": ("homodyname",),
    "homoeoplastique": ("homoeoplastique",),
    "homoeoplastiques": ("homoeoplastique",),
    "homofocale": ("homofocal",),
    "homofocales": ("homofocal",),
    "homofocal": ("homofocal",),
    "homofocaux": ("homofocal",),
    "homogame": ("homogame",),
    "homogames": ("homogame",),
    "homogamétique": ("homogamétique",),
    "homogamétiques": ("homogamétique",),
    "homogène": ("homogène",),
    "homogènes": ("homogène",),
    "homogénéisateur": ("homogénéisateur",),
    "homogénéisateurs": ("homogénéisateur",),
    "homogénéisatrice": ("homogénéisateur",),
    "homogénéisatrices": ("homogénéisateur",),
    "homogentisique": ("homogentisique",),
    "homogentisiques": ("homogentisique",),
    "homograde": ("homograde",),
    "homogrades": ("homograde",),
    "homogramme": ("homogramme",),
    "homogrammes": ("homogramme",),
    "homographe": ("homographe",),
    "homographes": ("homographe",),
    "homographique": ("homographique",),
    "homographiques": ("homographique",),
    "homolatérale": ("homolatéral",),
    "homolatérales": ("homolatéral",),
    "homolatéral": ("homolatéral",),
    "homolatéraux": ("homolatéral",),
    "homolécithe": ("homolécithe",),
    "homolécithes": ("homolécithe",),
    "homolécithique": ("homolécithique",),
    "homolécithiques": ("homolécithique",),
    "homologable": ("homologable",),
    "homologables": ("homologable",),
    "homologatif": ("homologatif",),
    "homologatifs": ("homologatif",),
    "homologative": ("homologatif",),
    "homologatives": ("homologatif",),
    "homologique": ("homologique",),
    "homologiques": ("homologique",),
    "homologuée": ("homologué",),
    "homologuées": ("homologué",),
    "homologué": ("homologué",),
    "homologue": ("homologue",),
    "homologués": ("homologué",),
    "homologues": ("homologue",),
    "homolytique": ("homolytique",),
    "homolytiques": ("homolytique",),
    "homomorphe": ("homomorphe",),
    "homomorphes": ("homomorphe",),
    "homomorphique": ("homomorphique",),
    "homomorphiques": ("homomorphique",),
    "homonucléaire": ("homonucléaire",),
    "homonucléaires": ("homonucléaire",),
    "homonyme": ("homonyme",),
    "homonymes": ("homonyme",),
    "homonymique": ("homonymique",),
    "homonymiques": ("homonymique",),
    "homophasique": ("homophasique",),
    "homophasiques": ("homophasique",),
    "homophile": ("homophile",),
    "homophiles": ("homophile",),
    "homophone": ("homophone",),
    "homophones": ("homophone",),
    "homophonique": ("homophonique",),
    "homophoniques": ("homophonique",),
    "homopolaire": ("homopolaire",),
    "homopolaires": ("homopolaire",),
    "homorganique": ("homorganique",),
    "homorganiques": ("homorganique",),
    "homorythmique": ("homorythmique",),
    "homorythmiques": ("homorythmique",),
    "homosexuelle": ("homosexuel",),
    "homosexuelles": ("homosexuel",),
    "homosexuel": ("homosexuel",),
    "homosexuels": ("homosexuel",),
    "homotaxe": ("homotaxe",),
    "homotaxes": ("homotaxe",),
    "homothalame": ("homothalame",),
    "homothalames": ("homothalame",),
    "homotherme": ("homotherme",),
    "homothermes": ("homotherme",),
    "homothétique": ("homothétique",),
    "homothétiques": ("homothétique",),
    "homotope": ("homotope",),
    "homotopes": ("homotope",),
    "homotype": ("homotype",),
    "homotypes": ("homotype",),
    "homotypique": ("homotypique",),
    "homotypiques": ("homotypique",),
    "homousien": ("homousien",),
    "homousienne": ("homousien",),
    "homousiennes": ("homousien",),
    "homousiens": ("homousien",),
    "homozygote": ("homozygote",),
    "homozygotes": ("homozygote",),
    "hondurien": ("hondurien",),
    "hondurienne": ("hondurien",),
    "honduriennes": ("hondurien",),
    "honduriens": ("hondurien",),
    "hongkongaise": ("hongkongais",),
    "hongkongaises": ("hongkongais",),
    "hongkongais": ("hongkongais",),
    "hongre": ("hongre",),
    "hongres": ("hongre",),
    "hongroise": ("hongrois",),
    "hongroises": ("hongrois",),
    "hongrois": ("hongrois",),
    "honnête": ("honnête",),
    "honnêtes": ("honnête",),
    "honorable": ("honorable",),
    "honorables": ("honorable",),
    "honoraire": ("honoraire",),
    "honoraires": ("honoraire",),
    "honorifique": ("honorifique",),
    "honorifiques": ("honorifique",),
    "honteuse": ("honteux",),
    "honteuses": ("honteux",),
    "honteux": ("honteux",),
    "horaire": ("horaire",),
    "horaires": ("horaire",),
    "hordéiforme": ("hordéiforme",),
    "hordéiformes": ("hordéiforme",),
    "horizontale": ("horizontal",),
    "horizontales": ("horizontal",),
    "horizontal": ("horizontal",),
    "horizontaux": ("horizontal",),
    "horlogère": ("horloger",),
    "horlogères": ("horloger",),
    "horloger": ("horloger",),
    "horlogers": ("horloger",),
    "hormonale": ("hormonal",),
    "hormonales": ("hormonal",),
    "hormonal": ("hormonal",),
    "hormonaux": ("hormonal",),
    "hormonodépendante": ("hormonodépendant",),
    "hormonodépendantes": ("hormonodépendant",),
    "hormono-dépendant": ("hormono-dépendant",),
    "hormonodépendant": ("hormonodépendant",),
    "hormonodépendants": ("hormonodépendant",),
    "hormonogène": ("hormonogène",),
    "hormonogènes": ("hormonogène",),
    "hornière": ("hornier",),
    "hornières": ("hornier",),
    "hornier": ("hornier",),
    "horniers": ("hornier",),
    "horodateur": ("horodateur",),
    "horodateurs": ("horodateur",),
    "horodatrice": ("horodateur",),
    "horodatrices": ("horodateur",),
    "horographique": ("horographique",),
    "horographiques": ("horographique",),
    "horokilométrique": ("horokilométrique",),
    "horokilométriques": ("horokilométrique",),
    "horométrique": ("horométrique",),
    "horométriques": ("horométrique",),
    "horoptérique": ("horoptérique",),
    "horoptériques": ("horoptérique",),
    "horoscopique": ("horoscopique",),
    "horoscopiques": ("horoscopique",),
    "horrible": ("horrible",),
    "horribles": ("horrible",),
    "horrifique": ("horrifique",),
    "horrifiques": ("horrifique",),
    "horripilateur": ("horripilateur",),
    "horripilateurs": ("horripilateur",),
    "hors-jeu": ("hors-jeu",),
    "horticole": ("horticole",),
    "horticoles": ("horticole",),
    "horticulturale": ("horticultural",),
    "horticulturales": ("horticultural",),
    "horticultural": ("horticultural",),
    "horticulturaux": ("horticultural",),
    "hosannière": ("hosannière",),
    "hosannières": ("hosannière",),
    "hospitalière": ("hospitalier",),
    "hospitalières": ("hospitalier",),
    "hospitalier": ("hospitalier",),
    "hospitaliers": ("hospitalier",),
    "hospitalo-universitaire": ("hospitalo-universitaire",),
    "hospitalo-universitaires": ("hospitalo-universitaire",),
    "hostile": ("hostile",),
    "hostiles": ("hostile",),
    "hot": ("hot",),
    "hôtelière": ("hôtelier",),
    "hôtelières": ("hôtelier",),
    "hôtelier": ("hôtelier",),
    "hôteliers": ("hôtelier",),
    "houblonnière": ("houblonnier",),
    "houblonnières": ("houblonnier",),
    "houblonnier": ("houblonnier",),
    "houblonniers": ("houblonnier",),
    "houillère": ("houiller",),
    "houillères": ("houiller",),
    "houiller": ("houiller",),
    "houillers": ("houiller",),
    "houilleuse": ("houilleux",),
    "houilleuses": ("houilleux",),
    "houilleux": ("houilleux",),
    "houleuse": ("houleux",),
    "houleuses": ("houleux",),
    "houleux": ("houleux",),
    "hourrite": ("hourrite",),
    "hourrites": ("hourrite",),
    "huaxtèque": ("huaxtèque",),
    "huaxtèques": ("huaxtèque",),
    "huileuse": ("huileux",),
    "huileuses": ("huileux",),
    "huileux": ("huileux",),
    "huilière": ("huilier",),
    "huilières": ("huilier",),
    "huilier": ("huilier",),
    "huiliers": ("huilier",),
    "huitantième": ("huitantième",),
    "huitantièmes": ("huitantième",),
    "huitième": ("huitième",),
    "huitièmes": ("huitième",),
    "huîtrière": ("huîtrier",),
    "huîtrières": ("huîtrier",),
    "huîtrier": ("huîtrier",),
    "huîtriers": ("huîtrier",),
    "humanisable": ("humanisable",),
    "humanisables": ("humanisable",),
    "humaniste": ("humaniste",),
    "humanistes": ("humaniste",),
    "humanistique": ("humanistique",),
    "humanistiques": ("humanistique",),
    "humanitaire": ("humanitaire",),
    "humanitaires": ("humanitaire",),
    "humanitariste": ("humanitariste",),
    "humanitaristes": ("humanitariste",),
    "humanoïde": ("humanoïde",),
    "humanoïdes": ("humanoïde",),
    "humble": ("humble",),
    "humbles": ("humble",),
    "humérale": ("huméral",),
    "humérales": ("huméral",),
    "huméral": ("huméral",),
    "huméraux": ("huméral",),
    "humicole": ("humicole",),
    "humicoles": ("humicole",),
    "humide": ("humide",),
    "humides": ("humide",),
    "humidifuge": ("humidifuge",),
    "humidifuges": ("humidifuge",),
    "humifère": ("humifère",),
    "humifères": ("humifère",),
    "humifuse": ("humifuse",),
    "humifuses": ("humifuse",),
    "humique": ("humique",),
    "humiques": ("humique",),
    "humocalcaire": ("humocalcaire",),
    "humocalcaires": ("humocalcaire",),
    "humorale": ("humoral",),
    "humorales": ("humoral",),
    "humoral": ("humoral",),
    "humoraux": ("humoral",),
    "humoriste": ("humoriste",),
    "humoristes": ("humoriste",),
    "humoristique": ("humoristique",),
    "humoristiques": ("humoristique",),
    "hunnique": ("hunnique",),
    "hunniques": ("hunnique",),
    "hurlérien": ("hurlérien",),
    "hurlérienne": ("hurlérien",),
    "hurlériennes": ("hurlérien",),
    "hurlériens": ("hurlérien",),
    "hurleur": ("hurleur",),
    "hurleurs": ("hurleur",),
    "hurleuse": ("hurleur",),
    "hurleuses": ("hurleur",),
    "huron": ("huron",),
    "huronne": ("huron",),
    "huronnes": ("huron",),
    "hurons": ("huron",),
    "huronien": ("huronien",),
    "huronienne": ("huronien",),
    "huroniennes": ("huronien",),
    "huroniens": ("huronien",),
    "husserlien": ("husserlien",),
    "husserlienne": ("husserlien",),
    "husserliennes": ("husserlien",),
    "husserliens": ("husserlien",),
    "hussite": ("hussite",),
    "hussites": ("hussite",),
    "hutchinsonien": ("hutchinsonien",),
    "hutchinsonienne": ("hutchinsonien",),
    "hutchinsoniennes": ("hutchinsonien",),
    "hutchinsoniens": ("hutchinsonien",),
    "hyacinthe": ("hyacinthe",),
    "hyalobiuronique": ("hyalobiuronique",),
    "hyalobiuroniques": ("hyalobiuronique",),
    "hyaloclastique": ("hyaloclastique",),
    "hyaloclastiques": ("hyaloclastique",),
    "hyaloïde": ("hyaloïde",),
    "hyaloïdes": ("hyaloïde",),
    "hyaluronique": ("hyaluronique",),
    "hyaluroniques": ("hyaluronique",),
    "hybride": ("hybride",),
    "hybrides": ("hybride",),
    "hydantoïque": ("hydantoïque",),
    "hydantoïques": ("hydantoïque",),
    "hydatiforme": ("hydatiforme",),
    "hydatiformes": ("hydatiforme",),
    "hydatique": ("hydatique",),
    "hydatiques": ("hydatique",),
    "hydnocarpique": ("hydnocarpique",),
    "hydnocarpiques": ("hydnocarpique",),
    "hydracrylique": ("hydracrylique",),
    "hydracryliques": ("hydracrylique",),
    "hydragogue": ("hydragogue",),
    "hydragogues": ("hydragogue",),
    "hydralcoolique": ("hydralcoolique",),
    "hydralcooliques": ("hydralcoolique",),
    "hydrargyrique": ("hydrargyrique",),
    "hydrargyriques": ("hydrargyrique",),
    "hydratable": ("hydratable",),
    "hydratables": ("hydratable",),
    "hydratropique": ("hydratropique",),
    "hydratropiques": ("hydratropique",),
    "hydraulicien": ("hydraulicien",),
    "hydraulicienne": ("hydraulicien",),
    "hydrauliciennes": ("hydraulicien",),
    "hydrauliciens": ("hydraulicien",),
    "hydraulique": ("hydraulique",),
    "hydrauliques": ("hydraulique",),
    "hydrencéphalique": ("hydrencéphalique",),
    "hydrencéphaliques": ("hydrencéphalique",),
    "hydrique": ("hydrique",),
    "hydriques": ("hydrique",),
    "hydroactif": ("hydroactif",),
    "hydroactifs": ("hydroactif",),
    "hydroactive": ("hydroactif",),
    "hydroactives": ("hydroactif",),
    "hydroaérique": ("hydroaérique",),
    "hydroaériques": ("hydroaérique",),
    "hydroagricole": ("hydroagricole",),
    "hydroagricoles": ("hydroagricole",),
    "hydroalcoolique": ("hydroalcoolique",),
    "hydroalcooliques": ("hydroalcoolique",),
    "hydroaromatique": ("hydroaromatique",),
    "hydroaromatiques": ("hydroaromatique",),
    "hydrocéphale": ("hydrocéphale",),
    "hydrocéphales": ("hydrocéphale",),
    "hydrochore": ("hydrochore",),
    "hydrochores": ("hydrochore",),
    "hydrocinnamique": ("hydrocinnamique",),
    "hydrocinnamiques": ("hydrocinnamique",),
    "hydrocyclique": ("hydrocyclique",),
    "hydrocycliques": ("hydrocyclique",),
    "hydrodynamique": ("hydrodynamique",),
    "hydrodynamiques": ("hydrodynamique",),
    "hydro-électrique": ("hydroélectrique",),
    "hydroélectrique": ("hydroélectrique",),
    "hydroélectriques": ("hydroélectrique",),
    "hydro-électrolytique": ("hydro-électrolytique",),
    "hydroélectrolytique": ("hydroélectrolytique",),
    "hydroélectrolytiques": ("hydroélectrolytique",),
    "hydroénergétique": ("hydroénergétique",),
    "hydroénergétiques": ("hydroénergétique",),
    "hydroéolien": ("hydroéolien",),
    "hydroéolienne": ("hydroéolien",),
    "hydroéoliennes": ("hydroéolien",),
    "hydroéoliens": ("hydroéolien",),
    "hydrofuge": ("hydrofuge",),
    "hydrofuges": ("hydrofuge",),
    "hydrogénoïde": ("hydrogénoïde",),
    "hydrogénoïdes": ("hydrogénoïde",),
    "hydrogéologique": ("hydrogéologique",),
    "hydrogéologiques": ("hydrogéologique",),
    "hydrographique": ("hydrographique",),
    "hydrographiques": ("hydrographique",),
    "hydrologique": ("hydrologique",),
    "hydrologiques": ("hydrologique",),
    "hydrolysable": ("hydrolysable",),
    "hydrolysables": ("hydrolysable",),
    "hydrolytique": ("hydrolytique",),
    "hydrolytiques": ("hydrolytique",),
    "hydromagnétique": ("hydromagnétique",),
    "hydromagnétiques": ("hydromagnétique",),
    "hydromécanique": ("hydromécanique",),
    "hydromécaniques": ("hydromécanique",),
    "hydrométallurgique": ("hydrométallurgique",),
    "hydrométallurgiques": ("hydrométallurgique",),
    "hydrométrique": ("hydrométrique",),
    "hydrométriques": ("hydrométrique",),
    "hydrominérale": ("hydrominéral",),
    "hydrominérales": ("hydrominéral",),
    "hydrominéral": ("hydrominéral",),
    "hydrominéraux": ("hydrominéral",),
    "hydromorphe": ("hydromorphe",),
    "hydromorphes": ("hydromorphe",),
    "hydronéphrotique": ("hydronéphrotique",),
    "hydronéphrotiques": ("hydronéphrotique",),
    "hydrophane": ("hydrophane",),
    "hydrophanes": ("hydrophane",),
    "hydrophile": ("hydrophile",),
    "hydrophiles": ("hydrophile",),
    "hydrophobe": ("hydrophobe",),
    "hydrophobes": ("hydrophobe",),
    "hydrophore": ("hydrophore",),
    "hydrophores": ("hydrophore",),
    "hydropigène": ("hydropigène",),
    "hydropigènes": ("hydropigène",),
    "hydropique": ("hydropique",),
    "hydropiques": ("hydropique",),
    "hydropneumatique": ("hydropneumatique",),
    "hydropneumatiques": ("hydropneumatique",),
    "hydroponique": ("hydroponique",),
    "hydroponiques": ("hydroponique",),
    "hydrosodique": ("hydrosodique",),
    "hydrosodiques": ("hydrosodique",),
    "hydrosoluble": ("hydrosoluble",),
    "hydrosolubles": ("hydrosoluble",),
    "hydrostatique": ("hydrostatique",),
    "hydrostatiques": ("hydrostatique",),
    "hydrosulfureuse": ("hydrosulfureux",),
    "hydrosulfureuses": ("hydrosulfureux",),
    "hydrosulfureux": ("hydrosulfureux",),
    "hydrotechnique": ("hydrotechnique",),
    "hydrotechniques": ("hydrotechnique",),
    "hydrothérapique": ("hydrothérapique",),
    "hydrothérapiques": ("hydrothérapique",),
    "hydrothermale": ("hydrothermal",),
    "hydrothermales": ("hydrothermal",),
    "hydrothermal": ("hydrothermal",),
    "hydrothermaux": ("hydrothermal",),
    "hydrothermique": ("hydrothermique",),
    "hydrothermiques": ("hydrothermique",),
    "hydrotimétrique": ("hydrotimétrique",),
    "hydrotimétriques": ("hydrotimétrique",),
    "hydroxamique": ("hydroxamique",),
    "hydroxamiques": ("hydroxamique",),
    "hydroxyacétique": ("hydroxyacétique",),
    "hydroxyacétiques": ("hydroxyacétique",),
    "hydroxyazoïque": ("hydroxyazoïque",),
    "hydroxyazoïques": ("hydroxyazoïque",),
    "hydroxybenzoïque": ("hydroxybenzoïque",),
    "hydroxybenzoïques": ("hydroxybenzoïque",),
    "hydroxybenzylique": ("hydroxybenzylique",),
    "hydroxybenzyliques": ("hydroxybenzylique",),
    "hydroxybutyrique": ("hydroxybutyrique",),
    "hydroxybutyriques": ("hydroxybutyrique",),
    "hydroxycinnamique": ("hydroxycinnamique",),
    "hydroxycinnamiques": ("hydroxycinnamique",),
    "hydroxylique": ("hydroxylique",),
    "hydroxyliques": ("hydroxylique",),
    "hydroxymalonique": ("hydroxymalonique",),
    "hydroxymaloniques": ("hydroxymalonique",),
    "hydroxynaphtoïque": ("hydroxynaphtoïque",),
    "hydroxynaphtoïques": ("hydroxynaphtoïque",),
    "hydroxypropanoïque": ("hydroxypropanoïque",),
    "hydroxypropanoïques": ("hydroxypropanoïque",),
    "hydroxypropionique": ("hydroxypropionique",),
    "hydroxypropioniques": ("hydroxypropionique",),
    "hydroxysalicylique": ("hydroxysalicylique",),
    "hydroxysalicyliques": ("hydroxysalicylique",),
    "hydroxysuccinique": ("hydroxysuccinique",),
    "hydroxysucciniques": ("hydroxysuccinique",),
    "hygiénique": ("hygiénique",),
    "hygiéniques": ("hygiénique",),
    "hygiénodiététique": ("hygiénodiététique",),
    "hygiénodiététiques": ("hygiénodiététique",),
    "hygrométrique": ("hygrométrique",),
    "hygrométriques": ("hygrométrique",),
    "hygrophile": ("hygrophile",),
    "hygrophiles": ("hygrophile",),
    "hygrophobe": ("hygrophobe",),
    "hygrophobes": ("hygrophobe",),
    "hygroscopique": ("hygroscopique",),
    "hygroscopiques": ("hygroscopique",),
    "hylétique": ("hylétique",),
    "hylétiques": ("hylétique",),
    "hyménéale": ("hyménéal",),
    "hyménéales": ("hyménéal",),
    "hyménéal": ("hyménéal",),
    "hyménéaux": ("hyménéal",),
    "hyméniale": ("hyménial",),
    "hyméniales": ("hyménial",),
    "hyménial": ("hyménial",),
    "hyméniaux": ("hyménial",),
    "hyménoptère": ("hyménoptère",),
    "hyménoptères": ("hyménoptère",),
    "hymnique": ("hymnique",),
    "hymniques": ("hymnique",),
    "hymnographique": ("hymnographique",),
    "hymnographiques": ("hymnographique",),
    "hyodésoxycholique": ("hyodésoxycholique",),
    "hyodésoxycholiques": ("hyodésoxycholique",),
    "hyoglosse": ("hyoglosse",),
    "hyoglosses": ("hyoglosse",),
    "hyoïde": ("hyoïde",),
    "hyoïdes": ("hyoïde",),
    "hyoïdien": ("hyoïdien",),
    "hyoïdienne": ("hyoïdien",),
    "hyoïdiennes": ("hyoïdien",),
    "hyoïdiens": ("hyoïdien",),
    "hyostylique": ("hyostylique",),
    "hyostyliques": ("hyostylique",),
    "hypate": ("hypate",),
    "hypates": ("hypate",),
    "hyperactif": ("hyperactif",),
    "hyperactifs": ("hyperactif",),
    "hyperactive": ("hyperactif",),
    "hyperactives": ("hyperactif",),
    "hyperaiguë": ("hyperaigu",),
    "hyperaiguës": ("hyperaigu",),
    "hyperaigu": ("hyperaigu",),
    "hyperaigus": ("hyperaigu",),
    "hyperalgésique": ("hyperalgésique",),
    "hyperalgésiques": ("hyperalgésique",),
    "hyperalgique": ("hyperalgique",),
    "hyperalgiques": ("hyperalgique",),
    "hyperandroïde": ("hyperandroïde",),
    "hyperandroïdes": ("hyperandroïde",),
    "hyperaride": ("hyperaride",),
    "hyperarides": ("hyperaride",),
    "hyperbare": ("hyperbare",),
    "hyperbares": ("hyperbare",),
    "hyperbarique": ("hyperbarique",),
    "hyperbariques": ("hyperbarique",),
    "hyperbasophile": ("hyperbasophile",),
    "hyperbasophiles": ("hyperbasophile",),
    "hyperbolique": ("hyperbolique",),
    "hyperboliques": ("hyperbolique",),
    "hyperboréen": ("hyperboréen",),
    "hyperboréenne": ("hyperboréen",),
    "hyperboréennes": ("hyperboréen",),
    "hyperboréens": ("hyperboréen",),
    "hypercalculateur": ("hypercalculateur",),
    "hypercalculateurs": ("hypercalculateur",),
    "hypercalculatrice": ("hypercalculateur",),
    "hypercalculatrices": ("hypercalculateur",),
    "hypercalorique": ("hypercalorique",),
    "hypercaloriques": ("hypercalorique",),
    "hypercapnique": ("hypercapnique",),
    "hypercapniques": ("hypercapnique",),
    "hypercellulosique": ("hypercellulosique",),
    "hypercellulosiques": ("hypercellulosique",),
    "hyperchrome": ("hyperchrome",),
    "hyperchromes": ("hyperchrome",),
    "hyperchromique": ("hyperchromique",),
    "hyperchromiques": ("hyperchromique",),
    "hyperchylique": ("hyperchylique",),
    "hyperchyliques": ("hyperchylique",),
    "hypercinétique": ("hypercinétique",),
    "hypercinétiques": ("hypercinétique",),
    "hypercomplexe": ("hypercomplexe",),
    "hypercomplexes": ("hypercomplexe",),
    "hypercompound": ("hypercompound",),
    "hypercorrecteur": ("hypercorrecteur",),
    "hypercorrecteurs": ("hypercorrecteur",),
    "hypercorrectrice": ("hypercorrecteur",),
    "hypercorrectrices": ("hypercorrecteur",),
    "hypercritique": ("hypercritique",),
    "hypercritiques": ("hypercritique",),
    "hyperdense": ("hyperdense",),
    "hyperdenses": ("hyperdense",),
    "hyperdialectique": ("hyperdialectique",),
    "hyperdialectiques": ("hyperdialectique",),
    "hyperdiastématique": ("hyperdiastématique",),
    "hyperdiastématiques": ("hyperdiastématique",),
    "hyperdiploïde": ("hyperdiploïde",),
    "hyperdiploïdes": ("hyperdiploïde",),
    "hyperéchogène": ("hyperéchogène",),
    "hyperéchogènes": ("hyperéchogène",),
    "hyperémique": ("hyperémique",),
    "hyperémiques": ("hyperémique",),
    "hyperémotif": ("hyperémotif",),
    "hyperémotifs": ("hyperémotif",),
    "hyperémotive": ("hyperémotif",),
    "hyperémotives": ("hyperémotif",),
    "hyperéosinophilique": ("hyperéosinophilique",),
    "hyperéosinophiliques": ("hyperéosinophilique",),
    "hyperergique": ("hyperergique",),
    "hyperergiques": ("hyperergique",),
    "hyperesthésique": ("hyperesthésique",),
    "hyperesthésiques": ("hyperesthésique",),
    "hypereutectique": ("hypereutectique",),
    "hypereutectiques": ("hypereutectique",),
    "hypereutectoïde": ("hypereutectoïde",),
    "hypereutectoïdes": ("hypereutectoïde",),
    "hyperfocale": ("hyperfocal",),
    "hyperfocales": ("hyperfocal",),
    "hyperfocal": ("hyperfocal",),
    "hyperfocaux": ("hyperfocal",),
    "hypergéométrique": ("hypergéométrique",),
    "hypergéométriques": ("hypergéométrique",),
    "hyperglobulinémique": ("hyperglobulinémique",),
    "hyperglobulinémiques": ("hyperglobulinémique",),
    "hyperglucidique": ("hyperglucidique",),
    "hyperglucidiques": ("hyperglucidique",),
    "hyperglycémique": ("hyperglycémique",),
    "hyperglycémiques": ("hyperglycémique",),
    "hypergolique": ("hypergolique",),
    "hypergoliques": ("hypergolique",),
    "hypergonadotrophique": ("hypergonadotrophique",),
    "hypergonadotrophiques": ("hypergonadotrophique",),
    "hypergynoïde": ("hypergynoïde",),
    "hypergynoïdes": ("hypergynoïde",),
    "hyperhormonale": ("hyperhormonal",),
    "hyperhormonales": ("hyperhormonal",),
    "hyperhormonal": ("hyperhormonal",),
    "hyperhormonaux": ("hyperhormonal",),
    "hyperhydropexique": ("hyperhydropexique",),
    "hyperhydropexiques": ("hyperhydropexique",),
    "hyperimmunoglobulinémique": ("hyperimmunoglobulinémique",),
    "hyperimmunoglobulinémiques": ("hyperimmunoglobulinémique",),
    "hyperinsulinémique": ("hyperinsulinémique",),
    "hyperinsulinémiques": ("hyperinsulinémique",),
    "hyperinsulinique": ("hyperinsulinique",),
    "hyperinsuliniques": ("hyperinsulinique",),
    "hyperintense": ("hyperintense",),
    "hyperintenses": ("hyperintense",),
    "hyperkératosique": ("hyperkératosique",),
    "hyperkératosiques": ("hyperkératosique",),
    "hyperkinétique": ("hyperkinétique",),
    "hyperkinétiques": ("hyperkinétique",),
    "hyperlaxe": ("hyperlaxe",),
    "hyperlaxes": ("hyperlaxe",),
    "hyperlipidémique": ("hyperlipidémique",),
    "hyperlipidémiques": ("hyperlipidémique",),
    "hyperlipidique": ("hyperlipidique",),
    "hyperlipidiques": ("hyperlipidique",),
    "hypermètre": ("hypermètre",),
    "hypermètres": ("hypermètre",),
    "hypermétrique": ("hypermétrique",),
    "hypermétriques": ("hypermétrique",),
    "hypermétrope": ("hypermétrope",),
    "hypermétropes": ("hypermétrope",),
    "hypermnésique": ("hypermnésique",),
    "hypermnésiques": ("hypermnésique",),
    "hypernerveuse": ("hypernerveux",),
    "hypernerveuses": ("hypernerveux",),
    "hypernerveux": ("hypernerveux",),
    "hyperope": ("hyperope",),
    "hyperopes": ("hyperope",),
    "hyperorganique": ("hyperorganique",),
    "hyperorganiques": ("hyperorganique",),
    "hyperosmolaire": ("hyperosmolaire",),
    "hyperosmolaires": ("hyperosmolaire",),
    "hyperostosique": ("hyperostosique",),
    "hyperostosiques": ("hyperostosique",),
    "hyperparasite": ("hyperparasite",),
    "hyperparasites": ("hyperparasite",),
    "hyperpeptique": ("hyperpeptique",),
    "hyperpeptiques": ("hyperpeptique",),
    "hyperphosphaturique": ("hyperphosphaturique",),
    "hyperphosphaturiques": ("hyperphosphaturique",),
    "hyperplasique": ("hyperplasique",),
    "hyperplasiques": ("hyperplasique",),
    "hyperplastique": ("hyperplastique",),
    "hyperplastiques": ("hyperplastique",),
    "hyperpopulaire": ("hyperpopulaire",),
    "hyperpopulaires": ("hyperpopulaire",),
    "hyperprotecteur": ("hyperprotecteur",),
    "hyperprotecteurs": ("hyperprotecteur",),
    "hyperprotectrice": ("hyperprotecteur",),
    "hyperprotectrices": ("hyperprotecteur",),
    "hyperprotidique": ("hyperprotidique",),
    "hyperprotidiques": ("hyperprotidique",),
    "hyperréaliste": ("hyperréaliste",),
    "hyperréalistes": ("hyperréaliste",),
    "hypersensible": ("hypersensible",),
    "hypersensibles": ("hypersensible",),
    "hypersidérémique": ("hypersidérémique",),
    "hypersidérémiques": ("hypersidérémique",),
    "hypersodique": ("hypersodique",),
    "hypersodiques": ("hypersodique",),
    "hypersomniaque": ("hypersomniaque",),
    "hypersomniaques": ("hypersomniaque",),
    "hypersonique": ("hypersonique",),
    "hypersoniques": ("hypersonique",),
    "hyperspasmodique": ("hyperspasmodique",),
    "hyperspasmodiques": ("hyperspasmodique",),
    "hyperspastique": ("hyperspastique",),
    "hyperspastiques": ("hyperspastique",),
    "hypersphérique": ("hypersphérique",),
    "hypersphériques": ("hypersphérique",),
    "hyperstatique": ("hyperstatique",),
    "hyperstatiques": ("hyperstatique",),
    "hypersthénique": ("hypersthénique",),
    "hypersthéniques": ("hypersthénique",),
    "hypersustentateur": ("hypersustentateur",),
    "hypersustentateurs": ("hypersustentateur",),
    "hypersustentatrice": ("hypersustentateur",),
    "hypersustentatrices": ("hypersustentateur",),
    "hypersynchrone": ("hypersynchrone",),
    "hypersynchrones": ("hypersynchrone",),
    "hypertélique": ("hypertélique",),
    "hypertéliques": ("hypertélique",),
    "hypertenseur": ("hypertenseur",),
    "hypertenseurs": ("hypertenseur",),
    "hypertensif": ("hypertensif",),
    "hypertensifs": ("hypertensif",),
    "hypertensive": ("hypertensif",),
    "hypertensives": ("hypertensif",),
    "hyperthermale": ("hyperthermal",),
    "hyperthermales": ("hyperthermal",),
    "hyperthermal": ("hyperthermal",),
    "hyperthermaux": ("hyperthermal",),
    "hyperthermique": ("hyperthermique",),
    "hyperthermiques": ("hyperthermique",),
    "hyperthermophile": ("hyperthermophile",),
    "hyperthermophiles": ("hyperthermophile",),
    "hyperthrombocytaire": ("hyperthrombocytaire",),
    "hyperthrombocytaires": ("hyperthrombocytaire",),
    "hyperthymique": ("hyperthymique",),
    "hyperthymiques": ("hyperthymique",),
    "hyperthyroïdien": ("hyperthyroïdien",),
    "hyperthyroïdienne": ("hyperthyroïdien",),
    "hyperthyroïdiennes": ("hyperthyroïdien",),
    "hyperthyroïdiens": ("hyperthyroïdien",),
    "hypertonique": ("hypertonique",),
    "hypertoniques": ("hypertonique",),
    "hypertrophique": ("hypertrophique",),
    "hypertrophiques": ("hypertrophique",),
    "hyperuricémique": ("hyperuricémique",),
    "hyperuricémiques": ("hyperuricémique",),
    "hypervariable": ("hypervariable",),
    "hypervariables": ("hypervariable",),
    "hypnagogique": ("hypnagogique",),
    "hypnagogiques": ("hypnagogique",),
    "hypnogène": ("hypnogène",),
    "hypnogènes": ("hypnogène",),
    "hypnoïde": ("hypnoïde",),
    "hypnoïdes": ("hypnoïde",),
    "hypnologique": ("hypnologique",),
    "hypnologiques": ("hypnologique",),
    "hypnopompique": ("hypnopompique",),
    "hypnopompiques": ("hypnopompique",),
    "hypnotique": ("hypnotique",),
    "hypnotiques": ("hypnotique",),
    "hypoallergénique": ("hypoallergénique",),
    "hypoallergéniques": ("hypoallergénique",),
    "hypoallergique": ("hypoallergique",),
    "hypoallergiques": ("hypoallergique",),
    "hypobare": ("hypobare",),
    "hypobares": ("hypobare",),
    "hypobromeuse": ("hypobromeux",),
    "hypobromeuses": ("hypobromeux",),
    "hypobromeux": ("hypobromeux",),
    "hypocalorique": ("hypocalorique",),
    "hypocaloriques": ("hypocalorique",),
    "hypocarotinémique": ("hypocarotinémique",),
    "hypocarotinémiques": ("hypocarotinémique",),
    "hypochloreuse": ("hypochloreux",),
    "hypochloreuses": ("hypochloreux",),
    "hypochloreux": ("hypochloreux",),
    "hypochondre": ("hypochondre",),
    "hypochondres": ("hypochondre",),
    "hypochondriaque": ("hypochondriaque",),
    "hypochondriaques": ("hypochondriaque",),
    "hypochrome": ("hypochrome",),
    "hypochromes": ("hypochrome",),
    "hypochromique": ("hypochromique",),
    "hypochromiques": ("hypochromique",),
    "hypocinétique": ("hypocinétique",),
    "hypocinétiques": ("hypocinétique",),
    "hypocompound": ("hypocompound",),
    "hypocondre": ("hypocondre",),
    "hypocondres": ("hypocondre",),
    "hypocondriaque": ("hypocondriaque",),
    "hypocondriaques": ("hypocondriaque",),
    "hypocoristique": ("hypocoristique",),
    "hypocoristiques": ("hypocoristique",),
    "hypocratériforme": ("hypocratériforme",),
    "hypocratériformes": ("hypocratériforme",),
    "hypocratérimorphe": ("hypocratérimorphe",),
    "hypocratérimorphes": ("hypocratérimorphe",),
    "hypocrite": ("hypocrite",),
    "hypocrites": ("hypocrite",),
    "hypocritique": ("hypocritique",),
    "hypocritiques": ("hypocritique",),
    "hypocycloïdale": ("hypocycloïdal",),
    "hypocycloïdales": ("hypocycloïdal",),
    "hypocycloïdal": ("hypocycloïdal",),
    "hypocycloïdaux": ("hypocycloïdal",),
    "hypodermique": ("hypodermique",),
    "hypodermiques": ("hypodermique",),
    "hypodiploïde": ("hypodiploïde",),
    "hypodiploïdes": ("hypodiploïde",),
    "hypoéchogène": ("hypoéchogène",),
    "hypoéchogènes": ("hypoéchogène",),
    "hypoesthésique": ("hypoesthésique",),
    "hypoesthésiques": ("hypoesthésique",),
    "hypoeutectique": ("hypoeutectique",),
    "hypoeutectiques": ("hypoeutectique",),
    "hypoeutectoïde": ("hypoeutectoïde",),
    "hypoeutectoïdes": ("hypoeutectoïde",),
    "hypogastrique": ("hypogastrique",),
    "hypogastriques": ("hypogastrique",),
    "hypogénitale": ("hypogénital",),
    "hypogénitales": ("hypogénital",),
    "hypogénital": ("hypogénital",),
    "hypogénitaux": ("hypogénital",),
    "hypoglandulaire": ("hypoglandulaire",),
    "hypoglandulaires": ("hypoglandulaire",),
    "hypoglosse": ("hypoglosse",),
    "hypoglosses": ("hypoglosse",),
    "hypoglucidique": ("hypoglucidique",),
    "hypoglucidiques": ("hypoglucidique",),
    "hypoglycémique": ("hypoglycémique",),
    "hypoglycémiques": ("hypoglycémique",),
    "hypogonadique": ("hypogonadique",),
    "hypogonadiques": ("hypogonadique",),
    "hypogonadotrophique": ("hypogonadotrophique",),
    "hypogonadotrophiques": ("hypogonadotrophique",),
    "hypogyne": ("hypogyne",),
    "hypogynes": ("hypogyne",),
    "hypoïde": ("hypoïde",),
    "hypoïdes": ("hypoïde",),
    "hypoinsulinémique": ("hypoinsulinémique",),
    "hypoinsulinémiques": ("hypoinsulinémique",),
    "hypo-iodeuse": ("hypo-iodeux",),
    "hypomaniaque": ("hypomaniaque",),
    "hypomaniaques": ("hypomaniaque",),
    "hyponitreuse": ("hyponitreux",),
    "hyponitreuses": ("hyponitreux",),
    "hyponitreux": ("hyponitreux",),
    "hypopepsique": ("hypopepsique",),
    "hypopepsiques": ("hypopepsique",),
    "hypophosphaturique": ("hypophosphaturique",),
    "hypophosphaturiques": ("hypophosphaturique",),
    "hypophosphoreuse": ("hypophosphoreux",),
    "hypophosphoreuses": ("hypophosphoreux",),
    "hypophosphoreux": ("hypophosphoreux",),
    "hypophosphorique": ("hypophosphorique",),
    "hypophosphoriques": ("hypophosphorique",),
    "hypophysaire": ("hypophysaire",),
    "hypophysaires": ("hypophysaire",),
    "hypophyséoprive": ("hypophyséoprive",),
    "hypophyséoprives": ("hypophyséoprive",),
    "hypophysiotrope": ("hypophysiotrope",),
    "hypophysiotropes": ("hypophysiotrope",),
    "hypophysoprive": ("hypophysoprive",),
    "hypophysoprives": ("hypophysoprive",),
    "hypopituitaire": ("hypopituitaire",),
    "hypopituitaires": ("hypopituitaire",),
    "hypoplasique": ("hypoplasique",),
    "hypoplasiques": ("hypoplasique",),
    "hypoplastique": ("hypoplastique",),
    "hypoplastiques": ("hypoplastique",),
    "hypoprotidique": ("hypoprotidique",),
    "hypoprotidiques": ("hypoprotidique",),
    "hyporépondeur": ("hyporépondeur",),
    "hyporépondeurs": ("hyporépondeur",),
    "hyporépondeuse": ("hyporépondeur",),
    "hyporépondeuses": ("hyporépondeur",),
    "hyposidérémique": ("hyposidérémique",),
    "hyposidérémiques": ("hyposidérémique",),
    "hyposodique": ("hyposodique",),
    "hyposodiques": ("hyposodique",),
    "hypospade": ("hypospade",),
    "hypospades": ("hypospade",),
    "hypostatique": ("hypostatique",),
    "hypostatiques": ("hypostatique",),
    "hyposthénique": ("hyposthénique",),
    "hyposthéniques": ("hyposthénique",),
    "hypostyle": ("hypostyle",),
    "hypostyles": ("hypostyle",),
    "hyposulfureuse": ("hyposulfureux",),
    "hyposulfureuses": ("hyposulfureux",),
    "hyposulfureux": ("hyposulfureux",),
    "hyposulfurique": ("hyposulfurique",),
    "hyposulfuriques": ("hyposulfurique",),
    "hypotactique": ("hypotactique",),
    "hypotactiques": ("hypotactique",),
    "hypotenseur": ("hypotenseur",),
    "hypotenseurs": ("hypotenseur",),
    "hypotensif": ("hypotensif",),
    "hypotensifs": ("hypotensif",),
    "hypotensive": ("hypotensif",),
    "hypotensives": ("hypotensif",),
    "hypothalamique": ("hypothalamique",),
    "hypothalamiques": ("hypothalamique",),
    "hypothalamo-hypophysaire": ("hypothalamo-hypophysaire",),
    "hypothécable": ("hypothécable",),
    "hypothécables": ("hypothécable",),
    "hypothécaire": ("hypothécaire",),
    "hypothécaires": ("hypothécaire",),
    "hypothermale": ("hypothermal",),
    "hypothermales": ("hypothermal",),
    "hypothermal": ("hypothermal",),
    "hypothermaux": ("hypothermal",),
    "hypothermique": ("hypothermique",),
    "hypothermiques": ("hypothermique",),
    "hypothético-déductif": ("hypothético-déductif",),
    "hypothético-déductives": ("hypothético-déductif",),
    "hypothétique": ("hypothétique",),
    "hypothétiques": ("hypothétique",),
    "hypothyroxinémique": ("hypothyroxinémique",),
    "hypothyroxinémiques": ("hypothyroxinémique",),
    "hypothyroxinique": ("hypothyroxinique",),
    "hypothyroxiniques": ("hypothyroxinique",),
    "hypotone": ("hypotone",),
    "hypotones": ("hypotone",),
    "hypotonique": ("hypotonique",),
    "hypotoniques": ("hypotonique",),
    "hypotrophique": ("hypotrophique",),
    "hypotrophiques": ("hypotrophique",),
    "hypovanadeuse": ("hypovanadeux",),
    "hypovanadeuses": ("hypovanadeux",),
    "hypovanadeux": ("hypovanadeux",),
    "hypovanadique": ("hypovanadique",),
    "hypovanadiques": ("hypovanadique",),
    "hypovolcanique": ("hypovolcanique",),
    "hypovolcaniques": ("hypovolcanique",),
    "hypovolémique": ("hypovolémique",),
    "hypovolémiques": ("hypovolémique",),
    "hypovolhémique": ("hypovolhémique",),
    "hypovolhémiques": ("hypovolhémique",),
    "hypoxique": ("hypoxique",),
    "hypoxiques": ("hypoxique",),
    "hypsarythmique": ("hypsarythmique",),
    "hypsarythmiques": ("hypsarythmique",),
    "hypsochrome": ("hypsochrome",),
    "hypsochromes": ("hypsochrome",),
    "hypsodonte": ("hypsodonte",),
    "hypsodontes": ("hypsodonte",),
    "hypsométrique": ("hypsométrique",),
    "hypsométriques": ("hypsométrique",),
    "hystérétique": ("hystérétique",),
    "hystérétiques": ("hystérétique",),
    "hystériforme": ("hystériforme",),
    "hystériformes": ("hystériforme",),
    "hystérique": ("hystérique",),
    "hystériques": ("hystérique",),
    "hystéro-épileptique": ("hystéro-épileptique",),
    "hystérogène": ("hystérogène",),
    "hystérogènes": ("hystérogène",),
    "hystéroïde": ("hystéroïde",),
    "hystéroïdes": ("hystéroïde",),
    "iakoute": ("iakoute",),
    "iakoutes": ("iakoute",),
    "iambélégiaque": ("iambélégiaque",),
    "iambélégiaques": ("iambélégiaque",),
    "iambique": ("iambique",),
    "ïambique": ("ïambique",),
    "iambiques": ("iambique",),
    "ïambiques": ("ïambique",),
    "iambotrochaïque": ("iambotrochaïque",),
    "iambotrochaïques": ("iambotrochaïque",),
    "iatrogène": ("iatrogène",),
    "iatrogènes": ("iatrogène",),
    "iatrogénique": ("iatrogénique",),
    "iatrogéniques": ("iatrogénique",),
    "ibère": ("ibère",),
    "ibères": ("ibère",),
    "ibérien": ("ibérien",),
    "ibérienne": ("ibérien",),
    "ibériennes": ("ibérien",),
    "ibériens": ("ibérien",),
    "ibérique": ("ibérique",),
    "ibériques": ("ibérique",),
    "ibérocaucasien": ("ibérocaucasien",),
    "ibérocaucasienne": ("ibérocaucasien",),
    "ibérocaucasiennes": ("ibérocaucasien",),
    "ibérocaucasiens": ("ibérocaucasien",),
    "ibéromaurusien": ("ibéromaurusien",),
    "ibéromaurusienne": ("ibéromaurusien",),
    "ibéromaurusiennes": ("ibéromaurusien",),
    "ibéromaurusiens": ("ibéromaurusien",),
    "ibsénien": ("ibsénien",),
    "ibsénienne": ("ibsénien",),
    "ibséniennes": ("ibsénien",),
    "ibséniens": ("ibsénien",),
    "icarien": ("icarien",),
    "icarienne": ("icarien",),
    "icariennes": ("icarien",),
    "icariens": ("icarien",),
    "icartien": ("icartien",),
    "icartienne": ("icartien",),
    "icartiennes": ("icartien",),
    "icartiens": ("icartien",),
    "ichoreuse": ("ichoreux",),
    "ichoreuses": ("ichoreux",),
    "ichoreux": ("ichoreux",),
    "ichtyoïde": ("ichtyoïde",),
    "ichtyoïdes": ("ichtyoïde",),
    "ichtyologique": ("ichtyologique",),
    "ichtyologiques": ("ichtyologique",),
    "ichtyophage": ("ichtyophage",),
    "ichtyophages": ("ichtyophage",),
    "ichtyosiforme": ("ichtyosiforme",),
    "ichtyosiformes": ("ichtyosiforme",),
    "ichtyosique": ("ichtyosique",),
    "ichtyosiques": ("ichtyosique",),
    "iconique": ("iconique",),
    "iconiques": ("iconique",),
    "iconoclaste": ("iconoclaste",),
    "iconoclastes": ("iconoclaste",),
    "iconographique": ("iconographique",),
    "iconographiques": ("iconographique",),
    "iconolâtrique": ("iconolâtrique",),
    "iconolâtriques": ("iconolâtrique",),
    "iconologique": ("iconologique",),
    "iconologiques": ("iconologique",),
    "iconométrique": ("iconométrique",),
    "iconométriques": ("iconométrique",),
    "ictérigène": ("ictérigène",),
    "ictérigènes": ("ictérigène",),
    "ictérique": ("ictérique",),
    "ictériques": ("ictérique",),
    "ictéro-ascitiques": ("ictéro-ascitique",),
    "idéalisateur": ("idéalisateur",),
    "idéalisateurs": ("idéalisateur",),
    "idéalisatrice": ("idéalisateur",),
    "idéalisatrices": ("idéalisateur",),
    "idéaliste": ("idéaliste",),
    "idéalistes": ("idéaliste",),
    "idéatif": ("idéatif",),
    "idéatifs": ("idéatif",),
    "idéative": ("idéatif",),
    "idéatives": ("idéatif",),
    "idéationnelle": ("idéationnel",),
    "idéationnelles": ("idéationnel",),
    "idéationnel": ("idéationnel",),
    "idéationnels": ("idéationnel",),
    "idéatoire": ("idéatoire",),
    "idéatoires": ("idéatoire",),
    "idéelle": ("idéel",),
    "idéelles": ("idéel",),
    "idéel": ("idéel",),
    "idéels": ("idéel",),
    "identifiable": ("identifiable",),
    "identifiables": ("identifiable",),
    "identificatoire": ("identificatoire",),
    "identificatoires": ("identificatoire",),
    "identique": ("identique",),
    "identiques": ("identique",),
    "identitaire": ("identitaire",),
    "identitaires": ("identitaire",),
    "idéocratique": ("idéocratique",),
    "idéocratiques": ("idéocratique",),
    "idéogrammatique": ("idéogrammatique",),
    "idéogrammatiques": ("idéogrammatique",),
    "idéographique": ("idéographique",),
    "idéographiques": ("idéographique",),
    "idéologique": ("idéologique",),
    "idéologiques": ("idéologique",),
    "idéomoteur": ("idéomoteur",),
    "idéomoteurs": ("idéomoteur",),
    "idéomotrice": ("idéomoteur",),
    "idéomotrices": ("idéomoteur",),
    "idéovisuelle": ("idéovisuel",),
    "idéovisuelles": ("idéovisuel",),
    "idéovisuel": ("idéovisuel",),
    "idéovisuels": ("idéovisuel",),
    "idiocinétique": ("idiocinétique",),
    "idiocinétiques": ("idiocinétique",),
    "idiolectale": ("idiolectal",),
    "idiolectales": ("idiolectal",),
    "idiolectal": ("idiolectal",),
    "idiolectaux": ("idiolectal",),
    "idiomatique": ("idiomatique",),
    "idiomatiques": ("idiomatique",),
    "idiomorphe": ("idiomorphe",),
    "idiomorphes": ("idiomorphe",),
    "idiomusculaire": ("idiomusculaire",),
    "idiomusculaires": ("idiomusculaire",),
    "idiopathique": ("idiopathique",),
    "idiopathiques": ("idiopathique",),
    "idiorrythmique": ("idiorrythmique",),
    "idiorrythmiques": ("idiorrythmique",),
    "idiostatique": ("idiostatique",),
    "idiostatiques": ("idiostatique",),
    "idiosyncrasique": ("idiosyncrasique",),
    "idiosyncrasiques": ("idiosyncrasique",),
    "idiosyncratique": ("idiosyncratique",),
    "idiosyncratiques": ("idiosyncratique",),
    "idiotique": ("idiotique",),
    "idiotiques": ("idiotique",),
    "idiotypique": ("idiotypique",),
    "idiotypiques": ("idiotypique",),
    "idioventriculaire": ("idioventriculaire",),
    "idioventriculaires": ("idioventriculaire",),
    "idiste": ("idiste",),
    "idistes": ("idiste",),
    "idoine": ("idoine",),
    "idoines": ("idoine",),
    "idolâtre": ("idolâtre",),
    "idolâtres": ("idolâtre",),
    "idolâtrique": ("idolâtrique",),
    "idolâtriques": ("idolâtrique",),
    "idonique": ("idonique",),
    "idoniques": ("idonique",),
    "idosaccharique": ("idosaccharique",),
    "idosacchariques": ("idosaccharique",),
    "idyllique": ("idyllique",),
    "idylliques": ("idyllique",),
    "ième": ("ième",),
    "ièmes": ("ième",),
    "ignacien": ("ignacien",),
    "ignacienne": ("ignacien",),
    "ignaciennes": ("ignacien",),
    "ignaciens": ("ignacien",),
    "ignare": ("ignare",),
    "ignares": ("ignare",),
    "ignifuge": ("ignifuge",),
    "ignifuges": ("ignifuge",),
    "ignigène": ("ignigène",),
    "ignigènes": ("ignigène",),
    "ignimbritique": ("ignimbritique",),
    "ignimbritiques": ("ignimbritique",),
    "ignitubulaire": ("ignitubulaire",),
    "ignitubulaires": ("ignitubulaire",),
    "ignivome": ("ignivome",),
    "ignivomes": ("ignivome",),
    "ignoble": ("ignoble",),
    "ignobles": ("ignoble",),
    "ignominieuse": ("ignominieux",),
    "ignominieuses": ("ignominieux",),
    "ignominieux": ("ignominieux",),
    "ignorantiste": ("ignorantiste",),
    "ignorantistes": ("ignorantiste",),
    "iléale": ("iléal",),
    "iléales": ("iléal",),
    "iléal": ("iléal",),
    "iléaux": ("iléal",),
    "iléocaecale": ("iléocaecale",),
    "iléocaecales": ("iléocaecale",),
    "iléo-caecal": ("iléo-caecal",),
    "iléocaecal": ("iléocaecal",),
    "iléo-caecaux": ("iléo-caecal",),
    "iléocaecaux": ("iléocaecal",),
    "iliaque": ("iliaque",),
    "iliaques": ("iliaque",),
    "îlien": ("îlien",),
    "îlienne": ("îlien",),
    "îliennes": ("îlien",),
    "îliens": ("îlien",),
    "ilio-fémorales": ("ilio-fémoral",),
    "ilio-lombaires": ("ilio-lombaire",),
    "ilio-pectinées": ("ilio-pectiné",),
    "ilio-pubienne": ("ilio-pubien",),
    "illégale": ("illégal",),
    "illégales": ("illégal",),
    "illégal": ("illégal",),
    "illégaux": ("illégal",),
    "illégitime": ("illégitime",),
    "illégitimes": ("illégitime",),
    "illicite": ("illicite",),
    "illicites": ("illicite",),
    "illimitable": ("illimitable",),
    "illimitables": ("illimitable",),
    "illisible": ("illisible",),
    "illisibles": ("illisible",),
    "illocutionnaire": ("illocutionnaire",),
    "illocutionnaires": ("illocutionnaire",),
    "illocutoire": ("illocutoire",),
    "illocutoires": ("illocutoire",),
    "illogique": ("illogique",),
    "illogiques": ("illogique",),
    "illuminable": ("illuminable",),
    "illuminables": ("illuminable",),
    "illuminateur": ("illuminateur",),
    "illuminateurs": ("illuminateur",),
    "illuminatrice": ("illuminateur",),
    "illuminatrices": ("illuminateur",),
    "illuminatif": ("illuminatif",),
    "illuminatifs": ("illuminatif",),
    "illuminative": ("illuminatif",),
    "illuminatives": ("illuminatif",),
    "illuministe": ("illuministe",),
    "illuministes": ("illuministe",),
    "illusionnelle": ("illusionnel",),
    "illusionnelles": ("illusionnel",),
    "illusionnel": ("illusionnel",),
    "illusionnels": ("illusionnel",),
    "illusionniste": ("illusionniste",),
    "illusionnistes": ("illusionniste",),
    "illusoire": ("illusoire",),
    "illusoires": ("illusoire",),
    "illustratif": ("illustratif",),
    "illustratifs": ("illustratif",),
    "illustrative": ("illustratif",),
    "illustratives": ("illustratif",),
    "illustrée": ("illustré",),
    "illustrées": ("illustré",),
    "illustré": ("illustré",),
    "illustre": ("illustre",),
    "illustrés": ("illustré",),
    "illustres": ("illustre",),
    "illustrissime": ("illustrissime",),
    "illustrissimes": ("illustrissime",),
    "illuviale": ("illuvial",),
    "illuviales": ("illuvial",),
    "illuvial": ("illuvial",),
    "illuviaux": ("illuvial",),
    "illyrien": ("illyrien",),
    "illyrienne": ("illyrien",),
    "illyriennes": ("illyrien",),
    "illyriens": ("illyrien",),
    "illyrique": ("illyrique",),
    "illyriques": ("illyrique",),
    "imagière": ("imagier",),
    "imagières": ("imagier",),
    "imagier": ("imagier",),
    "imagiers": ("imagier",),
    "imaginable": ("imaginable",),
    "imaginables": ("imaginable",),
    "imaginaire": ("imaginaire",),
    "imaginaires": ("imaginaire",),
    "imaginale": ("imaginal",),
    "imaginales": ("imaginal",),
    "imaginal": ("imaginal",),
    "imaginaux": ("imaginal",),
    "imaginatif": ("imaginatif",),
    "imaginatifs": ("imaginatif",),
    "imaginative": ("imaginatif",),
    "imaginatives": ("imaginatif",),
    "imagiste": ("imagiste",),
    "imagistes": ("imagiste",),
    "imamite": ("imamite",),
    "imamites": ("imamite",),
    "imbattable": ("imbattable",),
    "imbattables": ("imbattable",),
    "imbécile": ("imbécile",),
    "imbéciles": ("imbécile",),
    "imberbe": ("imberbe",),
    "imberbes": ("imberbe",),
    "imbitable": ("imbitable",),
    "imbitables": ("imbitable",),
    "imbittable": ("imbittable",),
    "imbittables": ("imbittable",),
    "imbouchable": ("imbouchable",),
    "imbouchables": ("imbouchable",),
    "imbrisable": ("imbrisable",),
    "imbrisables": ("imbrisable",),
    "imbrûlable": ("imbrûlable",),
    "imbrûlables": ("imbrûlable",),
    "imbuvable": ("imbuvable",),
    "imbuvables": ("imbuvable",),
    "imipraminique": ("imipraminique",),
    "imipraminiques": ("imipraminique",),
    "imitable": ("imitable",),
    "imitables": ("imitable",),
    "imitateur": ("imitateur",),
    "imitateurs": ("imitateur",),
    "imitatrice": ("imitateur",),
    "imitatrices": ("imitateur",),
    "imitatif": ("imitatif",),
    "imitatifs": ("imitatif",),
    "imitative": ("imitatif",),
    "imitatives": ("imitatif",),
    "immanentiste": ("immanentiste",),
    "immanentistes": ("immanentiste",),
    "immangeable": ("immangeable",),
    "immangeables": ("immangeable",),
    "immaniable": ("immaniable",),
    "immaniables": ("immaniable",),
    "immanquable": ("immanquable",),
    "immanquables": ("immanquable",),
    "immarcescible": ("immarcescible",),
    "immarcescibles": ("immarcescible",),
    "immariable": ("immariable",),
    "immariables": ("immariable",),
    "immatérialiste": ("immatérialiste",),
    "immatérialistes": ("immatérialiste",),
    "immatérielle": ("immatériel",),
    "immatérielles": ("immatériel",),
    "immatériel": ("immatériel",),
    "immatériels": ("immatériel",),
    "immaturée": ("immaturé",),
    "immaturées": ("immaturé",),
    "immaturé": ("immaturé",),
    "immature": ("immature",),
    "immaturés": ("immaturé",),
    "immatures": ("immature",),
    "immémorable": ("immémorable",),
    "immémorables": ("immémorable",),
    "immémoriale": ("immémorial",),
    "immémoriales": ("immémorial",),
    "immémorial": ("immémorial",),
    "immémoriaux": ("immémorial",),
    "immense": ("immense",),
    "immenses": ("immense",),
    "immensurable": ("immensurable",),
    "immensurables": ("immensurable",),
    "immersif": ("immersif",),
    "immersifs": ("immersif",),
    "immersive": ("immersif",),
    "immersives": ("immersif",),
    "immesurable": ("immesurable",),
    "immesurables": ("immesurable",),
    "immettable": ("immettable",),
    "immettables": ("immettable",),
    "immeuble": ("immeuble",),
    "immeubles": ("immeuble",),
    "immiscible": ("immiscible",),
    "immiscibles": ("immiscible",),
    "immobile": ("immobile",),
    "immobiles": ("immobile",),
    "immobilière": ("immobilier",),
    "immobilières": ("immobilier",),
    "immobilier": ("immobilier",),
    "immobiliers": ("immobilier",),
    "immobiliste": ("immobiliste",),
    "immobilistes": ("immobiliste",),
    "immodeste": ("immodeste",),
    "immodestes": ("immodeste",),
    "immonde": ("immonde",),
    "immondes": ("immonde",),
    "immorale": ("immoral",),
    "immorales": ("immoral",),
    "immoral": ("immoral",),
    "immoraux": ("immoral",),
    "immoraliste": ("immoraliste",),
    "immoralistes": ("immoraliste",),
    "immortelle": ("immortel",),
    "immortelles": ("immortel",),
    "immortel": ("immortel",),
    "immortels": ("immortel",),
    "immuable": ("immuable",),
    "immuables": ("immuable",),
    "immunitaire": ("immunitaire",),
    "immunitaires": ("immunitaire",),
    "immunoblastique": ("immunoblastique",),
    "immunoblastiques": ("immunoblastique",),
    "immunocalcique": ("immunocalcique",),
    "immunocalciques": ("immunocalcique",),
    "immunochimique": ("immunochimique",),
    "immunochimiques": ("immunochimique",),
    "immunodéficitaire": ("immunodéficitaire",),
    "immuno-déficitaires": ("immunodéficitaire",),
    "immunodéficitaires": ("immunodéficitaire",),
    "immunodépresseur": ("immunodépresseur",),
    "immunodépresseurs": ("immunodépresseur",),
    "immunodépressif": ("immunodépressif",),
    "immunodépressifs": ("immunodépressif",),
    "immunodépressive": ("immunodépressif",),
    "immunodépressives": ("immunodépressif",),
    "immuno-effectrice": ("immuno-effecteur",),
    "immunoenzymatique": ("immunoenzymatique",),
    "immuno-enzymatiques": ("immuno-enzymatique",),
    "immunoenzymatiques": ("immunoenzymatique",),
    "immunogène": ("immunogène",),
    "immunogènes": ("immunogène",),
    "immunogénétique": ("immunogénétique",),
    "immunogénétiques": ("immunogénétique",),
    "immunogénique": ("immunogénique",),
    "immunogéniques": ("immunogénique",),
    "immunohématologique": ("immunohématologique",),
    "immunohématologiques": ("immunohématologique",),
    "immuno-inhibiteur": ("immuno-inhibiteur",),
    "immuno-inhibitrices": ("immuno-inhibiteur",),
    "immunologique": ("immunologique",),
    "immunologiques": ("immunologique",),
    "immunométrique": ("immunométrique",),
    "immunométriques": ("immunométrique",),
    "immunomimétique": ("immunomimétique",),
    "immunomimétiques": ("immunomimétique",),
    "immunomodulateur": ("immunomodulateur",),
    "immunomodulateurs": ("immunomodulateur",),
    "immunomodulatrice": ("immunomodulateur",),
    "immunomodulatrices": ("immunomodulateur",),
    "immunopathologique": ("immunopathologique",),
    "immunopathologiques": ("immunopathologique",),
    "immunoprolifératif": ("immunoprolifératif",),
    "immunoprolifératifs": ("immunoprolifératif",),
    "immunoproliférative": ("immunoprolifératif",),
    "immunoprolifératives": ("immunoprolifératif",),
    "immunoprotecteur": ("immunoprotecteur",),
    "immunoprotecteurs": ("immunoprotecteur",),
    "immunoprotectrice": ("immunoprotecteur",),
    "immunoprotectrices": ("immunoprotecteur",),
    "immunorégulateur": ("immunorégulateur",),
    "immunorégulateurs": ("immunorégulateur",),
    "immunorégulatrice": ("immunorégulateur",),
    "immunorégulatrices": ("immunorégulateur",),
    "immunorépressif": ("immunorépressif",),
    "immunorépressifs": ("immunorépressif",),
    "immunorépressive": ("immunorépressif",),
    "immunorépressives": ("immunorépressif",),
    "immunosérologique": ("immunosérologique",),
    "immunosérologiques": ("immunosérologique",),
    "immunostimulateur": ("immunostimulateur",),
    "immunostimulateurs": ("immunostimulateur",),
    "immunostimulatrice": ("immunostimulateur",),
    "immunostimulatrices": ("immunostimulateur",),
    "immunostimulating": ("immunostimulating",),
    "immunosuppresseur": ("immunosuppresseur",),
    "immunosuppresseurs": ("immunosuppresseur",),
    "immunosuppressif": ("immunosuppressif",),
    "immunosuppressifs": ("immunosuppressif",),
    "immunosuppressive": ("immunosuppressif",),
    "immunosuppressives": ("immunosuppressif",),
    "immunothérapeutique": ("immunothérapeutique",),
    "immunothérapeutiques": ("immunothérapeutique",),
    "immunothérapique": ("immunothérapique",),
    "immunothérapiques": ("immunothérapique",),
    "immunotrophique": ("immunotrophique",),
    "immunotrophiques": ("immunotrophique",),
    "immutable": ("immutable",),
    "immutables": ("immutable",),
    "impact": ("impact",),
    "impalpable": ("impalpable",),
    "impalpables": ("impalpable",),
    "imparable": ("imparable",),
    "imparables": ("imparable",),
    "impardonnable": ("impardonnable",),
    "impardonnables": ("impardonnable",),
    "imparisyllabique": ("imparisyllabique",),
    "imparisyllabiques": ("imparisyllabique",),
    "impartageable": ("impartageable",),
    "impartageables": ("impartageable",),
    "impartiale": ("impartial",),
    "impartiales": ("impartial",),
    "impartial": ("impartial",),
    "impartiaux": ("impartial",),
    "impassable": ("impassable",),
    "impassables": ("impassable",),
    "impassible": ("impassible",),
    "impassibles": ("impassible",),
    "impavide": ("impavide",),
    "impavides": ("impavide",),
    "impayable": ("impayable",),
    "impayables": ("impayable",),
    "impec": ("impec",),
    "impeccable": ("impeccable",),
    "impeccables": ("impeccable",),
    "impécunieuse": ("impécunieux",),
    "impécunieuses": ("impécunieux",),
    "impécunieux": ("impécunieux",),
    "impeignable": ("impeignable",),
    "impeignables": ("impeignable",),
    "impendable": ("impendable",),
    "impendables": ("impendable",),
    "impénétrable": ("impénétrable",),
    "impénétrables": ("impénétrable",),
    "impensable": ("impensable",),
    "impensables": ("impensable",),
    "impératif": ("impératif",),
    "impératifs": ("impératif",),
    "impérative": ("impératif",),
    "impératives": ("impératif",),
    "imperceptible": ("imperceptible",),
    "imperceptibles": ("imperceptible",),
    "imperdable": ("imperdable",),
    "imperdables": ("imperdable",),
    "imperfectible": ("imperfectible",),
    "imperfectibles": ("imperfectible",),
    "imperfectif": ("imperfectif",),
    "imperfectifs": ("imperfectif",),
    "imperfective": ("imperfectif",),
    "imperfectives": ("imperfectif",),
    "impériale": ("impérial",),
    "impériales": ("impérial",),
    "impérial": ("impérial",),
    "impériaux": ("impérial",),
    "impérialiste": ("impérialiste",),
    "impérialistes": ("impérialiste",),
    "impérieuse": ("impérieux",),
    "impérieuses": ("impérieux",),
    "impérieux": ("impérieux",),
    "impérissable": ("impérissable",),
    "impérissables": ("impérissable",),
    "imperméable": ("imperméable",),
    "imperméables": ("imperméable",),
    "impersonnelle": ("impersonnel",),
    "impersonnelles": ("impersonnel",),
    "impersonnel": ("impersonnel",),
    "impersonnels": ("impersonnel",),
    "imperturbable": ("imperturbable",),
    "imperturbables": ("imperturbable",),
    "impétigineuse": ("impétigineux",),
    "impétigineuses": ("impétigineux",),
    "impétigineux": ("impétigineux",),
    "impétrable": ("impétrable",),
    "impétrables": ("impétrable",),
    "impétueuse": ("impétueux",),
    "impétueuses": ("impétueux",),
    "impétueux": ("impétueux",),
    "impie": ("impie",),
    "impies": ("impie",),
    "impitoyable": ("impitoyable",),
    "impitoyables": ("impitoyable",),
    "implacable": ("implacable",),
    "implacables": ("implacable",),
    "implanifiable": ("implanifiable",),
    "implanifiables": ("implanifiable",),
    "implantable": ("implantable",),
    "implantables": ("implantable",),
    "implémentatoire": ("implémentatoire",),
    "implémentatoires": ("implémentatoire",),
    "implexe": ("implexe",),
    "implexes": ("implexe",),
    "impliable": ("impliable",),
    "impliables": ("impliable",),
    "implicatif": ("implicatif",),
    "implicatifs": ("implicatif",),
    "implicative": ("implicatif",),
    "implicatives": ("implicatif",),
    "implicite": ("implicite",),
    "implicites": ("implicite",),
    "implorable": ("implorable",),
    "implorables": ("implorable",),
    "implosif": ("implosif",),
    "implosifs": ("implosif",),
    "implosive": ("implosif",),
    "implosives": ("implosif",),
    "imployable": ("imployable",),
    "imployables": ("imployable",),
    "impolarisable": ("impolarisable",),
    "impolarisables": ("impolarisable",),
    "impolitique": ("impolitique",),
    "impolitiques": ("impolitique",),
    "impolluable": ("impolluable",),
    "impolluables": ("impolluable",),
    "impondérable": ("impondérable",),
    "impondérables": ("impondérable",),
    "impopulaire": ("impopulaire",),
    "impopulaires": ("impopulaire",),
    "importable": ("importable",),
    "importables": ("importable",),
    "importateur": ("importateur",),
    "importateurs": ("importateur",),
    "importatrice": ("importateur",),
    "importatrices": ("importateur",),
    "imposable": ("imposable",),
    "imposables": ("imposable",),
    "impossible": ("impossible",),
    "impossibles": ("impossible",),
    "impraticable": ("impraticable",),
    "impraticables": ("impraticable",),
    "imprécatoire": ("imprécatoire",),
    "imprécatoires": ("imprécatoire",),
    "imprécisable": ("imprécisable",),
    "imprécisables": ("imprécisable",),
    "imprécise": ("imprécis",),
    "imprécises": ("imprécis",),
    "imprécis": ("imprécis",),
    "imprédicatif": ("imprédicatif",),
    "imprédicatifs": ("imprédicatif",),
    "imprédicative": ("imprédicatif",),
    "imprédicatives": ("imprédicatif",),
    "imprédictible": ("imprédictible",),
    "imprédictibles": ("imprédictible",),
    "imprenable": ("imprenable",),
    "imprenables": ("imprenable",),
    "imprescriptible": ("imprescriptible",),
    "imprescriptibles": ("imprescriptible",),
    "impressible": ("impressible",),
    "impressibles": ("impressible",),
    "impressif": ("impressif",),
    "impressifs": ("impressif",),
    "impressive": ("impressif",),
    "impressives": ("impressif",),
    "impressionnable": ("impressionnable",),
    "impressionnables": ("impressionnable",),
    "impressionniste": ("impressionniste",),
    "impressionnistes": ("impressionniste",),
    "imprévisible": ("imprévisible",),
    "imprévisibles": ("imprévisible",),
    "imprimable": ("imprimable",),
    "imprimables": ("imprimable",),
    "imprimeur": ("imprimeur",),
    "imprimeurs": ("imprimeur",),
    "imprimeuse": ("imprimeur",),
    "imprimeuses": ("imprimeur",),
    "improbable": ("improbable",),
    "improbables": ("improbable",),
    "improbateur": ("improbateur",),
    "improbateurs": ("improbateur",),
    "improbatrice": ("improbateur",),
    "improbatrices": ("improbateur",),
    "improductible": ("improductible",),
    "improductibles": ("improductible",),
    "improductif": ("improductif",),
    "improductifs": ("improductif",),
    "improductive": ("improductif",),
    "improductives": ("improductif",),
    "improlongeable": ("improlongeable",),
    "improlongeables": ("improlongeable",),
    "imprononçable": ("imprononçable",),
    "imprononçables": ("imprononçable",),
    "improposable": ("improposable",),
    "improposables": ("improposable",),
    "impropre": ("impropre",),
    "impropres": ("impropre",),
    "improuvable": ("improuvable",),
    "improuvables": ("improuvable",),
    "impubère": ("impubère",),
    "impubères": ("impubère",),
    "impubliable": ("impubliable",),
    "impubliables": ("impubliable",),
    "impudique": ("impudique",),
    "impudiques": ("impudique",),
    "impulsif": ("impulsif",),
    "impulsifs": ("impulsif",),
    "impulsive": ("impulsif",),
    "impulsives": ("impulsif",),
    "impulsionnelle": ("impulsionnel",),
    "impulsionnelles": ("impulsionnel",),
    "impulsionnel": ("impulsionnel",),
    "impulsionnels": ("impulsionnel",),
    "impunissable": ("impunissable",),
    "impunissables": ("impunissable",),
    "impurifiable": ("impurifiable",),
    "impurifiables": ("impurifiable",),
    "imputable": ("imputable",),
    "imputables": ("imputable",),
    "imputréfiable": ("imputréfiable",),
    "imputréfiables": ("imputréfiable",),
    "imputrescible": ("imputrescible",),
    "imputrescibles": ("imputrescible",),
    "inabordable": ("inabordable",),
    "inabordables": ("inabordable",),
    "inabrogeable": ("inabrogeable",),
    "inabrogeables": ("inabrogeable",),
    "inacceptable": ("inacceptable",),
    "inacceptables": ("inacceptable",),
    "inaccessible": ("inaccessible",),
    "inaccessibles": ("inaccessible",),
    "inaccommodable": ("inaccommodable",),
    "inaccommodables": ("inaccommodable",),
    "inaccordable": ("inaccordable",),
    "inaccordables": ("inaccordable",),
    "inaccostable": ("inaccostable",),
    "inaccostables": ("inaccostable",),
    "inaccusable": ("inaccusable",),
    "inaccusables": ("inaccusable",),
    "inaccusatif": ("inaccusatif",),
    "inaccusatifs": ("inaccusatif",),
    "inaccusative": ("inaccusatif",),
    "inaccusatives": ("inaccusatif",),
    "inachetable": ("inachetable",),
    "inachetables": ("inachetable",),
    "inactif": ("inactif",),
    "inactifs": ("inactif",),
    "inactive": ("inactif",),
    "inactives": ("inactif",),
    "inactinique": ("inactinique",),
    "inactiniques": ("inactinique",),
    "inactuelle": ("inactuel",),
    "inactuelles": ("inactuel",),
    "inactuel": ("inactuel",),
    "inactuels": ("inactuel",),
    "inadaptable": ("inadaptable",),
    "inadaptables": ("inadaptable",),
    "inadmissible": ("inadmissible",),
    "inadmissibles": ("inadmissible",),
    "inaffectif": ("inaffectif",),
    "inaffectifs": ("inaffectif",),
    "inaffective": ("inaffectif",),
    "inaffectives": ("inaffectif",),
    "in": ("in",),
    "inajournable": ("inajournable",),
    "inajournables": ("inajournable",),
    "inaliénable": ("inaliénable",),
    "inaliénables": ("inaliénable",),
    "inalliable": ("inalliable",),
    "inalliables": ("inalliable",),
    "inallumable": ("inallumable",),
    "inallumables": ("inallumable",),
    "inaltérable": ("inaltérable",),
    "inaltérables": ("inaltérable",),
    "inamicale": ("inamical",),
    "inamicales": ("inamical",),
    "inamical": ("inamical",),
    "inamicaux": ("inamical",),
    "inamissible": ("inamissible",),
    "inamissibles": ("inamissible",),
    "inamovible": ("inamovible",),
    "inamovibles": ("inamovible",),
    "inanalysable": ("inanalysable",),
    "inanalysables": ("inanalysable",),
    "inapaisable": ("inapaisable",),
    "inapaisables": ("inapaisable",),
    "inappareillable": ("inappareillable",),
    "inappareillables": ("inappareillable",),
    "inapplicable": ("inapplicable",),
    "inapplicables": ("inapplicable",),
    "inappréciable": ("inappréciable",),
    "inappréciables": ("inappréciable",),
    "inapprenable": ("inapprenable",),
    "inapprenables": ("inapprenable",),
    "inapprivoisable": ("inapprivoisable",),
    "inapprivoisables": ("inapprivoisable",),
    "inapprochable": ("inapprochable",),
    "inapprochables": ("inapprochable",),
    "inappropriable": ("inappropriable",),
    "inappropriables": ("inappropriable",),
    "inapte": ("inapte",),
    "inaptes": ("inapte",),
    "inarrachable": ("inarrachable",),
    "inarrachables": ("inarrachable",),
    "inarrangeable": ("inarrangeable",),
    "inarrangeables": ("inarrangeable",),
    "inarrêtable": ("inarrêtable",),
    "inarrêtables": ("inarrêtable",),
    "inarticulable": ("inarticulable",),
    "inarticulables": ("inarticulable",),
    "inassimilable": ("inassimilable",),
    "inassimilables": ("inassimilable",),
    "inassouvissable": ("inassouvissable",),
    "inassouvissables": ("inassouvissable",),
    "inattaquable": ("inattaquable",),
    "inattaquables": ("inattaquable",),
    "inatteignable": ("inatteignable",),
    "inatteignables": ("inatteignable",),
    "inattentif": ("inattentif",),
    "inattentifs": ("inattentif",),
    "inattentive": ("inattentif",),
    "inattentives": ("inattentif",),
    "inaudible": ("inaudible",),
    "inaudibles": ("inaudible",),
    "inaugurale": ("inaugural",),
    "inaugurales": ("inaugural",),
    "inaugural": ("inaugural",),
    "inauguraux": ("inaugural",),
    "inauthentique": ("inauthentique",),
    "inauthentiques": ("inauthentique",),
    "inavouable": ("inavouable",),
    "inavouables": ("inavouable",),
    "inca": ("inca",),
    "incas": ("inca",),
    "incalculable": ("incalculable",),
    "incalculables": ("incalculable",),
    "incalmable": ("incalmable",),
    "incalmables": ("incalmable",),
    "incantatoire": ("incantatoire",),
    "incantatoires": ("incantatoire",),
    "incapable": ("incapable",),
    "incapables": ("incapable",),
    "incarcérable": ("incarcérable",),
    "incarcérables": ("incarcérable",),
    "incasable": ("incasable",),
    "incasables": ("incasable",),
    "incasique": ("incasique",),
    "incasiques": ("incasique",),
    "incassable": ("incassable",),
    "incassables": ("incassable",),
    "incendiaire": ("incendiaire",),
    "incendiaires": ("incendiaire",),
    "incernable": ("incernable",),
    "incernables": ("incernable",),
    "incessible": ("incessible",),
    "incessibles": ("incessible",),
    "inceste": ("inceste",),
    "incestes": ("inceste",),
    "incestueuse": ("incestueux",),
    "incestueuses": ("incestueux",),
    "incestueux": ("incestueux",),
    "inchangeable": ("inchangeable",),
    "inchangeables": ("inchangeable",),
    "inchantable": ("inchantable",),
    "inchantables": ("inchantable",),
    "inchauffable": ("inchauffable",),
    "inchauffables": ("inchauffable",),
    "inchavirable": ("inchavirable",),
    "inchavirables": ("inchavirable",),
    "inchiffrable": ("inchiffrable",),
    "inchiffrables": ("inchiffrable",),
    "inchoatif": ("inchoatif",),
    "inchoatifs": ("inchoatif",),
    "inchoative": ("inchoatif",),
    "inchoatives": ("inchoatif",),
    "inchoquable": ("inchoquable",),
    "inchoquables": ("inchoquable",),
    "inchrétien": ("inchrétien",),
    "inchrétienne": ("inchrétien",),
    "inchrétiennes": ("inchrétien",),
    "inchrétiens": ("inchrétien",),
    "incidentelle": ("incidentel",),
    "incidentelles": ("incidentel",),
    "incidentel": ("incidentel",),
    "incidentels": ("incidentel",),
    "incinérateur": ("incinérateur",),
    "incinérateurs": ("incinérateur",),
    "incinératrice": ("incinérateur",),
    "incinératrices": ("incinérateur",),
    "incipiens": ("incipiens",),
    "incirconcise": ("incirconcis",),
    "incirconcises": ("incirconcis",),
    "incirconcis": ("incirconcis",),
    "incisée": ("incisé",),
    "incisées": ("incisé",),
    "incise": ("incise",),
    "incisé": ("incisé",),
    "incises": ("incise",),
    "incisés": ("incisé",),
    "incisif": ("incisif",),
    "incisifs": ("incisif",),
    "incisive": ("incisif",),
    "incisives": ("incisif",),
    "incitable": ("incitable",),
    "incitables": ("incitable",),
    "incitateur": ("incitateur",),
    "incitateurs": ("incitateur",),
    "incitatrice": ("incitateur",),
    "incitatrices": ("incitateur",),
    "incitatif": ("incitatif",),
    "incitatifs": ("incitatif",),
    "incitative": ("incitatif",),
    "incitatives": ("incitatif",),
    "incitomoteur": ("incitomoteur",),
    "incitomoteurs": ("incitomoteur",),
    "incitomotrice": ("incitomoteur",),
    "incitomotrices": ("incitomoteur",),
    "incivilisable": ("incivilisable",),
    "incivilisables": ("incivilisable",),
    "incivique": ("incivique",),
    "inciviques": ("incivique",),
    "inclassable": ("inclassable",),
    "inclassables": ("inclassable",),
    "inclinable": ("inclinable",),
    "inclinables": ("inclinable",),
    "incluse": ("inclus",),
    "incluses": ("inclus",),
    "inclus": ("inclus",),
    "inclusif": ("inclusif",),
    "inclusifs": ("inclusif",),
    "inclusive": ("inclusif",),
    "inclusives": ("inclusif",),
    "incoagulable": ("incoagulable",),
    "incoagulables": ("incoagulable",),
    "incodifiable": ("incodifiable",),
    "incodifiables": ("incodifiable",),
    "incoercible": ("incoercible",),
    "incoercibles": ("incoercible",),
    "incoiffable": ("incoiffable",),
    "incoiffables": ("incoiffable",),
    "incollable": ("incollable",),
    "incollables": ("incollable",),
    "incolore": ("incolore",),
    "incolores": ("incolore",),
    "incombustible": ("incombustible",),
    "incombustibles": ("incombustible",),
    "incomestible": ("incomestible",),
    "incomestibles": ("incomestible",),
    "incommensurable": ("incommensurable",),
    "incommensurables": ("incommensurable",),
    "incommodée": ("incommodé",),
    "incommodées": ("incommodé",),
    "incommodé": ("incommodé",),
    "incommode": ("incommode",),
    "incommodés": ("incommodé",),
    "incommodes": ("incommode",),
    "incommunicable": ("incommunicable",),
    "incommunicables": ("incommunicable",),
    "incommutable": ("incommutable",),
    "incommutables": ("incommutable",),
    "incomparable": ("incomparable",),
    "incomparables": ("incomparable",),
    "incompatible": ("incompatible",),
    "incompatibles": ("incompatible",),
    "incompensable": ("incompensable",),
    "incompensables": ("incompensable",),
    "incompilable": ("incompilable",),
    "incompilables": ("incompilable",),
    "incomplète": ("incomplet",),
    "incomplètes": ("incomplet",),
    "incomplet": ("incomplet",),
    "incomplets": ("incomplet",),
    "incompréhensible": ("incompréhensible",),
    "incompréhensibles": ("incompréhensible",),
    "incompréhensif": ("incompréhensif",),
    "incompréhensifs": ("incompréhensif",),
    "incompréhensive": ("incompréhensif",),
    "incompréhensives": ("incompréhensif",),
    "incompressible": ("incompressible",),
    "incompressibles": ("incompressible",),
    "incomprise": ("incompris",),
    "incomprises": ("incompris",),
    "incompris": ("incompris",),
    "inconcevable": ("inconcevable",),
    "inconcevables": ("inconcevable",),
    "inconciliable": ("inconciliable",),
    "inconciliables": ("inconciliable",),
    "incondensable": ("incondensable",),
    "incondensables": ("incondensable",),
    "inconditionnelle": ("inconditionnel",),
    "inconditionnelles": ("inconditionnel",),
    "inconditionnel": ("inconditionnel",),
    "inconditionnels": ("inconditionnel",),
    "inconfortable": ("inconfortable",),
    "inconfortables": ("inconfortable",),
    "incongédiable": ("incongédiable",),
    "incongédiables": ("incongédiable",),
    "incongelable": ("incongelable",),
    "incongelables": ("incongelable",),
    "inconjugable": ("inconjugable",),
    "inconjugables": ("inconjugable",),
    "inconnaissable": ("inconnaissable",),
    "inconnaissables": ("inconnaissable",),
    "inconsolable": ("inconsolable",),
    "inconsolables": ("inconsolable",),
    "inconsommable": ("inconsommable",),
    "inconsommables": ("inconsommable",),
    "inconstatable": ("inconstatable",),
    "inconstatables": ("inconstatable",),
    "inconstitutionnelle": ("inconstitutionnel",),
    "inconstitutionnelles": ("inconstitutionnel",),
    "inconstitutionnel": ("inconstitutionnel",),
    "inconstitutionnels": ("inconstitutionnel",),
    "inconstructible": ("inconstructible",),
    "inconstructibles": ("inconstructible",),
    "incontentable": ("incontentable",),
    "incontentables": ("incontentable",),
    "incontestable": ("incontestable",),
    "incontestables": ("incontestable",),
    "incontournable": ("incontournable",),
    "incontournables": ("incontournable",),
    "incontrôlable": ("incontrôlable",),
    "incontrôlables": ("incontrôlable",),
    "incontroversable": ("incontroversable",),
    "incontroversables": ("incontroversable",),
    "inconvenable": ("inconvenable",),
    "inconvenables": ("inconvenable",),
    "inconversible": ("inconversible",),
    "inconversibles": ("inconversible",),
    "inconvertible": ("inconvertible",),
    "inconvertibles": ("inconvertible",),
    "inconvertissable": ("inconvertissable",),
    "inconvertissables": ("inconvertissable",),
    "incorporable": ("incorporable",),
    "incorporables": ("incorporable",),
    "incorporelle": ("incorporel",),
    "incorporelles": ("incorporel",),
    "incorporel": ("incorporel",),
    "incorporels": ("incorporel",),
    "incorrigible": ("incorrigible",),
    "incorrigibles": ("incorrigible",),
    "incorruptible": ("incorruptible",),
    "incorruptibles": ("incorruptible",),
    "incouvé": ("incouvé",),
    "incouvés": ("incouvé",),
    "incréable": ("incréable",),
    "incréables": ("incréable",),
    "incrédule": ("incrédule",),
    "incrédules": ("incrédule",),
    "incrémentale": ("incrémental",),
    "incrémentales": ("incrémental",),
    "incrémental": ("incrémental",),
    "incrémentaux": ("incrémental",),
    "incrémentielle": ("incrémentiel",),
    "incrémentielles": ("incrémentiel",),
    "incrémentiel": ("incrémentiel",),
    "incrémentiels": ("incrémentiel",),
    "increvable": ("increvable",),
    "increvables": ("increvable",),
    "incriminable": ("incriminable",),
    "incriminables": ("incriminable",),
    "incristallisable": ("incristallisable",),
    "incristallisables": ("incristallisable",),
    "incritiquable": ("incritiquable",),
    "incritiquables": ("incritiquable",),
    "incrochetable": ("incrochetable",),
    "incrochetables": ("incrochetable",),
    "incroyable": ("incroyable",),
    "incroyables": ("incroyable",),
    "incubateur": ("incubateur",),
    "incubateurs": ("incubateur",),
    "incubatrice": ("incubateur",),
    "incubatrices": ("incubateur",),
    "incuisable": ("incuisable",),
    "incuisables": ("incuisable",),
    "inculpable": ("inculpable",),
    "inculpables": ("inculpable",),
    "inculte": ("inculte",),
    "incultes": ("inculte",),
    "incultivable": ("incultivable",),
    "incultivables": ("incultivable",),
    "incunable": ("incunable",),
    "incunables": ("incunable",),
    "incurable": ("incurable",),
    "incurables": ("incurable",),
    "incurieuse": ("incurieux",),
    "incurieuses": ("incurieux",),
    "incurieux": ("incurieux",),
    "incuse": ("incus",),
    "incuses": ("incus",),
    "incus": ("incus",),
    "indanthrénique": ("indanthrénique",),
    "indanthréniques": ("indanthrénique",),
    "indatable": ("indatable",),
    "indatables": ("indatable",),
    "indéboulonnable": ("indéboulonnable",),
    "indéboulonnables": ("indéboulonnable",),
    "indébrouillable": ("indébrouillable",),
    "indébrouillables": ("indébrouillable",),
    "indécachetable": ("indécachetable",),
    "indécachetables": ("indécachetable",),
    "indécelable": ("indécelable",),
    "indécelables": ("indécelable",),
    "indéchiffrable": ("indéchiffrable",),
    "indéchiffrables": ("indéchiffrable",),
    "indéchirable": ("indéchirable",),
    "indéchirables": ("indéchirable",),
    "indécidable": ("indécidable",),
    "indécidables": ("indécidable",),
    "indécise": ("indécis",),
    "indécises": ("indécis",),
    "indécis": ("indécis",),
    "indéclinable": ("indéclinable",),
    "indéclinables": ("indéclinable",),
    "indécolable": ("indécolable",),
    "indécolables": ("indécolable",),
    "indécollable": ("indécollable",),
    "indécollables": ("indécollable",),
    "indécomposable": ("indécomposable",),
    "indécomposables": ("indécomposable",),
    "indéconcertable": ("indéconcertable",),
    "indéconcertables": ("indéconcertable",),
    "indécousable": ("indécousable",),
    "indécousables": ("indécousable",),
    "indécrassable": ("indécrassable",),
    "indécrassables": ("indécrassable",),
    "indécrochable": ("indécrochable",),
    "indécrochables": ("indécrochable",),
    "indécrottable": ("indécrottable",),
    "indécrottables": ("indécrottable",),
    "indédoublable": ("indédoublable",),
    "indédoublables": ("indédoublable",),
    "indéfectible": ("indéfectible",),
    "indéfectibles": ("indéfectible",),
    "indéfendable": ("indéfendable",),
    "indéfendables": ("indéfendable",),
    "indéfinissable": ("indéfinissable",),
    "indéfinissables": ("indéfinissable",),
    "indéformable": ("indéformable",),
    "indéformables": ("indéformable",),
    "indéfrichable": ("indéfrichable",),
    "indéfrichables": ("indéfrichable",),
    "indéfrisable": ("indéfrisable",),
    "indéfrisables": ("indéfrisable",),
    "indégonflable": ("indégonflable",),
    "indégonflables": ("indégonflable",),
    "indégradable": ("indégradable",),
    "indégradables": ("indégradable",),
    "indélébile": ("indélébile",),
    "indélébiles": ("indélébile",),
    "indélivrable": ("indélivrable",),
    "indélivrables": ("indélivrable",),
    "indélogeable": ("indélogeable",),
    "indélogeables": ("indélogeable",),
    "indémaillable": ("indémaillable",),
    "indémaillables": ("indémaillable",),
    "indémêlable": ("indémêlable",),
    "indémêlables": ("indémêlable",),
    "indémerdable": ("indémerdable",),
    "indémerdables": ("indémerdable",),
    "indemne": ("indemne",),
    "indemnes": ("indemne",),
    "indemnisable": ("indemnisable",),
    "indemnisables": ("indemnisable",),
    "indemnitaire": ("indemnitaire",),
    "indemnitaires": ("indemnitaire",),
    "indémodable": ("indémodable",),
    "indémodables": ("indémodable",),
    "indémontable": ("indémontable",),
    "indémontables": ("indémontable",),
    "indémontrable": ("indémontrable",),
    "indémontrables": ("indémontrable",),
    "indéniable": ("indéniable",),
    "indéniables": ("indéniable",),
    "indénombrable": ("indénombrable",),
    "indénombrables": ("indénombrable",),
    "indénouable": ("indénouable",),
    "indénouables": ("indénouable",),
    "indépassable": ("indépassable",),
    "indépassables": ("indépassable",),
    "indépendantiste": ("indépendantiste",),
    "indépendantistes": ("indépendantiste",),
    "indépliable": ("indépliable",),
    "indépliables": ("indépliable",),
    "indéracinable": ("indéracinable",),
    "indéracinables": ("indéracinable",),
    "indéraillable": ("indéraillable",),
    "indéraillables": ("indéraillable",),
    "indéréglable": ("indéréglable",),
    "indéréglables": ("indéréglable",),
    "indescriptible": ("indescriptible",),
    "indescriptibles": ("indescriptible",),
    "indésirable": ("indésirable",),
    "indésirables": ("indésirable",),
    "indestructible": ("indestructible",),
    "indestructibles": ("indestructible",),
    "indétectable": ("indétectable",),
    "indétectables": ("indétectable",),
    "indéterminable": ("indéterminable",),
    "indéterminables": ("indéterminable",),
    "indéterministe": ("indéterministe",),
    "indéterministes": ("indéterministe",),
    "indétrônable": ("indétrônable",),
    "indétrônables": ("indétrônable",),
    "indéveloppable": ("indéveloppable",),
    "indéveloppables": ("indéveloppable",),
    "indevinable": ("indevinable",),
    "indevinables": ("indevinable",),
    "indévissable": ("indévissable",),
    "indévissables": ("indévissable",),
    "indexataire": ("indexataire",),
    "indexataires": ("indexataire",),
    "indexatoire": ("indexatoire",),
    "indexatoires": ("indexatoire",),
    "indianiste": ("indianiste",),
    "indianistes": ("indianiste",),
    "indianophone": ("indianophone",),
    "indianophones": ("indianophone",),
    "indicateur": ("indicateur",),
    "indicateurs": ("indicateur",),
    "indicatrice": ("indicateur",),
    "indicatrices": ("indicateur",),
    "indicatif": ("indicatif",),
    "indicatifs": ("indicatif",),
    "indicative": ("indicatif",),
    "indicatives": ("indicatif",),
    "indiciaire": ("indiciaire",),
    "indiciaires": ("indiciaire",),
    "indicible": ("indicible",),
    "indicibles": ("indicible",),
    "indicielle": ("indiciel",),
    "indicielles": ("indiciel",),
    "indiciel": ("indiciel",),
    "indiciels": ("indiciel",),
    "indien": ("indien",),
    "indienne": ("indien",),
    "indiennes": ("indien",),
    "indiens": ("indien",),
    "indifférenciable": ("indifférenciable",),
    "indifférenciables": ("indifférenciable",),
    "indifférentiste": ("indifférentiste",),
    "indifférentistes": ("indifférentiste",),
    "indiffusible": ("indiffusible",),
    "indiffusibles": ("indiffusible",),
    "indigène": ("indigène",),
    "indigènes": ("indigène",),
    "indigéniste": ("indigéniste",),
    "indigénistes": ("indigéniste",),
    "indigeste": ("indigeste",),
    "indigestes": ("indigeste",),
    "indigestible": ("indigestible",),
    "indigestibles": ("indigestible",),
    "indigète": ("indigète",),
    "indigètes": ("indigète",),
    "indignée": ("indigné",),
    "indignées": ("indigné",),
    "indigné": ("indigné",),
    "indigne": ("indigne",),
    "indignés": ("indigné",),
    "indignes": ("indigne",),
    "indigo": ("indigo",),
    "indigoïde": ("indigoïde",),
    "indigoïdes": ("indigoïde",),
    "indigotière": ("indigotier",),
    "indigotières": ("indigotier",),
    "indigotier": ("indigotier",),
    "indigotiers": ("indigotier",),
    "indiquée": ("indiqué",),
    "indiquées": ("indiqué",),
    "indiqué": ("indiqué",),
    "indique": ("indique",),
    "indiqués": ("indiqué",),
    "indiques": ("indique",),
    "indirigeable": ("indirigeable",),
    "indirigeables": ("indirigeable",),
    "indiscernable": ("indiscernable",),
    "indiscernables": ("indiscernable",),
    "indisciplinable": ("indisciplinable",),
    "indisciplinables": ("indisciplinable",),
    "indiscrète": ("indiscret",),
    "indiscrètes": ("indiscret",),
    "indiscret": ("indiscret",),
    "indiscrets": ("indiscret",),
    "indiscutable": ("indiscutable",),
    "indiscutables": ("indiscutable",),
    "indispensable": ("indispensable",),
    "indispensables": ("indispensable",),
    "indisponible": ("indisponible",),
    "indisponibles": ("indisponible",),
    "indisputable": ("indisputable",),
    "indisputables": ("indisputable",),
    "indissociable": ("indissociable",),
    "indissociables": ("indissociable",),
    "indissoluble": ("indissoluble",),
    "indissolubles": ("indissoluble",),
    "indistinguable": ("indistinguable",),
    "indistinguables": ("indistinguable",),
    "individualiste": ("individualiste",),
    "individualistes": ("individualiste",),
    "individuatif": ("individuatif",),
    "individuatifs": ("individuatif",),
    "individuative": ("individuatif",),
    "individuatives": ("individuatif",),
    "individuelle": ("individuel",),
    "individuelles": ("individuel",),
    "individuel": ("individuel",),
    "individuels": ("individuel",),
    "indivise": ("indivis",),
    "indivises": ("indivis",),
    "indivis": ("indivis",),
    "indivisible": ("indivisible",),
    "indivisibles": ("indivisible",),
    "indo-afghanne": ("indo-afghan",),
    "indo-aryen": ("indo-aryen",),
    "indo-aryennes": ("indo-aryen",),
    "indochinoise": ("indochinois",),
    "indochinoises": ("indochinois",),
    "indochinois": ("indochinois",),
    "indocile": ("indocile",),
    "indociles": ("indocile",),
    "indo-européen": ("indo-européen",),
    "indo-européenne": ("indo-européen",),
    "indo-européennes": ("indo-européen",),
    "indo-européens": ("indo-européen",),
    "indo-gangétiques": ("indo-gangétique",),
    "indo-hellénique": ("indo-hellénique",),
    "indo-iranienne": ("indo-iranien",),
    "indolacétique": ("indolacétique",),
    "indolacétiques": ("indolacétique",),
    "indolaminergique": ("indolaminergique",),
    "indolaminergiques": ("indolaminergique",),
    "indolique": ("indolique",),
    "indoliques": ("indolique",),
    "indolore": ("indolore",),
    "indolores": ("indolore",),
    "indo-malais": ("indo-malais",),
    "indomptable": ("indomptable",),
    "indomptables": ("indomptable",),
    "indonésien": ("indonésien",),
    "indonésienne": ("indonésien",),
    "indonésiennes": ("indonésien",),
    "indonésiens": ("indonésien",),
    "indo-persan": ("indo-persan",),
    "indo-persans": ("indo-persan",),
    "indoxylique": ("indoxylique",),
    "indoxyliques": ("indoxylique",),
    "indubitable": ("indubitable",),
    "indubitables": ("indubitable",),
    "inducteur": ("inducteur",),
    "inducteurs": ("inducteur",),
    "inductrice": ("inducteur",),
    "inductrices": ("inducteur",),
    "inductif": ("inductif",),
    "inductifs": ("inductif",),
    "inductive": ("inductif",),
    "inductives": ("inductif",),
    "induplicatif": ("induplicatif",),
    "induplicatifs": ("induplicatif",),
    "induplicative": ("induplicatif",),
    "induplicatives": ("induplicatif",),
    "indusien": ("indusien",),
    "indusienne": ("indusien",),
    "indusiennes": ("indusien",),
    "indusiens": ("indusien",),
    "industrialisable": ("industrialisable",),
    "industrialisables": ("industrialisable",),
    "industrialiste": ("industrialiste",),
    "industrialistes": ("industrialiste",),
    "industrielle": ("industriel",),
    "industrielles": ("industriel",),
    "industriel": ("industriel",),
    "industriels": ("industriel",),
    "industrieuse": ("industrieux",),
    "industrieuses": ("industrieux",),
    "industrieux": ("industrieux",),
    "inébranlable": ("inébranlable",),
    "inébranlables": ("inébranlable",),
    "inéchangeable": ("inéchangeable",),
    "inéchangeables": ("inéchangeable",),
    "inécoutable": ("inécoutable",),
    "inécoutables": ("inécoutable",),
    "inéditable": ("inéditable",),
    "inéditables": ("inéditable",),
    "inéducable": ("inéducable",),
    "inéducables": ("inéducable",),
    "ineffable": ("ineffable",),
    "ineffables": ("ineffable",),
    "ineffaçable": ("ineffaçable",),
    "ineffaçables": ("ineffaçable",),
    "ineffectif": ("ineffectif",),
    "ineffectifs": ("ineffectif",),
    "ineffective": ("ineffectif",),
    "ineffectives": ("ineffectif",),
    "inefficace": ("inefficace",),
    "inefficaces": ("inefficace",),
    "inégalable": ("inégalable",),
    "inégalables": ("inégalable",),
    "inégale": ("inégal",),
    "inégales": ("inégal",),
    "inégal": ("inégal",),
    "inégaux": ("inégal",),
    "inégalistariste": ("inégalistariste",),
    "inégalistaristes": ("inégalistariste",),
    "inégalitaire": ("inégalitaire",),
    "inégalitaires": ("inégalitaire",),
    "inélastique": ("inélastique",),
    "inélastiques": ("inélastique",),
    "inélevable": ("inélevable",),
    "inélevables": ("inélevable",),
    "inéligible": ("inéligible",),
    "inéligibles": ("inéligible",),
    "inéluctable": ("inéluctable",),
    "inéluctables": ("inéluctable",),
    "inéludable": ("inéludable",),
    "inéludables": ("inéludable",),
    "inemployable": ("inemployable",),
    "inemployables": ("inemployable",),
    "inénarrable": ("inénarrable",),
    "inénarrables": ("inénarrable",),
    "inentamable": ("inentamable",),
    "inentamables": ("inentamable",),
    "inentendable": ("inentendable",),
    "inentendables": ("inentendable",),
    "inenvisageable": ("inenvisageable",),
    "inenvisageables": ("inenvisageable",),
    "inepte": ("inepte",),
    "ineptes": ("inepte",),
    "inépuisable": ("inépuisable",),
    "inépuisables": ("inépuisable",),
    "inéquilatérale": ("inéquilatéral",),
    "inéquilatérales": ("inéquilatéral",),
    "inéquilatéral": ("inéquilatéral",),
    "inéquilatéraux": ("inéquilatéral",),
    "inéquitable": ("inéquitable",),
    "inéquitables": ("inéquitable",),
    "inéquivalve": ("inéquivalve",),
    "inéquivalves": ("inéquivalve",),
    "inéraillable": ("inéraillable",),
    "inéraillables": ("inéraillable",),
    "inerme": ("inerme",),
    "inermes": ("inerme",),
    "inerte": ("inerte",),
    "inertes": ("inerte",),
    "inertielle": ("inertiel",),
    "inertielles": ("inertiel",),
    "inertiel": ("inertiel",),
    "inertiels": ("inertiel",),
    "inescomptable": ("inescomptable",),
    "inescomptables": ("inescomptable",),
    "inespérable": ("inespérable",),
    "inespérables": ("inespérable",),
    "inesquivable": ("inesquivable",),
    "inesquivables": ("inesquivable",),
    "inessentielle": ("inessentiel",),
    "inessentielles": ("inessentiel",),
    "inessentiel": ("inessentiel",),
    "inessentiels": ("inessentiel",),
    "inesthétique": ("inesthétique",),
    "inesthétiques": ("inesthétique",),
    "inestimable": ("inestimable",),
    "inestimables": ("inestimable",),
    "inétanche": ("inétanche",),
    "inétanches": ("inétanche",),
    "inétreignable": ("inétreignable",),
    "inétreignables": ("inétreignable",),
    "inétudiable": ("inétudiable",),
    "inétudiables": ("inétudiable",),
    "inévitable": ("inévitable",),
    "inévitables": ("inévitable",),
    "inexcitable": ("inexcitable",),
    "inexcitables": ("inexcitable",),
    "inexcusable": ("inexcusable",),
    "inexcusables": ("inexcusable",),
    "inexécutable": ("inexécutable",),
    "inexécutables": ("inexécutable",),
    "inexhaustible": ("inexhaustible",),
    "inexhaustibles": ("inexhaustible",),
    "inexigible": ("inexigible",),
    "inexigibles": ("inexigible",),
    "inexorable": ("inexorable",),
    "inexorables": ("inexorable",),
    "inexpédiable": ("inexpédiable",),
    "inexpédiables": ("inexpédiable",),
    "inexpiable": ("inexpiable",),
    "inexpiables": ("inexpiable",),
    "inexplicable": ("inexplicable",),
    "inexplicables": ("inexplicable",),
    "inexploitable": ("inexploitable",),
    "inexploitables": ("inexploitable",),
    "inexplorable": ("inexplorable",),
    "inexplorables": ("inexplorable",),
    "inexplosible": ("inexplosible",),
    "inexplosibles": ("inexplosible",),
    "inexposable": ("inexposable",),
    "inexposables": ("inexposable",),
    "inexpressible": ("inexpressible",),
    "inexpressibles": ("inexpressible",),
    "inexpressif": ("inexpressif",),
    "inexpressifs": ("inexpressif",),
    "inexpressive": ("inexpressif",),
    "inexpressives": ("inexpressif",),
    "inexprimable": ("inexprimable",),
    "inexprimables": ("inexprimable",),
    "inexpugnable": ("inexpugnable",),
    "inexpugnables": ("inexpugnable",),
    "inextensible": ("inextensible",),
    "inextensibles": ("inextensible",),
    "inexterminable": ("inexterminable",),
    "inexterminables": ("inexterminable",),
    "inextinguible": ("inextinguible",),
    "inextinguibles": ("inextinguible",),
    "inextirpable": ("inextirpable",),
    "inextirpables": ("inextirpable",),
    "inextricable": ("inextricable",),
    "inextricables": ("inextricable",),
    "infaillibiliste": ("infaillibiliste",),
    "infaillibilistes": ("infaillibiliste",),
    "infaillible": ("infaillible",),
    "infaillibles": ("infaillible",),
    "infaisable": ("infaisable",),
    "infaisables": ("infaisable",),
    "infalsifiable": ("infalsifiable",),
    "infalsifiables": ("infalsifiable",),
    "infâme": ("infâme",),
    "infâmes": ("infâme",),
    "infanticide": ("infanticide",),
    "infanticides": ("infanticide",),
    "infantile": ("infantile",),
    "infantiles": ("infantile",),
    "infarctogène": ("infarctogène",),
    "infarctogènes": ("infarctogène",),
    "infatigable": ("infatigable",),
    "infatigables": ("infatigable",),
    "infectieuse": ("infectieux",),
    "infectieuses": ("infectieux",),
    "infectieux": ("infectieux",),
    "infère": ("infère",),
    "infères": ("infère",),
    "infermentescible": ("infermentescible",),
    "infermentescibles": ("infermentescible",),
    "infernale": ("infernal",),
    "infernales": ("infernal",),
    "infernal": ("infernal",),
    "infernaux": ("infernal",),
    "inféro-postérieures": ("inféro-postérieur",),
    "infertile": ("infertile",),
    "infertiles": ("infertile",),
    "infeutrable": ("infeutrable",),
    "infeutrables": ("infeutrable",),
    "infidèle": ("infidèle",),
    "infidèles": ("infidèle",),
    "infime": ("infime",),
    "infimes": ("infime",),
    "infiniste": ("infiniste",),
    "infinistes": ("infiniste",),
    "infinitésimale": ("infinitésimal",),
    "infinitésimales": ("infinitésimal",),
    "infinitésimal": ("infinitésimal",),
    "infinitésimaux": ("infinitésimal",),
    "infinitif": ("infinitif",),
    "infinitifs": ("infinitif",),
    "infinitive": ("infinitif",),
    "infinitives": ("infinitif",),
    "infinitiste": ("infinitiste",),
    "infinitistes": ("infinitiste",),
    "infirmable": ("infirmable",),
    "infirmables": ("infirmable",),
    "infirmatif": ("infirmatif",),
    "infirmatifs": ("infirmatif",),
    "infirmative": ("infirmatif",),
    "infirmatives": ("infirmatif",),
    "infirme": ("infirme",),
    "infirmes": ("infirme",),
    "infirmière": ("infirmier",),
    "infirmières": ("infirmier",),
    "infirmier": ("infirmier",),
    "infirmiers": ("infirmier",),
    "inflammable": ("inflammable",),
    "inflammables": ("inflammable",),
    "inflammatoire": ("inflammatoire",),
    "inflammatoires": ("inflammatoire",),
    "inflationniste": ("inflationniste",),
    "inflationnistes": ("inflationniste",),
    "infléchissable": ("infléchissable",),
    "infléchissables": ("infléchissable",),
    "inflexible": ("inflexible",),
    "inflexibles": ("inflexible",),
    "inflexionnelle": ("inflexionnel",),
    "inflexionnelles": ("inflexionnel",),
    "inflexionnel": ("inflexionnel",),
    "inflexionnels": ("inflexionnel",),
    "influençable": ("influençable",),
    "influençables": ("influençable",),
    "infographique": ("infographique",),
    "infographiques": ("infographique",),
    "inforgeable": ("inforgeable",),
    "inforgeables": ("inforgeable",),
    "informatif": ("informatif",),
    "informatifs": ("informatif",),
    "informative": ("informatif",),
    "informatives": ("informatif",),
    "informationnelle": ("informationnel",),
    "informationnelles": ("informationnel",),
    "informationnel": ("informationnel",),
    "informationnels": ("informationnel",),
    "informatique": ("informatique",),
    "informatiques": ("informatique",),
    "informatisable": ("informatisable",),
    "informatisables": ("informatisable",),
    "informée": ("informé",),
    "informées": ("informé",),
    "informé": ("informé",),
    "informe": ("informe",),
    "informés": ("informé",),
    "informes": ("informe",),
    "informelle": ("informel",),
    "informelles": ("informel",),
    "informel": ("informel",),
    "informels": ("informel",),
    "informulable": ("informulable",),
    "informulables": ("informulable",),
    "infortifiable": ("infortifiable",),
    "infortifiables": ("infortifiable",),
    "infracellulaire": ("infracellulaire",),
    "infracellulaires": ("infracellulaire",),
    "infraclinique": ("infraclinique",),
    "infracliniques": ("infraclinique",),
    "infraconstitutionnelle": ("infraconstitutionnel",),
    "infraconstitutionnelles": ("infraconstitutionnel",),
    "infraconstitutionnel": ("infraconstitutionnel",),
    "infraconstitutionnels": ("infraconstitutionnel",),
    "infradien": ("infradien",),
    "infradienne": ("infradien",),
    "infradiennes": ("infradien",),
    "infradiens": ("infradien",),
    "infradyne": ("infradyne",),
    "infradynes": ("infradyne",),
    "infragénérique": ("infragénérique",),
    "infragénériques": ("infragénérique",),
    "infraliminaire": ("infraliminaire",),
    "infraliminaires": ("infraliminaire",),
    "infraliminale": ("infraliminal",),
    "infraliminales": ("infraliminal",),
    "infraliminal": ("infraliminal",),
    "infraliminaux": ("infraliminal",),
    "infralittorale": ("infralittoral",),
    "infralittorales": ("infralittoral",),
    "infralittoral": ("infralittoral",),
    "infralittoraux": ("infralittoral",),
    "infranationale": ("infranational",),
    "infranationales": ("infranational",),
    "infranational": ("infranational",),
    "infranationaux": ("infranational",),
    "infranchissable": ("infranchissable",),
    "infranchissables": ("infranchissable",),
    "infrangible": ("infrangible",),
    "infrangibles": ("infrangible",),
    "infrarouge": ("infrarouge",),
    "infrarouges": ("infrarouge",),
    "infrasonore": ("infrasonore",),
    "infrasonores": ("infrasonore",),
    "infraspécifique": ("infraspécifique",),
    "infraspécifiques": ("infraspécifique",),
    "infrastructurelle": ("infrastructurel",),
    "infrastructurelles": ("infrastructurel",),
    "infrastructurel": ("infrastructurel",),
    "infrastructurels": ("infrastructurel",),
    "infratidale": ("infratidal",),
    "infratidales": ("infratidal",),
    "infratidal": ("infratidal",),
    "infratidaux": ("infratidal",),
    "infréquentable": ("infréquentable",),
    "infréquentables": ("infréquentable",),
    "infroissable": ("infroissable",),
    "infroissables": ("infroissable",),
    "infructueuse": ("infructueux",),
    "infructueuses": ("infructueux",),
    "infructueux": ("infructueux",),
    "infumable": ("infumable",),
    "infumables": ("infumable",),
    "infundibulaire": ("infundibulaire",),
    "infundibulaires": ("infundibulaire",),
    "infundibuliforme": ("infundibuliforme",),
    "infundibuliformes": ("infundibuliforme",),
    "infuse": ("infus",),
    "infuses": ("infus",),
    "infus": ("infus",),
    "infusible": ("infusible",),
    "infusibles": ("infusible",),
    "ingagnable": ("ingagnable",),
    "ingagnables": ("ingagnable",),
    "ingambe": ("ingambe",),
    "ingambes": ("ingambe",),
    "ingélif": ("ingélif",),
    "ingélifs": ("ingélif",),
    "ingélive": ("ingélif",),
    "ingélives": ("ingélif",),
    "ingénieuse": ("ingénieux",),
    "ingénieuses": ("ingénieux",),
    "ingénieux": ("ingénieux",),
    "ingérable": ("ingérable",),
    "ingérables": ("ingérable",),
    "inglorieuse": ("inglorieux",),
    "inglorieuses": ("inglorieux",),
    "inglorieux": ("inglorieux",),
    "ingluviale": ("ingluvial",),
    "ingluviales": ("ingluvial",),
    "ingluvial": ("ingluvial",),
    "ingluviaux": ("ingluvial",),
    "ingouche": ("ingouche",),
    "ingouches": ("ingouche",),
    "ingouvernable": ("ingouvernable",),
    "ingouvernables": ("ingouvernable",),
    "ingraissable": ("ingraissable",),
    "ingraissables": ("ingraissable",),
    "ingresque": ("ingresque",),
    "ingresques": ("ingresque",),
    "ingressif": ("ingressif",),
    "ingressifs": ("ingressif",),
    "ingressive": ("ingressif",),
    "ingressives": ("ingressif",),
    "ingrisable": ("ingrisable",),
    "ingrisables": ("ingrisable",),
    "ingriste": ("ingriste",),
    "ingristes": ("ingriste",),
    "inguérissable": ("inguérissable",),
    "inguérissables": ("inguérissable",),
    "inguinale": ("inguinal",),
    "inguinales": ("inguinal",),
    "inguinal": ("inguinal",),
    "inguinaux": ("inguinal",),
    "inhabile": ("inhabile",),
    "inhabiles": ("inhabile",),
    "inhabitable": ("inhabitable",),
    "inhabitables": ("inhabitable",),
    "inhabituelle": ("inhabituel",),
    "inhabituelles": ("inhabituel",),
    "inhabituel": ("inhabituel",),
    "inhabituels": ("inhabituel",),
    "inhalateur": ("inhalateur",),
    "inhalateurs": ("inhalateur",),
    "inhalatrice": ("inhalateur",),
    "inhalatrices": ("inhalateur",),
    "inharmonieuse": ("inharmonieux",),
    "inharmonieuses": ("inharmonieux",),
    "inharmonieux": ("inharmonieux",),
    "inharmonique": ("inharmonique",),
    "inharmoniques": ("inharmonique",),
    "inhibiteur": ("inhibiteur",),
    "inhibiteurs": ("inhibiteur",),
    "inhibitrice": ("inhibiteur",),
    "inhibitrices": ("inhibiteur",),
    "inhibitif": ("inhibitif",),
    "inhibitifs": ("inhibitif",),
    "inhibitive": ("inhibitif",),
    "inhibitives": ("inhibitif",),
    "inhomogène": ("inhomogène",),
    "inhomogènes": ("inhomogène",),
    "inhospitalière": ("inhospitalier",),
    "inhospitalières": ("inhospitalier",),
    "inhospitalier": ("inhospitalier",),
    "inhospitaliers": ("inhospitalier",),
    "inidentifiable": ("inidentifiable",),
    "inidentifiables": ("inidentifiable",),
    "inimaginable": ("inimaginable",),
    "inimaginables": ("inimaginable",),
    "inimitable": ("inimitable",),
    "inimitables": ("inimitable",),
    "inimprimable": ("inimprimable",),
    "inimprimables": ("inimprimable",),
    "inimputable": ("inimputable",),
    "inimputables": ("inimputable",),
    "ininflammable": ("ininflammable",),
    "ininflammables": ("ininflammable",),
    "inintelligible": ("inintelligible",),
    "inintelligibles": ("inintelligible",),
    "inintentionnelle": ("inintentionnel",),
    "inintentionnelles": ("inintentionnel",),
    "inintentionnel": ("inintentionnel",),
    "inintentionnels": ("inintentionnel",),
    "ininterprétable": ("ininterprétable",),
    "ininterprétables": ("ininterprétable",),
    "iniodyme": ("iniodyme",),
    "iniodymes": ("iniodyme",),
    "inique": ("inique",),
    "iniques": ("inique",),
    "initiale": ("initial",),
    "initiales": ("initial",),
    "initial": ("initial",),
    "initiaux": ("initial",),
    "initiateur": ("initiateur",),
    "initiateurs": ("initiateur",),
    "initiatrice": ("initiateur",),
    "initiatrices": ("initiateur",),
    "initiatique": ("initiatique",),
    "initiatiques": ("initiatique",),
    "injectable": ("injectable",),
    "injectables": ("injectable",),
    "injecteur": ("injecteur",),
    "injecteurs": ("injecteur",),
    "injectrice": ("injecteur",),
    "injectrices": ("injecteur",),
    "injectif": ("injectif",),
    "injectifs": ("injectif",),
    "injective": ("injectif",),
    "injectives": ("injectif",),
    "injoignable": ("injoignable",),
    "injoignables": ("injoignable",),
    "injonctif": ("injonctif",),
    "injonctifs": ("injonctif",),
    "injonctive": ("injonctif",),
    "injonctives": ("injonctif",),
    "injouable": ("injouable",),
    "injouables": ("injouable",),
    "injurieuse": ("injurieux",),
    "injurieuses": ("injurieux",),
    "injurieux": ("injurieux",),
    "injuste": ("injuste",),
    "injustes": ("injuste",),
    "injustifiable": ("injustifiable",),
    "injustifiables": ("injustifiable",),
    "inlassable": ("inlassable",),
    "inlassables": ("inlassable",),
    "innavigable": ("innavigable",),
    "innavigables": ("innavigable",),
    "innéiste": ("innéiste",),
    "innéistes": ("innéiste",),
    "innettoyable": ("innettoyable",),
    "innettoyables": ("innettoyable",),
    "innombrable": ("innombrable",),
    "innombrables": ("innombrable",),
    "innommable": ("innommable",),
    "innommables": ("innommable",),
    "innovateur": ("innovateur",),
    "innovateurs": ("innovateur",),
    "innovatrice": ("innovateur",),
    "innovatrices": ("innovateur",),
    "inobservable": ("inobservable",),
    "inobservables": ("inobservable",),
    "inoccupable": ("inoccupable",),
    "inoccupables": ("inoccupable",),
    "inoculable": ("inoculable",),
    "inoculables": ("inoculable",),
    "inodore": ("inodore",),
    "inodores": ("inodore",),
    "inoffensif": ("inoffensif",),
    "inoffensifs": ("inoffensif",),
    "inoffensive": ("inoffensif",),
    "inoffensives": ("inoffensif",),
    "inofficielle": ("inofficiel",),
    "inofficielles": ("inofficiel",),
    "inofficiel": ("inofficiel",),
    "inofficiels": ("inofficiel",),
    "inofficieuse": ("inofficieux",),
    "inofficieuses": ("inofficieux",),
    "inofficieux": ("inofficieux",),
    "inondable": ("inondable",),
    "inondables": ("inondable",),
    "inopérable": ("inopérable",),
    "inopérables": ("inopérable",),
    "inopposable": ("inopposable",),
    "inopposables": ("inopposable",),
    "inorganique": ("inorganique",),
    "inorganiques": ("inorganique",),
    "inorganisable": ("inorganisable",),
    "inorganisables": ("inorganisable",),
    "inorthodoxe": ("inorthodoxe",),
    "inorthodoxes": ("inorthodoxe",),
    "inosinique": ("inosinique",),
    "inosiniques": ("inosinique",),
    "inositohexaphosphorique": ("inositohexaphosphorique",),
    "inositohexaphosphoriques": ("inositohexaphosphorique",),
    "inotrope": ("inotrope",),
    "inotropes": ("inotrope",),
    "inoubliable": ("inoubliable",),
    "inoubliables": ("inoubliable",),
    "inoxydable": ("inoxydable",),
    "inoxydables": ("inoxydable",),
    "inqualifiable": ("inqualifiable",),
    "inqualifiables": ("inqualifiable",),
    "inquantifiable": ("inquantifiable",),
    "inquantifiables": ("inquantifiable",),
    "inquiète": ("inquiet",),
    "inquiètes": ("inquiet",),
    "inquiet": ("inquiet",),
    "inquiets": ("inquiet",),
    "inquilin": ("inquilin",),
    "inquilins": ("inquilin",),
    "inquisiteur": ("inquisiteur",),
    "inquisiteurs": ("inquisiteur",),
    "inquisitrice": ("inquisiteur",),
    "inquisitrices": ("inquisiteur",),
    "inquisitoire": ("inquisitoire",),
    "inquisitoires": ("inquisitoire",),
    "inquisitoriale": ("inquisitorial",),
    "inquisitoriales": ("inquisitorial",),
    "inquisitorial": ("inquisitorial",),
    "inquisitoriaux": ("inquisitorial",),
    "inracontable": ("inracontable",),
    "inracontables": ("inracontable",),
    "inramonable": ("inramonable",),
    "inramonables": ("inramonable",),
    "inratable": ("inratable",),
    "inratables": ("inratable",),
    "inrectifiable": ("inrectifiable",),
    "inrectifiables": ("inrectifiable",),
    "insaisissable": ("insaisissable",),
    "insaisissables": ("insaisissable",),
    "insalifiable": ("insalifiable",),
    "insalifiables": ("insalifiable",),
    "insalissable": ("insalissable",),
    "insalissables": ("insalissable",),
    "insalubre": ("insalubre",),
    "insalubres": ("insalubre",),
    "insane": ("insane",),
    "insanes": ("insane",),
    "insaponifiable": ("insaponifiable",),
    "insaponifiables": ("insaponifiable",),
    "insatiable": ("insatiable",),
    "insatiables": ("insatiable",),
    "insaturable": ("insaturable",),
    "insaturables": ("insaturable",),
    "inscolarisable": ("inscolarisable",),
    "inscolarisables": ("inscolarisable",),
    "inscripteur": ("inscripteur",),
    "inscripteurs": ("inscripteur",),
    "inscriptrice": ("inscripteur",),
    "inscriptrices": ("inscripteur",),
    "inscriptible": ("inscriptible",),
    "inscriptibles": ("inscriptible",),
    "inscrutable": ("inscrutable",),
    "inscrutables": ("inscrutable",),
    "insécable": ("insécable",),
    "insécables": ("insécable",),
    "insecouable": ("insecouable",),
    "insecouables": ("insecouable",),
    "insecourable": ("insecourable",),
    "insecourables": ("insecourable",),
    "insecticide": ("insecticide",),
    "insecticides": ("insecticide",),
    "insectifuge": ("insectifuge",),
    "insectifuges": ("insectifuge",),
    "insectivore": ("insectivore",),
    "insectivores": ("insectivore",),
    "insécure": ("insécure",),
    "insécures": ("insécure",),
    "inséductible": ("inséductible",),
    "inséductibles": ("inséductible",),
    "inséminateur": ("inséminateur",),
    "inséminateurs": ("inséminateur",),
    "inséminatrice": ("inséminateur",),
    "inséminatrices": ("inséminateur",),
    "insensible": ("insensible",),
    "insensibles": ("insensible",),
    "inséparable": ("inséparable",),
    "inséparables": ("inséparable",),
    "insérable": ("insérable",),
    "insérables": ("insérable",),
    "inservable": ("inservable",),
    "inservables": ("inservable",),
    "inserviable": ("inserviable",),
    "inserviables": ("inserviable",),
    "insidieuse": ("insidieux",),
    "insidieuses": ("insidieux",),
    "insidieux": ("insidieux",),
    "insigne": ("insigne",),
    "insignes": ("insigne",),
    "insincère": ("insincère",),
    "insincères": ("insincère",),
    "insipide": ("insipide",),
    "insipides": ("insipide",),
    "insociable": ("insociable",),
    "insociables": ("insociable",),
    "insolite": ("insolite",),
    "insolites": ("insolite",),
    "insoluble": ("insoluble",),
    "insolubles": ("insoluble",),
    "insolvable": ("insolvable",),
    "insolvables": ("insolvable",),
    "insomniaque": ("insomniaque",),
    "insomniaques": ("insomniaque",),
    "insomnieuse": ("insomnieux",),
    "insomnieuses": ("insomnieux",),
    "insomnieux": ("insomnieux",),
    "insondable": ("insondable",),
    "insondables": ("insondable",),
    "insonore": ("insonore",),
    "insonores": ("insonore",),
    "insoucieuse": ("insoucieux",),
    "insoucieuses": ("insoucieux",),
    "insoucieux": ("insoucieux",),
    "insoumise": ("insoumis",),
    "insoumises": ("insoumis",),
    "insoumis": ("insoumis",),
    "insoupçonnable": ("insoupçonnable",),
    "insoupçonnables": ("insoupçonnable",),
    "insoutenable": ("insoutenable",),
    "insoutenables": ("insoutenable",),
    "inspirateur": ("inspirateur",),
    "inspirateurs": ("inspirateur",),
    "inspiratrice": ("inspirateur",),
    "inspiratrices": ("inspirateur",),
    "inspiratoire": ("inspiratoire",),
    "inspiratoires": ("inspiratoire",),
    "instable": ("instable",),
    "instables": ("instable",),
    "instinctif": ("instinctif",),
    "instinctifs": ("instinctif",),
    "instinctive": ("instinctif",),
    "instinctives": ("instinctif",),
    "instinctuelle": ("instinctuel",),
    "instinctuelles": ("instinctuel",),
    "instinctuel": ("instinctuel",),
    "instinctuels": ("instinctuel",),
    "institutionnaliste": ("institutionnaliste",),
    "institutionnalistes": ("institutionnaliste",),
    "institutionnelle": ("institutionnel",),
    "institutionnelles": ("institutionnel",),
    "institutionnel": ("institutionnel",),
    "institutionnels": ("institutionnel",),
    "instructeur": ("instructeur",),
    "instructeurs": ("instructeur",),
    "instructrice": ("instructeur",),
    "instructrices": ("instructeur",),
    "instructif": ("instructif",),
    "instructifs": ("instructif",),
    "instructive": ("instructif",),
    "instructives": ("instructif",),
    "instrumentaire": ("instrumentaire",),
    "instrumentaires": ("instrumentaire",),
    "instrumentale": ("instrumental",),
    "instrumentales": ("instrumental",),
    "instrumental": ("instrumental",),
    "instrumentaux": ("instrumental",),
    "instrumentaliste": ("instrumentaliste",),
    "instrumentalistes": ("instrumentaliste",),
    "insubmersible": ("insubmersible",),
    "insubmersibles": ("insubmersible",),
    "insulaire": ("insulaire",),
    "insulaires": ("insulaire",),
    "insulinique": ("insulinique",),
    "insuliniques": ("insulinique",),
    "insulinogène": ("insulinogène",),
    "insulinogènes": ("insulinogène",),
    "insulinoprive": ("insulinoprive",),
    "insulinoprives": ("insulinoprive",),
    "insulteur": ("insulteur",),
    "insulteurs": ("insulteur",),
    "insulteuse": ("insulteur",),
    "insulteuses": ("insulteur",),
    "insupportable": ("insupportable",),
    "insupportables": ("insupportable",),
    "insupprimable": ("insupprimable",),
    "insupprimables": ("insupprimable",),
    "insurmontable": ("insurmontable",),
    "insurmontables": ("insurmontable",),
    "insurpassable": ("insurpassable",),
    "insurpassables": ("insurpassable",),
    "insurrectionnelle": ("insurrectionnel",),
    "insurrectionnelles": ("insurrectionnel",),
    "insurrectionnel": ("insurrectionnel",),
    "insurrectionnels": ("insurrectionnel",),
    "insusceptible": ("insusceptible",),
    "insusceptibles": ("insusceptible",),
    "intachable": ("intachable",),
    "intachables": ("intachable",),
    "intactile": ("intactile",),
    "intactiles": ("intactile",),
    "intaillable": ("intaillable",),
    "intaillables": ("intaillable",),
    "intangible": ("intangible",),
    "intangibles": ("intangible",),
    "intarissable": ("intarissable",),
    "intarissables": ("intarissable",),
    "intégrable": ("intégrable",),
    "intégrables": ("intégrable",),
    "intégrale": ("intégral",),
    "intégrales": ("intégral",),
    "intégral": ("intégral",),
    "intégraux": ("intégral",),
    "intégrateur": ("intégrateur",),
    "intégrateurs": ("intégrateur",),
    "intégratrice": ("intégrateur",),
    "intégratrices": ("intégrateur",),
    "intégratif": ("intégratif",),
    "intégratifs": ("intégratif",),
    "intégrative": ("intégratif",),
    "intégratives": ("intégratif",),
    "intégrationniste": ("intégrationniste",),
    "intégrationnistes": ("intégrationniste",),
    "intégrée": ("intégré",),
    "intégrées": ("intégré",),
    "intégré": ("intégré",),
    "intègre": ("intègre",),
    "intégrés": ("intégré",),
    "intègres": ("intègre",),
    "intégriste": ("intégriste",),
    "intégristes": ("intégriste",),
    "intellectualiste": ("intellectualiste",),
    "intellectualistes": ("intellectualiste",),
    "intellectuelle": ("intellectuel",),
    "intellectuelles": ("intellectuel",),
    "intellectuel": ("intellectuel",),
    "intellectuels": ("intellectuel",),
    "intelligible": ("intelligible",),
    "intelligibles": ("intelligible",),
    "intello": ("intello",),
    "intellos": ("intello",),
    "intempestif": ("intempestif",),
    "intempestifs": ("intempestif",),
    "intempestive": ("intempestif",),
    "intempestives": ("intempestif",),
    "intemporelle": ("intemporel",),
    "intemporelles": ("intemporel",),
    "intemporel": ("intemporel",),
    "intemporels": ("intemporel",),
    "intenable": ("intenable",),
    "intenables": ("intenable",),
    "intense": ("intense",),
    "intenses": ("intense",),
    "intensif": ("intensif",),
    "intensifs": ("intensif",),
    "intensive": ("intensif",),
    "intensives": ("intensif",),
    "intensionnelle": ("intensionnel",),
    "intensionnelles": ("intensionnel",),
    "intensionnel": ("intensionnel",),
    "intensionnels": ("intensionnel",),
    "intentionnaliste": ("intentionnaliste",),
    "intentionnalistes": ("intentionnaliste",),
    "intentionnelle": ("intentionnel",),
    "intentionnelles": ("intentionnel",),
    "intentionnel": ("intentionnel",),
    "intentionnels": ("intentionnel",),
    "interactif": ("interactif",),
    "interactifs": ("interactif",),
    "interactive": ("interactif",),
    "interactives": ("interactif",),
    "interactionnelle": ("interactionnel",),
    "interactionnelles": ("interactionnel",),
    "interactionnel": ("interactionnel",),
    "interactionnels": ("interactionnel",),
    "interactionniste": ("interactionniste",),
    "interactionnistes": ("interactionniste",),
    "interâge": ("interâge",),
    "interâges": ("interâge",),
    "interambulacraire": ("interambulacraire",),
    "interambulacraires": ("interambulacraire",),
    "interannuelle": ("interannuel",),
    "interannuelles": ("interannuel",),
    "interannuel": ("interannuel",),
    "interannuels": ("interannuel",),
    "interarabe": ("interarabe",),
    "interarabes": ("interarabe",),
    "interarmées": ("interarmées",),
    "interarmes": ("interarmes",),
    "interassociatif": ("interassociatif",),
    "interassociatifs": ("interassociatif",),
    "interassociative": ("interassociatif",),
    "interassociatives": ("interassociatif",),
    "interastrale": ("interastral",),
    "interastrales": ("interastral",),
    "interastral": ("interastral",),
    "interastraux": ("interastral",),
    "interatomique": ("interatomique",),
    "interatomiques": ("interatomique",),
    "interauriculaire": ("interauriculaire",),
    "interauriculaires": ("interauriculaire",),
    "interbancaire": ("interbancaire",),
    "interbancaires": ("interbancaire",),
    "interbanlieues": ("interbanlieues",),
    "intercalaire": ("intercalaire",),
    "intercalaires": ("intercalaire",),
    "intercapillaire": ("intercapillaire",),
    "intercapillaires": ("intercapillaire",),
    "intercatégorielle": ("intercatégoriel",),
    "intercatégorielles": ("intercatégoriel",),
    "intercatégoriel": ("intercatégoriel",),
    "intercatégoriels": ("intercatégoriel",),
    "intercellulaire": ("intercellulaire",),
    "intercellulaires": ("intercellulaire",),
    "intercensitaire": ("intercensitaire",),
    "intercensitaires": ("intercensitaire",),
    "intercepteur": ("intercepteur",),
    "intercepteurs": ("intercepteur",),
    "interceptrice": ("intercepteur",),
    "interceptrices": ("intercepteur",),
    "intercérébrale": ("intercérébral",),
    "intercérébrales": ("intercérébral",),
    "intercérébral": ("intercérébral",),
    "intercérébraux": ("intercérébral",),
    "interchangeable": ("interchangeable",),
    "interchangeables": ("interchangeable",),
    "intercloison": ("intercloison",),
    "intercloisons": ("intercloison",),
    "interclubs": ("interclubs",),
    "intercommunale": ("intercommunal",),
    "intercommunales": ("intercommunal",),
    "intercommunal": ("intercommunal",),
    "intercommunaux": ("intercommunal",),
    "intercommunautaire": ("intercommunautaire",),
    "intercommunautaires": ("intercommunautaire",),
    "intercondylien": ("intercondylien",),
    "intercondylienne": ("intercondylien",),
    "intercondyliennes": ("intercondylien",),
    "intercondyliens": ("intercondylien",),
    "interconfessionnelle": ("interconfessionnel",),
    "interconfessionnelles": ("interconfessionnel",),
    "interconfessionnel": ("interconfessionnel",),
    "interconfessionnels": ("interconfessionnel",),
    "intercontinentale": ("intercontinental",),
    "intercontinentales": ("intercontinental",),
    "intercontinental": ("intercontinental",),
    "intercontinentaux": ("intercontinental",),
    "interconvertible": ("interconvertible",),
    "interconvertibles": ("interconvertible",),
    "intercostale": ("intercostal",),
    "intercostales": ("intercostal",),
    "intercostal": ("intercostal",),
    "intercostaux": ("intercostal",),
    "intercotidale": ("intercotidal",),
    "intercotidales": ("intercotidal",),
    "intercotidal": ("intercotidal",),
    "intercotidaux": ("intercotidal",),
    "interculturelle": ("interculturel",),
    "interculturelles": ("interculturel",),
    "interculturel": ("interculturel",),
    "interculturels": ("interculturel",),
    "intercuspidien": ("intercuspidien",),
    "intercuspidienne": ("intercuspidien",),
    "intercuspidiennes": ("intercuspidien",),
    "intercuspidiens": ("intercuspidien",),
    "intercuve": ("intercuve",),
    "intercuves": ("intercuve",),
    "interdécennale": ("interdécennal",),
    "interdécennales": ("interdécennal",),
    "interdécennal": ("interdécennal",),
    "interdécennaux": ("interdécennal",),
    "interdécile": ("interdécile",),
    "interdéciles": ("interdécile",),
    "interdentaire": ("interdentaire",),
    "interdentaires": ("interdentaire",),
    "interdentale": ("interdental",),
    "interdentales": ("interdental",),
    "interdental": ("interdental",),
    "interdentaux": ("interdental",),
    "interdépartementale": ("interdépartemental",),
    "interdépartementales": ("interdépartemental",),
    "interdépartemental": ("interdépartemental",),
    "interdépartementaux": ("interdépartemental",),
    "interdigitale": ("interdigital",),
    "interdigitales": ("interdigital",),
    "interdigital": ("interdigital",),
    "interdigitaux": ("interdigital",),
    "inter-disciplinaire": ("inter-disciplinaire",),
    "interdisciplinaire": ("interdisciplinaire",),
    "interdisciplinaires": ("interdisciplinaire",),
    "interdistricts": ("interdistricts",),
    "interdunaire": ("interdunaire",),
    "interdunaires": ("interdunaire",),
    "interecclésiastique": ("interecclésiastique",),
    "interecclésiastiques": ("interecclésiastique",),
    "interentreprises": ("interentreprises",),
    "interépineuse": ("interépineux",),
    "interépineuses": ("interépineux",),
    "interépineux": ("interépineux",),
    "interépiscopale": ("interépiscopal",),
    "interépiscopales": ("interépiscopal",),
    "interépiscopal": ("interépiscopal",),
    "interépiscopaux": ("interépiscopal",),
    "interespèce": ("interespèce",),
    "interespèces": ("interespèce",),
    "interétatique": ("interétatique",),
    "interétatiques": ("interétatique",),
    "interethnique": ("interethnique",),
    "interethniques": ("interethnique",),
    "intereuropéen": ("intereuropéen",),
    "intereuropéenne": ("intereuropéen",),
    "intereuropéennes": ("intereuropéen",),
    "intereuropéens": ("intereuropéen",),
    "interfaciale": ("interfacial",),
    "interfaciales": ("interfacial",),
    "interfacial": ("interfacial",),
    "interfaciaux": ("interfacial",),
    "interférentielle": ("interférentiel",),
    "interférentielles": ("interférentiel",),
    "interférentiel": ("interférentiel",),
    "interférentiels": ("interférentiel",),
    "interférométrique": ("interférométrique",),
    "interférométriques": ("interférométrique",),
    "interfibrillaire": ("interfibrillaire",),
    "interfibrillaires": ("interfibrillaire",),
    "interfoliaire": ("interfoliaire",),
    "interfoliaires": ("interfoliaire",),
    "interfractile": ("interfractile",),
    "interfractiles": ("interfractile",),
    "intergalactique": ("intergalactique",),
    "intergalactiques": ("intergalactique",),
    "intergénérations": ("intergénérations",),
    "intergénérique": ("intergénérique",),
    "intergénériques": ("intergénérique",),
    "interglaciaire": ("interglaciaire",),
    "interglaciaires": ("interglaciaire",),
    "intergouvernementale": ("intergouvernemental",),
    "intergouvernementales": ("intergouvernemental",),
    "intergouvernemental": ("intergouvernemental",),
    "intergouvernementaux": ("intergouvernemental",),
    "intergrade": ("intergrade",),
    "intergrades": ("intergrade",),
    "intergranulaire": ("intergranulaire",),
    "intergranulaires": ("intergranulaire",),
    "intergroupe": ("intergroupe",),
    "intergroupes": ("intergroupes",),
    "interhémisphérique": ("interhémisphérique",),
    "interhémisphériques": ("interhémisphérique",),
    "intérimaire": ("intérimaire",),
    "intérimaires": ("intérimaire",),
    "interindividuelle": ("interindividuel",),
    "interindividuelles": ("interindividuel",),
    "interindividuel": ("interindividuel",),
    "interindividuels": ("interindividuel",),
    "interindustrielle": ("interindustriel",),
    "interindustrielles": ("interindustriel",),
    "interindustriel": ("interindustriel",),
    "interindustriels": ("interindustriel",),
    "interinsulaire": ("interinsulaire",),
    "interinsulaires": ("interinsulaire",),
    "interionique": ("interionique",),
    "interioniques": ("interionique",),
    "interjectif": ("interjectif",),
    "interjectifs": ("interjectif",),
    "interjective": ("interjectif",),
    "interjectives": ("interjectif",),
    "interjeune": ("interjeune",),
    "interjeunes": ("interjeune",),
    "interlinéaire": ("interlinéaire",),
    "interlinéaires": ("interlinéaire",),
    "interlinguistique": ("interlinguistique",),
    "interlinguistiques": ("interlinguistique",),
    "interlobaire": ("interlobaire",),
    "interlobaires": ("interlobaire",),
    "interlobulaire": ("interlobulaire",),
    "interlobulaires": ("interlobulaire",),
    "interlocutoire": ("interlocutoire",),
    "interlocutoires": ("interlocutoire",),
    "interlope": ("interlope",),
    "interlopes": ("interlope",),
    "intermaxillaire": ("intermaxillaire",),
    "intermaxillaires": ("intermaxillaire",),
    "intermédiaire": ("intermédiaire",),
    "intermédiaires": ("intermédiaire",),
    "intermenstruelle": ("intermenstruel",),
    "intermenstruelles": ("intermenstruel",),
    "intermenstruel": ("intermenstruel",),
    "intermenstruels": ("intermenstruel",),
    "intermétallique": ("intermétallique",),
    "intermétalliques": ("intermétallique",),
    "interminable": ("interminable",),
    "interminables": ("interminable",),
    "interministérielle": ("interministériel",),
    "interministérielles": ("interministériel",),
    "interministériel": ("interministériel",),
    "interministériels": ("interministériel",),
    "interminoritaire": ("interminoritaire",),
    "interminoritaires": ("interminoritaire",),
    "intermoléculaire": ("intermoléculaire",),
    "intermoléculaires": ("intermoléculaire",),
    "intermunicipale": ("intermunicipal",),
    "intermunicipales": ("intermunicipal",),
    "intermunicipal": ("intermunicipal",),
    "intermunicipaux": ("intermunicipal",),
    "intermusculaire": ("intermusculaire",),
    "intermusculaires": ("intermusculaire",),
    "internasale": ("internasal",),
    "internasales": ("internasal",),
    "internasal": ("internasal",),
    "internasaux": ("internasal",),
    "internationale": ("international",),
    "internationales": ("international",),
    "international": ("international",),
    "internationaux": ("international",),
    "internationalisable": ("internationalisable",),
    "internationalisables": ("internationalisable",),
    "internationaliste": ("internationaliste",),
    "internationalistes": ("internationaliste",),
    "internée": ("interné",),
    "internées": ("interné",),
    "interné": ("interné",),
    "interne": ("interne",),
    "internés": ("interné",),
    "internes": ("interne",),
    "internodale": ("internodal",),
    "internodales": ("internodal",),
    "internodal": ("internodal",),
    "internodaux": ("internodal",),
    "internucléaire": ("internucléaire",),
    "internucléaires": ("internucléaire",),
    "interocéanique": ("interocéanique",),
    "interocéaniques": ("interocéanique",),
    "interoceptif": ("interoceptif",),
    "intéroceptif": ("intéroceptif",),
    "interoceptifs": ("interoceptif",),
    "intéroceptifs": ("intéroceptif",),
    "interoceptive": ("interoceptif",),
    "intéroceptive": ("intéroceptif",),
    "interoceptives": ("interoceptif",),
    "intéroceptives": ("intéroceptif",),
    "interoculaire": ("interoculaire",),
    "interoculaires": ("interoculaire",),
    "interolivaire": ("interolivaire",),
    "interolivaires": ("interolivaire",),
    "interopérable": ("interopérable",),
    "interopérables": ("interopérable",),
    "interoperculaire": ("interoperculaire",),
    "interoperculaires": ("interoperculaire",),
    "interorbitaire": ("interorbitaire",),
    "interorbitaires": ("interorbitaire",),
    "interorbitale": ("interorbital",),
    "interorbitales": ("interorbital",),
    "interorbital": ("interorbital",),
    "interorbitaux": ("interorbital",),
    "interosseuse": ("interosseux",),
    "interosseuses": ("interosseux",),
    "interosseux": ("interosseux",),
    "interpapillaire": ("interpapillaire",),
    "interpapillaires": ("interpapillaire",),
    "interpariétale": ("interpariétal",),
    "interpariétales": ("interpariétal",),
    "interpariétal": ("interpariétal",),
    "interpariétaux": ("interpariétal",),
    "interparlementaire": ("interparlementaire",),
    "interparlementaires": ("interparlementaire",),
    "interparticulaire": ("interparticulaire",),
    "interparticulaires": ("interparticulaire",),
    "interpartite": ("interpartite",),
    "interpartites": ("interpartite",),
    "interpédonculaire": ("interpédonculaire",),
    "interpédonculaires": ("interpédonculaire",),
    "interpellatif": ("interpellatif",),
    "interpellatifs": ("interpellatif",),
    "interpellative": ("interpellatif",),
    "interpellatives": ("interpellatif",),
    "interpersonnelle": ("interpersonnel",),
    "interpersonnelles": ("interpersonnel",),
    "interpersonnel": ("interpersonnel",),
    "interpersonnels": ("interpersonnel",),
    "interpharmaceutique": ("interpharmaceutique",),
    "interpharmaceutiques": ("interpharmaceutique",),
    "interphasique": ("interphasique",),
    "interphasiques": ("interphasique",),
    "interphonique": ("interphonique",),
    "interphoniques": ("interphonique",),
    "interplanétaire": ("interplanétaire",),
    "interplanétaires": ("interplanétaire",),
    "interprétable": ("interprétable",),
    "interprétables": ("interprétable",),
    "interprétateur": ("interprétateur",),
    "interprétateurs": ("interprétateur",),
    "interprétatrice": ("interprétateur",),
    "interprétatrices": ("interprétateur",),
    "interprétatif": ("interprétatif",),
    "interprétatifs": ("interprétatif",),
    "interprétative": ("interprétatif",),
    "interprétatives": ("interprétatif",),
    "interprofessionnelle": ("interprofessionnel",),
    "interprofessionnelles": ("interprofessionnel",),
    "interprofessionnel": ("interprofessionnel",),
    "interprofessionnels": ("interprofessionnel",),
    "interprovinciale": ("interprovincial",),
    "interprovinciales": ("interprovincial",),
    "interprovincial": ("interprovincial",),
    "interprovinciaux": ("interprovincial",),
    "interquartiers": ("interquartiers",),
    "interraciale": ("interracial",),
    "interraciales": ("interracial",),
    "interracial": ("interracial",),
    "interraciaux": ("interracial",),
    "interradiale": ("interradial",),
    "interradiales": ("interradial",),
    "interradial": ("interradial",),
    "interradiaux": ("interradial",),
    "interrégionale": ("interrégional",),
    "interrégionales": ("interrégional",),
    "interrégional": ("interrégional",),
    "interrégionaux": ("interrégional",),
    "interreligieuse": ("interreligieux",),
    "interreligieuses": ("interreligieux",),
    "interreligieux": ("interreligieux",),
    "interrénale": ("interrénal",),
    "interrénales": ("interrénal",),
    "interrénal": ("interrénal",),
    "interrénaux": ("interrénal",),
    "interro-emphatiques": ("interro-emphatique",),
    "interrogateur": ("interrogateur",),
    "interrogateurs": ("interrogateur",),
    "interrogatrice": ("interrogateur",),
    "interrogatrices": ("interrogateur",),
    "interrogatif": ("interrogatif",),
    "interrogatifs": ("interrogatif",),
    "interrogative": ("interrogatif",),
    "interrogatives": ("interrogatif",),
    "interrogeable": ("interrogeable",),
    "interrogeables": ("interrogeable",),
    "interrupteur": ("interrupteur",),
    "interrupteurs": ("interrupteur",),
    "interruptrice": ("interrupteur",),
    "interruptrices": ("interrupteur",),
    "interruptif": ("interruptif",),
    "interruptifs": ("interruptif",),
    "interruptive": ("interruptif",),
    "interruptives": ("interruptif",),
    "interruptus": ("interruptus",),
    "interscapulaire": ("interscapulaire",),
    "interscapulaires": ("interscapulaire",),
    "interscolaire": ("interscolaire",),
    "interscolaires": ("interscolaire",),
    "intersectorielle": ("intersectoriel",),
    "intersectorielles": ("intersectoriel",),
    "intersectoriel": ("intersectoriel",),
    "intersectoriels": ("intersectoriel",),
    "intersegmentaire": ("intersegmentaire",),
    "intersegmentaires": ("intersegmentaire",),
    "intersertale": ("intersertal",),
    "intersertales": ("intersertal",),
    "intersertal": ("intersertal",),
    "intersertaux": ("intersertal",),
    "intersexuelle": ("intersexuel",),
    "intersexuelles": ("intersexuel",),
    "intersexuel": ("intersexuel",),
    "intersexuels": ("intersexuel",),
    "intersidérale": ("intersidéral",),
    "intersidérales": ("intersidéral",),
    "intersidéral": ("intersidéral",),
    "intersidéraux": ("intersidéral",),
    "interspécifique": ("interspécifique",),
    "interspécifiques": ("interspécifique",),
    "interstellaire": ("interstellaire",),
    "interstellaires": ("interstellaire",),
    "interstérile": ("interstérile",),
    "interstériles": ("interstérile",),
    "interstitielle": ("interstitiel",),
    "interstitielles": ("interstitiel",),
    "interstitiel": ("interstitiel",),
    "interstitiels": ("interstitiel",),
    "intersubjectif": ("intersubjectif",),
    "intersubjectifs": ("intersubjectif",),
    "intersubjective": ("intersubjectif",),
    "intersubjectives": ("intersubjectif",),
    "intersynaptique": ("intersynaptique",),
    "intersynaptiques": ("intersynaptique",),
    "intersyndicale": ("intersyndical",),
    "intersyndicales": ("intersyndical",),
    "intersyndical": ("intersyndical",),
    "intersyndicaux": ("intersyndical",),
    "intertechnique": ("intertechnique",),
    "intertechniques": ("intertechnique",),
    "intertemporelle": ("intertemporel",),
    "intertemporelles": ("intertemporel",),
    "intertemporel": ("intertemporel",),
    "intertemporels": ("intertemporel",),
    "interterritoriale": ("interterritorial",),
    "interterritoriales": ("interterritorial",),
    "interterritorial": ("interterritorial",),
    "interterritoriaux": ("interterritorial",),
    "intertextuelle": ("intertextuel",),
    "intertextuelles": ("intertextuel",),
    "intertextuel": ("intertextuel",),
    "intertextuels": ("intertextuel",),
    "interthalamique": ("interthalamique",),
    "interthalamiques": ("interthalamique",),
    "interthématique": ("interthématique",),
    "interthématiques": ("interthématique",),
    "intertidale": ("intertidal",),
    "intertidales": ("intertidal",),
    "intertidal": ("intertidal",),
    "intertidaux": ("intertidal",),
    "intertransversaire": ("intertransversaire",),
    "intertransversaires": ("intertransversaire",),
    "intertribale": ("intertribal",),
    "intertribales": ("intertribal",),
    "intertribal": ("intertribal",),
    "intertribaux": ("intertribal",),
    "intertrigineuse": ("intertrigineux",),
    "intertrigineuses": ("intertrigineux",),
    "intertrigineux": ("intertrigineux",),
    "intertropicale": ("intertropical",),
    "intertropicales": ("intertropical",),
    "intertropical": ("intertropical",),
    "intertropicaux": ("intertropical",),
    "interuniversitaire": ("interuniversitaire",),
    "interuniversitaires": ("interuniversitaire",),
    "intervallaire": ("intervallaire",),
    "intervallaires": ("intervallaire",),
    "interventionnelle": ("interventionnel",),
    "interventionnelles": ("interventionnel",),
    "interventionnel": ("interventionnel",),
    "interventionnels": ("interventionnel",),
    "interventionniste": ("interventionniste",),
    "interventionnistes": ("interventionniste",),
    "interventriculaire": ("interventriculaire",),
    "interventriculaires": ("interventriculaire",),
    "intervertébrale": ("intervertébral",),
    "intervertébrales": ("intervertébral",),
    "intervertébral": ("intervertébral",),
    "intervertébraux": ("intervertébral",),
    "intervilleuse": ("intervilleux",),
    "intervilleuses": ("intervilleux",),
    "intervilleux": ("intervilleux",),
    "intervisible": ("intervisible",),
    "intervisibles": ("intervisible",),
    "intervocalique": ("intervocalique",),
    "intervocaliques": ("intervocalique",),
    "interzonale": ("interzonal",),
    "interzonales": ("interzonal",),
    "interzonal": ("interzonal",),
    "interzonaux": ("interzonal",),
    "interzone": ("interzone",),
    "interzones": ("interzones",),
    "intestable": ("intestable",),
    "intestables": ("intestable",),
    "intestat": ("intestat",),
    "intestinale": ("intestinal",),
    "intestinales": ("intestinal",),
    "intestinal": ("intestinal",),
    "intestinaux": ("intestinal",),
    "intimale": ("intimal",),
    "intimales": ("intimal",),
    "intimal": ("intimal",),
    "intimaux": ("intimal",),
    "intimée": ("intimé",),
    "intimées": ("intimé",),
    "intimé": ("intimé",),
    "intime": ("intime",),
    "intimés": ("intimé",),
    "intimes": ("intime",),
    "intimidable": ("intimidable",),
    "intimidables": ("intimidable",),
    "intimidateur": ("intimidateur",),
    "intimidateurs": ("intimidateur",),
    "intimidatrice": ("intimidateur",),
    "intimidatrices": ("intimidateur",),
    "intimiste": ("intimiste",),
    "intimistes": ("intimiste",),
    "intirable": ("intirable",),
    "intirables": ("intirable",),
    "intolérable": ("intolérable",),
    "intolérables": ("intolérable",),
    "intonatif": ("intonatif",),
    "intonatifs": ("intonatif",),
    "intonative": ("intonatif",),
    "intonatives": ("intonatif",),
    "intonatoire": ("intonatoire",),
    "intonatoires": ("intonatoire",),
    "intonologique": ("intonologique",),
    "intonologiques": ("intonologique",),
    "intouchable": ("intouchable",),
    "intouchables": ("intouchable",),
    "intournable": ("intournable",),
    "intournables": ("intournable",),
    "intra-artérielle": ("intra-artériel",),
    "intra-artérielles": ("intra-artériel",),
    "intra-articulaires": ("intra-articulaire",),
    "intra-atomique": ("intra-atomique",),
    "intrabranche": ("intrabranche",),
    "intrabranches": ("intrabranche",),
    "intracamérulaire": ("intracamérulaire",),
    "intracamérulaires": ("intracamérulaire",),
    "intracapsulaire": ("intracapsulaire",),
    "intracapsulaires": ("intracapsulaire",),
    "intracardiaque": ("intracardiaque",),
    "intracardiaques": ("intracardiaque",),
    "intracavitaire": ("intracavitaire",),
    "intracavitaires": ("intracavitaire",),
    "intracellulaire": ("intracellulaire",),
    "intracellulaires": ("intracellulaire",),
    "intraceptif": ("intraceptif",),
    "intraceptifs": ("intraceptif",),
    "intraceptive": ("intraceptif",),
    "intraceptives": ("intraceptif",),
    "intracérébrale": ("intracérébral",),
    "intracérébrales": ("intracérébral",),
    "intracérébral": ("intracérébral",),
    "intracérébraux": ("intracérébral",),
    "intracervicale": ("intracervical",),
    "intracervicales": ("intracervical",),
    "intracervical": ("intracervical",),
    "intracervicaux": ("intracervical",),
    "intracisternale": ("intracisternal",),
    "intracisternales": ("intracisternal",),
    "intracisternal": ("intracisternal",),
    "intracisternaux": ("intracisternal",),
    "intracommunautaire": ("intracommunautaire",),
    "intracommunautaires": ("intracommunautaire",),
    "intracontinentale": ("intracontinental",),
    "intracontinentales": ("intracontinental",),
    "intracontinental": ("intracontinental",),
    "intracontinentaux": ("intracontinental",),
    "intracornéen": ("intracornéen",),
    "intracornéenne": ("intracornéen",),
    "intracornéennes": ("intracornéen",),
    "intracornéens": ("intracornéen",),
    "intracrânien": ("intracrânien",),
    "intracrânienne": ("intracrânien",),
    "intracrâniennes": ("intracrânien",),
    "intracrâniens": ("intracrânien",),
    "intracratonique": ("intracratonique",),
    "intracratoniques": ("intracratonique",),
    "intracytoplasmique": ("intracytoplasmique",),
    "intracytoplasmiques": ("intracytoplasmique",),
    "intradéférentielle": ("intradéférentiel",),
    "intradéférentielles": ("intradéférentiel",),
    "intradéférentiel": ("intradéférentiel",),
    "intradéférentiels": ("intradéférentiel",),
    "intradermique": ("intradermique",),
    "intradermiques": ("intradermique",),
    "intradigestif": ("intradigestif",),
    "intradigestifs": ("intradigestif",),
    "intradigestive": ("intradigestif",),
    "intradigestives": ("intradigestif",),
    "intraduisible": ("intraduisible",),
    "intraduisibles": ("intraduisible",),
    "intrafamiliale": ("intrafamilial",),
    "intrafamiliales": ("intrafamilial",),
    "intrafamilial": ("intrafamilial",),
    "intrafamiliaux": ("intrafamilial",),
    "intrafémorale": ("intrafémoral",),
    "intrafémorales": ("intrafémoral",),
    "intrafémoral": ("intrafémoral",),
    "intrafémoraux": ("intrafémoral",),
    "intraformationnelle": ("intraformationnel",),
    "intraformationnelles": ("intraformationnel",),
    "intraformationnel": ("intraformationnel",),
    "intraformationnels": ("intraformationnel",),
    "intragalactique": ("intragalactique",),
    "intragalactiques": ("intragalactique",),
    "intragastrique": ("intragastrique",),
    "intragastriques": ("intragastrique",),
    "intragénérique": ("intragénérique",),
    "intragénériques": ("intragénérique",),
    "intraglaciaire": ("intraglaciaire",),
    "intraglaciaires": ("intraglaciaire",),
    "intragranulaire": ("intragranulaire",),
    "intragranulaires": ("intragranulaire",),
    "intrahépatique": ("intrahépatique",),
    "intrahépatiques": ("intrahépatique",),
    "intraire": ("intraire",),
    "intraires": ("intraire",),
    "intraitable": ("intraitable",),
    "intraitables": ("intraitable",),
    "intralaminaire": ("intralaminaire",),
    "intralaminaires": ("intralaminaire",),
    "intralobulaire": ("intralobulaire",),
    "intralobulaires": ("intralobulaire",),
    "intramammaire": ("intramammaire",),
    "intramammaires": ("intramammaire",),
    "intramédullaire": ("intramédullaire",),
    "intramédullaires": ("intramédullaire",),
    "intramercurielle": ("intramercuriel",),
    "intramercurielles": ("intramercuriel",),
    "intramercuriel": ("intramercuriel",),
    "intramercuriels": ("intramercuriel",),
    "intramoléculaire": ("intramoléculaire",),
    "intramoléculaires": ("intramoléculaire",),
    "intramontagneuse": ("intramontagneux",),
    "intramontagneuses": ("intramontagneux",),
    "intramontagneux": ("intramontagneux",),
    "intramurale": ("intramural",),
    "intramurales": ("intramural",),
    "intramural": ("intramural",),
    "intramuraux": ("intramural",),
    "intramusculaire": ("intramusculaire",),
    "intramusculaires": ("intramusculaire",),
    "intranasale": ("intranasal",),
    "intranasales": ("intranasal",),
    "intranasal": ("intranasal",),
    "intranasaux": ("intranasal",),
    "intransférable": ("intransférable",),
    "intransférables": ("intransférable",),
    "intransitif": ("intransitif",),
    "intransitifs": ("intransitif",),
    "intransitive": ("intransitif",),
    "intransitives": ("intransitif",),
    "intransmissible": ("intransmissible",),
    "intransmissibles": ("intransmissible",),
    "intransportable": ("intransportable",),
    "intransportables": ("intransportable",),
    "intranucléaire": ("intranucléaire",),
    "intranucléaires": ("intranucléaire",),
    "intraoculaire": ("intraoculaire",),
    "intraoculaires": ("intraoculaire",),
    "intraparenchymateuse": ("intraparenchymateux",),
    "intraparenchymateuses": ("intraparenchymateux",),
    "intraparenchymateux": ("intraparenchymateux",),
    "intrapariétale": ("intrapariétal",),
    "intrapariétales": ("intrapariétal",),
    "intrapariétal": ("intrapariétal",),
    "intrapariétaux": ("intrapariétal",),
    "intrapelvien": ("intrapelvien",),
    "intrapelvienne": ("intrapelvien",),
    "intrapelviennes": ("intrapelvien",),
    "intrapelviens": ("intrapelvien",),
    "intrapéritonéale": ("intrapéritonéal",),
    "intrapéritonéales": ("intrapéritonéal",),
    "intrapéritonéal": ("intrapéritonéal",),
    "intrapéritonéaux": ("intrapéritonéal",),
    "intrapleurale": ("intrapleural",),
    "intrapleurales": ("intrapleural",),
    "intrapleural": ("intrapleural",),
    "intrapleuraux": ("intrapleural",),
    "intrapsychique": ("intrapsychique",),
    "intrapsychiques": ("intrapsychique",),
    "intrarachidien": ("intrarachidien",),
    "intrarachidienne": ("intrarachidien",),
    "intrarachidiennes": ("intrarachidien",),
    "intrarachidiens": ("intrarachidien",),
    "intrarégionale": ("intrarégional",),
    "intrarégionales": ("intrarégional",),
    "intrarégional": ("intrarégional",),
    "intrarégionaux": ("intrarégional",),
    "intrarénale": ("intrarénal",),
    "intrarénales": ("intrarénal",),
    "intrarénal": ("intrarénal",),
    "intrarénaux": ("intrarénal",),
    "intrasacculaire": ("intrasacculaire",),
    "intrasacculaires": ("intrasacculaire",),
    "intrasclérale": ("intrascléral",),
    "intrasclérales": ("intrascléral",),
    "intrascléral": ("intrascléral",),
    "intrascléraux": ("intrascléral",),
    "intrasellaire": ("intrasellaire",),
    "intrasellaires": ("intrasellaire",),
    "intraspécifique": ("intraspécifique",),
    "intraspécifiques": ("intraspécifique",),
    "intratellurique": ("intratellurique",),
    "intratelluriques": ("intratellurique",),
    "intraténonien": ("intraténonien",),
    "intraténonienne": ("intraténonien",),
    "intraténoniennes": ("intraténonien",),
    "intraténoniens": ("intraténonien",),
    "intratesticulaire": ("intratesticulaire",),
    "intratesticulaires": ("intratesticulaire",),
    "intrathécale": ("intrathécal",),
    "intrathécales": ("intrathécal",),
    "intrathécal": ("intrathécal",),
    "intrathécaux": ("intrathécal",),
    "intrathoracique": ("intrathoracique",),
    "intrathoraciques": ("intrathoracique",),
    "intratubaire": ("intratubaire",),
    "intratubaires": ("intratubaire",),
    "intra-urbaine": ("intra-urbain",),
    "intra-utérine": ("intra-utérin",),
    "intra-utérin": ("intra-utérin",),
    "intra-utérins": ("intra-utérin",),
    "intravaginale": ("intravaginal",),
    "intravaginales": ("intravaginal",),
    "intravaginal": ("intravaginal",),
    "intravaginaux": ("intravaginal",),
    "intravasculaire": ("intravasculaire",),
    "intravasculaires": ("intravasculaire",),
    "intraveineuse": ("intraveineux",),
    "intraveineuses": ("intraveineux",),
    "intra-veineux": ("intra-veineux",),
    "intraveineux": ("intraveineux",),
    "intraventriculaire": ("intraventriculaire",),
    "intraventriculaires": ("intraventriculaire",),
    "intraversable": ("intraversable",),
    "intraversables": ("intraversable",),
    "intravertébrale": ("intravertébral",),
    "intravertébrales": ("intravertébral",),
    "intravertébral": ("intravertébral",),
    "intravertébraux": ("intravertébral",),
    "intravésicale": ("intravésical",),
    "intravésicales": ("intravésical",),
    "intravésical": ("intravésical",),
    "intravésicaux": ("intravésical",),
    "intrazonale": ("intrazonal",),
    "intrazonales": ("intrazonal",),
    "intrazonal": ("intrazonal",),
    "intrazonaux": ("intrazonal",),
    "intrépide": ("intrépide",),
    "intrépides": ("intrépide",),
    "intrinsécoïde": ("intrinsécoïde",),
    "intrinsécoïdes": ("intrinsécoïde",),
    "intrinsèque": ("intrinsèque",),
    "intrinsèques": ("intrinsèque",),
    "introductible": ("introductible",),
    "introductibles": ("introductible",),
    "introductif": ("introductif",),
    "introductifs": ("introductif",),
    "introductive": ("introductif",),
    "introductives": ("introductif",),
    "introjectif": ("introjectif",),
    "introjectifs": ("introjectif",),
    "introjective": ("introjectif",),
    "introjectives": ("introjectif",),
    "introrse": ("introrse",),
    "introrses": ("introrse",),
    "introspectif": ("introspectif",),
    "introspectifs": ("introspectif",),
    "introspective": ("introspectif",),
    "introspectives": ("introspectif",),
    "introuvable": ("introuvable",),
    "introuvables": ("introuvable",),
    "introversif": ("introversif",),
    "introversifs": ("introversif",),
    "introversive": ("introversif",),
    "introversives": ("introversif",),
    "intruse": ("intrus",),
    "intruses": ("intrus",),
    "intrus": ("intrus",),
    "intrusif": ("intrusif",),
    "intrusifs": ("intrusif",),
    "intrusive": ("intrusif",),
    "intrusives": ("intrusif",),
    "intuitif": ("intuitif",),
    "intuitifs": ("intuitif",),
    "intuitive": ("intuitif",),
    "intuitives": ("intuitif",),
    "intuitionniste": ("intuitionniste",),
    "intuitionnistes": ("intuitionniste",),
    "inuit": ("inuit",),
    "inuits": ("inuit",),
    "inusable": ("inusable",),
    "inusables": ("inusable",),
    "inusuelle": ("inusuel",),
    "inusuelles": ("inusuel",),
    "inusuel": ("inusuel",),
    "inusuels": ("inusuel",),
    "inutile": ("inutile",),
    "inutiles": ("inutile",),
    "inutilisable": ("inutilisable",),
    "inutilisables": ("inutilisable",),
    "invalide": ("invalide",),
    "invalides": ("invalide",),
    "invariable": ("invariable",),
    "invariables": ("invariable",),
    "invasif": ("invasif",),
    "invasifs": ("invasif",),
    "invasive": ("invasive",),
    "invasives": ("invasive",),
    "invendable": ("invendable",),
    "invendables": ("invendable",),
    "inventeur": ("inventeur",),
    "inventeurs": ("inventeur",),
    "inventrice": ("inventeur",),
    "inventrices": ("inventeur",),
    "inventif": ("inventif",),
    "inventifs": ("inventif",),
    "inventive": ("inventif",),
    "inventives": ("inventif",),
    "inverdissable": ("inverdissable",),
    "inverdissables": ("inverdissable",),
    "invérifiable": ("invérifiable",),
    "invérifiables": ("invérifiable",),
    "inversable": ("inversable",),
    "inversables": ("inversable",),
    "inversée": ("inversé",),
    "inversées": ("inversé",),
    "inversé": ("inversé",),
    "inverse": ("inverse",),
    "inversés": ("inversé",),
    "inverses": ("inverse",),
    "inversible": ("inversible",),
    "inversibles": ("inversible",),
    "inversif": ("inversif",),
    "inversifs": ("inversif",),
    "inversive": ("inversif",),
    "inversives": ("inversif",),
    "investigateur": ("investigateur",),
    "investigateurs": ("investigateur",),
    "investigatrice": ("investigateur",),
    "investigatrices": ("investigateur",),
    "investisseur": ("investisseur",),
    "investisseurs": ("investisseur",),
    "investisseuse": ("investisseur",),
    "investisseuses": ("investisseur",),
    "inviable": ("inviable",),
    "inviables": ("inviable",),
    "invincible": ("invincible",),
    "invincibles": ("invincible",),
    "inviolable": ("inviolable",),
    "inviolables": ("inviolable",),
    "invisible": ("invisible",),
    "invisibles": ("invisible",),
    "invitatif": ("invitatif",),
    "invitatifs": ("invitatif",),
    "invitative": ("invitatif",),
    "invitatives": ("invitatif",),
    "invitatoire": ("invitatoire",),
    "invitatoires": ("invitatoire",),
    "invivable": ("invivable",),
    "invivables": ("invivable",),
    "invocateur": ("invocateur",),
    "invocateurs": ("invocateur",),
    "invocatrice": ("invocateur",),
    "invocatrices": ("invocateur",),
    "invocatoire": ("invocatoire",),
    "invocatoires": ("invocatoire",),
    "involable": ("involable",),
    "involables": ("involable",),
    "involontaire": ("involontaire",),
    "involontaires": ("involontaire",),
    "involutif": ("involutif",),
    "involutifs": ("involutif",),
    "involutive": ("involutif",),
    "involutives": ("involutif",),
    "invraisemblable": ("invraisemblable",),
    "invraisemblables": ("invraisemblable",),
    "invulnérable": ("invulnérable",),
    "invulnérables": ("invulnérable",),
    "iodacétique": ("iodacétique",),
    "iodacétiques": ("iodacétique",),
    "iodeuse": ("iodeux",),
    "iodeuses": ("iodeux",),
    "iodeux": ("iodeux",),
    "iodhydrique": ("iodhydrique",),
    "iodhydriques": ("iodhydrique",),
    "iodifère": ("iodifère",),
    "iodifères": ("iodifère",),
    "iodique": ("iodique",),
    "iodiques": ("iodique",),
    "iodogorgonique": ("iodogorgonique",),
    "iodogorgoniques": ("iodogorgonique",),
    "iodo-iodurées": ("iodo-ioduré",),
    "iodométrique": ("iodométrique",),
    "iodométriques": ("iodométrique",),
    "iodo-organiques": ("iodo-organique",),
    "iodophile": ("iodophile",),
    "iodophiles": ("iodophile",),
    "iodorganique": ("iodorganique",),
    "iodorganiques": ("iodorganique",),
    "iodotannique": ("iodotannique",),
    "iodotanniques": ("iodotannique",),
    "ionien": ("ionien",),
    "ionienne": ("ionien",),
    "ioniennes": ("ionien",),
    "ioniens": ("ionien",),
    "ionique": ("ionique",),
    "ioniques": ("ionique",),
    "ionosphérique": ("ionosphérique",),
    "ionosphériques": ("ionosphérique",),
    "ipsilatérale": ("ipsilatéral",),
    "ipsilatérales": ("ipsilatéral",),
    "ipsilatéral": ("ipsilatéral",),
    "ipsilatéraux": ("ipsilatéral",),
    "ipsiversif": ("ipsiversif",),
    "ipsiversifs": ("ipsiversif",),
    "ipsiversive": ("ipsiversif",),
    "ipsiversives": ("ipsiversif",),
    "irakien": ("irakien",),
    "irakienne": ("irakien",),
    "irakiennes": ("irakien",),
    "irakiens": ("irakien",),
    "iranien": ("iranien",),
    "iranienne": ("iranien",),
    "iraniennes": ("iranien",),
    "iraniens": ("iranien",),
    "iraqien": ("iraqien",),
    "iraqienne": ("iraqien",),
    "iraqiennes": ("iraqien",),
    "iraqiens": ("iraqien",),
    "iraquien": ("iraquien",),
    "iraquienne": ("iraquien",),
    "iraquiennes": ("iraquien",),
    "iraquiens": ("iraquien",),
    "irascible": ("irascible",),
    "irascibles": ("irascible",),
    "irénique": ("irénique",),
    "iréniques": ("irénique",),
    "iridien": ("iridien",),
    "iridienne": ("iridien",),
    "iridiennes": ("iridien",),
    "iridiens": ("iridien",),
    "iridoconstricteur": ("iridoconstricteur",),
    "iridoconstricteurs": ("iridoconstricteur",),
    "iridocornéen": ("iridocornéen",),
    "iridocornéenne": ("iridocornéen",),
    "iridocornéennes": ("iridocornéen",),
    "iridocornéens": ("iridocornéen",),
    "irien": ("irien",),
    "irienne": ("irien",),
    "iriennes": ("irien",),
    "iriens": ("irien",),
    "irisable": ("irisable",),
    "irisables": ("irisable",),
    "irlandaise": ("irlandais",),
    "irlandaises": ("irlandais",),
    "irlandais": ("irlandais",),
    "ironique": ("ironique",),
    "ironiques": ("ironique",),
    "iroquoise": ("iroquois",),
    "iroquoises": ("iroquois",),
    "iroquois": ("iroquois",),
    "irraccommodable": ("irraccommodable",),
    "irraccommodables": ("irraccommodable",),
    "irrachetable": ("irrachetable",),
    "irrachetables": ("irrachetable",),
    "irracontable": ("irracontable",),
    "irracontables": ("irracontable",),
    "irraisonnable": ("irraisonnable",),
    "irraisonnables": ("irraisonnable",),
    "irrassasiable": ("irrassasiable",),
    "irrassasiables": ("irrassasiable",),
    "irrationaliste": ("irrationaliste",),
    "irrationalistes": ("irrationaliste",),
    "irrationnaliste": ("irrationnaliste",),
    "irrationnalistes": ("irrationnaliste",),
    "irrationnelle": ("irrationnel",),
    "irrationnelles": ("irrationnel",),
    "irrationnel": ("irrationnel",),
    "irrationnels": ("irrationnel",),
    "irrattrapable": ("irrattrapable",),
    "irrattrapables": ("irrattrapable",),
    "irréalisable": ("irréalisable",),
    "irréalisables": ("irréalisable",),
    "irréaliste": ("irréaliste",),
    "irréalistes": ("irréaliste",),
    "irrecevable": ("irrecevable",),
    "irrecevables": ("irrecevable",),
    "irréconciliable": ("irréconciliable",),
    "irréconciliables": ("irréconciliable",),
    "irrécouvrable": ("irrécouvrable",),
    "irrécouvrables": ("irrécouvrable",),
    "irrécupérable": ("irrécupérable",),
    "irrécupérables": ("irrécupérable",),
    "irrécusable": ("irrécusable",),
    "irrécusables": ("irrécusable",),
    "irrédentiste": ("irrédentiste",),
    "irrédentistes": ("irrédentiste",),
    "irréductible": ("irréductible",),
    "irréductibles": ("irréductible",),
    "irréelle": ("irréel",),
    "irréelles": ("irréel",),
    "irréel": ("irréel",),
    "irréels": ("irréel",),
    "irréformable": ("irréformable",),
    "irréformables": ("irréformable",),
    "irréfragable": ("irréfragable",),
    "irréfragables": ("irréfragable",),
    "irréfrangible": ("irréfrangible",),
    "irréfrangibles": ("irréfrangible",),
    "irréfrénable": ("irréfrénable",),
    "irréfrénables": ("irréfrénable",),
    "irréfutable": ("irréfutable",),
    "irréfutables": ("irréfutable",),
    "irrégulière": ("irrégulier",),
    "irrégulières": ("irrégulier",),
    "irrégulier": ("irrégulier",),
    "irréguliers": ("irrégulier",),
    "irréligieuse": ("irréligieux",),
    "irréligieuses": ("irréligieux",),
    "irréligieux": ("irréligieux",),
    "irremarquable": ("irremarquable",),
    "irremarquables": ("irremarquable",),
    "irremboursable": ("irremboursable",),
    "irremboursables": ("irremboursable",),
    "irrémédiable": ("irrémédiable",),
    "irrémédiables": ("irrémédiable",),
    "irrémissible": ("irrémissible",),
    "irrémissibles": ("irrémissible",),
    "irremplaçable": ("irremplaçable",),
    "irremplaçables": ("irremplaçable",),
    "irremplissable": ("irremplissable",),
    "irremplissables": ("irremplissable",),
    "irremuable": ("irremuable",),
    "irremuables": ("irremuable",),
    "irrémunérable": ("irrémunérable",),
    "irrémunérables": ("irrémunérable",),
    "irréparable": ("irréparable",),
    "irréparables": ("irréparable",),
    "irrepassable": ("irrepassable",),
    "irrepassables": ("irrepassable",),
    "irrépétible": ("irrépétible",),
    "irrépétibles": ("irrépétible",),
    "irrépréhensible": ("irrépréhensible",),
    "irrépréhensibles": ("irrépréhensible",),
    "irreprésentable": ("irreprésentable",),
    "irreprésentables": ("irreprésentable",),
    "irrépressible": ("irrépressible",),
    "irrépressibles": ("irrépressible",),
    "irréprimable": ("irréprimable",),
    "irréprimables": ("irréprimable",),
    "irréprochable": ("irréprochable",),
    "irréprochables": ("irréprochable",),
    "irrésistible": ("irrésistible",),
    "irrésistibles": ("irrésistible",),
    "irrespectueuse": ("irrespectueux",),
    "irrespectueuses": ("irrespectueux",),
    "irrespectueux": ("irrespectueux",),
    "irrespirable": ("irrespirable",),
    "irrespirables": ("irrespirable",),
    "irresponsable": ("irresponsable",),
    "irresponsables": ("irresponsable",),
    "irrétractable": ("irrétractable",),
    "irrétractables": ("irrétractable",),
    "irrétrécissable": ("irrétrécissable",),
    "irrétrécissables": ("irrétrécissable",),
    "irretrouvable": ("irretrouvable",),
    "irretrouvables": ("irretrouvable",),
    "irrévélable": ("irrévélable",),
    "irrévélables": ("irrévélable",),
    "irrevendable": ("irrevendable",),
    "irrevendables": ("irrevendable",),
    "irrévérencieuse": ("irrévérencieux",),
    "irrévérencieuses": ("irrévérencieux",),
    "irrévérencieux": ("irrévérencieux",),
    "irréversible": ("irréversible",),
    "irréversibles": ("irréversible",),
    "irrévocable": ("irrévocable",),
    "irrévocables": ("irrévocable",),
    "irrigable": ("irrigable",),
    "irrigables": ("irrigable",),
    "irrigateur": ("irrigateur",),
    "irrigateurs": ("irrigateur",),
    "irrigatrice": ("irrigateur",),
    "irrigatrices": ("irrigateur",),
    "irrigatoire": ("irrigatoire",),
    "irrigatoires": ("irrigatoire",),
    "irritable": ("irritable",),
    "irritables": ("irritable",),
    "irritatif": ("irritatif",),
    "irritatifs": ("irritatif",),
    "irritative": ("irritatif",),
    "irritatives": ("irritatif",),
    "irvingien": ("irvingien",),
    "irvingienne": ("irvingien",),
    "irvingiennes": ("irvingien",),
    "irvingiens": ("irvingien",),
    "irvingiste": ("irvingiste",),
    "irvingistes": ("irvingiste",),
    "isabelle": ("isabelle",),
    "isatique": ("isatique",),
    "isatiques": ("isatique",),
    "ischémique": ("ischémique",),
    "ischémiques": ("ischémique",),
    "ischiatique": ("ischiatique",),
    "ischiatiques": ("ischiatique",),
    "isenthalpique": ("isenthalpique",),
    "isenthalpiques": ("isenthalpique",),
    "isentropique": ("isentropique",),
    "isentropiques": ("isentropique",),
    "iséroise": ("isérois",),
    "iséroises": ("isérois",),
    "isérois": ("isérois",),
    "isiaque": ("isiaque",),
    "isiaques": ("isiaque",),
    "islamique": ("islamique",),
    "islamiques": ("islamique",),
    "islamiste": ("islamiste",),
    "islamistes": ("islamiste",),
    "islandaise": ("islandais",),
    "islandaises": ("islandais",),
    "islandais": ("islandais",),
    "ismaélien": ("ismaélien",),
    "ismaélienne": ("ismaélien",),
    "ismaéliennes": ("ismaélien",),
    "ismaéliens": ("ismaélien",),
    "ismaélite": ("ismaélite",),
    "ismaélites": ("ismaélite",),
    "ismaïlien": ("ismaïlien",),
    "ismaïlienne": ("ismaïlien",),
    "ismaïliennes": ("ismaïlien",),
    "ismaïliens": ("ismaïlien",),
    "isoamylique": ("isoamylique",),
    "isoamyliques": ("isoamylique",),
    "isobare": ("isobare",),
    "isobares": ("isobare",),
    "isobarique": ("isobarique",),
    "isobariques": ("isobarique",),
    "isobathe": ("isobathe",),
    "isobathes": ("isobathe",),
    "isobutylique": ("isobutylique",),
    "isobutyliques": ("isobutylique",),
    "isobutyrique": ("isobutyrique",),
    "isobutyriques": ("isobutyrique",),
    "isocalorique": ("isocalorique",),
    "isocaloriques": ("isocalorique",),
    "isocarène": ("isocarène",),
    "isocarènes": ("isocarène",),
    "isocèle": ("isocèle",),
    "isocèles": ("isocèle",),
    "isochimène": ("isochimène",),
    "isochimènes": ("isochimène",),
    "isochore": ("isochore",),
    "isochores": ("isochore",),
    "isochromatique": ("isochromatique",),
    "isochromatiques": ("isochromatique",),
    "isochrome": ("isochrome",),
    "isochromes": ("isochrome",),
    "isochrone": ("isochrone",),
    "isochrones": ("isochrone",),
    "isochronique": ("isochronique",),
    "isochroniques": ("isochronique",),
    "isocitrique": ("isocitrique",),
    "isocitriques": ("isocitrique",),
    "isoclinale": ("isoclinal",),
    "isoclinales": ("isoclinal",),
    "isoclinal": ("isoclinal",),
    "isoclinaux": ("isoclinal",),
    "isocline": ("isocline",),
    "isoclines": ("isocline",),
    "isoclinique": ("isoclinique",),
    "isocliniques": ("isoclinique",),
    "isocore": ("isocore",),
    "isocores": ("isocore",),
    "isocrotonique": ("isocrotonique",),
    "isocrotoniques": ("isocrotonique",),
    "isocyanique": ("isocyanique",),
    "isocyaniques": ("isocyanique",),
    "isocyclique": ("isocyclique",),
    "isocycliques": ("isocyclique",),
    "isodiastolique": ("isodiastolique",),
    "isodiastoliques": ("isodiastolique",),
    "isodome": ("isodome",),
    "isodomes": ("isodome",),
    "isodonte": ("isodonte",),
    "isodontes": ("isodonte",),
    "isodose": ("isodose",),
    "isodoses": ("isodose",),
    "isodyname": ("isodyname",),
    "isodynames": ("isodyname",),
    "isodynamique": ("isodynamique",),
    "isodynamiques": ("isodynamique",),
    "isoédrique": ("isoédrique",),
    "isoédriques": ("isoédrique",),
    "isoélectrique": ("isoélectrique",),
    "isoélectriques": ("isoélectrique",),
    "isoélectronique": ("isoélectronique",),
    "isoélectroniques": ("isoélectronique",),
    "isogame": ("isogame",),
    "isogames": ("isogame",),
    "isogamme": ("isogamme",),
    "isogammes": ("isogamme",),
    "isogène": ("isogène",),
    "isogènes": ("isogène",),
    "isogénique": ("isogénique",),
    "isogéniques": ("isogénique",),
    "isogéotherme": ("isogéotherme",),
    "isogéothermes": ("isogéotherme",),
    "isoglosse": ("isoglosse",),
    "isoglosses": ("isoglosse",),
    "isogonale": ("isogonal",),
    "isogonales": ("isogonal",),
    "isogonal": ("isogonal",),
    "isogonaux": ("isogonal",),
    "isogone": ("isogone",),
    "isogones": ("isogone",),
    "isogonique": ("isogonique",),
    "isogoniques": ("isogonique",),
    "isograde": ("isograde",),
    "isogrades": ("isograde",),
    "isogranulaire": ("isogranulaire",),
    "isogranulaires": ("isogranulaire",),
    "isogroupe": ("isogroupe",),
    "isogroupes": ("isogroupe",),
    "isohumique": ("isohumique",),
    "isohumiques": ("isohumique",),
    "isohydrique": ("isohydrique",),
    "isohydriques": ("isohydrique",),
    "isohyète": ("isohyète",),
    "isohyètes": ("isohyète",),
    "isohypse": ("isohypse",),
    "isohypses": ("isohypse",),
    "iso-ioniques": ("isoionique",),
    "isolable": ("isolable",),
    "isolables": ("isolable",),
    "isolateur": ("isolateur",),
    "isolateurs": ("isolateur",),
    "isolatrice": ("isolateur",),
    "isolatrices": ("isolateur",),
    "isolationniste": ("isolationniste",),
    "isolationnistes": ("isolationniste",),
    "isologue": ("isologue",),
    "isologues": ("isologue",),
    "isolympique": ("isolympique",),
    "isolympiques": ("isolympique",),
    "isomère": ("isomère",),
    "isomères": ("isomère",),
    "isomérique": ("isomérique",),
    "isomériques": ("isomérique",),
    "isomètre": ("isomètre",),
    "isomètres": ("isomètre",),
    "isométrique": ("isométrique",),
    "isométriques": ("isométrique",),
    "isomorphe": ("isomorphe",),
    "isomorphes": ("isomorphe",),
    "isonèphe": ("isonèphe",),
    "isonèphes": ("isonèphe",),
    "isonicotinique": ("isonicotinique",),
    "isonicotiniques": ("isonicotinique",),
    "isopaque": ("isopaque",),
    "isopaques": ("isopaque",),
    "isopenténylique": ("isopenténylique",),
    "isopentényliques": ("isopenténylique",),
    "isopentylique": ("isopentylique",),
    "isopentyliques": ("isopentylique",),
    "isopérimètre": ("isopérimètre",),
    "isopérimètres": ("isopérimètre",),
    "isopérimétrique": ("isopérimétrique",),
    "isopérimétriques": ("isopérimétrique",),
    "isophane": ("isophane",),
    "isophanes": ("isophane",),
    "isophase": ("isophase",),
    "isophases": ("isophase",),
    "isophtalique": ("isophtalique",),
    "isophtaliques": ("isophtalique",),
    "isophygmique": ("isophygmique",),
    "isophygmiques": ("isophygmique",),
    "isopièze": ("isopièze",),
    "isopièzes": ("isopièze",),
    "isopique": ("isopique",),
    "isopiques": ("isopique",),
    "isopode": ("isopode",),
    "isopodes": ("isopode",),
    "isopolaire": ("isopolaire",),
    "isopolaires": ("isopolaire",),
    "isoprénique": ("isoprénique",),
    "isopréniques": ("isoprénique",),
    "isopropylique": ("isopropylique",),
    "isopropyliques": ("isopropylique",),
    "isopycne": ("isopycne",),
    "isopycnes": ("isopycne",),
    "isorythmique": ("isorythmique",),
    "isorythmiques": ("isorythmique",),
    "isoséiste": ("isoséiste",),
    "isoséistes": ("isoséiste",),
    "isosexuelle": ("isosexuel",),
    "isosexuelles": ("isosexuel",),
    "isosexuel": ("isosexuel",),
    "isosexuels": ("isosexuel",),
    "isosiste": ("isosiste",),
    "isosistes": ("isosiste",),
    "isosonique": ("isosonique",),
    "isosoniques": ("isosonique",),
    "isostatique": ("isostatique",),
    "isostatiques": ("isostatique",),
    "isostémone": ("isostémone",),
    "isostémones": ("isostémone",),
    "isostère": ("isostère",),
    "isostères": ("isostère",),
    "isosyllabique": ("isosyllabique",),
    "isosyllabiques": ("isosyllabique",),
    "isotactique": ("isotactique",),
    "isotactiques": ("isotactique",),
    "isothérapique": ("isothérapique",),
    "isothérapiques": ("isothérapique",),
    "isothère": ("isothère",),
    "isothères": ("isothère",),
    "isotherme": ("isotherme",),
    "isothermes": ("isotherme",),
    "isothermique": ("isothermique",),
    "isothermiques": ("isothermique",),
    "isothiocyanique": ("isothiocyanique",),
    "isothiocyaniques": ("isothiocyanique",),
    "isotone": ("isotone",),
    "isotones": ("isotone",),
    "isotonique": ("isotonique",),
    "isotoniques": ("isotonique",),
    "isotope": ("isotope",),
    "isotopes": ("isotope",),
    "isotopique": ("isotopique",),
    "isotopiques": ("isotopique",),
    "isotrope": ("isotrope",),
    "isotropes": ("isotrope",),
    "isotype": ("isotype",),
    "isotypes": ("isotype",),
    "isotypique": ("isotypique",),
    "isotypiques": ("isotypique",),
    "isovalérique": ("isovalérique",),
    "isovalériques": ("isovalérique",),
    "isovolumétrique": ("isovolumétrique",),
    "isovolumétriques": ("isovolumétrique",),
    "isovolumique": ("isovolumique",),
    "isovolumiques": ("isovolumique",),
    "israélien": ("israélien",),
    "israélienne": ("israélien",),
    "israéliennes": ("israélien",),
    "israéliens": ("israélien",),
    "israélite": ("israélite",),
    "israélites": ("israélite",),
    "israélo-arabe": ("israélo-arabe",),
    "israélo-arabes": ("israélo-arabe",),
    "israélo-libanaise": ("israélo-libanais",),
    "israélo-libanaises": ("israélo-libanais",),
    "israélo-libanais": ("israélo-libanais",),
    "israélo-palestinien": ("israélo-palestinien",),
    "israélo-palestinienne": ("israélo-palestinien",),
    "israélo-palestiniennes": ("israélo-palestinien",),
    "israélo-syrien": ("israélo-syrien",),
    "israélo-syrienne": ("israélo-syrien",),
    "israélo-syriennes": ("israélo-syrien",),
    "israélo-syriens": ("israélo-syrien",),
    "issa": ("issa",),
    "issas": ("issa",),
    "isthmique": ("isthmique",),
    "isthmiques": ("isthmique",),
    "italien": ("italien",),
    "italienne": ("italien",),
    "italiennes": ("italien",),
    "italiens": ("italien",),
    "italique": ("italique",),
    "italiques": ("italique",),
    "italo-celtique": ("italo-celtique",),
    "italophone": ("italophone",),
    "italophones": ("italophone",),
    "itératif": ("itératif",),
    "itératifs": ("itératif",),
    "itérative": ("itératif",),
    "itératives": ("itératif",),
    "ithyphallique": ("ithyphallique",),
    "ithyphalliques": ("ithyphallique",),
    "itinéraire": ("itinéraire",),
    "itinéraires": ("itinéraire",),
    "ivoirien": ("ivoirien",),
    "ivoirienne": ("ivoirien",),
    "ivoiriennes": ("ivoirien",),
    "ivoiriens": ("ivoirien",),
    "ivre": ("ivre",),
    "ivres": ("ivre",),
    "ixophrénique": ("ixophrénique",),
    "ixophréniques": ("ixophrénique",),
    "ixothymique": ("ixothymique",),
    "ixothymiques": ("ixothymique",),
    "jacasseur": ("jacasseur",),
    "jacasseurs": ("jacasseur",),
    "jacasseuse": ("jacasseur",),
    "jacasseuses": ("jacasseur",),
    "jacassière": ("jacassier",),
    "jacassières": ("jacassier",),
    "jacassier": ("jacassier",),
    "jacassiers": ("jacassier",),
    "jaciste": ("jaciste",),
    "jacistes": ("jaciste",),
    "jacksonien": ("jacksonien",),
    "jacksonienne": ("jacksonien",),
    "jacksoniennes": ("jacksonien",),
    "jacksoniens": ("jacksonien",),
    "jacksoniste": ("jacksoniste",),
    "jacksonistes": ("jacksoniste",),
    "jacobéen": ("jacobéen",),
    "jacobéenne": ("jacobéen",),
    "jacobéennes": ("jacobéen",),
    "jacobéens": ("jacobéen",),
    "jacobien": ("jacobien",),
    "jacobienne": ("jacobien",),
    "jacobiennes": ("jacobien",),
    "jacobiens": ("jacobien",),
    "jacobite": ("jacobite",),
    "jacobites": ("jacobite",),
    "jacquard": ("jacquard",),
    "jactancière": ("jactancier",),
    "jactancières": ("jactancier",),
    "jactancier": ("jactancier",),
    "jactanciers": ("jactancier",),
    "jaculatoire": ("jaculatoire",),
    "jaculatoires": ("jaculatoire",),
    "jade": ("jade",),
    "jaïna": ("jaïna",),
    "jalonneur": ("jalonneur",),
    "jalonneurs": ("jalonneur",),
    "jalonneuse": ("jalonneur",),
    "jalonneuses": ("jalonneur",),
    "jalouse": ("jaloux",),
    "jalouses": ("jaloux",),
    "jaloux": ("jaloux",),
    "jambière": ("jambier",),
    "jambières": ("jambier",),
    "jambier": ("jambier",),
    "jambiers": ("jambier",),
    "janiforme": ("janiforme",),
    "janiformes": ("janiforme",),
    "janséniste": ("janséniste",),
    "jansénistes": ("janséniste",),
    "japonaise": ("japonais",),
    "japonaises": ("japonais",),
    "japonais": ("japonais",),
    "jappeur": ("jappeur",),
    "jappeurs": ("jappeur",),
    "jappeuse": ("jappeur",),
    "jappeuses": ("jappeur",),
    "jardinatoire": ("jardinatoire",),
    "jardinatoires": ("jardinatoire",),
    "jardineuse": ("jardineux",),
    "jardineuses": ("jardineux",),
    "jardineux": ("jardineux",),
    "jardinière": ("jardinier",),
    "jardinières": ("jardinier",),
    "jardinier": ("jardinier",),
    "jardiniers": ("jardinier",),
    "jargonagraphique": ("jargonagraphique",),
    "jargonagraphiques": ("jargonagraphique",),
    "jargonaphasique": ("jargonaphasique",),
    "jargonaphasiques": ("jargonaphasique",),
    "jarreuse": ("jarreux",),
    "jarreuses": ("jarreux",),
    "jarreux": ("jarreux",),
    "jaseur": ("jaseur",),
    "jaseurs": ("jaseur",),
    "jaseuse": ("jaseur",),
    "jaseuses": ("jaseur",),
    "jaspineur": ("jaspineur",),
    "jaspineurs": ("jaspineur",),
    "jaspineuse": ("jaspineur",),
    "jaspineuses": ("jaspineur",),
    "jaunâtre": ("jaunâtre",),
    "jaunâtres": ("jaunâtre",),
    "jaune": ("jaune",),
    "jaunes": ("jaune",),
    "jaunet": ("jaunet",),
    "jaunets": ("jaunet",),
    "jaunette": ("jaunet",),
    "jaunettes": ("jaunet",),
    "jauressiste": ("jauressiste",),
    "jauressistes": ("jauressiste",),
    "javanaise": ("javanais",),
    "javanaises": ("javanais",),
    "javanais": ("javanais",),
    "javeleur": ("javeleur",),
    "javeleurs": ("javeleur",),
    "javeleuse": ("javeleur",),
    "javeleuses": ("javeleur",),
    "jazzique": ("jazzique",),
    "jazziques": ("jazzique",),
    "jazziste": ("jazziste",),
    "jazzistes": ("jazziste",),
    "jazzistique": ("jazzistique",),
    "jazzistiques": ("jazzistique",),
    "jazzy": ("jazzy",),
    "jéciste": ("jéciste",),
    "jécistes": ("jéciste",),
    "jectisse": ("jectisse",),
    "jectisses": ("jectisse",),
    "jéjunale": ("jéjunal",),
    "jéjunales": ("jéjunal",),
    "jéjunal": ("jéjunal",),
    "jéjunaux": ("jéjunal",),
    "jéjunocolique": ("jéjunocolique",),
    "jéjunocoliques": ("jéjunocolique",),
    "jennérien": ("jennérien",),
    "jennérienne": ("jennérien",),
    "jennériennes": ("jennérien",),
    "jennériens": ("jennérien",),
    "jersiaise": ("jersiais",),
    "jersiaises": ("jersiais",),
    "jersiais": ("jersiais",),
    "jésuite": ("jésuite",),
    "jésuites": ("jésuite",),
    "jésuitique": ("jésuitique",),
    "jésuitiques": ("jésuitique",),
    "jetable": ("jetable",),
    "jetables": ("jetable",),
    "jetisse": ("jetisse",),
    "jetisses": ("jetisse",),
    "jettice": ("jettice",),
    "jettices": ("jettice",),
    "jeune": ("jeune",),
    "jeunes": ("jeune",),
    "jeunet": ("jeunet",),
    "jeunets": ("jeunet",),
    "jeunette": ("jeunet",),
    "jeunettes": ("jeunet",),
    "jeunot": ("jeunot",),
    "jeunots": ("jeunot",),
    "jeunotte": ("jeunot",),
    "jeunottes": ("jeunot",),
    "jingoïste": ("jingoïste",),
    "jingoïstes": ("jingoïste",),
    "jociste": ("jociste",),
    "jocistes": ("jociste",),
    "johannique": ("johannique",),
    "johanniques": ("johannique",),
    "johannite": ("johannite",),
    "johannites": ("johannite",),
    "joignable": ("joignable",),
    "joignables": ("joignable",),
    "jointif": ("jointif",),
    "jointifs": ("jointif",),
    "jointive": ("jointif",),
    "jointives": ("jointif",),
    "jojo": ("jojo",),
    "joliet": ("joliet",),
    "joliets": ("joliet",),
    "joliette": ("joliet",),
    "joliettes": ("joliet",),
    "jomon": ("jomon",),
    "jonciforme": ("jonciforme",),
    "jonciformes": ("jonciforme",),
    "jonctionnelle": ("jonctionnel",),
    "jonctionnelles": ("jonctionnel",),
    "jonctionnel": ("jonctionnel",),
    "jonctionnels": ("jonctionnel",),
    "jonquille": ("jonquille",),
    "jordanien": ("jordanien",),
    "jordanienne": ("jordanien",),
    "jordaniennes": ("jordanien",),
    "jordaniens": ("jordanien",),
    "joseph": ("joseph",),
    "joséphiste": ("joséphiste",),
    "joséphistes": ("joséphiste",),
    "jouable": ("jouable",),
    "jouables": ("jouable",),
    "jouasse": ("jouasse",),
    "jouasses": ("jouasse",),
    "joueur": ("joueur",),
    "joueurs": ("joueur",),
    "joueuse": ("joueur",),
    "joueuses": ("joueur",),
    "jouisseur": ("jouisseur",),
    "jouisseurs": ("jouisseur",),
    "jouisseuse": ("jouisseur",),
    "jouisseuses": ("jouisseur",),
    "jouissif": ("jouissif",),
    "jouissifs": ("jouissif",),
    "jouissive": ("jouissif",),
    "jouissives": ("jouissif",),
    "journalière": ("journalier",),
    "journalières": ("journalier",),
    "journalier": ("journalier",),
    "journaliers": ("journalier",),
    "journalistique": ("journalistique",),
    "journalistiques": ("journalistique",),
    "jovien": ("jovien",),
    "jovienne": ("jovien",),
    "joviennes": ("jovien",),
    "joviens": ("jovien",),
    "joycien": ("joycien",),
    "joycienne": ("joycien",),
    "joyciennes": ("joycien",),
    "joyciens": ("joycien",),
    "joyeuse": ("joyeux",),
    "joyeuses": ("joyeux",),
    "joyeux": ("joyeux",),
    "jubilaire": ("jubilaire",),
    "jubilaires": ("jubilaire",),
    "jubilatoire": ("jubilatoire",),
    "jubilatoires": ("jubilatoire",),
    "judaïque": ("judaïque",),
    "judaïques": ("judaïque",),
    "judéo-allemande": ("judéo-allemand",),
    "judéo-allemand": ("judéo-allemand",),
    "judéo-arabe": ("judéo-arabe",),
    "judéo-chrétien": ("judéo-chrétien",),
    "judéo-chrétienne": ("judéo-chrétien",),
    "judéo-chrétiennes": ("judéo-chrétien",),
    "judéo-chrétiens": ("judéo-chrétien",),
    "judéo-espagnols": ("judéo-espagnol",),
    "judéo-française": ("judéo-français",),
    "judéo-maçonnique": ("judéo-maçonnique",),
    "judéo-maçonniques": ("judéo-maçonnique",),
    "judéo-marxistes": ("judéo-marxiste",),
    "judiciaire": ("judiciaire",),
    "judiciaires": ("judiciaire",),
    "judicieuse": ("judicieux",),
    "judicieuses": ("judicieux",),
    "judicieux": ("judicieux",),
    "jugale": ("jugal",),
    "jugales": ("jugal",),
    "jugal": ("jugal",),
    "jugaux": ("jugal",),
    "jugeable": ("jugeable",),
    "jugeables": ("jugeable",),
    "jugeur": ("jugeur",),
    "jugeurs": ("jugeur",),
    "jugeuse": ("jugeur",),
    "jugeuses": ("jugeur",),
    "jugulaire": ("jugulaire",),
    "jugulaires": ("jugulaire",),
    "juif": ("juif",),
    "juifs": ("juif",),
    "juive": ("juif",),
    "juives": ("juif",),
    "julien": ("julien",),
    "julienne": ("julien",),
    "juliennes": ("julien",),
    "juliens": ("julien",),
    "jumeau": ("jumeau",),
    "jumeaux": ("jumeau",),
    "jumelle": ("jumeau",),
    "jumelles": ("jumeau",),
    "jumel": ("jumel",),
    "jumenteuse": ("jumenteux",),
    "jumenteuses": ("jumenteux",),
    "jumenteux": ("jumenteux",),
    "jungien": ("jungien",),
    "jungienne": ("jungien",),
    "jungiennes": ("jungien",),
    "jungiens": ("jungien",),
    "junien": ("junien",),
    "junienne": ("junien",),
    "juniennes": ("junien",),
    "juniens": ("junien",),
    "junior": ("junior",),
    "juniors": ("junior",),
    "junonien": ("junonien",),
    "junonienne": ("junonien",),
    "junoniennes": ("junonien",),
    "junoniens": ("junonien",),
    "jupitérien": ("jupitérien",),
    "jupitérienne": ("jupitérien",),
    "jupitériennes": ("jupitérien",),
    "jupitériens": ("jupitérien",),
    "jurable": ("jurable",),
    "jurables": ("jurable",),
    "jurassien": ("jurassien",),
    "jurassienne": ("jurassien",),
    "jurassiennes": ("jurassien",),
    "jurassiens": ("jurassien",),
    "jurassique": ("jurassique",),
    "jurassiques": ("jurassique",),
    "juratoire": ("juratoire",),
    "juratoires": ("juratoire",),
    "jureur": ("jureur",),
    "jureurs": ("jureur",),
    "jureuse": ("jureur",),
    "jureuses": ("jureur",),
    "juridiciaire": ("juridiciaire",),
    "juridiciaires": ("juridiciaire",),
    "juridictionnelle": ("juridictionnel",),
    "juridictionnelles": ("juridictionnel",),
    "juridictionnel": ("juridictionnel",),
    "juridictionnels": ("juridictionnel",),
    "juridique": ("juridique",),
    "juridiques": ("juridique",),
    "jurisprudentielle": ("jurisprudentiel",),
    "jurisprudentielles": ("jurisprudentiel",),
    "jurisprudentiel": ("jurisprudentiel",),
    "jurisprudentiels": ("jurisprudentiel",),
    "jussif": ("jussif",),
    "jussifs": ("jussif",),
    "jussive": ("jussif",),
    "jussives": ("jussif",),
    "juste": ("juste",),
    "justes": ("juste",),
    "justiciable": ("justiciable",),
    "justiciables": ("justiciable",),
    "justicialiste": ("justicialiste",),
    "justicialistes": ("justicialiste",),
    "justicière": ("justicier",),
    "justicières": ("justicier",),
    "justicier": ("justicier",),
    "justiciers": ("justicier",),
    "justien": ("justien",),
    "justienne": ("justien",),
    "justiennes": ("justien",),
    "justiens": ("justien",),
    "justifiable": ("justifiable",),
    "justifiables": ("justifiable",),
    "justificateur": ("justificateur",),
    "justificateurs": ("justificateur",),
    "justificatrice": ("justificateur",),
    "justificatrices": ("justificateur",),
    "justificatif": ("justificatif",),
    "justificatifs": ("justificatif",),
    "justificative": ("justificatif",),
    "justificatives": ("justificatif",),
    "justinien": ("justinien",),
    "justinienne": ("justinien",),
    "justiniennes": ("justinien",),
    "justiniens": ("justinien",),
    "juteuse": ("juteux",),
    "juteuses": ("juteux",),
    "juteux": ("juteux",),
    "juvénile": ("juvénile",),
    "juvéniles": ("juvénile",),
    "juxtaglaciaire": ("juxtaglaciaire",),
    "juxtaglaciaires": ("juxtaglaciaire",),
    "juxtaliminaire": ("juxtaliminaire",),
    "juxtaliminaires": ("juxtaliminaire",),
    "juxtalinéaire": ("juxtalinéaire",),
    "juxtalinéaires": ("juxtalinéaire",),
    "juxtanucléaire": ("juxtanucléaire",),
    "juxtanucléaires": ("juxtanucléaire",),
    "juxtaposable": ("juxtaposable",),
    "juxtaposables": ("juxtaposable",),
    "juxtarétinien": ("juxtarétinien",),
    "juxtarétinienne": ("juxtarétinien",),
    "juxtarétiniennes": ("juxtarétinien",),
    "juxtarétiniens": ("juxtarétinien",),
    "juxtatropicale": ("juxtatropical",),
    "juxtatropicales": ("juxtatropical",),
    "juxtatropical": ("juxtatropical",),
    "juxtatropicaux": ("juxtatropical",),
    "kabbaliste": ("kabbaliste",),
    "kabbalistes": ("kabbaliste",),
    "kabbalistique": ("kabbalistique",),
    "kabbalistiques": ("kabbalistique",),
    "kabyle": ("kabyle",),
    "kabyles": ("kabyle",),
    "kachoube": ("kachoube",),
    "kachoubes": ("kachoube",),
    "kafkaïen": ("kafkaïen",),
    "kafkaïenne": ("kafkaïen",),
    "kafkaïennes": ("kafkaïen",),
    "kafkaïens": ("kafkaïen",),
    "kaki": ("kaki",),
    "kaléidoscopique": ("kaléidoscopique",),
    "kaléidoscopiques": ("kaléidoscopique",),
    "kampuchéen": ("kampuchéen",),
    "kampuchéenne": ("kampuchéen",),
    "kampuchéennes": ("kampuchéen",),
    "kampuchéens": ("kampuchéen",),
    "kanouri": ("kanouri",),
    "kanouris": ("kanouri",),
    "kantien": ("kantien",),
    "kantienne": ("kantien",),
    "kantiennes": ("kantien",),
    "kantiens": ("kantien",),
    "kaolinique": ("kaolinique",),
    "kaoliniques": ("kaolinique",),
    "kaolinitique": ("kaolinitique",),
    "kaolinitiques": ("kaolinitique",),
    "kaposien": ("kaposien",),
    "kaposienne": ("kaposien",),
    "kaposiennes": ("kaposien",),
    "kaposiens": ("kaposien",),
    "karpatique": ("karpatique",),
    "karpatiques": ("karpatique",),
    "karstique": ("karstique",),
    "karstiques": ("karstique",),
    "kascher": ("kascher",),
    "kasher": ("kasher",),
    "kelvin": ("kelvin",),
    "képlérien": ("képlérien",),
    "képlérienne": ("képlérien",),
    "képlériennes": ("képlérien",),
    "képlériens": ("képlérien",),
    "kéraphylleuse": ("kéraphylleux",),
    "kéraphylleuses": ("kéraphylleux",),
    "kéraphylleux": ("kéraphylleux",),
    "kératique": ("kératique",),
    "kératiques": ("kératique",),
    "kératolytique": ("kératolytique",),
    "kératolytiques": ("kératolytique",),
    "kératoplastique": ("kératoplastique",),
    "kératoplastiques": ("kératoplastique",),
    "kératosique": ("kératosique",),
    "kératosiques": ("kératosique",),
    "keynesien": ("keynesien",),
    "keynésien": ("keynésien",),
    "keynesienne": ("keynesien",),
    "keynésienne": ("keynésien",),
    "keynesiennes": ("keynesien",),
    "keynésiennes": ("keynésien",),
    "keynesiens": ("keynesien",),
    "keynésiens": ("keynésien",),
    "khâgneuse": ("khâgneux",),
    "khâgneuses": ("khâgneux",),
    "khâgneux": ("khâgneux",),
    "kharidjite": ("kharidjite",),
    "khâridjite": ("khâridjite",),
    "kharidjites": ("kharidjite",),
    "khâridjites": ("khâridjite",),
    "khasi": ("khasi",),
    "khasis": ("khasi",),
    "khédivale": ("khédival",),
    "khédivales": ("khédival",),
    "khédival": ("khédival",),
    "khédivaux": ("khédival",),
    "khédiviale": ("khédivial",),
    "khédiviales": ("khédivial",),
    "khédivial": ("khédivial",),
    "khédiviaux": ("khédivial",),
    "khmère": ("khmer",),
    "khmères": ("khmer",),
    "khmer": ("khmer",),
    "khmers": ("khmer",),
    "khoisan": ("khoisan",),
    "kikuyu": ("kikuyu",),
    "kikuyus": ("kikuyu",),
    "kilométrique": ("kilométrique",),
    "kilométriques": ("kilométrique",),
    "kilotonnique": ("kilotonnique",),
    "kilotonniques": ("kilotonnique",),
    "kimono": ("kimono",),
    "kinésimétrique": ("kinésimétrique",),
    "kinésimétriques": ("kinésimétrique",),
    "kinésique": ("kinésique",),
    "kinésiques": ("kinésique",),
    "kinésithérapique": ("kinésithérapique",),
    "kinésithérapiques": ("kinésithérapique",),
    "kinésodique": ("kinésodique",),
    "kinésodiques": ("kinésodique",),
    "kinesthésique": ("kinesthésique",),
    "kinesthésiques": ("kinesthésique",),
    "kirghize": ("kirghiz",),
    "kirghizes": ("kirghiz",),
    "kirghiz": ("kirghiz",),
    "kitsch": ("kitsch",),
    "kleptomane": ("kleptomane",),
    "kleptomanes": ("kleptomane",),
    "kolhkozien": ("kolhkozien",),
    "kolhkozienne": ("kolhkozien",),
    "kolhkoziennes": ("kolhkozien",),
    "kolhkoziens": ("kolhkozien",),
    "kolkhozien": ("kolkhozien",),
    "kolkhozienne": ("kolkhozien",),
    "kolkhoziennes": ("kolkhozien",),
    "kolkhoziens": ("kolkhozien",),
    "koweitien": ("koweitien",),
    "koweïtien": ("koweïtien",),
    "koweitienne": ("koweitien",),
    "koweïtienne": ("koweïtien",),
    "koweitiennes": ("koweitien",),
    "koweïtiennes": ("koweïtien",),
    "koweitiens": ("koweitien",),
    "koweïtiens": ("koweïtien",),
    "kraft": ("kraft",),
    "kufique": ("kufique",),
    "kufiques": ("kufique",),
    "kupfférien": ("kupfférien",),
    "kupfférienne": ("kupfférien",),
    "kupffériennes": ("kupfférien",),
    "kupffériens": ("kupfférien",),
    "kurde": ("kurde",),
    "kurdes": ("kurde",),
    "kymrique": ("kymrique",),
    "kymriques": ("kymrique",),
    "kystique": ("kystique",),
    "kystiques": ("kystique",),
    "labiale": ("labial",),
    "labiales": ("labial",),
    "labial": ("labial",),
    "labiaux": ("labial",),
    "labile": ("labile",),
    "labiles": ("labile",),
    "labiodentale": ("labiodental",),
    "labio-dentales": ("labiodental",),
    "labiodentales": ("labiodental",),
    "labio-dental": ("labiodental",),
    "labiodental": ("labiodental",),
    "labiodentaux": ("labiodental",),
    "labiographique": ("labiographique",),
    "labiographiques": ("labiographique",),
    "labiopalatale": ("labiopalatal",),
    "labio-palatales": ("labiopalatal",),
    "labiopalatales": ("labiopalatal",),
    "labio-palatal": ("labiopalatal",),
    "labiopalatal": ("labiopalatal",),
    "labiopalataux": ("labiopalatal",),
    "laborieuse": ("laborieux",),
    "laborieuses": ("laborieux",),
    "laborieux": ("laborieux",),
    "labourable": ("labourable",),
    "labourables": ("labourable",),
    "labyrinthique": ("labyrinthique",),
    "labyrinthiques": ("labyrinthique",),
    "lacanien": ("lacanien",),
    "lacanienne": ("lacanien",),
    "lacaniennes": ("lacanien",),
    "lacaniens": ("lacanien",),
    "lacédémonien": ("lacédémonien",),
    "lacédémonienne": ("lacédémonien",),
    "lacédémoniennes": ("lacédémonien",),
    "lacédémoniens": ("lacédémonien",),
    "lacérable": ("lacérable",),
    "lacérables": ("lacérable",),
    "lâchée": ("lâché",),
    "lâchées": ("lâché",),
    "lâché": ("lâché",),
    "lâche": ("lâche",),
    "lâchés": ("lâché",),
    "lâches": ("lâche",),
    "laconique": ("laconique",),
    "laconiques": ("laconique",),
    "lacrymale": ("lacrymal",),
    "lacrymales": ("lacrymal",),
    "lacrymal": ("lacrymal",),
    "lacrymaux": ("lacrymal",),
    "lacrymogène": ("lacrymogène",),
    "lacrymogènes": ("lacrymogène",),
    "lactaire": ("lactaire",),
    "lactaires": ("lactaire",),
    "lactamique": ("lactamique",),
    "lactamiques": ("lactamique",),
    "lactasique": ("lactasique",),
    "lactasiques": ("lactasique",),
    "lactéale": ("lactéal",),
    "lactéales": ("lactéal",),
    "lactéal": ("lactéal",),
    "lactéaux": ("lactéal",),
    "lacticigène": ("lacticigène",),
    "lacticigènes": ("lacticigène",),
    "lactifère": ("lactifère",),
    "lactifères": ("lactifère",),
    "lactique": ("lactique",),
    "lactiques": ("lactique",),
    "lactonique": ("lactonique",),
    "lactoniques": ("lactonique",),
    "lactophile": ("lactophile",),
    "lactophiles": ("lactophile",),
    "lactotrope": ("lactotrope",),
    "lactotropes": ("lactotrope",),
    "lacunaire": ("lacunaire",),
    "lacunaires": ("lacunaire",),
    "lacuneuse": ("lacuneux",),
    "lacuneuses": ("lacuneux",),
    "lacuneux": ("lacuneux",),
    "lacustre": ("lacustre",),
    "lacustres": ("lacustre",),
    "ladre": ("ladre",),
    "ladres": ("ladre",),
    "laevogyre": ("laevogyre",),
    "laevogyres": ("laevogyre",),
    "lagénaire": ("lagénaire",),
    "lagénaires": ("lagénaire",),
    "lagide": ("lagide",),
    "lagides": ("lagide",),
    "lagrangien": ("lagrangien",),
    "lagrangienne": ("lagrangien",),
    "lagrangiennes": ("lagrangien",),
    "lagrangiens": ("lagrangien",),
    "lagunaire": ("lagunaire",),
    "lagunaires": ("lagunaire",),
    "laïc": ("laïc",),
    "laïcs": ("laïc",),
    "laïque": ("laïque",),
    "laïques": ("laïque",),
    "laïciste": ("laïciste",),
    "laïcistes": ("laïciste",),
    "laideron": ("laideron",),
    "laideronne": ("laideron",),
    "laideronnes": ("laideron",),
    "laiderons": ("laideron",),
    "laineuse": ("laineux",),
    "laineuses": ("laineux",),
    "laineux": ("laineux",),
    "lainière": ("lainier",),
    "lainières": ("lainier",),
    "lainier": ("lainier",),
    "lainiers": ("lainier",),
    "laiteuse": ("laiteux",),
    "laiteuses": ("laiteux",),
    "laiteux": ("laiteux",),
    "laitière": ("laitier",),
    "laitières": ("laitier",),
    "laitier": ("laitier",),
    "laitiers": ("laitier",),
    "laïusseur": ("laïusseur",),
    "laïusseurs": ("laïusseur",),
    "laïusseuse": ("laïusseur",),
    "laïusseuses": ("laïusseur",),
    "lakiste": ("lakiste",),
    "lakistes": ("lakiste",),
    "lamaïste": ("lamaïste",),
    "lamaïstes": ("lamaïste",),
    "lamarckien": ("lamarckien",),
    "lamarckienne": ("lamarckien",),
    "lamarckiennes": ("lamarckien",),
    "lamarckiens": ("lamarckien",),
    "lamartinien": ("lamartinien",),
    "lamartinienne": ("lamartinien",),
    "lamartiniennes": ("lamartinien",),
    "lamartiniens": ("lamartinien",),
    "lambdoïde": ("lambdoïde",),
    "lambdoïdes": ("lambdoïde",),
    "lamellaire": ("lamellaire",),
    "lamellaires": ("lamellaire",),
    "lamelleuse": ("lamelleux",),
    "lamelleuses": ("lamelleux",),
    "lamelleux": ("lamelleux",),
    "lamellicorne": ("lamellicorne",),
    "lamellicornes": ("lamellicorne",),
    "lamelliforme": ("lamelliforme",),
    "lamelliformes": ("lamelliforme",),
    "lamellirostre": ("lamellirostre",),
    "lamellirostres": ("lamellirostre",),
    "lamentable": ("lamentable",),
    "lamentables": ("lamentable",),
    "lamiaque": ("lamiaque",),
    "lamiaques": ("lamiaque",),
    "laminaire": ("laminaire",),
    "laminaires": ("laminaire",),
    "laminale": ("laminal",),
    "laminales": ("laminal",),
    "laminal": ("laminal",),
    "laminaux": ("laminal",),
    "lamineur": ("lamineur",),
    "lamineurs": ("lamineur",),
    "lamineuse": ("lamineux",),
    "lamineuses": ("lamineux",),
    "lamineux": ("lamineux",),
    "lamoute": ("lamoute",),
    "lamoutes": ("lamoute",),
    "lampadophore": ("lampadophore",),
    "lampadophores": ("lampadophore",),
    "lancastrien": ("lancastrien",),
    "lancastrienne": ("lancastrien",),
    "lancastriennes": ("lancastrien",),
    "lancastriens": ("lancastrien",),
    "lancéiforme": ("lancéiforme",),
    "lancéiformes": ("lancéiforme",),
    "landaise": ("landais",),
    "landaises": ("landais",),
    "landais": ("landais",),
    "langagière": ("langagier",),
    "langagières": ("langagier",),
    "langagier": ("langagier",),
    "langagiers": ("langagier",),
    "langerhansien": ("langerhansien",),
    "langerhansienne": ("langerhansien",),
    "langerhansiennes": ("langerhansien",),
    "langerhansiens": ("langerhansien",),
    "langoureuse": ("langoureux",),
    "langoureuses": ("langoureux",),
    "langoureux": ("langoureux",),
    "languedocien": ("languedocien",),
    "languedocienne": ("languedocien",),
    "languedociennes": ("languedocien",),
    "languedociens": ("languedocien",),
    "languide": ("languide",),
    "languides": ("languide",),
    "laniaire": ("laniaire",),
    "laniaires": ("laniaire",),
    "lanice": ("lanice",),
    "lanices": ("lanice",),
    "lanifère": ("lanifère",),
    "lanifères": ("lanifère",),
    "lanigère": ("lanigère",),
    "lanigères": ("lanigère",),
    "lanugineuse": ("lanugineux",),
    "lanugineuses": ("lanugineux",),
    "lanugineux": ("lanugineux",),
    "laotien": ("laotien",),
    "laotienne": ("laotien",),
    "laotiennes": ("laotien",),
    "laotiens": ("laotien",),
    "lapidaire": ("lapidaire",),
    "lapidaires": ("lapidaire",),
    "lapidicole": ("lapidicole",),
    "lapidicoles": ("lapidicole",),
    "lapilleuse": ("lapilleux",),
    "lapilleuses": ("lapilleux",),
    "lapilleux": ("lapilleux",),
    "lapis": ("lapis",),
    "laplacien": ("laplacien",),
    "laplacienne": ("laplacien",),
    "laplaciennes": ("laplacien",),
    "laplaciens": ("laplacien",),
    "lapse": ("laps",),
    "lapses": ("laps",),
    "laps": ("laps",),
    "laqueuse": ("laqueux",),
    "laqueuses": ("laqueux",),
    "laqueux": ("laqueux",),
    "lare": ("lare",),
    "lares": ("lare",),
    "largable": ("largable",),
    "largables": ("largable",),
    "large": ("large",),
    "larges": ("large",),
    "largue": ("largue",),
    "largues": ("largue",),
    "larmeuse": ("larmeux",),
    "larmeuses": ("larmeux",),
    "larmeux": ("larmeux",),
    "larmoyeur": ("larmoyeur",),
    "larmoyeurs": ("larmoyeur",),
    "larmoyeuse": ("larmoyeur",),
    "larmoyeuses": ("larmoyeur",),
    "larvaire": ("larvaire",),
    "larvaires": ("larvaire",),
    "larvicide": ("larvicide",),
    "larvicides": ("larvicide",),
    "laryngale": ("laryngal",),
    "laryngales": ("laryngal",),
    "laryngal": ("laryngal",),
    "laryngaux": ("laryngal",),
    "laryngien": ("laryngien",),
    "laryngienne": ("laryngien",),
    "laryngiennes": ("laryngien",),
    "laryngiens": ("laryngien",),
    "laryngologique": ("laryngologique",),
    "laryngologiques": ("laryngologique",),
    "laryngoscopique": ("laryngoscopique",),
    "laryngoscopiques": ("laryngoscopique",),
    "laryngotomique": ("laryngotomique",),
    "laryngotomiques": ("laryngotomique",),
    "las": ("las",),
    "lasse": ("las",),
    "lasses": ("las",),
    "lascif": ("lascif",),
    "lascifs": ("lascif",),
    "lascive": ("lascif",),
    "lascives": ("lascif",),
    "latérale": ("latéral",),
    "latérales": ("latéral",),
    "latéral": ("latéral",),
    "latéraux": ("latéral",),
    "latéritique": ("latéritique",),
    "latéritiques": ("latéritique",),
    "latérodigestif": ("latérodigestif",),
    "latérodigestifs": ("latérodigestif",),
    "latérodigestive": ("latérodigestif",),
    "latérodigestives": ("latérodigestif",),
    "latérodorsale": ("latérodorsal",),
    "latérodorsales": ("latérodorsal",),
    "latérodorsal": ("latérodorsal",),
    "latérodorsaux": ("latérodorsal",),
    "latérolatérale": ("latérolatéral",),
    "latérolatérales": ("latérolatéral",),
    "latérolatéral": ("latérolatéral",),
    "latérolatéraux": ("latérolatéral",),
    "latérosellaire": ("latérosellaire",),
    "latérosellaires": ("latérosellaire",),
    "latéroterminale": ("latéroterminal",),
    "latéroterminales": ("latéroterminal",),
    "latéroterminal": ("latéroterminal",),
    "latéroterminaux": ("latéroterminal",),
    "laticifère": ("laticifère",),
    "laticifères": ("laticifère",),
    "latifundiaire": ("latifundiaire",),
    "latifundiaires": ("latifundiaire",),
    "latifundiste": ("latifundiste",),
    "latifundistes": ("latifundiste",),
    "latiniste": ("latiniste",),
    "latinistes": ("latiniste",),
    "latino": ("latino",),
    "latinos": ("latino",),
    "latino-américaine": ("latino-américain",),
    "latino-américaines": ("latino-américain",),
    "latino-américain": ("latino-américain",),
    "latino-américains": ("latino-américain",),
    "latitudinaire": ("latitudinaire",),
    "latitudinaires": ("latitudinaire",),
    "latreutique": ("latreutique",),
    "latreutiques": ("latreutique",),
    "laudatif": ("laudatif",),
    "laudatifs": ("laudatif",),
    "laudative": ("laudatif",),
    "laudatives": ("laudatif",),
    "laurique": ("laurique",),
    "lauriques": ("laurique",),
    "lausannoise": ("lausannois",),
    "lausannoises": ("lausannois",),
    "lausannois": ("lausannois",),
    "lavable": ("lavable",),
    "lavables": ("lavable",),
    "lavallière": ("lavallière",),
    "lavallières": ("lavallière",),
    "lavande": ("lavande",),
    "laveur": ("laveur",),
    "laveurs": ("laveur",),
    "laveuse": ("laveur",),
    "laveuses": ("laveur",),
    "lavique": ("lavique",),
    "laviques": ("lavique",),
    "laxatif": ("laxatif",),
    "laxatifs": ("laxatif",),
    "laxative": ("laxatif",),
    "laxatives": ("laxatif",),
    "laxiste": ("laxiste",),
    "laxistes": ("laxiste",),
    "layetière": ("layetier",),
    "layetières": ("layetier",),
    "layetier": ("layetier",),
    "layetiers": ("layetier",),
    "lazariste": ("lazariste",),
    "lazaristes": ("lazariste",),
    "laze": ("laze",),
    "lazes": ("laze",),
    "lécanorique": ("lécanorique",),
    "lécanoriques": ("lécanorique",),
    "lécheur": ("lécheur",),
    "lécheurs": ("lécheur",),
    "lécheuse": ("lécheur",),
    "lécheuses": ("lécheur",),
    "ladite": ("ledit",),
    "ledit": ("ledit",),
    "lesdites": ("ledit",),
    "lesdits": ("ledit",),
    "lédonien": ("lédonien",),
    "lédonienne": ("lédonien",),
    "lédoniennes": ("lédonien",),
    "lédoniens": ("lédonien",),
    "légale": ("légal",),
    "légales": ("légal",),
    "légal": ("légal",),
    "légaux": ("légal",),
    "légaliste": ("légaliste",),
    "légalistes": ("légaliste",),
    "lège": ("lège",),
    "lèges": ("lège",),
    "légendaire": ("légendaire",),
    "légendaires": ("légendaire",),
    "légère": ("léger",),
    "légères": ("léger",),
    "léger": ("léger",),
    "légers": ("léger",),
    "légionnaire": ("légionnaire",),
    "légionnaires": ("légionnaire",),
    "législateur": ("législateur",),
    "législateurs": ("législateur",),
    "législatrice": ("législateur",),
    "législatrices": ("législateur",),
    "législatif": ("législatif",),
    "législatifs": ("législatif",),
    "législative": ("législatif",),
    "législatives": ("législatif",),
    "légiste": ("légiste",),
    "légistes": ("légiste",),
    "légitimée": ("légitimé",),
    "légitimées": ("légitimé",),
    "légitimé": ("légitimé",),
    "légitime": ("légitime",),
    "légitimés": ("légitimé",),
    "légitimes": ("légitime",),
    "légitimiste": ("légitimiste",),
    "légitimistes": ("légitimiste",),
    "légumière": ("légumier",),
    "légumières": ("légumier",),
    "légumier": ("légumier",),
    "légumiers": ("légumier",),
    "légumineuse": ("légumineux",),
    "légumineuses": ("légumineux",),
    "légumineux": ("légumineux",),
    "léiotonique": ("léiotonique",),
    "léiotoniques": ("léiotonique",),
    "lemmatique": ("lemmatique",),
    "lemmatiques": ("lemmatique",),
    "lemniscale": ("lemniscal",),
    "lemniscales": ("lemniscal",),
    "lemniscal": ("lemniscal",),
    "lemniscaux": ("lemniscal",),
    "léniniste": ("léniniste",),
    "léninistes": ("léniniste",),
    "lénitif": ("lénitif",),
    "lénitifs": ("lénitif",),
    "lénitive": ("lénitif",),
    "lénitives": ("lénitif",),
    "lenticulaire": ("lenticulaire",),
    "lenticulaires": ("lenticulaire",),
    "lentiforme": ("lentiforme",),
    "lentiformes": ("lentiforme",),
    "lentigineuse": ("lentigineux",),
    "lentigineuses": ("lentigineux",),
    "lentigineux": ("lentigineux",),
    "léonaise": ("léonais",),
    "léonaises": ("léonais",),
    "léonais": ("léonais",),
    "léontocéphale": ("léontocéphale",),
    "léontocéphales": ("léontocéphale",),
    "lépidoblastique": ("lépidoblastique",),
    "lépidoblastiques": ("lépidoblastique",),
    "lépreuse": ("lépreux",),
    "lépreuses": ("lépreux",),
    "lépreux": ("lépreux",),
    "léproïde": ("léproïde",),
    "léproïdes": ("léproïde",),
    "lépromateuse": ("lépromateux",),
    "lépromateuses": ("lépromateux",),
    "lépromateux": ("lépromateux",),
    "leptique": ("leptique",),
    "leptiques": ("leptique",),
    "leptocurtique": ("leptocurtique",),
    "leptocurtiques": ("leptocurtique",),
    "leptoïde": ("leptoïde",),
    "leptoïdes": ("leptoïde",),
    "leptolithique": ("leptolithique",),
    "leptolithiques": ("leptolithique",),
    "leptomorphe": ("leptomorphe",),
    "leptomorphes": ("leptomorphe",),
    "leptonique": ("leptonique",),
    "leptoniques": ("leptonique",),
    "leptoprosope": ("leptoprosope",),
    "leptoprosopes": ("leptoprosope",),
    "leptorhinien": ("leptorhinien",),
    "leptorhinienne": ("leptorhinien",),
    "leptorhiniennes": ("leptorhinien",),
    "leptorhiniens": ("leptorhinien",),
    "leptosome": ("leptosome",),
    "leptosomes": ("leptosome",),
    "leptotène": ("leptotène",),
    "leptotènes": ("leptotène",),
    "lesbien": ("lesbien",),
    "lesbienne": ("lesbien",),
    "lesbiennes": ("lesbien",),
    "lesbiens": ("lesbien",),
    "lésineur": ("lésineur",),
    "lésineurs": ("lésineur",),
    "lésineuse": ("lésineur",),
    "lésineuses": ("lésineur",),
    "lésionnaire": ("lésionnaire",),
    "lésionnaires": ("lésionnaire",),
    "lésionnelle": ("lésionnel",),
    "lésionnelles": ("lésionnel",),
    "lésionnel": ("lésionnel",),
    "lésionnels": ("lésionnel",),
    "lessivable": ("lessivable",),
    "lessivables": ("lessivable",),
    "lessivielle": ("lessiviel",),
    "lessivielles": ("lessiviel",),
    "lessiviel": ("lessiviel",),
    "lessiviels": ("lessiviel",),
    "lessivière": ("lessivier",),
    "lessivières": ("lessivier",),
    "lessivier": ("lessivier",),
    "lessiviers": ("lessivier",),
    "leste": ("leste",),
    "lestes": ("leste",),
    "lesteur": ("lesteur",),
    "lesteurs": ("lesteur",),
    "lesteuse": ("lesteur",),
    "lesteuses": ("lesteur",),
    "létale": ("létal",),
    "létales": ("létal",),
    "létal": ("létal",),
    "létaux": ("létal",),
    "let": ("let",),
    "léthale": ("léthal",),
    "léthales": ("léthal",),
    "léthal": ("léthal",),
    "léthaux": ("léthal",),
    "léthargique": ("léthargique",),
    "léthargiques": ("léthargique",),
    "létique": ("létique",),
    "létiques": ("létique",),
    "lettriste": ("lettriste",),
    "lettristes": ("lettriste",),
    "leucémique": ("leucémique",),
    "leucémiques": ("leucémique",),
    "leucémogène": ("leucémogène",),
    "leucémogènes": ("leucémogène",),
    "leucémoïde": ("leucémoïde",),
    "leucémoïdes": ("leucémoïde",),
    "leucoblastique": ("leucoblastique",),
    "leucoblastiques": ("leucoblastique",),
    "leucocrate": ("leucocrate",),
    "leucocrates": ("leucocrate",),
    "leucocytaire": ("leucocytaire",),
    "leucocytaires": ("leucocytaire",),
    "leucocytoïde": ("leucocytoïde",),
    "leucocytoïdes": ("leucocytoïde",),
    "leucoderme": ("leucoderme",),
    "leucodermes": ("leucoderme",),
    "leucodermique": ("leucodermique",),
    "leucodermiques": ("leucodermique",),
    "leucogène": ("leucogène",),
    "leucogènes": ("leucogène",),
    "leucopénique": ("leucopénique",),
    "leucopéniques": ("leucopénique",),
    "leucoplaquettaire": ("leucoplaquettaire",),
    "leucoplaquettaires": ("leucoplaquettaire",),
    "leucoplasique": ("leucoplasique",),
    "leucoplasiques": ("leucoplasique",),
    "leucopoïétique": ("leucopoïétique",),
    "leucopoïétiques": ("leucopoïétique",),
    "leucorrhéique": ("leucorrhéique",),
    "leucorrhéiques": ("leucorrhéique",),
    "leucosique": ("leucosique",),
    "leucosiques": ("leucosique",),
    "leucotaxique": ("leucotaxique",),
    "leucotaxiques": ("leucotaxique",),
    "leucotoxique": ("leucotoxique",),
    "leucotoxiques": ("leucotoxique",),
    "levalloisien": ("levalloisien",),
    "levalloisienne": ("levalloisien",),
    "levalloisiennes": ("levalloisien",),
    "levalloisiens": ("levalloisien",),
    "lévitique": ("lévitique",),
    "lévitiques": ("lévitique",),
    "lévogyre": ("lévogyre",),
    "lévogyres": ("lévogyre",),
    "lévulique": ("lévulique",),
    "lévuliques": ("lévulique",),
    "levulosurique": ("levulosurique",),
    "lévulosurique": ("lévulosurique",),
    "levulosuriques": ("levulosurique",),
    "lévulosuriques": ("lévulosurique",),
    "léwinien": ("léwinien",),
    "léwinienne": ("léwinien",),
    "léwiniennes": ("léwinien",),
    "léwiniens": ("léwinien",),
    "lexicale": ("lexical",),
    "lexicales": ("lexical",),
    "lexical": ("lexical",),
    "lexicaux": ("lexical",),
    "lexico-grammaticales": ("lexico-grammatical",),
    "lexicographique": ("lexicographique",),
    "lexicographiques": ("lexicographique",),
    "lexicologique": ("lexicologique",),
    "lexicologiques": ("lexicologique",),
    "leydigien": ("leydigien",),
    "leydigienne": ("leydigien",),
    "leydigiennes": ("leydigien",),
    "leydigiens": ("leydigien",),
    "liasique": ("liasique",),
    "liasiques": ("liasique",),
    "libanaise": ("libanais",),
    "libanaises": ("libanais",),
    "libanais": ("libanais",),
    "libérable": ("libérable",),
    "libérables": ("libérable",),
    "libérale": ("libéral",),
    "libérales": ("libéral",),
    "libéral": ("libéral",),
    "libéraux": ("libéral",),
    "libérateur": ("libérateur",),
    "libérateurs": ("libérateur",),
    "libératrice": ("libérateur",),
    "libératrices": ("libérateur",),
    "libératoire": ("libératoire",),
    "libératoires": ("libératoire",),
    "libérien": ("libérien",),
    "libérienne": ("libérien",),
    "libériennes": ("libérien",),
    "libériens": ("libérien",),
    "libériste": ("libériste",),
    "libéristes": ("libériste",),
    "libéro-ligneuse": ("libéro-ligneux",),
    "libertaire": ("libertaire",),
    "libertaires": ("libertaire",),
    "libertarien": ("libertarien",),
    "libertarienne": ("libertarien",),
    "libertariennes": ("libertarien",),
    "libertariens": ("libertarien",),
    "liberticide": ("liberticide",),
    "liberticides": ("liberticide",),
    "liberty": ("liberty",),
    "libidinale": ("libidinal",),
    "libidinales": ("libidinal",),
    "libidinal": ("libidinal",),
    "libidinaux": ("libidinal",),
    "libidineuse": ("libidineux",),
    "libidineuses": ("libidineux",),
    "libidineux": ("libidineux",),
    "libre": ("libre",),
    "libres": ("libre",),
    "libyen": ("libyen",),
    "libyenne": ("libyen",),
    "libyennes": ("libyen",),
    "libyens": ("libyen",),
    "licanique": ("licanique",),
    "licaniques": ("licanique",),
    "licenciable": ("licenciable",),
    "licenciables": ("licenciable",),
    "licencieuse": ("licencieux",),
    "licencieuses": ("licencieux",),
    "licencieux": ("licencieux",),
    "lichéneuse": ("lichéneux",),
    "lichéneuses": ("lichéneux",),
    "lichéneux": ("lichéneux",),
    "lichénique": ("lichénique",),
    "lichéniques": ("lichénique",),
    "lichénoïde": ("lichénoïde",),
    "lichénoïdes": ("lichénoïde",),
    "licite": ("licite",),
    "licites": ("licite",),
    "liégeoise": ("liégeois",),
    "liégeoises": ("liégeois",),
    "liégeois": ("liégeois",),
    "liégeuse": ("liégeux",),
    "liégeuses": ("liégeux",),
    "liégeux": ("liégeux",),
    "liénale": ("liénal",),
    "liénales": ("liénal",),
    "liénal": ("liénal",),
    "liénaux": ("liénal",),
    "liénique": ("liénique",),
    "liéniques": ("liénique",),
    "lientérique": ("lientérique",),
    "lientériques": ("lientérique",),
    "lieur": ("lieur",),
    "lieurs": ("lieur",),
    "lieuse": ("lieur",),
    "lieuses": ("lieur",),
    "ligamentaire": ("ligamentaire",),
    "ligamentaires": ("ligamentaire",),
    "ligamenteuse": ("ligamenteux",),
    "ligamenteuses": ("ligamenteux",),
    "ligamenteux": ("ligamenteux",),
    "lige": ("lige",),
    "liges": ("lige",),
    "ligérien": ("ligérien",),
    "ligérienne": ("ligérien",),
    "ligériennes": ("ligérien",),
    "ligériens": ("ligérien",),
    "lignagère": ("lignager",),
    "lignagères": ("lignager",),
    "lignager": ("lignager",),
    "lignagers": ("lignager",),
    "ligneuse": ("ligneux",),
    "ligneuses": ("ligneux",),
    "ligneux": ("ligneux",),
    "lignicole": ("lignicole",),
    "lignicoles": ("lignicole",),
    "ligniteuse": ("ligniteux",),
    "ligniteuses": ("ligniteux",),
    "ligniteux": ("ligniteux",),
    "lignivore": ("lignivore",),
    "lignivores": ("lignivore",),
    "lignocérique": ("lignocérique",),
    "lignocériques": ("lignocérique",),
    "ligueur": ("ligueur",),
    "ligueurs": ("ligueur",),
    "ligueuse": ("ligueur",),
    "ligueuses": ("ligueur",),
    "liguliflore": ("liguliflore",),
    "liguliflores": ("liguliflore",),
    "ligure": ("ligure",),
    "ligures": ("ligure",),
    "ligurien": ("ligurien",),
    "ligurienne": ("ligurien",),
    "liguriennes": ("ligurien",),
    "liguriens": ("ligurien",),
    "lilas": ("lilas",),
    "liliale": ("lilial",),
    "liliales": ("lilial",),
    "lilial": ("lilial",),
    "liliaux": ("lilial",),
    "lilliputien": ("lilliputien",),
    "lilliputienne": ("lilliputien",),
    "lilliputiennes": ("lilliputien",),
    "lilliputiens": ("lilliputien",),
    "lilloise": ("lillois",),
    "lilloises": ("lillois",),
    "lillois": ("lillois",),
    "limaciforme": ("limaciforme",),
    "limaciformes": ("limaciforme",),
    "limbaire": ("limbaire",),
    "limbaires": ("limbaire",),
    "limbique": ("limbique",),
    "limbiques": ("limbique",),
    "limeur": ("limeur",),
    "limeurs": ("limeur",),
    "limeuse": ("limeur",),
    "limeuses": ("limeur",),
    "limicole": ("limicole",),
    "limicoles": ("limicole",),
    "liminaire": ("liminaire",),
    "liminaires": ("liminaire",),
    "liminale": ("liminal",),
    "liminales": ("liminal",),
    "liminal": ("liminal",),
    "liminaux": ("liminal",),
    "limitable": ("limitable",),
    "limitables": ("limitable",),
    "limitatif": ("limitatif",),
    "limitatifs": ("limitatif",),
    "limitative": ("limitatif",),
    "limitatives": ("limitatif",),
    "limitée": ("limité",),
    "limitées": ("limité",),
    "limité": ("limité",),
    "limite": ("limite",),
    "limités": ("limité",),
    "limites": ("limite",),
    "limitrophe": ("limitrophe",),
    "limitrophes": ("limitrophe",),
    "limivore": ("limivore",),
    "limivores": ("limivore",),
    "limnémique": ("limnémique",),
    "limnémiques": ("limnémique",),
    "limnicole": ("limnicole",),
    "limnicoles": ("limnicole",),
    "limnigraphique": ("limnigraphique",),
    "limnigraphiques": ("limnigraphique",),
    "limnimétrique": ("limnimétrique",),
    "limnimétriques": ("limnimétrique",),
    "limnique": ("limnique",),
    "limniques": ("limnique",),
    "limnivore": ("limnivore",),
    "limnivores": ("limnivore",),
    "limnologique": ("limnologique",),
    "limnologiques": ("limnologique",),
    "limonadière": ("limonadier",),
    "limonadières": ("limonadier",),
    "limonadier": ("limonadier",),
    "limonadiers": ("limonadier",),
    "limoneuse": ("limoneux",),
    "limoneuses": ("limoneux",),
    "limoneux": ("limoneux",),
    "limpide": ("limpide",),
    "limpides": ("limpide",),
    "linéaire": ("linéaire",),
    "linéaires": ("linéaire",),
    "linéale": ("linéal",),
    "linéales": ("linéal",),
    "linéal": ("linéal",),
    "linéaux": ("linéal",),
    "linéique": ("linéique",),
    "linéiques": ("linéique",),
    "linguale": ("lingual",),
    "linguales": ("lingual",),
    "lingual": ("lingual",),
    "linguaux": ("lingual",),
    "linguiforme": ("linguiforme",),
    "linguiformes": ("linguiforme",),
    "linguistique": ("linguistique",),
    "linguistiques": ("linguistique",),
    "linière": ("linier",),
    "linières": ("linier",),
    "linier": ("linier",),
    "liniers": ("linier",),
    "linnéen": ("linnéen",),
    "linnéenne": ("linnéen",),
    "linnéennes": ("linnéen",),
    "linnéens": ("linnéen",),
    "linoléique": ("linoléique",),
    "linoléiques": ("linoléique",),
    "linolénique": ("linolénique",),
    "linoléniques": ("linolénique",),
    "liothrique": ("liothrique",),
    "liothriques": ("liothrique",),
    "lipasique": ("lipasique",),
    "lipasiques": ("lipasique",),
    "lipémique": ("lipémique",),
    "lipémiques": ("lipémique",),
    "lipidique": ("lipidique",),
    "lipidiques": ("lipidique",),
    "lipidogène": ("lipidogène",),
    "lipidogènes": ("lipidogène",),
    "lipidoprotéinique": ("lipidoprotéinique",),
    "lipidoprotéiniques": ("lipidoprotéinique",),
    "lipidoprotidique": ("lipidoprotidique",),
    "lipidoprotidiques": ("lipidoprotidique",),
    "lipizzan": ("lipizzan",),
    "lipizzans": ("lipizzan",),
    "lipo-albuminiques": ("lipo-albuminique",),
    "lipoatrophique": ("lipoatrophique",),
    "lipoatrophiques": ("lipoatrophique",),
    "lipocaïque": ("lipocaïque",),
    "lipocaïques": ("lipocaïque",),
    "lipocytique": ("lipocytique",),
    "lipocytiques": ("lipocytique",),
    "lipogène": ("lipogène",),
    "lipogènes": ("lipogène",),
    "lipoïde": ("lipoïde",),
    "lipoïdes": ("lipoïde",),
    "lipoïdique": ("lipoïdique",),
    "lipoïdiques": ("lipoïdique",),
    "lipoïque": ("lipoïque",),
    "lipoïques": ("lipoïque",),
    "lipolytique": ("lipolytique",),
    "lipolytiques": ("lipolytique",),
    "lipomateuse": ("lipomateux",),
    "lipomateuses": ("lipomateux",),
    "lipomateux": ("lipomateux",),
    "lipomélanique": ("lipomélanique",),
    "lipomélaniques": ("lipomélanique",),
    "lipo-nucléoprotéique": ("lipo-nucléoprotéique",),
    "lipophagique": ("lipophagique",),
    "lipophagiques": ("lipophagique",),
    "lipophile": ("lipophile",),
    "lipophiles": ("lipophile",),
    "lipophobe": ("lipophobe",),
    "lipophobes": ("lipophobe",),
    "lipoprotéique": ("lipoprotéique",),
    "lipoprotéiques": ("lipoprotéique",),
    "liposoluble": ("liposoluble",),
    "liposolubles": ("liposoluble",),
    "lipothymique": ("lipothymique",),
    "lipothymiques": ("lipothymique",),
    "lipotrope": ("lipotrope",),
    "lipotropes": ("lipotrope",),
    "liquéfiable": ("liquéfiable",),
    "liquéfiables": ("liquéfiable",),
    "liquidable": ("liquidable",),
    "liquidables": ("liquidable",),
    "liquidateur": ("liquidateur",),
    "liquidateurs": ("liquidateur",),
    "liquidatrice": ("liquidateur",),
    "liquidatrices": ("liquidateur",),
    "liquidatif": ("liquidatif",),
    "liquidatifs": ("liquidatif",),
    "liquidative": ("liquidatif",),
    "liquidatives": ("liquidatif",),
    "liquide": ("liquide",),
    "liquides": ("liquide",),
    "liquidien": ("liquidien",),
    "liquidienne": ("liquidien",),
    "liquidiennes": ("liquidien",),
    "liquidiens": ("liquidien",),
    "liquoreuse": ("liquoreux",),
    "liquoreuses": ("liquoreux",),
    "liquoreux": ("liquoreux",),
    "liquoriste": ("liquoriste",),
    "liquoristes": ("liquoriste",),
    "lisboète": ("lisboète",),
    "lisboètes": ("lisboète",),
    "liseur": ("liseur",),
    "liseurs": ("liseur",),
    "liseuse": ("liseur",),
    "liseuses": ("liseur",),
    "lisible": ("lisible",),
    "lisibles": ("lisible",),
    "lissée": ("lissé",),
    "lissées": ("lissé",),
    "lissé": ("lissé",),
    "lisse": ("lisse",),
    "lissés": ("lissé",),
    "lisses": ("lisse",),
    "lissenkiste": ("lissenkiste",),
    "lissenkistes": ("lissenkiste",),
    "lisseur": ("lisseur",),
    "lisseurs": ("lisseur",),
    "lisseuse": ("lisseur",),
    "lisseuses": ("lisseur",),
    "lissière": ("lissier",),
    "lissières": ("lissier",),
    "lissier": ("lissier",),
    "lissiers": ("lissier",),
    "listérien": ("listérien",),
    "listérienne": ("listérien",),
    "listériennes": ("listérien",),
    "listériens": ("listérien",),
    "lisztien": ("lisztien",),
    "lisztienne": ("lisztien",),
    "lisztiennes": ("lisztien",),
    "lisztiens": ("lisztien",),
    "lithiasique": ("lithiasique",),
    "lithiasiques": ("lithiasique",),
    "lithinifère": ("lithinifère",),
    "lithinifères": ("lithinifère",),
    "lithique": ("lithique",),
    "lithiques": ("lithique",),
    "lithocholique": ("lithocholique",),
    "lithocholiques": ("lithocholique",),
    "lithogène": ("lithogène",),
    "lithogènes": ("lithogène",),
    "lithographe": ("lithographe",),
    "lithographes": ("lithographe",),
    "lithographique": ("lithographique",),
    "lithographiques": ("lithographique",),
    "lithologique": ("lithologique",),
    "lithologiques": ("lithologique",),
    "litholytique": ("litholytique",),
    "litholytiques": ("litholytique",),
    "lithophage": ("lithophage",),
    "lithophages": ("lithophage",),
    "lithophile": ("lithophile",),
    "lithophiles": ("lithophile",),
    "lithosphérique": ("lithosphérique",),
    "lithosphériques": ("lithosphérique",),
    "lithostatique": ("lithostatique",),
    "lithostatiques": ("lithostatique",),
    "lithostratigraphique": ("lithostratigraphique",),
    "lithostratigraphiques": ("lithostratigraphique",),
    "lithotriptique": ("lithotriptique",),
    "lithotriptiques": ("lithotriptique",),
    "lithuanien": ("lithuanien",),
    "lithuanienne": ("lithuanien",),
    "lithuaniennes": ("lithuanien",),
    "lithuaniens": ("lithuanien",),
    "litigieuse": ("litigieux",),
    "litigieuses": ("litigieux",),
    "litigieux": ("litigieux",),
    "littéraire": ("littéraire",),
    "littéraires": ("littéraire",),
    "littérale": ("littéral",),
    "littérales": ("littéral",),
    "littéral": ("littéral",),
    "littéraux": ("littéral",),
    "littéraliste": ("littéraliste",),
    "littéralistes": ("littéraliste",),
    "littorale": ("littoral",),
    "littorales": ("littoral",),
    "littoral": ("littoral",),
    "littoraux": ("littoral",),
    "lituanien": ("lituanien",),
    "lituanienne": ("lituanien",),
    "lituaniennes": ("lituanien",),
    "lituaniens": ("lituanien",),
    "liturgique": ("liturgique",),
    "liturgiques": ("liturgique",),
    "live": ("live",),
    "livédoïde": ("livédoïde",),
    "livédoïdes": ("livédoïde",),
    "livide": ("livide",),
    "livides": ("livide",),
    "livrable": ("livrable",),
    "livrables": ("livrable",),
    "livresque": ("livresque",),
    "livresques": ("livresque",),
    "livreur": ("livreur",),
    "livreurs": ("livreur",),
    "livreuse": ("livreur",),
    "livreuses": ("livreur",),
    "llandeilien": ("llandeilien",),
    "llandeilienne": ("llandeilien",),
    "llandeiliennes": ("llandeilien",),
    "llandeiliens": ("llandeilien",),
    "llanvirnien": ("llanvirnien",),
    "llanvirnienne": ("llanvirnien",),
    "llanvirniennes": ("llanvirnien",),
    "llanvirniens": ("llanvirnien",),
    "lobaire": ("lobaire",),
    "lobaires": ("lobaire",),
    "lobulaire": ("lobulaire",),
    "lobulaires": ("lobulaire",),
    "lobuleuse": ("lobuleux",),
    "lobuleuses": ("lobuleux",),
    "lobuleux": ("lobuleux",),
    "locale": ("local",),
    "locales": ("local",),
    "local": ("local",),
    "locaux": ("local",),
    "localisable": ("localisable",),
    "localisables": ("localisable",),
    "localisateur": ("localisateur",),
    "localisateurs": ("localisateur",),
    "localisatrice": ("localisateur",),
    "localisatrices": ("localisateur",),
    "localisationniste": ("localisationniste",),
    "localisationnistes": ("localisationniste",),
    "locatif": ("locatif",),
    "locatifs": ("locatif",),
    "locative": ("locatif",),
    "locatives": ("locatif",),
    "lochiale": ("lochial",),
    "lochiales": ("lochial",),
    "lochial": ("lochial",),
    "lochiaux": ("lochial",),
    "locomobile": ("locomobile",),
    "locomobiles": ("locomobile",),
    "locomoteur": ("locomoteur",),
    "locomoteurs": ("locomoteur",),
    "locomotrice": ("locomoteur",),
    "locomotrices": ("locomoteur",),
    "locomotif": ("locomotif",),
    "locomotifs": ("locomotif",),
    "locomotive": ("locomotif",),
    "locomotives": ("locomotif",),
    "loco-régionale": ("loco-régional",),
    "locorégionale": ("locorégional",),
    "locorégionales": ("locorégional",),
    "loco-régional": ("loco-régional",),
    "locorégional": ("locorégional",),
    "locorégionaux": ("locorégional",),
    "loculaire": ("loculaire",),
    "loculaires": ("loculaire",),
    "loculeuse": ("loculeux",),
    "loculeuses": ("loculeux",),
    "loculeux": ("loculeux",),
    "loculicide": ("loculicide",),
    "loculicides": ("loculicide",),
    "logaédique": ("logaédique",),
    "logaédiques": ("logaédique",),
    "logarithmique": ("logarithmique",),
    "logarithmiques": ("logarithmique",),
    "logeable": ("logeable",),
    "logeables": ("logeable",),
    "logicielle": ("logiciel",),
    "logicielles": ("logiciel",),
    "logiciel": ("logiciel",),
    "logiciels": ("logiciel",),
    "logiciste": ("logiciste",),
    "logicistes": ("logiciste",),
    "logico-mathématique": ("logico-mathématique",),
    "logico-mathématiques": ("logico-mathématique",),
    "logique": ("logique",),
    "logiques": ("logique",),
    "logistique": ("logistique",),
    "logistiques": ("logistique",),
    "logographique": ("logographique",),
    "logographiques": ("logographique",),
    "logomachique": ("logomachique",),
    "logomachiques": ("logomachique",),
    "logopédique": ("logopédique",),
    "logopédiques": ("logopédique",),
    "logophonique": ("logophonique",),
    "logophoniques": ("logophonique",),
    "logorrhéique": ("logorrhéique",),
    "logorrhéiques": ("logorrhéique",),
    "logosémiotique": ("logosémiotique",),
    "logosémiotiques": ("logosémiotique",),
    "loisible": ("loisible",),
    "loisibles": ("loisible",),
    "lombaire": ("lombaire",),
    "lombaires": ("lombaire",),
    "lombale": ("lombal",),
    "lombales": ("lombal",),
    "lombal": ("lombal",),
    "lombaux": ("lombal",),
    "lombalgique": ("lombalgique",),
    "lombalgiques": ("lombalgique",),
    "lombardique": ("lombardique",),
    "lombardiques": ("lombardique",),
    "lombo-sacré": ("lombo-sacré",),
    "lombo-sacrés": ("lombo-sacré",),
    "lombricale": ("lombrical",),
    "lombricales": ("lombrical",),
    "lombrical": ("lombrical",),
    "lombricaux": ("lombrical",),
    "lombriciforme": ("lombriciforme",),
    "lombriciformes": ("lombriciforme",),
    "lombricoïde": ("lombricoïde",),
    "lombricoïdes": ("lombricoïde",),
    "lombricole": ("lombricole",),
    "lombricoles": ("lombricole",),
    "londonien": ("londonien",),
    "londonienne": ("londonien",),
    "londoniennes": ("londonien",),
    "londoniens": ("londonien",),
    "long": ("long",),
    "longs": ("long",),
    "longue": ("long",),
    "longues": ("long",),
    "longanime": ("longanime",),
    "longanimes": ("longanime",),
    "longibande": ("longibande",),
    "longibandes": ("longibande",),
    "longicorne": ("longicorne",),
    "longicornes": ("longicorne",),
    "longiligne": ("longiligne",),
    "longilignes": ("longiligne",),
    "longisète": ("longisète",),
    "longisètes": ("longisète",),
    "longistylée": ("longistylé",),
    "longistylées": ("longistylé",),
    "longistylé": ("longistylé",),
    "longistyle": ("longistyle",),
    "longistylés": ("longistylé",),
    "longistyles": ("longistyle",),
    "longitudinale": ("longitudinal",),
    "longitudinales": ("longitudinal",),
    "longitudinal": ("longitudinal",),
    "longitudinaux": ("longitudinal",),
    "longuet": ("longuet",),
    "longuets": ("longuet",),
    "longuette": ("longuet",),
    "longuettes": ("longuet",),
    "lophodonte": ("lophodonte",),
    "lophodontes": ("lophodonte",),
    "loquace": ("loquace",),
    "loquaces": ("loquace",),
    "loqueteuse": ("loqueteux",),
    "loqueteuses": ("loqueteux",),
    "loqueteux": ("loqueteux",),
    "loqueuse": ("loqueux",),
    "loqueuses": ("loqueux",),
    "loqueux": ("loqueux",),
    "lordosique": ("lordosique",),
    "lordosiques": ("lordosique",),
    "lordotique": ("lordotique",),
    "lordotiques": ("lordotique",),
    "lorientaise": ("lorientais",),
    "lorientaises": ("lorientais",),
    "lorientais": ("lorientais",),
    "lormière": ("lormier",),
    "lormières": ("lormier",),
    "lormier": ("lormier",),
    "lormiers": ("lormier",),
    "losangique": ("losangique",),
    "losangiques": ("losangique",),
    "louable": ("louable",),
    "louables": ("louable",),
    "louageur": ("louageur",),
    "louageurs": ("louageur",),
    "louageuse": ("louageur",),
    "louageuses": ("louageur",),
    "louangeur": ("louangeur",),
    "louangeurs": ("louangeur",),
    "louangeuse": ("louangeur",),
    "louangeuses": ("louangeur",),
    "louche": ("louche",),
    "louches": ("louche",),
    "louchon": ("louchon",),
    "louchonne": ("louchon",),
    "louchonnes": ("louchon",),
    "louchons": ("louchon",),
    "louf": ("louf",),
    "loufoque": ("loufoque",),
    "loufoques": ("loufoque",),
    "louftingue": ("louftingue",),
    "louftingues": ("louftingue",),
    "louisianaise": ("louisianais",),
    "louisianaises": ("louisianais",),
    "louisianais": ("louisianais",),
    "louisiannaise": ("louisiannais",),
    "louisiannaises": ("louisiannais",),
    "louisiannais": ("louisiannais",),
    "louisquatorzien": ("louisquatorzien",),
    "louisquatorzienne": ("louisquatorzien",),
    "louisquatorziennes": ("louisquatorzien",),
    "louisquatorziens": ("louisquatorzien",),
    "lourdingue": ("lourdingue",),
    "lourdingues": ("lourdingue",),
    "lourianique": ("lourianique",),
    "lourianiques": ("lourianique",),
    "louvet": ("louvet",),
    "louvets": ("louvet",),
    "louvette": ("louvet",),
    "louvettes": ("louvet",),
    "loxodonte": ("loxodonte",),
    "loxodontes": ("loxodonte",),
    "loxodromique": ("loxodromique",),
    "loxodromiques": ("loxodromique",),
    "loyale": ("loyal",),
    "loyales": ("loyal",),
    "loyal": ("loyal",),
    "loyaux": ("loyal",),
    "loyaliste": ("loyaliste",),
    "loyalistes": ("loyaliste",),
    "lubrificateur": ("lubrificateur",),
    "lubrificateurs": ("lubrificateur",),
    "lubrificatrice": ("lubrificateur",),
    "lubrificatrices": ("lubrificateur",),
    "lubrique": ("lubrique",),
    "lubriques": ("lubrique",),
    "lucanien": ("lucanien",),
    "lucanienne": ("lucanien",),
    "lucaniennes": ("lucanien",),
    "lucaniens": ("lucanien",),
    "lucernoise": ("lucernois",),
    "lucernoises": ("lucernois",),
    "lucernois": ("lucernois",),
    "lucide": ("lucide",),
    "lucides": ("lucide",),
    "luciférien": ("luciférien",),
    "luciférienne": ("luciférien",),
    "lucifériennes": ("luciférien",),
    "lucifériens": ("luciférien",),
    "lucifuge": ("lucifuge",),
    "lucifuges": ("lucifuge",),
    "lucratif": ("lucratif",),
    "lucratifs": ("lucratif",),
    "lucrative": ("lucratif",),
    "lucratives": ("lucratif",),
    "luddite": ("luddite",),
    "luddites": ("luddite",),
    "ludien": ("ludien",),
    "ludienne": ("ludien",),
    "ludiennes": ("ludien",),
    "ludiens": ("ludien",),
    "ludique": ("ludique",),
    "ludiques": ("ludique",),
    "luétique": ("luétique",),
    "luétiques": ("luétique",),
    "lugubre": ("lugubre",),
    "lugubres": ("lugubre",),
    "lumachellique": ("lumachellique",),
    "lumachelliques": ("lumachellique",),
    "lumineuse": ("lumineux",),
    "lumineuses": ("lumineux",),
    "lumineux": ("lumineux",),
    "luministe": ("luministe",),
    "luministes": ("luministe",),
    "luminocinétique": ("luminocinétique",),
    "luminocinétiques": ("luminocinétique",),
    "luminogène": ("luminogène",),
    "luminogènes": ("luminogène",),
    "lunaire": ("lunaire",),
    "lunaires": ("lunaire",),
    "lunatique": ("lunatique",),
    "lunatiques": ("lunatique",),
    "lunetière": ("lunetier",),
    "lunetières": ("lunetier",),
    "lunetier": ("lunetier",),
    "lunetiers": ("lunetier",),
    "lunettière": ("lunettier",),
    "lunettières": ("lunettier",),
    "lunettier": ("lunettier",),
    "lunettiers": ("lunettier",),
    "luo": ("luo",),
    "luos": ("luo",),
    "lupique": ("lupique",),
    "lupiques": ("lupique",),
    "lupoïde": ("lupoïde",),
    "lupoïdes": ("lupoïde",),
    "lusitanien": ("lusitanien",),
    "lusitanienne": ("lusitanien",),
    "lusitaniennes": ("lusitanien",),
    "lusitaniens": ("lusitanien",),
    "luso-brésilienne": ("luso-brésilien",),
    "lusophone": ("lusophone",),
    "lusophones": ("lusophone",),
    "lustrale": ("lustral",),
    "lustrales": ("lustral",),
    "lustral": ("lustral",),
    "lustraux": ("lustral",),
    "lutéale": ("lutéal",),
    "lutéales": ("lutéal",),
    "lutéal": ("lutéal",),
    "lutéaux": ("lutéal",),
    "lutéinique": ("lutéinique",),
    "lutéiniques": ("lutéinique",),
    "lutéinomimétique": ("lutéinomimétique",),
    "lutéinomimétiques": ("lutéinomimétique",),
    "lutéocobaltique": ("lutéocobaltique",),
    "lutéocobaltiques": ("lutéocobaltique",),
    "lutéomimétique": ("lutéomimétique",),
    "lutéomimétiques": ("lutéomimétique",),
    "lutéotrophique": ("lutéotrophique",),
    "lutéotrophiques": ("lutéotrophique",),
    "lutétien": ("lutétien",),
    "lutétienne": ("lutétien",),
    "lutétiennes": ("lutétien",),
    "lutétiens": ("lutétien",),
    "luthérien": ("luthérien",),
    "luthérienne": ("luthérien",),
    "luthériennes": ("luthérien",),
    "luthériens": ("luthérien",),
    "luxable": ("luxable",),
    "luxables": ("luxable",),
    "luxembourgeoise": ("luxembourgeois",),
    "luxembourgeoises": ("luxembourgeois",),
    "luxembourgeois": ("luxembourgeois",),
    "luxueuse": ("luxueux",),
    "luxueuses": ("luxueux",),
    "luxueux": ("luxueux",),
    "luxurieuse": ("luxurieux",),
    "luxurieuses": ("luxurieux",),
    "luxurieux": ("luxurieux",),
    "luzernière": ("luzernier",),
    "luzernières": ("luzernier",),
    "luzernier": ("luzernier",),
    "luzerniers": ("luzernier",),
    "lybien": ("lybien",),
    "lybienne": ("lybien",),
    "lybiennes": ("lybien",),
    "lybiens": ("lybien",),
    "lycanthrope": ("lycanthrope",),
    "lycanthropes": ("lycanthrope",),
    "lycéen": ("lycéen",),
    "lycéenne": ("lycéen",),
    "lycéennes": ("lycéen",),
    "lycéens": ("lycéen",),
    "lydien": ("lydien",),
    "lydienne": ("lydien",),
    "lydiennes": ("lydien",),
    "lydiens": ("lydien",),
    "lymphadénoïde": ("lymphadénoïde",),
    "lymphadénoïdes": ("lymphadénoïde",),
    "lymphadénopathique": ("lymphadénopathique",),
    "lymphadénopathiques": ("lymphadénopathique",),
    "lymphagogue": ("lymphagogue",),
    "lymphagogues": ("lymphagogue",),
    "lymphatique": ("lymphatique",),
    "lymphatiques": ("lymphatique",),
    "lymphoblastique": ("lymphoblastique",),
    "lymphoblastiques": ("lymphoblastique",),
    "lymphocytaire": ("lymphocytaire",),
    "lymphocytaires": ("lymphocytaire",),
    "lymphocytotoxique": ("lymphocytotoxique",),
    "lymphocytotoxiques": ("lymphocytotoxique",),
    "lymphogène": ("lymphogène",),
    "lymphogènes": ("lymphogène",),
    "lymphogranulomateuse": ("lymphogranulomateux",),
    "lymphogranulomateuses": ("lymphogranulomateux",),
    "lymphogranulomateux": ("lymphogranulomateux",),
    "lymphoïde": ("lymphoïde",),
    "lymphoïdes": ("lymphoïde",),
    "lymphomateuse": ("lymphomateux",),
    "lymphomateuses": ("lymphomateux",),
    "lymphomateux": ("lymphomateux",),
    "lymphomatoïde": ("lymphomatoïde",),
    "lymphomatoïdes": ("lymphomatoïde",),
    "lymphonodulaire": ("lymphonodulaire",),
    "lymphonodulaires": ("lymphonodulaire",),
    "lymphophile": ("lymphophile",),
    "lymphophiles": ("lymphophile",),
    "lymphoplasmocytaire": ("lymphoplasmocytaire",),
    "lymphoplasmocytaires": ("lymphoplasmocytaire",),
    "lymphoprolifératif": ("lymphoprolifératif",),
    "lymphoprolifératifs": ("lymphoprolifératif",),
    "lymphoproliférative": ("lymphoprolifératif",),
    "lymphoprolifératives": ("lymphoprolifératif",),
    "lymphotrope": ("lymphotrope",),
    "lymphotropes": ("lymphotrope",),
    "lyonnaise": ("lyonnais",),
    "lyonnaises": ("lyonnais",),
    "lyonnais": ("lyonnais",),
    "lyophile": ("lyophile",),
    "lyophiles": ("lyophile",),
    "lyophobe": ("lyophobe",),
    "lyophobes": ("lyophobe",),
    "lyotrope": ("lyotrope",),
    "lyotropes": ("lyotrope",),
    "lyricomane": ("lyricomane",),
    "lyricomanes": ("lyricomane",),
    "lyrique": ("lyrique",),
    "lyriques": ("lyrique",),
    "lysergique": ("lysergique",),
    "lysergiques": ("lysergique",),
    "lysigène": ("lysigène",),
    "lysigènes": ("lysigène",),
    "lysogène": ("lysogène",),
    "lysogènes": ("lysogène",),
    "lysogénique": ("lysogénique",),
    "lysogéniques": ("lysogénique",),
    "lysosomale": ("lysosomal",),
    "lysosomales": ("lysosomal",),
    "lysosomal": ("lysosomal",),
    "lysosomaux": ("lysosomal",),
    "lysosomiale": ("lysosomial",),
    "lysosomiales": ("lysosomial",),
    "lysosomial": ("lysosomial",),
    "lysosomiaux": ("lysosomial",),
    "lytique": ("lytique",),
    "lytiques": ("lytique",),
    "macabre": ("macabre",),
    "macabres": ("macabre",),
    "macaronique": ("macaronique",),
    "macaroniques": ("macaronique",),
    "maccarthyste": ("maccarthyste",),
    "maccarthystes": ("maccarthyste",),
    "macédonien": ("macédonien",),
    "macédonienne": ("macédonien",),
    "macédoniennes": ("macédonien",),
    "macédoniens": ("macédonien",),
    "macédo-roumaine": ("macédo-roumain",),
    "macérateur": ("macérateur",),
    "macérateurs": ("macérateur",),
    "macérien": ("macérien",),
    "macérienne": ("macérien",),
    "macériennes": ("macérien",),
    "macériens": ("macérien",),
    "machiavélien": ("machiavélien",),
    "machiavélienne": ("machiavélien",),
    "machiavéliennes": ("machiavélien",),
    "machiavéliens": ("machiavélien",),
    "machiavélique": ("machiavélique",),
    "machiavéliques": ("machiavélique",),
    "machinale": ("machinal",),
    "machinales": ("machinal",),
    "machinal": ("machinal",),
    "machinaux": ("machinal",),
    "machinique": ("machinique",),
    "machiniques": ("machinique",),
    "machiniste": ("machiniste",),
    "machinistes": ("machiniste",),
    "machiste": ("machiste",),
    "machistes": ("machiste",),
    "macho": ("macho",),
    "machos": ("macho",),
    "maçon": ("maçon",),
    "maçonne": ("maçon",),
    "maçonnes": ("maçon",),
    "maçons": ("maçon",),
    "mâconnaise": ("mâconnais",),
    "mâconnaises": ("mâconnais",),
    "mâconnais": ("mâconnais",),
    "maçonnique": ("maçonnique",),
    "maçonniques": ("maçonnique",),
    "macoute": ("macoute",),
    "macoutes": ("macoute",),
    "macro": ("macro",),
    "macrobiotique": ("macrobiotique",),
    "macrobiotiques": ("macrobiotique",),
    "macrocéphale": ("macrocéphale",),
    "macrocéphales": ("macrocéphale",),
    "macrocosmique": ("macrocosmique",),
    "macrocosmiques": ("macrocosmique",),
    "macrocyclique": ("macrocyclique",),
    "macrocycliques": ("macrocyclique",),
    "macrocytaire": ("macrocytaire",),
    "macrocytaires": ("macrocytaire",),
    "macroéconométrique": ("macroéconométrique",),
    "macroéconométriques": ("macroéconométrique",),
    "macro-économique": ("macro-économique",),
    "macroéconomique": ("macroéconomique",),
    "macro-économiques": ("macro-économique",),
    "macroéconomiques": ("macroéconomique",),
    "macrofinancière": ("macrofinancier",),
    "macrofinancières": ("macrofinancier",),
    "macrofinancier": ("macrofinancier",),
    "macrofinanciers": ("macrofinancier",),
    "macroglosse": ("macroglosse",),
    "macroglosses": ("macroglosse",),
    "macrographique": ("macrographique",),
    "macrographiques": ("macrographique",),
    "macro-ionique": ("macro-ionique",),
    "macromoléculaire": ("macromoléculaire",),
    "macromoléculaires": ("macromoléculaire",),
    "macrophage": ("macrophage",),
    "macrophages": ("macrophage",),
    "macrophagique": ("macrophagique",),
    "macrophagiques": ("macrophagique",),
    "macropode": ("macropode",),
    "macropodes": ("macropode",),
    "macroptique": ("macroptique",),
    "macroptiques": ("macroptique",),
    "macroscopique": ("macroscopique",),
    "macroscopiques": ("macroscopique",),
    "macroséismique": ("macroséismique",),
    "macroséismiques": ("macroséismique",),
    "macrosismique": ("macrosismique",),
    "macrosismiques": ("macrosismique",),
    "macrosmatique": ("macrosmatique",),
    "macrosmatiques": ("macrosmatique",),
    "macrotype": ("macrotype",),
    "macrotypes": ("macrotype",),
    "macroure": ("macroure",),
    "macroures": ("macroure",),
    "maculaire": ("maculaire",),
    "maculaires": ("maculaire",),
    "maculeuse": ("maculeux",),
    "maculeuses": ("maculeux",),
    "maculeux": ("maculeux",),
    "maculo-papuleux": ("maculo-papuleux",),
    "madécasse": ("madécasse",),
    "madécasses": ("madécasse",),
    "madicole": ("madicole",),
    "madicoles": ("madicole",),
    "madréporeuse": ("madréporeux",),
    "madréporeuses": ("madréporeux",),
    "madréporeux": ("madréporeux",),
    "madréporien": ("madréporien",),
    "madréporienne": ("madréporien",),
    "madréporiennes": ("madréporien",),
    "madréporiens": ("madréporien",),
    "madréporique": ("madréporique",),
    "madréporiques": ("madréporique",),
    "madrigalesque": ("madrigalesque",),
    "madrigalesques": ("madrigalesque",),
    "madrigaliste": ("madrigaliste",),
    "madrigalistes": ("madrigaliste",),
    "madrilène": ("madrilène",),
    "madrilènes": ("madrilène",),
    "maffieuse": ("maffieux",),
    "maffieuses": ("maffieux",),
    "maffieux": ("maffieux",),
    "mafieuse": ("mafieux",),
    "mafieuses": ("mafieux",),
    "mafieux": ("mafieux",),
    "mafique": ("mafique",),
    "mafiques": ("mafique",),
    "magdalénien": ("magdalénien",),
    "magdalénienne": ("magdalénien",),
    "magdaléniennes": ("magdalénien",),
    "magdaléniens": ("magdalénien",),
    "mage": ("mage",),
    "mages": ("mage",),
    "magenta": ("magenta",),
    "magico-religieuse": ("magico-religieux",),
    "magico-religieux": ("magico-religieux",),
    "magique": ("magique",),
    "magiques": ("magique",),
    "magistrale": ("magistral",),
    "magistrales": ("magistral",),
    "magistral": ("magistral",),
    "magistraux": ("magistral",),
    "magmatique": ("magmatique",),
    "magmatiques": ("magmatique",),
    "magnanime": ("magnanime",),
    "magnanimes": ("magnanime",),
    "magnésien": ("magnésien",),
    "magnésienne": ("magnésien",),
    "magnésiennes": ("magnésien",),
    "magnésiens": ("magnésien",),
    "magnésique": ("magnésique",),
    "magnésiques": ("magnésique",),
    "magnétipolaire": ("magnétipolaire",),
    "magnétipolaires": ("magnétipolaire",),
    "magnétique": ("magnétique",),
    "magnétiques": ("magnétique",),
    "magnétisable": ("magnétisable",),
    "magnétisables": ("magnétisable",),
    "magnétoaérodynamique": ("magnétoaérodynamique",),
    "magnétoaérodynamiques": ("magnétoaérodynamique",),
    "magnétocalorique": ("magnétocalorique",),
    "magnétocaloriques": ("magnétocalorique",),
    "magnétochimique": ("magnétochimique",),
    "magnétochimiques": ("magnétochimique",),
    "magnétodynamique": ("magnétodynamique",),
    "magnétodynamiques": ("magnétodynamique",),
    "magnétoélastique": ("magnétoélastique",),
    "magnétoélastiques": ("magnétoélastique",),
    "magnétoélectrique": ("magnétoélectrique",),
    "magnétoélectriques": ("magnétoélectrique",),
    "magnétographique": ("magnétographique",),
    "magnétographiques": ("magnétographique",),
    "magnétohydrodynamique": ("magnétohydrodynamique",),
    "magnétohydrodynamiques": ("magnétohydrodynamique",),
    "magnétométrique": ("magnétométrique",),
    "magnétométriques": ("magnétométrique",),
    "magnétomoteur": ("magnétomoteur",),
    "magnétomoteurs": ("magnétomoteur",),
    "magnétomotrice": ("magnétomoteur",),
    "magnétomotrices": ("magnétomoteur",),
    "magnétoplasmadynamique": ("magnétoplasmadynamique",),
    "magnétoplasmadynamiques": ("magnétoplasmadynamique",),
    "magnétoscopique": ("magnétoscopique",),
    "magnétoscopiques": ("magnétoscopique",),
    "magnétosphérique": ("magnétosphérique",),
    "magnétosphériques": ("magnétosphérique",),
    "magnétostatique": ("magnétostatique",),
    "magnétostatiques": ("magnétostatique",),
    "magnétostrictif": ("magnétostrictif",),
    "magnétostrictifs": ("magnétostrictif",),
    "magnétostrictive": ("magnétostrictif",),
    "magnétostrictives": ("magnétostrictif",),
    "magnétotellurique": ("magnétotellurique",),
    "magnétotelluriques": ("magnétotellurique",),
    "magnétothermique": ("magnétothermique",),
    "magnétothermiques": ("magnétothermique",),
    "magnifique": ("magnifique",),
    "magnifiques": ("magnifique",),
    "magnocellulaire": ("magnocellulaire",),
    "magnocellulaires": ("magnocellulaire",),
    "magouilleur": ("magouilleur",),
    "magouilleurs": ("magouilleur",),
    "magouilleuse": ("magouilleur",),
    "magouilleuses": ("magouilleur",),
    "mahdiste": ("mahdiste",),
    "mahdistes": ("mahdiste",),
    "mahratte": ("mahratte",),
    "mahrattes": ("mahratte",),
    "maigre": ("maigre",),
    "maigres": ("maigre",),
    "maigrelet": ("maigrelet",),
    "maigrelets": ("maigrelet",),
    "maigrelette": ("maigrelet",),
    "maigrelettes": ("maigrelet",),
    "maigrichon": ("maigrichon",),
    "maigrichonne": ("maigrichon",),
    "maigrichonnes": ("maigrichon",),
    "maigrichons": ("maigrichon",),
    "maigriot": ("maigriot",),
    "maigriots": ("maigriot",),
    "maigriotte": ("maigriot",),
    "maigriottes": ("maigriot",),
    "maimonidien": ("maimonidien",),
    "maimonidienne": ("maimonidien",),
    "maimonidiennes": ("maimonidien",),
    "maimonidiens": ("maimonidien",),
    "mainmortable": ("mainmortable",),
    "mainmortables": ("mainmortable",),
    "maintenable": ("maintenable",),
    "maintenables": ("maintenable",),
    "maïsicole": ("maïsicole",),
    "maïsicoles": ("maïsicole",),
    "maître": ("maître",),
    "maîtres": ("maître",),
    "maîtresse": ("maître",),
    "maîtresses": ("maître",),
    "maîtrisable": ("maîtrisable",),
    "maîtrisables": ("maîtrisable",),
    "maje": ("maje",),
    "majes": ("maje",),
    "majestueuse": ("majestueux",),
    "majestueuses": ("majestueux",),
    "majestueux": ("majestueux",),
    "major": ("major",),
    "majorateur": ("majorateur",),
    "majorateurs": ("majorateur",),
    "majoratrice": ("majorateur",),
    "majoratrices": ("majorateur",),
    "majoratif": ("majoratif",),
    "majoratifs": ("majoratif",),
    "majorative": ("majoratif",),
    "majoratives": ("majoratif",),
    "majoritaire": ("majoritaire",),
    "majoritaires": ("majoritaire",),
    "majuscule": ("majuscule",),
    "majuscules": ("majuscule",),
    "malabare": ("malabare",),
    "malabares": ("malabare",),
    "malabre": ("malabre",),
    "malabres": ("malabre",),
    "malacique": ("malacique",),
    "malaciques": ("malacique",),
    "malacologique": ("malacologique",),
    "malacologiques": ("malacologique",),
    "malacophile": ("malacophile",),
    "malacophiles": ("malacophile",),
    "malade": ("malade",),
    "malades": ("malade",),
    "maladif": ("maladif",),
    "maladifs": ("maladif",),
    "maladive": ("maladif",),
    "maladives": ("maladif",),
    "malaire": ("malaire",),
    "malaires": ("malaire",),
    "malaise": ("malais",),
    "malaises": ("malais",),
    "malais": ("malais",),
    "malaisien": ("malaisien",),
    "malaisienne": ("malaisien",),
    "malaisiennes": ("malaisien",),
    "malaisiens": ("malaisien",),
    "mal": ("mal",),
    "malandreuse": ("malandreux",),
    "malandreuses": ("malandreux",),
    "malandreux": ("malandreux",),
    "malapprise": ("malappris",),
    "malapprises": ("malappris",),
    "malappris": ("malappris",),
    "malarien": ("malarien",),
    "malarienne": ("malarien",),
    "malariennes": ("malarien",),
    "malariens": ("malarien",),
    "malariologique": ("malariologique",),
    "malariologiques": ("malariologique",),
    "malaxeur": ("malaxeur",),
    "malaxeurs": ("malaxeur",),
    "malaxeuse": ("malaxeur",),
    "malaxeuses": ("malaxeur",),
    "malayophone": ("malayophone",),
    "malayophones": ("malayophone",),
    "malayo-polynésien": ("malayo-polynésien",),
    "malayo-polynésienne": ("malayo-polynésien",),
    "malayo-polynésiennes": ("malayo-polynésien",),
    "malchanceuse": ("malchanceux",),
    "malchanceuses": ("malchanceux",),
    "malchanceux": ("malchanceux",),
    "malcommode": ("malcommode",),
    "malcommodes": ("malcommode",),
    "maldivien": ("maldivien",),
    "maldivienne": ("maldivien",),
    "maldiviennes": ("maldivien",),
    "maldiviens": ("maldivien",),
    "mâle": ("mâle",),
    "mâles": ("mâle",),
    "maléfique": ("maléfique",),
    "maléfiques": ("maléfique",),
    "maléique": ("maléique",),
    "maléiques": ("maléique",),
    "malékite": ("malékite",),
    "malékites": ("malékite",),
    "malembouchée": ("malembouché",),
    "malembouchées": ("malembouché",),
    "malembouché": ("malembouché",),
    "malembouchés": ("malembouché",),
    "malencontreuse": ("malencontreux",),
    "malencontreuses": ("malencontreux",),
    "malencontreux": ("malencontreux",),
    "malfamée": ("malfamé",),
    "malfamées": ("malfamé",),
    "malfamé": ("malfamé",),
    "malfamés": ("malfamé",),
    "malformatif": ("malformatif",),
    "malformatifs": ("malformatif",),
    "malformative": ("malformatif",),
    "malformatives": ("malformatif",),
    "malgache": ("malgache",),
    "malgaches": ("malgache",),
    "malgachitique": ("malgachitique",),
    "malgachitiques": ("malgachitique",),
    "malgracieuse": ("malgracieux",),
    "malgracieuses": ("malgracieux",),
    "malgracieux": ("malgracieux",),
    "malhabile": ("malhabile",),
    "malhabiles": ("malhabile",),
    "malheureuse": ("malheureux",),
    "malheureuses": ("malheureux",),
    "malheureux": ("malheureux",),
    "malhonnête": ("malhonnête",),
    "malhonnêtes": ("malhonnête",),
    "malicieuse": ("malicieux",),
    "malicieuses": ("malicieux",),
    "malicieux": ("malicieux",),
    "malien": ("malien",),
    "malienne": ("malien",),
    "maliennes": ("malien",),
    "maliens": ("malien",),
    "malikite": ("malikite",),
    "malikites": ("malikite",),
    "maligne": ("malin",),
    "malignes": ("malin",),
    "malin": ("malin",),
    "malins": ("malin",),
    "malingre": ("malingre",),
    "malingres": ("malingre",),
    "malinoise": ("malinois",),
    "malinoises": ("malinois",),
    "malinois": ("malinois",),
    "malique": ("malique",),
    "maliques": ("malique",),
    "malivole": ("malivole",),
    "malivoles": ("malivole",),
    "mallarméen": ("mallarméen",),
    "mallarméenne": ("mallarméen",),
    "mallarméennes": ("mallarméen",),
    "mallarméens": ("mallarméen",),
    "malléable": ("malléable",),
    "malléables": ("malléable",),
    "malléaire": ("malléaire",),
    "malléaires": ("malléaire",),
    "malléale": ("malléal",),
    "malléales": ("malléal",),
    "malléal": ("malléal",),
    "malléaux": ("malléal",),
    "malléatoire": ("malléatoire",),
    "malléatoires": ("malléatoire",),
    "malléolaire": ("malléolaire",),
    "malléolaires": ("malléolaire",),
    "malletière": ("malletier",),
    "malletières": ("malletier",),
    "malletier": ("malletier",),
    "malletiers": ("malletier",),
    "malonique": ("malonique",),
    "maloniques": ("malonique",),
    "malpropre": ("malpropre",),
    "malpropres": ("malpropre",),
    "maltaise": ("maltais",),
    "maltaises": ("maltais",),
    "maltais": ("maltais",),
    "malthusien": ("malthusien",),
    "malthusienne": ("malthusien",),
    "malthusiennes": ("malthusien",),
    "malthusiens": ("malthusien",),
    "malvenue": ("malvenu",),
    "malvenues": ("malvenu",),
    "malvenu": ("malvenu",),
    "malvenus": ("malvenu",),
    "mamillaire": ("mamillaire",),
    "mamillaires": ("mamillaire",),
    "mammaire": ("mammaire",),
    "mammaires": ("mammaire",),
    "mammalien": ("mammalien",),
    "mammalienne": ("mammalien",),
    "mammaliennes": ("mammalien",),
    "mammaliens": ("mammalien",),
    "mammalogique": ("mammalogique",),
    "mammalogiques": ("mammalogique",),
    "mammifère": ("mammifère",),
    "mammifères": ("mammifère",),
    "mammotrope": ("mammotrope",),
    "mammotropes": ("mammotrope",),
    "managériale": ("managérial",),
    "managériales": ("managérial",),
    "managérial": ("managérial",),
    "managériaux": ("managérial",),
    "managerielle": ("manageriel",),
    "managerielles": ("manageriel",),
    "manageriel": ("manageriel",),
    "manageriels": ("manageriel",),
    "manceau": ("manceau",),
    "manceaux": ("manceau",),
    "mancelle": ("manceau",),
    "mancelles": ("manceau",),
    "mandarinale": ("mandarinal",),
    "mandarinales": ("mandarinal",),
    "mandarinal": ("mandarinal",),
    "mandarinaux": ("mandarinal",),
    "mandéen": ("mandéen",),
    "mandéenne": ("mandéen",),
    "mandéennes": ("mandéen",),
    "mandéens": ("mandéen",),
    "mandélique": ("mandélique",),
    "mandéliques": ("mandélique",),
    "mandibulaire": ("mandibulaire",),
    "mandibulaires": ("mandibulaire",),
    "manducateur": ("manducateur",),
    "manducateurs": ("manducateur",),
    "manducatrice": ("manducateur",),
    "manducatrices": ("manducateur",),
    "manganésien": ("manganésien",),
    "manganésienne": ("manganésien",),
    "manganésiennes": ("manganésien",),
    "manganésiens": ("manganésien",),
    "manganésifère": ("manganésifère",),
    "manganésifères": ("manganésifère",),
    "manganésique": ("manganésique",),
    "manganésiques": ("manganésique",),
    "manganeuse": ("manganeux",),
    "manganeuses": ("manganeux",),
    "manganeux": ("manganeux",),
    "manganifère": ("manganifère",),
    "manganifères": ("manganifère",),
    "manganique": ("manganique",),
    "manganiques": ("manganique",),
    "mangeable": ("mangeable",),
    "mangeables": ("mangeable",),
    "maniable": ("maniable",),
    "maniables": ("maniable",),
    "maniaco-dépressif": ("maniaco-dépressif",),
    "maniacodépressif": ("maniacodépressif",),
    "maniacodépressifs": ("maniacodépressif",),
    "maniacodépressive": ("maniacodépressif",),
    "maniaco-dépressives": ("maniaco-dépressif",),
    "maniacodépressives": ("maniacodépressif",),
    "maniaque": ("maniaque",),
    "maniaques": ("maniaque",),
    "manichéen": ("manichéen",),
    "manichéenne": ("manichéen",),
    "manichéennes": ("manichéen",),
    "manichéens": ("manichéen",),
    "maniériste": ("maniériste",),
    "maniéristes": ("maniériste",),
    "manifeste": ("manifeste",),
    "manifestes": ("manifeste",),
    "manipulable": ("manipulable",),
    "manipulables": ("manipulable",),
    "manipulaire": ("manipulaire",),
    "manipulaires": ("manipulaire",),
    "manipulateur": ("manipulateur",),
    "manipulateurs": ("manipulateur",),
    "manipulatrice": ("manipulateur",),
    "manipulatrices": ("manipulateur",),
    "manipulatoire": ("manipulatoire",),
    "manipulatoires": ("manipulatoire",),
    "mannipare": ("mannipare",),
    "mannipares": ("mannipare",),
    "mannonique": ("mannonique",),
    "mannoniques": ("mannonique",),
    "mannosaccharique": ("mannosaccharique",),
    "mannosacchariques": ("mannosaccharique",),
    "manoeuvrable": ("manoeuvrable",),
    "manoeuvrables": ("manoeuvrable",),
    "manoeuvrière": ("manoeuvrier",),
    "manoeuvrières": ("manoeuvrier",),
    "manoeuvrier": ("manoeuvrier",),
    "manoeuvriers": ("manoeuvrier",),
    "manométrique": ("manométrique",),
    "manométriques": ("manométrique",),
    "manouche": ("manouche",),
    "manouches": ("manouche",),
    "mantellique": ("mantellique",),
    "mantelliques": ("mantellique",),
    "manuelle": ("manuel",),
    "manuelles": ("manuel",),
    "manuel": ("manuel",),
    "manuels": ("manuel",),
    "manufacturable": ("manufacturable",),
    "manufacturables": ("manufacturable",),
    "manufacturière": ("manufacturier",),
    "manufacturières": ("manufacturier",),
    "manufacturier": ("manufacturier",),
    "manufacturiers": ("manufacturier",),
    "manxoise": ("manxois",),
    "manxoises": ("manxois",),
    "manxois": ("manxois",),
    "maoïste": ("maoïste",),
    "maoïstes": ("maoïste",),
    "maous": ("maous",),
    "maousse": ("maous",),
    "maousses": ("maous",),
    "maraging": ("maraging",),
    "maraîchère": ("maraîcher",),
    "maraîchères": ("maraîcher",),
    "maraîcher": ("maraîcher",),
    "maraîchers": ("maraîcher",),
    "marasmique": ("marasmique",),
    "marasmiques": ("marasmique",),
    "marastique": ("marastique",),
    "marastiques": ("marastique",),
    "marathe": ("marathe",),
    "marathes": ("marathe",),
    "marathi": ("marathi",),
    "maraudeur": ("maraudeur",),
    "maraudeurs": ("maraudeur",),
    "maraudeuse": ("maraudeur",),
    "maraudeuses": ("maraudeur",),
    "marbrière": ("marbrier",),
    "marbrières": ("marbrier",),
    "marbrier": ("marbrier",),
    "marbriers": ("marbrier",),
    "marcescible": ("marcescible",),
    "marcescibles": ("marcescible",),
    "marchandeur": ("marchandeur",),
    "marchandeurs": ("marchandeur",),
    "marchandeuse": ("marchandeur",),
    "marchandeuses": ("marchandeur",),
    "marcheur": ("marcheur",),
    "marcheurs": ("marcheur",),
    "marcheuse": ("marcheur",),
    "marcheuses": ("marcheur",),
    "marcioniste": ("marcioniste",),
    "marcionistes": ("marcioniste",),
    "marcionite": ("marcionite",),
    "marcionites": ("marcionite",),
    "marcusien": ("marcusien",),
    "marcusienne": ("marcusien",),
    "marcusiennes": ("marcusien",),
    "marcusiens": ("marcusien",),
    "marécageuse": ("marécageux",),
    "marécageuses": ("marécageux",),
    "marécageux": ("marécageux",),
    "maréchale": ("maréchale",),
    "maréchales": ("maréchale",),
    "marégraphique": ("marégraphique",),
    "marégraphiques": ("marégraphique",),
    "maremmatique": ("maremmatique",),
    "maremmatiques": ("maremmatique",),
    "marémoteur": ("marémoteur",),
    "marémoteurs": ("marémoteur",),
    "marémotrice": ("marémoteur",),
    "marémotrices": ("marémoteur",),
    "marengo": ("marengo",),
    "maréthermique": ("maréthermique",),
    "maréthermiques": ("maréthermique",),
    "mareyeur": ("mareyeur",),
    "mareyeurs": ("mareyeur",),
    "mareyeuse": ("mareyeur",),
    "mareyeuses": ("mareyeur",),
    "margarinière": ("margarinier",),
    "margarinières": ("margarinier",),
    "margarinier": ("margarinier",),
    "margariniers": ("margarinier",),
    "margarinique": ("margarinique",),
    "margariniques": ("margarinique",),
    "margeur": ("margeur",),
    "margeurs": ("margeur",),
    "margeuse": ("margeur",),
    "margeuses": ("margeur",),
    "marginale": ("marginal",),
    "marginales": ("marginal",),
    "marginal": ("marginal",),
    "marginaux": ("marginal",),
    "marginaliste": ("marginaliste",),
    "marginalistes": ("marginaliste",),
    "margraviale": ("margravial",),
    "margraviales": ("margravial",),
    "margravial": ("margravial",),
    "margraviaux": ("margravial",),
    "mariable": ("mariable",),
    "mariables": ("mariable",),
    "marianiste": ("marianiste",),
    "marianistes": ("marianiste",),
    "marinée": ("mariné",),
    "marinées": ("mariné",),
    "mariné": ("mariné",),
    "marine": ("marine",),
    "marinés": ("mariné",),
    "marinide": ("marinide",),
    "marinides": ("marinide",),
    "marinière": ("marinier",),
    "marinières": ("marinier",),
    "marinier": ("marinier",),
    "mariniers": ("marinier",),
    "mariolle": ("mariolle",),
    "mariolles": ("mariolle",),
    "mariste": ("mariste",),
    "maristes": ("mariste",),
    "maritale": ("marital",),
    "maritales": ("marital",),
    "marital": ("marital",),
    "maritaux": ("marital",),
    "maritime": ("maritime",),
    "maritimes": ("maritime",),
    "markovien": ("markovien",),
    "markovienne": ("markovien",),
    "markoviennes": ("markovien",),
    "markoviens": ("markovien",),
    "marle": ("marle",),
    "marles": ("marle",),
    "marlowien": ("marlowien",),
    "marlowiens": ("marlowien",),
    "marmenteau": ("marmenteau",),
    "marmenteaux": ("marmenteau",),
    "marmoréen": ("marmoréen",),
    "marmoréenne": ("marmoréen",),
    "marmoréennes": ("marmoréen",),
    "marmoréens": ("marmoréen",),
    "marmoriforme": ("marmoriforme",),
    "marmoriformes": ("marmoriforme",),
    "marmotteur": ("marmotteur",),
    "marmotteurs": ("marmotteur",),
    "marmotteuse": ("marmotteur",),
    "marmotteuses": ("marmotteur",),
    "marneur": ("marneur",),
    "marneurs": ("marneur",),
    "marneuse": ("marneux",),
    "marneuses": ("marneux",),
    "marneux": ("marneux",),
    "maronite": ("maronite",),
    "maronites": ("maronite",),
    "maroquinière": ("maroquinier",),
    "maroquinières": ("maroquinier",),
    "maroquinier": ("maroquinier",),
    "maroquiniers": ("maroquinier",),
    "marotique": ("marotique",),
    "marotiques": ("marotique",),
    "marotiste": ("marotiste",),
    "marotistes": ("marotiste",),
    "marqueteur": ("marqueteur",),
    "marqueteurs": ("marqueteur",),
    "marqueteuse": ("marqueteur",),
    "marqueteuses": ("marqueteur",),
    "marqueur": ("marqueur",),
    "marqueurs": ("marqueur",),
    "marqueuse": ("marqueur",),
    "marqueuses": ("marqueur",),
    "marquisien": ("marquisien",),
    "marquisienne": ("marquisien",),
    "marquisiennes": ("marquisien",),
    "marquisiens": ("marquisien",),
    "marrane": ("marrane",),
    "marranes": ("marrane",),
    "marron": ("marron",),
    "marronne": ("marron",),
    "marronnes": ("marron",),
    "marrons": ("marron",),
    "marseillaise": ("marseillais",),
    "marseillaises": ("marseillais",),
    "marseillais": ("marseillais",),
    "marsupiale": ("marsupial",),
    "marsupiales": ("marsupial",),
    "marsupial": ("marsupial",),
    "marsupiaux": ("marsupial",),
    "marteau": ("marteau",),
    "marteaux": ("marteau",),
    "marteleur": ("marteleur",),
    "marteleurs": ("marteleur",),
    "marteleuse": ("marteleur",),
    "marteleuses": ("marteleur",),
    "martellien": ("martellien",),
    "martelliens": ("martellien",),
    "martensitique": ("martensitique",),
    "martensitiques": ("martensitique",),
    "martiale": ("martial",),
    "martiales": ("martial",),
    "martial": ("martial",),
    "martiaux": ("martial",),
    "martien": ("martien",),
    "martienne": ("martien",),
    "martiennes": ("martien",),
    "martiens": ("martien",),
    "martiniquaise": ("martiniquais",),
    "martiniquaises": ("martiniquais",),
    "martiniquais": ("martiniquais",),
    "martiniste": ("martiniste",),
    "martinistes": ("martiniste",),
    "marxien": ("marxien",),
    "marxienne": ("marxien",),
    "marxiennes": ("marxien",),
    "marxiens": ("marxien",),
    "marxiste": ("marxiste",),
    "marxistes": ("marxiste",),
    "marxiste-léniniste": ("marxiste-léniniste",),
    "marxistes-léninistes": ("marxiste-léniniste",),
    "marxophile": ("marxophile",),
    "marxophiles": ("marxophile",),
    "maso": ("maso",),
    "masos": ("maso",),
    "masochiste": ("masochiste",),
    "masochistes": ("masochiste",),
    "massale": ("massale",),
    "massales": ("massale",),
    "massaliote": ("massaliote",),
    "massaliotes": ("massaliote",),
    "masséter": ("masséter",),
    "masséters": ("masséter",),
    "massif": ("massif",),
    "massifs": ("massif",),
    "massive": ("massif",),
    "massives": ("massif",),
    "massique": ("massique",),
    "massiques": ("massique",),
    "massorétique": ("massorétique",),
    "massorétiques": ("massorétique",),
    "mastic": ("mastic",),
    "masticateur": ("masticateur",),
    "masticateurs": ("masticateur",),
    "masticatrice": ("masticateur",),
    "masticatrices": ("masticateur",),
    "masticatoire": ("masticatoire",),
    "masticatoires": ("masticatoire",),
    "mastoc": ("mastoc",),
    "mastoïde": ("mastoïde",),
    "mastoïdes": ("mastoïde",),
    "mastoïdien": ("mastoïdien",),
    "mastoïdienne": ("mastoïdien",),
    "mastoïdiennes": ("mastoïdien",),
    "mastoïdiens": ("mastoïdien",),
    "masturbateur": ("masturbateur",),
    "masturbateurs": ("masturbateur",),
    "masturbatrice": ("masturbateur",),
    "masturbatrices": ("masturbateur",),
    "matérialiste": ("matérialiste",),
    "matérialistes": ("matérialiste",),
    "matérielle": ("matériel",),
    "matérielles": ("matériel",),
    "matériel": ("matériel",),
    "matériels": ("matériel",),
    "maternelle": ("maternel",),
    "maternelles": ("maternel",),
    "maternel": ("maternel",),
    "maternels": ("maternel",),
    "mathématique": ("mathématique",),
    "mathématiques": ("mathématique",),
    "mathématisable": ("mathématisable",),
    "mathématisables": ("mathématisable",),
    "matiériste": ("matiériste",),
    "matiéristes": ("matiériste",),
    "matinale": ("matinal",),
    "matinales": ("matinal",),
    "matinal": ("matinal",),
    "matinaux": ("matinal",),
    "matineuse": ("matineux",),
    "matineuses": ("matineux",),
    "matineux": ("matineux",),
    "matinière": ("matinier",),
    "matinières": ("matinier",),
    "matinier": ("matinier",),
    "matiniers": ("matinier",),
    "matissien": ("matissien",),
    "matissiens": ("matissien",),
    "matoise": ("matois",),
    "matoises": ("matois",),
    "matois": ("matois",),
    "matriarcale": ("matriarcal",),
    "matriarcales": ("matriarcal",),
    "matriarcal": ("matriarcal",),
    "matriarcaux": ("matriarcal",),
    "matricide": ("matricide",),
    "matricides": ("matricide",),
    "matricielle": ("matriciel",),
    "matricielles": ("matriciel",),
    "matriciel": ("matriciel",),
    "matriciels": ("matriciel",),
    "matricule": ("matricule",),
    "matricules": ("matricule",),
    "matrilinéaire": ("matrilinéaire",),
    "matrilinéaires": ("matrilinéaire",),
    "matrilocale": ("matrilocal",),
    "matrilocales": ("matrilocal",),
    "matrilocal": ("matrilocal",),
    "matrilocaux": ("matrilocal",),
    "matrimoniale": ("matrimonial",),
    "matrimoniales": ("matrimonial",),
    "matrimonial": ("matrimonial",),
    "matrimoniaux": ("matrimonial",),
    "matrocline": ("matrocline",),
    "matroclines": ("matrocline",),
    "matronymique": ("matronymique",),
    "matronymiques": ("matronymique",),
    "maturateur": ("maturateur",),
    "maturateurs": ("maturateur",),
    "maturatrice": ("maturateur",),
    "maturatrices": ("maturateur",),
    "maturationnelle": ("maturationnel",),
    "maturationnelles": ("maturationnel",),
    "maturationnel": ("maturationnel",),
    "maturationnels": ("maturationnel",),
    "mature": ("mature",),
    "matures": ("mature",),
    "matutinale": ("matutinal",),
    "matutinales": ("matutinal",),
    "matutinal": ("matutinal",),
    "matutinaux": ("matutinal",),
    "maudissable": ("maudissable",),
    "maudissables": ("maudissable",),
    "maurassien": ("maurassien",),
    "maurassienne": ("maurassien",),
    "maurassiennes": ("maurassien",),
    "maurassiens": ("maurassien",),
    "maure": ("maure",),
    "maures": ("maure",),
    "mauresque": ("mauresque",),
    "mauresques": ("mauresque",),
    "mauricien": ("mauricien",),
    "mauricienne": ("mauricien",),
    "mauriciennes": ("mauricien",),
    "mauriciens": ("mauricien",),
    "mauritanien": ("mauritanien",),
    "mauritanienne": ("mauritanien",),
    "mauritaniennes": ("mauritanien",),
    "mauritaniens": ("mauritanien",),
    "maurrassien": ("maurrassien",),
    "maurrassienne": ("maurrassien",),
    "maurrassiennes": ("maurrassien",),
    "maurrassiens": ("maurrassien",),
    "maussade": ("maussade",),
    "maussades": ("maussade",),
    "mauvaise": ("mauvais",),
    "mauvaises": ("mauvais",),
    "mauvais": ("mauvais",),
    "mauve": ("mauve",),
    "mauves": ("mauve",),
    "maxi": ("maxi",),
    "maxillaire": ("maxillaire",),
    "maxillaires": ("maxillaire",),
    "maximale": ("maximal",),
    "maximales": ("maximal",),
    "maximal": ("maximal",),
    "maximaux": ("maximal",),
    "maximaliste": ("maximaliste",),
    "maximalistes": ("maximaliste",),
    "maxima": ("maximum",),
    "maximum": ("maximum",),
    "maximums": ("maximum",),
    "maya": ("maya",),
    "mayas": ("maya",),
    "mayonnaise": ("mayonnaise",),
    "mayonnaises": ("mayonnaise",),
    "mazariniste": ("mazariniste",),
    "mazarinistes": ("mazariniste",),
    "mazdéen": ("mazdéen",),
    "mazdéenne": ("mazdéen",),
    "mazdéennes": ("mazdéen",),
    "mazdéens": ("mazdéen",),
    "méandreuse": ("méandreux",),
    "méandreuses": ("méandreux",),
    "méandreux": ("méandreux",),
    "mécanique": ("mécanique",),
    "mécaniques": ("mécanique",),
    "mécanisable": ("mécanisable",),
    "mécanisables": ("mécanisable",),
    "mécaniste": ("mécaniste",),
    "mécanistes": ("mécaniste",),
    "mécanoélectrique": ("mécanoélectrique",),
    "mécanoélectriques": ("mécanoélectrique",),
    "mécanographique": ("mécanographique",),
    "mécanographiques": ("mécanographique",),
    "mécheuse": ("mécheux",),
    "mécheuses": ("mécheux",),
    "mécheux": ("mécheux",),
    "mecklembourgeoise": ("mecklembourgeois",),
    "mecklembourgeoises": ("mecklembourgeois",),
    "mecklembourgeois": ("mecklembourgeois",),
    "méconiale": ("méconial",),
    "méconiales": ("méconial",),
    "méconial": ("méconial",),
    "méconiaux": ("méconial",),
    "méconique": ("méconique",),
    "méconiques": ("méconique",),
    "méconnaissable": ("méconnaissable",),
    "méconnaissables": ("méconnaissable",),
    "médaillable": ("médaillable",),
    "médaillables": ("médaillable",),
    "médailliste": ("médailliste",),
    "médaillistes": ("médailliste",),
    "mède": ("mède",),
    "mèdes": ("mède",),
    "médiale": ("médial",),
    "médiales": ("médial",),
    "médial": ("médial",),
    "médiaux": ("médial",),
    "médiamétrique": ("médiamétrique",),
    "médiamétriques": ("médiamétrique",),
    "médianimique": ("médianimique",),
    "médianimiques": ("médianimique",),
    "médiastinale": ("médiastinal",),
    "médiastinales": ("médiastinal",),
    "médiastinal": ("médiastinal",),
    "médiastinaux": ("médiastinal",),
    "médiateur": ("médiateur",),
    "médiateurs": ("médiateur",),
    "médiatrice": ("médiateur",),
    "médiatrices": ("médiateur",),
    "médiatique": ("médiatique",),
    "médiatiques": ("médiatique",),
    "médicale": ("médical",),
    "médicales": ("médical",),
    "médical": ("médical",),
    "médicaux": ("médical",),
    "médicamentaire": ("médicamentaire",),
    "médicamentaires": ("médicamentaire",),
    "médicamenteuse": ("médicamenteux",),
    "médicamenteuses": ("médicamenteux",),
    "médicamenteux": ("médicamenteux",),
    "médicinale": ("médicinal",),
    "médicinales": ("médicinal",),
    "médicinal": ("médicinal",),
    "médicinaux": ("médicinal",),
    "médico-légale": ("médico-légal",),
    "médicolégale": ("médicolégal",),
    "médico-légales": ("médico-légal",),
    "médicolégales": ("médicolégal",),
    "médico-légal": ("médico-légal",),
    "médicolégal": ("médicolégal",),
    "médico-légaux": ("médico-légal",),
    "médicolégaux": ("médicolégal",),
    "médico-sociale": ("médico-social",),
    "médico-social": ("médico-social",),
    "médico-sociaux": ("médico-social",),
    "médicosportif": ("médicosportif",),
    "médicosportifs": ("médicosportif",),
    "médicosportive": ("médicosportif",),
    "médicosportives": ("médicosportif",),
    "médiévale": ("médiéval",),
    "médiévales": ("médiéval",),
    "médiéval": ("médiéval",),
    "médiévaux": ("médiéval",),
    "médiévaliste": ("médiévaliste",),
    "médiévalistes": ("médiévaliste",),
    "médiéviste": ("médiéviste",),
    "médiévistes": ("médiéviste",),
    "médio-atlantique": ("médio-atlantique",),
    "médiocre": ("médiocre",),
    "médiocres": ("médiocre",),
    "médiodorsale": ("médiodorsal",),
    "médiodorsales": ("médiodorsal",),
    "médiodorsal": ("médiodorsal",),
    "médiodorsaux": ("médiodorsal",),
    "médiofrontale": ("médiofrontal",),
    "médiofrontales": ("médiofrontal",),
    "médiofrontal": ("médiofrontal",),
    "médiofrontaux": ("médiofrontal",),
    "médiolittorale": ("médiolittoral",),
    "médiolittorales": ("médiolittoral",),
    "médiolittoral": ("médiolittoral",),
    "médiolittoraux": ("médiolittoral",),
    "médio-océaniques": ("médio-océanique",),
    "médiopalatale": ("médiopalatal",),
    "médiopalatales": ("médiopalatal",),
    "médiopalatal": ("médiopalatal",),
    "médiopalataux": ("médiopalatal",),
    "médiopassif": ("médiopassif",),
    "médiopassifs": ("médiopassif",),
    "médiopassive": ("médiopassif",),
    "médiopassives": ("médiopassif",),
    "médioplantaire": ("médioplantaire",),
    "médioplantaires": ("médioplantaire",),
    "médiotarsien": ("médiotarsien",),
    "médiotarsienne": ("médiotarsien",),
    "médiotarsiennes": ("médiotarsien",),
    "médiotarsiens": ("médiotarsien",),
    "médiothoracique": ("médiothoracique",),
    "médiothoraciques": ("médiothoracique",),
    "médique": ("médique",),
    "médiques": ("médique",),
    "méditatif": ("méditatif",),
    "méditatifs": ("méditatif",),
    "méditative": ("méditatif",),
    "méditatives": ("méditatif",),
    "méditerranéen": ("méditerranéen",),
    "méditerranéenne": ("méditerranéen",),
    "méditerranéennes": ("méditerranéen",),
    "méditerranéens": ("méditerranéen",),
    "médiumnique": ("médiumnique",),
    "médiumniques": ("médiumnique",),
    "médullaire": ("médullaire",),
    "médullaires": ("médullaire",),
    "médulleuse": ("médulleux",),
    "médulleuses": ("médulleux",),
    "médulleux": ("médulleux",),
    "médullosurrénale": ("médullosurrénal",),
    "médullosurrénales": ("médullosurrénal",),
    "médullosurrénal": ("médullosurrénal",),
    "médullosurrénaux": ("médullosurrénal",),
    "médullotoxique": ("médullotoxique",),
    "médullotoxiques": ("médullotoxique",),
    "médullotrope": ("médullotrope",),
    "médullotropes": ("médullotrope",),
    "médusaire": ("médusaire",),
    "médusaires": ("médusaire",),
    "mégacaryocytaire": ("mégacaryocytaire",),
    "mégacaryocytaires": ("mégacaryocytaire",),
    "mégalithique": ("mégalithique",),
    "mégalithiques": ("mégalithique",),
    "mégalo": ("mégalo",),
    "mégalos": ("mégalo",),
    "mégaloblastique": ("mégaloblastique",),
    "mégaloblastiques": ("mégaloblastique",),
    "mégalocytaire": ("mégalocytaire",),
    "mégalocytaires": ("mégalocytaire",),
    "mégalocytique": ("mégalocytique",),
    "mégalocytiques": ("mégalocytique",),
    "mégalomane": ("mégalomane",),
    "mégalomanes": ("mégalomane",),
    "mégalomaniaque": ("mégalomaniaque",),
    "mégalomaniaques": ("mégalomaniaque",),
    "mégarique": ("mégarique",),
    "mégariques": ("mégarique",),
    "mégatherme": ("mégatherme",),
    "mégathermes": ("mégatherme",),
    "mégatonnique": ("mégatonnique",),
    "mégatonniques": ("mégatonnique",),
    "mégis": ("mégis",),
    "mégissière": ("mégissier",),
    "mégissières": ("mégissier",),
    "mégissier": ("mégissier",),
    "mégissiers": ("mégissier",),
    "méhariste": ("méhariste",),
    "méharistes": ("méhariste",),
    "meiji": ("meiji",),
    "meïji": ("meïji",),
    "méiotique": ("méiotique",),
    "méiotiques": ("méiotique",),
    "mékhitariste": ("mékhitariste",),
    "mékhitaristes": ("mékhitariste",),
    "mélancolique": ("mélancolique",),
    "mélancoliques": ("mélancolique",),
    "mélanèle": ("mélanèle",),
    "mélanèles": ("mélanèle",),
    "mélanésien": ("mélanésien",),
    "mélanésienne": ("mélanésien",),
    "mélanésiennes": ("mélanésien",),
    "mélanésiens": ("mélanésien",),
    "mélangeable": ("mélangeable",),
    "mélangeables": ("mélangeable",),
    "mélangeur": ("mélangeur",),
    "mélangeurs": ("mélangeur",),
    "mélangeuse": ("mélangeur",),
    "mélangeuses": ("mélangeur",),
    "mélanifère": ("mélanifère",),
    "mélanifères": ("mélanifère",),
    "mélanique": ("mélanique",),
    "mélaniques": ("mélanique",),
    "mélanocrate": ("mélanocrate",),
    "mélanocrates": ("mélanocrate",),
    "mélanoderme": ("mélanoderme",),
    "mélanodermes": ("mélanoderme",),
    "mélanoïde": ("mélanoïde",),
    "mélanoïdes": ("mélanoïde",),
    "mélano-indiennes": ("mélano-indien",),
    "mélanotique": ("mélanotique",),
    "mélanotiques": ("mélanotique",),
    "mélanotrope": ("mélanotrope",),
    "mélanotropes": ("mélanotrope",),
    "mélassigène": ("mélassigène",),
    "mélassigènes": ("mélassigène",),
    "melba": ("melba",),
    "melchite": ("melchite",),
    "melchites": ("melchite",),
    "meldoise": ("meldois",),
    "meldoises": ("meldois",),
    "meldois": ("meldois",),
    "mélicérique": ("mélicérique",),
    "mélicériques": ("mélicérique",),
    "mélioratif": ("mélioratif",),
    "mélioratifs": ("mélioratif",),
    "méliorative": ("mélioratif",),
    "mélioratives": ("mélioratif",),
    "mélioriste": ("mélioriste",),
    "mélioristes": ("mélioriste",),
    "mélique": ("mélique",),
    "méliques": ("mélique",),
    "mélismatique": ("mélismatique",),
    "mélismatiques": ("mélismatique",),
    "mélissique": ("mélissique",),
    "mélissiques": ("mélissique",),
    "mélitagreuse": ("mélitagreux",),
    "mélitagreuses": ("mélitagreux",),
    "mélitagreux": ("mélitagreux",),
    "mélitococcique": ("mélitococcique",),
    "mélitococciques": ("mélitococcique",),
    "melkite": ("melkite",),
    "melkites": ("melkite",),
    "mellifère": ("mellifère",),
    "mellifères": ("mellifère",),
    "mellifique": ("mellifique",),
    "mellifiques": ("mellifique",),
    "melliflue": ("melliflue",),
    "melliflues": ("melliflue",),
    "mellique": ("mellique",),
    "melliques": ("mellique",),
    "mellitique": ("mellitique",),
    "mellitiques": ("mellitique",),
    "mélo": ("mélo",),
    "mélos": ("mélo",),
    "mélodieuse": ("mélodieux",),
    "mélodieuses": ("mélodieux",),
    "mélodieux": ("mélodieux",),
    "mélodique": ("mélodique",),
    "mélodiques": ("mélodique",),
    "mélodramatique": ("mélodramatique",),
    "mélodramatiques": ("mélodramatique",),
    "mélomane": ("mélomane",),
    "mélomanes": ("mélomane",),
    "membranaire": ("membranaire",),
    "membranaires": ("membranaire",),
    "membraneuse": ("membraneux",),
    "membraneuses": ("membraneux",),
    "membraneux": ("membraneux",),
    "membrée": ("membré",),
    "membrées": ("membré",),
    "membré": ("membré",),
    "membre": ("membre",),
    "membrés": ("membré",),
    "membres": ("membre",),
    "même": ("même",),
    "mêmes": ("même",),
    "mémorable": ("mémorable",),
    "mémorables": ("mémorable",),
    "mémorielle": ("mémoriel",),
    "mémorielles": ("mémoriel",),
    "mémoriel": ("mémoriel",),
    "mémoriels": ("mémoriel",),
    "mémorisable": ("mémorisable",),
    "mémorisables": ("mémorisable",),
    "memphite": ("memphite",),
    "memphites": ("memphite",),
    "menable": ("menable",),
    "menables": ("menable",),
    "menaçable": ("menaçable",),
    "menaçables": ("menaçable",),
    "ménageable": ("ménageable",),
    "ménageables": ("ménageable",),
    "ménagère": ("ménager",),
    "ménagères": ("ménager",),
    "ménager": ("ménager",),
    "ménagers": ("ménager",),
    "ménagogue": ("ménagogue",),
    "ménagogues": ("ménagogue",),
    "menchevik": ("menchevik",),
    "mencheviks": ("menchevik",),
    "mendélien": ("mendélien",),
    "mendélienne": ("mendélien",),
    "mendéliennes": ("mendélien",),
    "mendéliens": ("mendélien",),
    "mendésiste": ("mendésiste",),
    "mendésistes": ("mendésiste",),
    "meneur": ("meneur",),
    "meneurs": ("meneur",),
    "meneuse": ("meneur",),
    "meneuses": ("meneur",),
    "méniérique": ("méniérique",),
    "méniériques": ("méniérique",),
    "méningétique": ("méningétique",),
    "méningétiques": ("méningétique",),
    "méningitique": ("méningitique",),
    "méningitiques": ("méningitique",),
    "méningococcique": ("méningococcique",),
    "méningococciques": ("méningococcique",),
    "méniscale": ("méniscal",),
    "méniscales": ("méniscal",),
    "méniscal": ("méniscal",),
    "méniscaux": ("méniscal",),
    "mennonite": ("mennonite",),
    "mennonites": ("mennonite",),
    "ménopausée": ("ménopausée",),
    "ménopausées": ("ménopausée",),
    "ménopausique": ("ménopausique",),
    "ménopausiques": ("ménopausique",),
    "ménorragique": ("ménorragique",),
    "ménorragiques": ("ménorragique",),
    "ménothermique": ("ménothermique",),
    "ménothermiques": ("ménothermique",),
    "mensongère": ("mensonger",),
    "mensongères": ("mensonger",),
    "mensonger": ("mensonger",),
    "mensongers": ("mensonger",),
    "menstruelle": ("menstruel",),
    "menstruelles": ("menstruel",),
    "menstruel": ("menstruel",),
    "menstruels": ("menstruel",),
    "mensuelle": ("mensuel",),
    "mensuelles": ("mensuel",),
    "mensuel": ("mensuel",),
    "mensuels": ("mensuel",),
    "mensurable": ("mensurable",),
    "mensurables": ("mensurable",),
    "mensurateur": ("mensurateur",),
    "mensurateurs": ("mensurateur",),
    "mensuratrice": ("mensurateur",),
    "mensuratrices": ("mensurateur",),
    "mentale": ("mental",),
    "mentales": ("mental",),
    "mental": ("mental",),
    "mentaux": ("mental",),
    "mentaliste": ("mentaliste",),
    "mentalistes": ("mentaliste",),
    "menteur": ("menteur",),
    "menteurs": ("menteur",),
    "menteuse": ("menteur",),
    "menteuses": ("menteur",),
    "mentionnable": ("mentionnable",),
    "mentionnables": ("mentionnable",),
    "mentonnière": ("mentonnier",),
    "mentonnières": ("mentonnier",),
    "mentonnier": ("mentonnier",),
    "mentonniers": ("mentonnier",),
    "menuisière": ("menuisier",),
    "menuisières": ("menuisier",),
    "menuisier": ("menuisier",),
    "menuisiers": ("menuisier",),
    "méphistophélique": ("méphistophélique",),
    "méphistophéliques": ("méphistophélique",),
    "méphitique": ("méphitique",),
    "méphitiques": ("méphitique",),
    "méprisable": ("méprisable",),
    "méprisables": ("méprisable",),
    "mercantile": ("mercantile",),
    "mercantiles": ("mercantile",),
    "mercantiliste": ("mercantiliste",),
    "mercantilistes": ("mercantiliste",),
    "mercatique": ("mercatique",),
    "mercatiques": ("mercatique",),
    "mercenaire": ("mercenaire",),
    "mercenaires": ("mercenaire",),
    "mercière": ("mercier",),
    "mercières": ("mercier",),
    "mercier": ("mercier",),
    "merciers": ("mercier",),
    "mercureuse": ("mercureux",),
    "mercureuses": ("mercureux",),
    "mercureux": ("mercureux",),
    "mercurielle": ("mercuriel",),
    "mercurielles": ("mercuriel",),
    "mercuriel": ("mercuriel",),
    "mercuriels": ("mercuriel",),
    "mercurien": ("mercurien",),
    "mercurienne": ("mercurien",),
    "mercuriennes": ("mercurien",),
    "mercuriens": ("mercurien",),
    "mercurifère": ("mercurifère",),
    "mercurifères": ("mercurifère",),
    "mercurique": ("mercurique",),
    "mercuriques": ("mercurique",),
    "merdeuse": ("merdeux",),
    "merdeuses": ("merdeux",),
    "merdeux": ("merdeux",),
    "merdique": ("merdique",),
    "merdiques": ("merdique",),
    "méridien": ("méridien",),
    "méridienne": ("méridien",),
    "méridiennes": ("méridien",),
    "méridiens": ("méridien",),
    "méridionale": ("méridional",),
    "méridionales": ("méridional",),
    "méridional": ("méridional",),
    "méridionaux": ("méridional",),
    "mérièdre": ("mérièdre",),
    "mérièdres": ("mérièdre",),
    "mérismatique": ("mérismatique",),
    "mérismatiques": ("mérismatique",),
    "méristématique": ("méristématique",),
    "méristématiques": ("méristématique",),
    "méristique": ("méristique",),
    "méristiques": ("méristique",),
    "méritocratique": ("méritocratique",),
    "méritocratiques": ("méritocratique",),
    "méritoire": ("méritoire",),
    "méritoires": ("méritoire",),
    "merle": ("merle",),
    "mérocrine": ("mérocrine",),
    "mérocrines": ("mérocrine",),
    "mérodiastolique": ("mérodiastolique",),
    "mérodiastoliques": ("mérodiastolique",),
    "méroïstique": ("méroïstique",),
    "méroïstiques": ("méroïstique",),
    "méroïtique": ("méroïtique",),
    "méroïtiques": ("méroïtique",),
    "méromictique": ("méromictique",),
    "méromictiques": ("méromictique",),
    "méromorphe": ("méromorphe",),
    "méromorphes": ("méromorphe",),
    "méronomique": ("méronomique",),
    "méronomiques": ("méronomique",),
    "mérosystolique": ("mérosystolique",),
    "mérosystoliques": ("mérosystolique",),
    "mérovingien": ("mérovingien",),
    "mérovingienne": ("mérovingien",),
    "mérovingiennes": ("mérovingien",),
    "mérovingiens": ("mérovingien",),
    "mertensien": ("mertensien",),
    "mertensienne": ("mertensien",),
    "mertensiennes": ("mertensien",),
    "mertensiens": ("mertensien",),
    "merveilleuse": ("merveilleux",),
    "merveilleuses": ("merveilleux",),
    "merveilleux": ("merveilleux",),
    "mésaconique": ("mésaconique",),
    "mésaconiques": ("mésaconique",),
    "mésangiale": ("mésangial",),
    "mésangiales": ("mésangial",),
    "mésangial": ("mésangial",),
    "mésangiaux": ("mésangial",),
    "mésangique": ("mésangique",),
    "mésangiques": ("mésangique",),
    "mescalinique": ("mescalinique",),
    "mescaliniques": ("mescalinique",),
    "mésencéphalique": ("mésencéphalique",),
    "mésencéphaliques": ("mésencéphalique",),
    "mésenchymateuse": ("mésenchymateux",),
    "mésenchymateuses": ("mésenchymateux",),
    "mésenchymateux": ("mésenchymateux",),
    "mésentérique": ("mésentérique",),
    "mésentériques": ("mésentérique",),
    "mésiale": ("mésial",),
    "mésiales": ("mésial",),
    "mésial": ("mésial",),
    "mésiaux": ("mésial",),
    "mésique": ("mésique",),
    "mésiques": ("mésique",),
    "mésitoïque": ("mésitoïque",),
    "mésitoïques": ("mésitoïque",),
    "mesmérien": ("mesmérien",),
    "mesmérienne": ("mesmérien",),
    "mesmériennes": ("mesmérien",),
    "mesmériens": ("mesmérien",),
    "mésobiotique": ("mésobiotique",),
    "mésobiotiques": ("mésobiotique",),
    "mésoblastique": ("mésoblastique",),
    "mésoblastiques": ("mésoblastique",),
    "mésoblatique": ("mésoblatique",),
    "mésoblatiques": ("mésoblatique",),
    "mésocéphale": ("mésocéphale",),
    "mésocéphales": ("mésocéphale",),
    "mésocéphalique": ("mésocéphalique",),
    "mésocéphaliques": ("mésocéphalique",),
    "mésochoriale": ("mésochorial",),
    "mésochoriales": ("mésochorial",),
    "mésochorial": ("mésochorial",),
    "mésochoriaux": ("mésochorial",),
    "mésochrone": ("mésochrone",),
    "mésochrones": ("mésochrone",),
    "mésocolique": ("mésocolique",),
    "mésocoliques": ("mésocolique",),
    "mésocorticale": ("mésocortical",),
    "mésocorticales": ("mésocortical",),
    "mésocortical": ("mésocortical",),
    "mésocorticaux": ("mésocortical",),
    "mésocurtique": ("mésocurtique",),
    "mésocurtiques": ("mésocurtique",),
    "mésodermique": ("mésodermique",),
    "mésodermiques": ("mésodermique",),
    "mésodiastolique": ("mésodiastolique",),
    "mésodiastoliques": ("mésodiastolique",),
    "mésogastrique": ("mésogastrique",),
    "mésogastriques": ("mésogastrique",),
    "mésolithique": ("mésolithique",),
    "mésolithiques": ("mésolithique",),
    "mésolittorale": ("mésolittoral",),
    "mésolittorales": ("mésolittoral",),
    "mésolittoral": ("mésolittoral",),
    "mésolittoraux": ("mésolittoral",),
    "mésologique": ("mésologique",),
    "mésologiques": ("mésologique",),
    "mésomélique": ("mésomélique",),
    "mésoméliques": ("mésomélique",),
    "mésomère": ("mésomère",),
    "mésomères": ("mésomère",),
    "mésomorphe": ("mésomorphe",),
    "mésomorphes": ("mésomorphe",),
    "mésomorphique": ("mésomorphique",),
    "mésomorphiques": ("mésomorphique",),
    "mésophile": ("mésophile",),
    "mésophiles": ("mésophile",),
    "mésophyte": ("mésophyte",),
    "mésophytes": ("mésophyte",),
    "mésopique": ("mésopique",),
    "mésopiques": ("mésopique",),
    "mésopotamien": ("mésopotamien",),
    "mésopotamienne": ("mésopotamien",),
    "mésopotamiennes": ("mésopotamien",),
    "mésopotamiens": ("mésopotamien",),
    "mésosphérique": ("mésosphérique",),
    "mésosphériques": ("mésosphérique",),
    "mésosternale": ("mésosternal",),
    "mésosternales": ("mésosternal",),
    "mésosternal": ("mésosternal",),
    "mésosternaux": ("mésosternal",),
    "mésosystolique": ("mésosystolique",),
    "mésosystoliques": ("mésosystolique",),
    "mésotartrique": ("mésotartrique",),
    "mésotartriques": ("mésotartrique",),
    "mésothéliale": ("mésothélial",),
    "mésothéliales": ("mésothélial",),
    "mésothélial": ("mésothélial",),
    "mésothéliaux": ("mésothélial",),
    "mésothermale": ("mésothermal",),
    "mésothermales": ("mésothermal",),
    "mésothermal": ("mésothermal",),
    "mésothermaux": ("mésothermal",),
    "mésotherme": ("mésotherme",),
    "mésothermes": ("mésotherme",),
    "mésothoracique": ("mésothoracique",),
    "mésothoraciques": ("mésothoracique",),
    "mésoxalique": ("mésoxalique",),
    "mésoxaliques": ("mésoxalique",),
    "mésozoïque": ("mésozoïque",),
    "mésozoïques": ("mésozoïque",),
    "mésozonale": ("mésozonal",),
    "mésozonales": ("mésozonal",),
    "mésozonal": ("mésozonal",),
    "mésozonaux": ("mésozonal",),
    "messianique": ("messianique",),
    "messianiques": ("messianique",),
    "messianiste": ("messianiste",),
    "messianistes": ("messianiste",),
    "mesurable": ("mesurable",),
    "mesurables": ("mesurable",),
    "métaarsénieuse": ("métaarsénieux",),
    "métaarsénieuses": ("métaarsénieux",),
    "métaarsénieux": ("métaarsénieux",),
    "métabole": ("métabole",),
    "métaboles": ("métabole",),
    "métabolique": ("métabolique",),
    "métaboliques": ("métabolique",),
    "métabolisable": ("métabolisable",),
    "métabolisables": ("métabolisable",),
    "métaborique": ("métaborique",),
    "métaboriques": ("métaborique",),
    "métacarpien": ("métacarpien",),
    "métacarpienne": ("métacarpien",),
    "métacarpiennes": ("métacarpien",),
    "métacarpiens": ("métacarpien",),
    "métacentrique": ("métacentrique",),
    "métacentriques": ("métacentrique",),
    "métachromatique": ("métachromatique",),
    "métachromatiques": ("métachromatique",),
    "métaclastique": ("métaclastique",),
    "métaclastiques": ("métaclastique",),
    "métacritique": ("métacritique",),
    "métacritiques": ("métacritique",),
    "métacrylique": ("métacrylique",),
    "métacryliques": ("métacrylique",),
    "métadiscursif": ("métadiscursif",),
    "métadiscursifs": ("métadiscursif",),
    "métadiscursive": ("métadiscursif",),
    "métadiscursives": ("métadiscursif",),
    "métagénésique": ("métagénésique",),
    "métagénésiques": ("métagénésique",),
    "métalinguistique": ("métalinguistique",),
    "métalinguistiques": ("métalinguistique",),
    "métallière": ("métallier",),
    "métallières": ("métallier",),
    "métallier": ("métallier",),
    "métalliers": ("métallier",),
    "métallifère": ("métallifère",),
    "métallifères": ("métallifère",),
    "métallique": ("métallique",),
    "métalliques": ("métallique",),
    "métalliseur": ("métalliseur",),
    "métalliseurs": ("métalliseur",),
    "métalliseuse": ("métalliseur",),
    "métalliseuses": ("métalliseur",),
    "métalliste": ("métalliste",),
    "métallistes": ("métalliste",),
    "métallogénique": ("métallogénique",),
    "métallogéniques": ("métallogénique",),
    "métallographique": ("métallographique",),
    "métallographiques": ("métallographique",),
    "métallographitique": ("métallographitique",),
    "métallographitiques": ("métallographitique",),
    "métalloïdique": ("métalloïdique",),
    "métalloïdiques": ("métalloïdique",),
    "métalloplastique": ("métalloplastique",),
    "métalloplastiques": ("métalloplastique",),
    "métallostatique": ("métallostatique",),
    "métallostatiques": ("métallostatique",),
    "métallurgique": ("métallurgique",),
    "métallurgiques": ("métallurgique",),
    "métallurgiste": ("métallurgiste",),
    "métallurgistes": ("métallurgiste",),
    "méta-logique": ("méta-logique",),
    "métalogique": ("métalogique",),
    "métalogiques": ("métalogique",),
    "métamagnétique": ("métamagnétique",),
    "métamagnétiques": ("métamagnétique",),
    "métamathématique": ("métamathématique",),
    "métamathématiques": ("métamathématique",),
    "métamère": ("métamère",),
    "métamères": ("métamère",),
    "métamérique": ("métamérique",),
    "métamériques": ("métamérique",),
    "métamicte": ("métamicte",),
    "métamictes": ("métamicte",),
    "métamorphique": ("métamorphique",),
    "métamorphiques": ("métamorphique",),
    "métamorphosable": ("métamorphosable",),
    "métamorphosables": ("métamorphosable",),
    "métanéphrétique": ("métanéphrétique",),
    "métanéphrétiques": ("métanéphrétique",),
    "métaphasique": ("métaphasique",),
    "métaphasiques": ("métaphasique",),
    "métaphonique": ("métaphonique",),
    "métaphoniques": ("métaphonique",),
    "métaphorique": ("métaphorique",),
    "métaphoriques": ("métaphorique",),
    "métaphosphorique": ("métaphosphorique",),
    "métaphosphoriques": ("métaphosphorique",),
    "métaphysaire": ("métaphysaire",),
    "métaphysaires": ("métaphysaire",),
    "métaphysicien": ("métaphysicien",),
    "métaphysicienne": ("métaphysicien",),
    "métaphysiciennes": ("métaphysicien",),
    "métaphysiciens": ("métaphysicien",),
    "métaphysique": ("métaphysique",),
    "métaphysiques": ("métaphysique",),
    "métaplasique": ("métaplasique",),
    "métaplasiques": ("métaplasique",),
    "métapléthorique": ("métapléthorique",),
    "métapléthoriques": ("métapléthorique",),
    "métapneustique": ("métapneustique",),
    "métapneustiques": ("métapneustique",),
    "métapositif": ("métapositif",),
    "métapositifs": ("métapositif",),
    "métapositive": ("métapositif",),
    "métapositives": ("métapositif",),
    "métapsychique": ("métapsychique",),
    "métapsychiques": ("métapsychique",),
    "métapsychologique": ("métapsychologique",),
    "métapsychologiques": ("métapsychologique",),
    "métasomatique": ("métasomatique",),
    "métasomatiques": ("métasomatique",),
    "métastable": ("métastable",),
    "métastables": ("métastable",),
    "métastannique": ("métastannique",),
    "métastanniques": ("métastannique",),
    "métastasique": ("métastasique",),
    "métastasiques": ("métastasique",),
    "métastatique": ("métastatique",),
    "métastatiques": ("métastatique",),
    "métasternale": ("métasternal",),
    "métasternales": ("métasternal",),
    "métasternal": ("métasternal",),
    "métasternaux": ("métasternal",),
    "métatarsien": ("métatarsien",),
    "métatarsienne": ("métatarsien",),
    "métatarsiennes": ("métatarsien",),
    "métatarsiens": ("métatarsien",),
    "métatectique": ("métatectique",),
    "métatectiques": ("métatectique",),
    "métatextuelle": ("métatextuel",),
    "métatextuelles": ("métatextuel",),
    "métatextuel": ("métatextuel",),
    "métatextuels": ("métatextuel",),
    "métathéorique": ("métathéorique",),
    "métathéoriques": ("métathéorique",),
    "métathérapeutique": ("métathérapeutique",),
    "métathérapeutiques": ("métathérapeutique",),
    "métathoracique": ("métathoracique",),
    "métathoraciques": ("métathoracique",),
    "métatropique": ("métatropique",),
    "métatropiques": ("métatropique",),
    "métatypique": ("métatypique",),
    "métatypiques": ("métatypique",),
    "métavariable": ("métavariable",),
    "métavariables": ("métavariable",),
    "métencéphalique": ("métencéphalique",),
    "métencéphaliques": ("métencéphalique",),
    "météo": ("météo",),
    "météos": ("météo",),
    "météorique": ("météorique",),
    "météoriques": ("météorique",),
    "météoritique": ("météoritique",),
    "météoritiques": ("météoritique",),
    "météorolabile": ("météorolabile",),
    "météorolabiles": ("météorolabile",),
    "météorologique": ("météorologique",),
    "météorologiques": ("météorologique",),
    "météoropathologique": ("météoropathologique",),
    "météoropathologiques": ("météoropathologique",),
    "météorotrope": ("météorotrope",),
    "météorotropes": ("météorotrope",),
    "méthacrylique": ("méthacrylique",),
    "méthacryliques": ("méthacrylique",),
    "méthanesulfonique": ("méthanesulfonique",),
    "méthanesulfoniques": ("méthanesulfonique",),
    "méthanogène": ("méthanogène",),
    "méthanogènes": ("méthanogène",),
    "méthanoïque": ("méthanoïque",),
    "méthanoïques": ("méthanoïque",),
    "méthodique": ("méthodique",),
    "méthodiques": ("méthodique",),
    "méthodiste": ("méthodiste",),
    "méthodistes": ("méthodiste",),
    "méthodologique": ("méthodologique",),
    "méthodologiques": ("méthodologique",),
    "méthylcaféique": ("méthylcaféique",),
    "méthylcaféiques": ("méthylcaféique",),
    "méthylénique": ("méthylénique",),
    "méthyléniques": ("méthylénique",),
    "méthylfumarique": ("méthylfumarique",),
    "méthylfumariques": ("méthylfumarique",),
    "méthylique": ("méthylique",),
    "méthyliques": ("méthylique",),
    "métiazinique": ("métiazinique",),
    "métiaziniques": ("métiazinique",),
    "méticuleuse": ("méticuleux",),
    "méticuleuses": ("méticuleux",),
    "méticuleux": ("méticuleux",),
    "métis": ("métis",),
    "métisse": ("métis",),
    "métisses": ("métis",),
    "métonymique": ("métonymique",),
    "métonymiques": ("métonymique",),
    "métopage": ("métopage",),
    "métopages": ("métopage",),
    "métopique": ("métopique",),
    "métopiques": ("métopique",),
    "métoposcopique": ("métoposcopique",),
    "métoposcopiques": ("métoposcopique",),
    "métrique": ("métrique",),
    "métriques": ("métrique",),
    "métrisable": ("métrisable",),
    "métrisables": ("métrisable",),
    "métrologique": ("métrologique",),
    "métrologiques": ("métrologique",),
    "métronomique": ("métronomique",),
    "métronomiques": ("métronomique",),
    "métrorragique": ("métrorragique",),
    "métrorragiques": ("métrorragique",),
    "mettable": ("mettable",),
    "mettables": ("mettable",),
    "meublée": ("meublé",),
    "meublées": ("meublé",),
    "meublé": ("meublé",),
    "meuble": ("meuble",),
    "meublés": ("meublé",),
    "meubles": ("meuble",),
    "meulière": ("meulier",),
    "meulières": ("meulier",),
    "meulier": ("meulier",),
    "meuliers": ("meulier",),
    "meunière": ("meunier",),
    "meunières": ("meunier",),
    "meunier": ("meunier",),
    "meuniers": ("meunier",),
    "meurtrière": ("meurtrier",),
    "meurtrières": ("meurtrier",),
    "meurtrier": ("meurtrier",),
    "meurtriers": ("meurtrier",),
    "mévalonique": ("mévalonique",),
    "mévaloniques": ("mévalonique",),
    "mex": ("mex",),
    "mexicaniste": ("mexicaniste",),
    "mexicanistes": ("mexicaniste",),
    "mexico": ("mexico",),
    "mexicos": ("mexico",),
    "mezzographe": ("mezzographe",),
    "mezzographes": ("mezzographe",),
    "miasmatique": ("miasmatique",),
    "miasmatiques": ("miasmatique",),
    "miauleur": ("miauleur",),
    "miauleurs": ("miauleur",),
    "miauleuse": ("miauleur",),
    "miauleuses": ("miauleur",),
    "micaschisteuse": ("micaschisteux",),
    "micaschisteuses": ("micaschisteux",),
    "micaschisteux": ("micaschisteux",),
    "micellaire": ("micellaire",),
    "micellaires": ("micellaire",),
    "michélangelesque": ("michélangelesque",),
    "michélangelesques": ("michélangelesque",),
    "michnaïque": ("michnaïque",),
    "michnaïques": ("michnaïque",),
    "micoquien": ("micoquien",),
    "micoquienne": ("micoquien",),
    "micoquiennes": ("micoquien",),
    "micoquiens": ("micoquien",),
    "microbicide": ("microbicide",),
    "microbicides": ("microbicide",),
    "microbien": ("microbien",),
    "microbienne": ("microbien",),
    "microbiennes": ("microbien",),
    "microbiens": ("microbien",),
    "microbiologique": ("microbiologique",),
    "microbiologiques": ("microbiologique",),
    "microbiotique": ("microbiotique",),
    "microbiotiques": ("microbiotique",),
    "microcalorimétrique": ("microcalorimétrique",),
    "microcalorimétriques": ("microcalorimétrique",),
    "microcanonique": ("microcanonique",),
    "microcanoniques": ("microcanonique",),
    "microcéphale": ("microcéphale",),
    "microcéphales": ("microcéphale",),
    "microchimique": ("microchimique",),
    "microchimiques": ("microchimique",),
    "microchirurgicale": ("microchirurgical",),
    "microchirurgicales": ("microchirurgical",),
    "microchirurgical": ("microchirurgical",),
    "microchirurgicaux": ("microchirurgical",),
    "microcinématographique": ("microcinématographique",),
    "microcinématographiques": ("microcinématographique",),
    "microcirculatoire": ("microcirculatoire",),
    "microcirculatoires": ("microcirculatoire",),
    "microclimatique": ("microclimatique",),
    "microclimatiques": ("microclimatique",),
    "microcornéen": ("microcornéen",),
    "microcornéenne": ("microcornéen",),
    "microcornéennes": ("microcornéen",),
    "microcornéens": ("microcornéen",),
    "microcosmique": ("microcosmique",),
    "microcosmiques": ("microcosmique",),
    "microcytaire": ("microcytaire",),
    "microcytaires": ("microcytaire",),
    "microcytique": ("microcytique",),
    "microcytiques": ("microcytique",),
    "microdactyle": ("microdactyle",),
    "microdactyles": ("microdactyle",),
    "micro-économique": ("microéconomique",),
    "microéconomique": ("microéconomique",),
    "microéconomiques": ("microéconomique",),
    "microélectronique": ("microélectronique",),
    "microélectroniques": ("microélectronique",),
    "microfilaricide": ("microfilaricide",),
    "microfilaricides": ("microfilaricide",),
    "microfundiaire": ("microfundiaire",),
    "microfundiaires": ("microfundiaire",),
    "micrographique": ("micrographique",),
    "micrographiques": ("micrographique",),
    "micro-informatique": ("micro-informatique",),
    "microkystique": ("microkystique",),
    "microkystiques": ("microkystique",),
    "microlithique": ("microlithique",),
    "microlithiques": ("microlithique",),
    "microlitique": ("microlitique",),
    "microlitiques": ("microlitique",),
    "micromécanique": ("micromécanique",),
    "micromécaniques": ("micromécanique",),
    "micromélien": ("micromélien",),
    "micromélienne": ("micromélien",),
    "microméliennes": ("micromélien",),
    "microméliens": ("micromélien",),
    "micromélique": ("micromélique",),
    "microméliques": ("micromélique",),
    "micromériste": ("micromériste",),
    "microméristes": ("micromériste",),
    "micrométrique": ("micrométrique",),
    "micrométriques": ("micrométrique",),
    "microminiature": ("microminiature",),
    "microminiatures": ("microminiature",),
    "micromorphologique": ("micromorphologique",),
    "micromorphologiques": ("micromorphologique",),
    "micronésien": ("micronésien",),
    "micronésienne": ("micronésien",),
    "micronésiennes": ("micronésien",),
    "micronésiens": ("micronésien",),
    "micronodulaire": ("micronodulaire",),
    "micronodulaires": ("micronodulaire",),
    "micropegmatitique": ("micropegmatitique",),
    "micropegmatitiques": ("micropegmatitique",),
    "microphage": ("microphage",),
    "microphages": ("microphage",),
    "microphonique": ("microphonique",),
    "microphoniques": ("microphonique",),
    "microphotographique": ("microphotographique",),
    "microphotographiques": ("microphotographique",),
    "microphysique": ("microphysique",),
    "microphysiques": ("microphysique",),
    "microporeuse": ("microporeux",),
    "microporeuses": ("microporeux",),
    "microporeux": ("microporeux",),
    "microprogrammable": ("microprogrammable",),
    "microprogrammables": ("microprogrammable",),
    "microptique": ("microptique",),
    "microptiques": ("microptique",),
    "microscopique": ("microscopique",),
    "microscopiques": ("microscopique",),
    "microséismique": ("microséismique",),
    "microséismiques": ("microséismique",),
    "microsismique": ("microsismique",),
    "microsismiques": ("microsismique",),
    "microsmatique": ("microsmatique",),
    "microsmatiques": ("microsmatique",),
    "microsociologique": ("microsociologique",),
    "microsociologiques": ("microsociologique",),
    "microsomiale": ("microsomial",),
    "microsomiales": ("microsomial",),
    "microsomial": ("microsomial",),
    "microsomiaux": ("microsomial",),
    "microsporique": ("microsporique",),
    "microsporiques": ("microsporique",),
    "microtherme": ("microtherme",),
    "microthermes": ("microtherme",),
    "microtype": ("microtype",),
    "microtypes": ("microtype",),
    "microvasculaire": ("microvasculaire",),
    "microvasculaires": ("microvasculaire",),
    "mictionnelle": ("mictionnel",),
    "mictionnelles": ("mictionnel",),
    "mictionnel": ("mictionnel",),
    "mictionnels": ("mictionnel",),
    "mictique": ("mictique",),
    "mictiques": ("mictique",),
    "midrashique": ("midrashique",),
    "midrashiques": ("midrashique",),
    "mielleuse": ("mielleux",),
    "mielleuses": ("mielleux",),
    "mielleux": ("mielleux",),
    "mien": ("mien",),
    "mienne": ("mien",),
    "miennes": ("mien",),
    "miens": ("mien",),
    "mièvre": ("mièvre",),
    "mièvres": ("mièvre",),
    "mignon": ("mignon",),
    "mignonne": ("mignon",),
    "mignonnes": ("mignon",),
    "mignons": ("mignon",),
    "mignonnet": ("mignonnet",),
    "mignonnets": ("mignonnet",),
    "mignonnette": ("mignonnet",),
    "mignonnettes": ("mignonnet",),
    "migraineuse": ("migraineux",),
    "migraineuses": ("migraineux",),
    "migraineux": ("migraineux",),
    "migrateur": ("migrateur",),
    "migrateurs": ("migrateur",),
    "migratrice": ("migrateur",),
    "migratrices": ("migrateur",),
    "migratoire": ("migratoire",),
    "migratoires": ("migratoire",),
    "miguéliste": ("miguéliste",),
    "miguélistes": ("miguéliste",),
    "mijoteur": ("mijoteur",),
    "mijoteurs": ("mijoteur",),
    "mijoteuse": ("mijoteur",),
    "mijoteuses": ("mijoteur",),
    "milaire": ("milaire",),
    "milaires": ("milaire",),
    "milanaise": ("milanais",),
    "milanaises": ("milanais",),
    "milanais": ("milanais",),
    "miliaire": ("miliaire",),
    "miliaires": ("miliaire",),
    "militaire": ("militaire",),
    "militaires": ("militaire",),
    "militariste": ("militariste",),
    "militaristes": ("militariste",),
    "militaro-industrielles": ("militaro-industriel",),
    "militaro-industriel": ("militaro-industriel",),
    "militaro-industriels": ("militaro-industriel",),
    "millénaire": ("millénaire",),
    "millénaires": ("millénaire",),
    "millénariste": ("millénariste",),
    "millénaristes": ("millénariste",),
    "millerandiste": ("millerandiste",),
    "millerandistes": ("millerandiste",),
    "milliaire": ("milliaire",),
    "milliaires": ("milliaire",),
    "milliardaire": ("milliardaire",),
    "milliardaires": ("milliardaire",),
    "milliardième": ("milliardième",),
    "milliardièmes": ("milliardième",),
    "millième": ("millième",),
    "millièmes": ("millième",),
    "millimétrique": ("millimétrique",),
    "millimétriques": ("millimétrique",),
    "millionième": ("millionième",),
    "millionièmes": ("millionième",),
    "millionnaire": ("millionnaire",),
    "millionnaires": ("millionnaire",),
    "mi-lourde": ("mi-lourd",),
    "mimétique": ("mimétique",),
    "mimétiques": ("mimétique",),
    "mimeuse": ("mimeuse",),
    "mimeuses": ("mimeuse",),
    "mimi": ("mimi",),
    "mimique": ("mimique",),
    "mimiques": ("mimique",),
    "mimocinétique": ("mimocinétique",),
    "mimocinétiques": ("mimocinétique",),
    "mimographique": ("mimographique",),
    "mimographiques": ("mimographique",),
    "mi-moyenne": ("mi-moyen",),
    "mi-moyens": ("mi-moyen",),
    "minable": ("minable",),
    "minables": ("minable",),
    "minaudière": ("minaudier",),
    "minaudières": ("minaudier",),
    "minaudier": ("minaudier",),
    "minaudiers": ("minaudier",),
    "mince": ("mince",),
    "minces": ("mince",),
    "minérale": ("minéral",),
    "minérales": ("minéral",),
    "minéral": ("minéral",),
    "minéraux": ("minéral",),
    "minéralière": ("minéralier",),
    "minéralières": ("minéralier",),
    "minéralier": ("minéralier",),
    "minéraliers": ("minéralier",),
    "minéralisable": ("minéralisable",),
    "minéralisables": ("minéralisable",),
    "minéralisateur": ("minéralisateur",),
    "minéralisateurs": ("minéralisateur",),
    "minéralisatrice": ("minéralisateur",),
    "minéralisatrices": ("minéralisateur",),
    "minéralo-corticoïde": ("minéralocorticoïde",),
    "minéralocorticoïde": ("minéralocorticoïde",),
    "minéralocorticoïdes": ("minéralocorticoïde",),
    "minéralogique": ("minéralogique",),
    "minéralogiques": ("minéralogique",),
    "minervale": ("minerval",),
    "minervales": ("minerval",),
    "minerval": ("minerval",),
    "minervaux": ("minerval",),
    "mingrélien": ("mingrélien",),
    "mingrélienne": ("mingrélien",),
    "mingréliennes": ("mingrélien",),
    "mingréliens": ("mingrélien",),
    "mini": ("mini",),
    "miniaturée": ("miniaturé",),
    "miniaturées": ("miniaturé",),
    "miniaturé": ("miniaturé",),
    "miniature": ("miniature",),
    "miniaturés": ("miniaturé",),
    "miniatures": ("miniature",),
    "minière": ("minier",),
    "minières": ("minier",),
    "minier": ("minier",),
    "miniers": ("minier",),
    "minimale": ("minimal",),
    "minimales": ("minimal",),
    "minimal": ("minimal",),
    "minimaux": ("minimal",),
    "minimaliste": ("minimaliste",),
    "minimalistes": ("minimaliste",),
    "minime": ("minime",),
    "minimes": ("minime",),
    "minima": ("minimum",),
    "minimum": ("minimum",),
    "minimums": ("minimum",),
    "ministérielle": ("ministériel",),
    "ministérielles": ("ministériel",),
    "ministériel": ("ministériel",),
    "ministériels": ("ministériel",),
    "ministrable": ("ministrable",),
    "ministrables": ("ministrable",),
    "minoen": ("minoen",),
    "minoenne": ("minoen",),
    "minoennes": ("minoen",),
    "minoens": ("minoen",),
    "minorateur": ("minorateur",),
    "minorateurs": ("minorateur",),
    "minoratrice": ("minorateur",),
    "minoratrices": ("minorateur",),
    "minoratif": ("minoratif",),
    "minoratifs": ("minoratif",),
    "minorative": ("minoratif",),
    "minoratives": ("minoratif",),
    "minoritaire": ("minoritaire",),
    "minoritaires": ("minoritaire",),
    "minuscule": ("minuscule",),
    "minuscules": ("minuscule",),
    "minutaire": ("minutaire",),
    "minutaires": ("minutaire",),
    "minute": ("minute",),
    "minutieuse": ("minutieux",),
    "minutieuses": ("minutieux",),
    "minutieux": ("minutieux",),
    "miocène": ("miocène",),
    "miocènes": ("miocène",),
    "miogéosynclinale": ("miogéosynclinal",),
    "miogéosynclinales": ("miogéosynclinal",),
    "miogéosynclinal": ("miogéosynclinal",),
    "miogéosynclinaux": ("miogéosynclinal",),
    "miotique": ("miotique",),
    "miotiques": ("miotique",),
    "miraculeuse": ("miraculeux",),
    "miraculeuses": ("miraculeux",),
    "miraculeux": ("miraculeux",),
    "mirepoix": ("mirepoix",),
    "mirifique": ("mirifique",),
    "mirifiques": ("mirifique",),
    "miro": ("miro",),
    "miroitière": ("miroitier",),
    "miroitières": ("miroitier",),
    "miroitier": ("miroitier",),
    "miroitiers": ("miroitier",),
    "mise": ("mis",),
    "mises": ("mis",),
    "mis": ("mis",),
    "misandre": ("misandre",),
    "misandres": ("misandre",),
    "misanthrope": ("misanthrope",),
    "misanthropes": ("misanthrope",),
    "misanthropique": ("misanthropique",),
    "misanthropiques": ("misanthropique",),
    "miscible": ("miscible",),
    "miscibles": ("miscible",),
    "misérabiliste": ("misérabiliste",),
    "misérabilistes": ("misérabiliste",),
    "misérable": ("misérable",),
    "misérables": ("misérable",),
    "miséreuse": ("miséreux",),
    "miséreuses": ("miséreux",),
    "miséreux": ("miséreux",),
    "miséricordieuse": ("miséricordieux",),
    "miséricordieuses": ("miséricordieux",),
    "miséricordieux": ("miséricordieux",),
    "mishnaïque": ("mishnaïque",),
    "mishnaïques": ("mishnaïque",),
    "misogyne": ("misogyne",),
    "misogynes": ("misogyne",),
    "misonéiste": ("misonéiste",),
    "misonéistes": ("misonéiste",),
    "missionnaire": ("missionnaire",),
    "missionnaires": ("missionnaire",),
    "missive": ("missive",),
    "missives": ("missive",),
    "miteuse": ("miteux",),
    "miteuses": ("miteux",),
    "miteux": ("miteux",),
    "mithraïque": ("mithraïque",),
    "mithraïques": ("mithraïque",),
    "mithriaque": ("mithriaque",),
    "mithriaques": ("mithriaque",),
    "mithridatique": ("mithridatique",),
    "mithridatiques": ("mithridatique",),
    "mitochondriale": ("mitochondrial",),
    "mitochondriales": ("mitochondrial",),
    "mitochondrial": ("mitochondrial",),
    "mitochondriaux": ("mitochondrial",),
    "mitoclasique": ("mitoclasique",),
    "mitoclasiques": ("mitoclasique",),
    "mitogène": ("mitogène",),
    "mitogènes": ("mitogène",),
    "mitogénique": ("mitogénique",),
    "mitogéniques": ("mitogénique",),
    "mitotique": ("mitotique",),
    "mitotiques": ("mitotique",),
    "mitoyen": ("mitoyen",),
    "mitoyenne": ("mitoyen",),
    "mitoyennes": ("mitoyen",),
    "mitoyens": ("mitoyen",),
    "mitrailleur": ("mitrailleur",),
    "mitrailleurs": ("mitrailleur",),
    "mitrailleuse": ("mitrailleur",),
    "mitrailleuses": ("mitrailleur",),
    "mitrale": ("mitral",),
    "mitrales": ("mitral",),
    "mitral": ("mitral",),
    "mitraux": ("mitral",),
    "mixeur": ("mixeur",),
    "mixeurs": ("mixeur",),
    "mixeuse": ("mixeur",),
    "mixeuses": ("mixeur",),
    "mixiologique": ("mixiologique",),
    "mixiologiques": ("mixiologique",),
    "mixte": ("mixte",),
    "mixtes": ("mixte",),
    "mixtèque": ("mixtèque",),
    "mixtèques": ("mixtèque",),
    "mixtiligne": ("mixtiligne",),
    "mixtilignes": ("mixtiligne",),
    "mnémonique": ("mnémonique",),
    "mnémoniques": ("mnémonique",),
    "mnémotactique": ("mnémotactique",),
    "mnémotactiques": ("mnémotactique",),
    "mnémotechnique": ("mnémotechnique",),
    "mnémotechniques": ("mnémotechnique",),
    "mnésique": ("mnésique",),
    "mnésiques": ("mnésique",),
    "moabite": ("moabite",),
    "moabites": ("moabite",),
    "mobile": ("mobile",),
    "mobiles": ("mobile",),
    "mobilière": ("mobilier",),
    "mobilières": ("mobilier",),
    "mobilier": ("mobilier",),
    "mobiliers": ("mobilier",),
    "mobilisable": ("mobilisable",),
    "mobilisables": ("mobilisable",),
    "mobilisateur": ("mobilisateur",),
    "mobilisateurs": ("mobilisateur",),
    "mobilisatrice": ("mobilisateur",),
    "mobilisatrices": ("mobilisateur",),
    "mobiliste": ("mobiliste",),
    "mobilistes": ("mobiliste",),
    "moche": ("moche",),
    "moches": ("moche",),
    "modacrylique": ("modacrylique",),
    "modacryliques": ("modacrylique",),
    "modale": ("modal",),
    "modales": ("modal",),
    "modal": ("modal",),
    "modaux": ("modal",),
    "modelable": ("modelable",),
    "modelables": ("modelable",),
    "modèle": ("modèle",),
    "modèles": ("modèle",),
    "modeleur": ("modeleur",),
    "modeleurs": ("modeleur",),
    "modeleuse": ("modeleur",),
    "modeleuses": ("modeleur",),
    "modélisable": ("modélisable",),
    "modélisables": ("modélisable",),
    "modéliste": ("modéliste",),
    "modélistes": ("modéliste",),
    "modérable": ("modérable",),
    "modérables": ("modérable",),
    "modérantiste": ("modérantiste",),
    "modérantistes": ("modérantiste",),
    "modérateur": ("modérateur",),
    "modérateurs": ("modérateur",),
    "modératrice": ("modérateur",),
    "modératrices": ("modérateur",),
    "moderne": ("moderne",),
    "modernes": ("moderne",),
    "modernisateur": ("modernisateur",),
    "modernisateurs": ("modernisateur",),
    "modernisatrice": ("modernisateur",),
    "modernisatrices": ("modernisateur",),
    "moderniste": ("moderniste",),
    "modernistes": ("moderniste",),
    "modeste": ("modeste",),
    "modestes": ("modeste",),
    "modifiable": ("modifiable",),
    "modifiables": ("modifiable",),
    "modificateur": ("modificateur",),
    "modificateurs": ("modificateur",),
    "modificatrice": ("modificateur",),
    "modificatrices": ("modificateur",),
    "modificatif": ("modificatif",),
    "modificatifs": ("modificatif",),
    "modificative": ("modificatif",),
    "modificatives": ("modificatif",),
    "modique": ("modique",),
    "modiques": ("modique",),
    "modulable": ("modulable",),
    "modulables": ("modulable",),
    "modulaire": ("modulaire",),
    "modulaires": ("modulaire",),
    "modulateur": ("modulateur",),
    "modulateurs": ("modulateur",),
    "modulatrice": ("modulateur",),
    "modulatrices": ("modulateur",),
    "modulo": ("modulo",),
    "moelleuse": ("moelleux",),
    "moelleuses": ("moelleux",),
    "moelleux": ("moelleux",),
    "moellier": ("moellier",),
    "moelliers": ("moellier",),
    "mohawk": ("mohawk",),
    "mohawks": ("mohawk",),
    "mohiste": ("mohiste",),
    "mohistes": ("mohiste",),
    "moï": ("moï",),
    "moïs": ("moï",),
    "moindre": ("moindre",),
    "moindres": ("moindre",),
    "moissonneuse": ("moissonneuse",),
    "moissonneuses": ("moissonneuse",),
    "moite": ("moite",),
    "moites": ("moite",),
    "molaire": ("molaire",),
    "môlaire": ("môlaire",),
    "molaires": ("molaire",),
    "môlaires": ("môlaire",),
    "mol": ("mol",),
    "mols": ("mol",),
    "molassique": ("molassique",),
    "molassiques": ("molassique",),
    "molasson": ("molasson",),
    "molassonne": ("molasson",),
    "molassonnes": ("molasson",),
    "molassons": ("molasson",),
    "moldave": ("moldave",),
    "moldaves": ("moldave",),
    "moléculaire": ("moléculaire",),
    "moléculaires": ("moléculaire",),
    "moliéresque": ("moliéresque",),
    "moliéresques": ("moliéresque",),
    "moliniste": ("moliniste",),
    "molinistes": ("moliniste",),
    "molinosiste": ("molinosiste",),
    "molinosistes": ("molinosiste",),
    "mollasse": ("mollasse",),
    "mollasses": ("mollasse",),
    "mollassique": ("mollassique",),
    "mollassiques": ("mollassique",),
    "mollasson": ("mollasson",),
    "mollassonne": ("mollasson",),
    "mollassonnes": ("mollasson",),
    "mollassons": ("mollasson",),
    "mollet": ("mollet",),
    "mollets": ("mollet",),
    "mollette": ("mollet",),
    "mollettes": ("mollet",),
    "molletière": ("molletière",),
    "molletières": ("molletière",),
    "molletonneuse": ("molletonneux",),
    "molletonneuses": ("molletonneux",),
    "molletonneux": ("molletonneux",),
    "molossique": ("molossique",),
    "molossiques": ("molossique",),
    "molybdique": ("molybdique",),
    "molybdiques": ("molybdique",),
    "môme": ("môme",),
    "mômes": ("môme",),
    "momificateur": ("momificateur",),
    "momificateurs": ("momificateur",),
    "momificatrice": ("momificateur",),
    "momificatrices": ("momificateur",),
    "monacale": ("monacal",),
    "monacales": ("monacal",),
    "monacal": ("monacal",),
    "monacaux": ("monacal",),
    "monadelphe": ("monadelphe",),
    "monadelphes": ("monadelphe",),
    "monadique": ("monadique",),
    "monadiques": ("monadique",),
    "monadiste": ("monadiste",),
    "monadistes": ("monadiste",),
    "monadologique": ("monadologique",),
    "monadologiques": ("monadologique",),
    "monalisesque": ("monalisesque",),
    "monalisesques": ("monalisesque",),
    "môn": ("môn",),
    "môns": ("môn",),
    "monandre": ("monandre",),
    "monandres": ("monandre",),
    "monanthe": ("monanthe",),
    "monanthes": ("monanthe",),
    "monarchien": ("monarchien",),
    "monarchienne": ("monarchien",),
    "monarchiennes": ("monarchien",),
    "monarchiens": ("monarchien",),
    "monarchique": ("monarchique",),
    "monarchiques": ("monarchique",),
    "monarchiste": ("monarchiste",),
    "monarchistes": ("monarchiste",),
    "monastique": ("monastique",),
    "monastiques": ("monastique",),
    "monaurale": ("monaural",),
    "monaurales": ("monaural",),
    "monaural": ("monaural",),
    "monauraux": ("monaural",),
    "monauriculaire": ("monauriculaire",),
    "monauriculaires": ("monauriculaire",),
    "mondiale": ("mondial",),
    "mondiales": ("mondial",),
    "mondial": ("mondial",),
    "mondiaux": ("mondial",),
    "mondialiste": ("mondialiste",),
    "mondialistes": ("mondialiste",),
    "mondien": ("mondien",),
    "mondienne": ("mondien",),
    "mondiennes": ("mondien",),
    "mondiens": ("mondien",),
    "mondiste": ("mondiste",),
    "mondistes": ("mondiste",),
    "mondoublotière": ("mondoublotier",),
    "mondoublotières": ("mondoublotier",),
    "mondoublotier": ("mondoublotier",),
    "mondoublotiers": ("mondoublotier",),
    "monégasque": ("monégasque",),
    "monégasques": ("monégasque",),
    "monétaire": ("monétaire",),
    "monétaires": ("monétaire",),
    "monétariste": ("monétariste",),
    "monétaristes": ("monétariste",),
    "mongolien": ("mongolien",),
    "mongolienne": ("mongolien",),
    "mongoliennes": ("mongolien",),
    "mongoliens": ("mongolien",),
    "mongolique": ("mongolique",),
    "mongoliques": ("mongolique",),
    "mongoloïde": ("mongoloïde",),
    "mongoloïdes": ("mongoloïde",),
    "moniale": ("monial",),
    "moniales": ("monial",),
    "monial": ("monial",),
    "moniaux": ("monial",),
    "moniliasique": ("moniliasique",),
    "moniliasiques": ("moniliasique",),
    "moniliforme": ("moniliforme",),
    "moniliformes": ("moniliforme",),
    "moniste": ("moniste",),
    "monistes": ("moniste",),
    "monitoire": ("monitoire",),
    "monitoires": ("monitoire",),
    "monitoriale": ("monitorial",),
    "monitoriales": ("monitorial",),
    "monitorial": ("monitorial",),
    "monitoriaux": ("monitorial",),
    "monnayable": ("monnayable",),
    "monnayables": ("monnayable",),
    "monoacide": ("monoacide",),
    "monoacides": ("monoacide",),
    "monoaminergique": ("monoaminergique",),
    "monoaminergiques": ("monoaminergique",),
    "mono": ("mono",),
    "monoarticulaire": ("monoarticulaire",),
    "monoarticulaires": ("monoarticulaire",),
    "monoatomique": ("monoatomique",),
    "monoatomiques": ("monoatomique",),
    "monoaxe": ("monoaxe",),
    "monoaxes": ("monoaxe",),
    "monoaxiale": ("monoaxial",),
    "monoaxiales": ("monoaxial",),
    "monoaxial": ("monoaxial",),
    "monoaxiaux": ("monoaxial",),
    "monobasique": ("monobasique",),
    "monobasiques": ("monobasique",),
    "monoblastique": ("monoblastique",),
    "monoblastiques": ("monoblastique",),
    "monobloc": ("monobloc",),
    "monocâble": ("monocâble",),
    "monocamérale": ("monocaméral",),
    "monocamérales": ("monocaméral",),
    "monocaméral": ("monocaméral",),
    "monocaméraux": ("monocaméral",),
    "monocarpien": ("monocarpien",),
    "monocarpienne": ("monocarpien",),
    "monocarpiennes": ("monocarpien",),
    "monocarpiens": ("monocarpien",),
    "monocarte": ("monocarte",),
    "monocartes": ("monocarte",),
    "monocaténaire": ("monocaténaire",),
    "monocaténaires": ("monocaténaire",),
    "monocausale": ("monocausal",),
    "monocausales": ("monocausal",),
    "monocausal": ("monocausal",),
    "monocausaux": ("monocausal",),
    "monocellulaire": ("monocellulaire",),
    "monocellulaires": ("monocellulaire",),
    "monocentrique": ("monocentrique",),
    "monocentriques": ("monocentrique",),
    "monocéphale": ("monocéphale",),
    "monocéphales": ("monocéphale",),
    "monochloracétique": ("monochloracétique",),
    "monochloracétiques": ("monochloracétique",),
    "monochorionique": ("monochorionique",),
    "monochorioniques": ("monochorionique",),
    "monochromate": ("monochromate",),
    "monochromates": ("monochromate",),
    "monochromatique": ("monochromatique",),
    "monochromatiques": ("monochromatique",),
    "monochrome": ("monochrome",),
    "monochromes": ("monochrome",),
    "monocinétique": ("monocinétique",),
    "monocinétiques": ("monocinétique",),
    "monoclinale": ("monoclinal",),
    "monoclinales": ("monoclinal",),
    "monoclinal": ("monoclinal",),
    "monoclinaux": ("monoclinal",),
    "monocline": ("monocline",),
    "monoclines": ("monocline",),
    "monoclinique": ("monoclinique",),
    "monocliniques": ("monoclinique",),
    "monoclonale": ("monoclonal",),
    "monoclonales": ("monoclonal",),
    "monoclonal": ("monoclonal",),
    "monoclonaux": ("monoclonal",),
    "monocolore": ("monocolore",),
    "monocolores": ("monocolore",),
    "monocoque": ("monocoque",),
    "monocoques": ("monocoque",),
    "monocorde": ("monocorde",),
    "monocordes": ("monocorde",),
    "monocotylédone": ("monocotylédone",),
    "monocotylédones": ("monocotylédone",),
    "monocratique": ("monocratique",),
    "monocratiques": ("monocratique",),
    "monoculaire": ("monoculaire",),
    "monoculaires": ("monoculaire",),
    "monocycle": ("monocycle",),
    "monocycles": ("monocycle",),
    "monocyclique": ("monocyclique",),
    "monocycliques": ("monocyclique",),
    "monocylindre": ("monocylindre",),
    "monocylindres": ("monocylindre",),
    "monocylindrique": ("monocylindrique",),
    "monocylindriques": ("monocylindrique",),
    "monocytaire": ("monocytaire",),
    "monocytaires": ("monocytaire",),
    "monocytémique": ("monocytémique",),
    "monocytémiques": ("monocytémique",),
    "monocytogène": ("monocytogène",),
    "monocytogènes": ("monocytogène",),
    "monocytoïde": ("monocytoïde",),
    "monocytoïdes": ("monocytoïde",),
    "monodactyle": ("monodactyle",),
    "monodactyles": ("monodactyle",),
    "monodelphe": ("monodelphe",),
    "monodelphes": ("monodelphe",),
    "monodépartementale": ("monodépartemental",),
    "monodépartementales": ("monodépartemental",),
    "monodépartemental": ("monodépartemental",),
    "monodépartementaux": ("monodépartemental",),
    "monodérive": ("monodérive",),
    "monodérives": ("monodérive",),
    "monodermique": ("monodermique",),
    "monodermiques": ("monodermique",),
    "monodique": ("monodique",),
    "monodiques": ("monodique",),
    "monodisciplinaire": ("monodisciplinaire",),
    "monodisciplinaires": ("monodisciplinaire",),
    "monoécique": ("monoécique",),
    "monoéciques": ("monoécique",),
    "monoénergétique": ("monoénergétique",),
    "monoénergétiques": ("monoénergétique",),
    "monoéthylique": ("monoéthylique",),
    "monoéthyliques": ("monoéthylique",),
    "monofactorielle": ("monofactoriel",),
    "monofactorielles": ("monofactoriel",),
    "monofactoriel": ("monofactoriel",),
    "monofactoriels": ("monofactoriel",),
    "monofamiliale": ("monofamilial",),
    "monofamiliales": ("monofamilial",),
    "monofamilial": ("monofamilial",),
    "monofamiliaux": ("monofamilial",),
    "monofilaire": ("monofilaire",),
    "monofilaires": ("monofilaire",),
    "monofocale": ("monofocal",),
    "monofocales": ("monofocal",),
    "monofocal": ("monofocal",),
    "monofocaux": ("monofocal",),
    "monogame": ("monogame",),
    "monogames": ("monogame",),
    "monogamique": ("monogamique",),
    "monogamiques": ("monogamique",),
    "monogastrique": ("monogastrique",),
    "monogastriques": ("monogastrique",),
    "monogène": ("monogène",),
    "monogènes": ("monogène",),
    "monogénique": ("monogénique",),
    "monogéniques": ("monogénique",),
    "monogéniste": ("monogéniste",),
    "monogénistes": ("monogéniste",),
    "monogerme": ("monogerme",),
    "monogermes": ("monogerme",),
    "monogrammatique": ("monogrammatique",),
    "monogrammatiques": ("monogrammatique",),
    "monographique": ("monographique",),
    "monographiques": ("monographique",),
    "monogyne": ("monogyne",),
    "monogynes": ("monogyne",),
    "monohybride": ("monohybride",),
    "monohybrides": ("monohybride",),
    "monoïdéique": ("monoïdéique",),
    "monoïdéiques": ("monoïdéique",),
    "monoïdéiste": ("monoïdéiste",),
    "monoïdéistes": ("monoïdéiste",),
    "monoïque": ("monoïque",),
    "monoïques": ("monoïque",),
    "monolingue": ("monolingue",),
    "monolingues": ("monolingue",),
    "monolithe": ("monolithe",),
    "monolithes": ("monolithe",),
    "monolithique": ("monolithique",),
    "monolithiques": ("monolithique",),
    "monologique": ("monologique",),
    "monologiques": ("monologique",),
    "monomane": ("monomane",),
    "monomanes": ("monomane",),
    "monomaniaque": ("monomaniaque",),
    "monomaniaques": ("monomaniaque",),
    "monomélique": ("monomélique",),
    "monoméliques": ("monomélique",),
    "monomère": ("monomère",),
    "monomères": ("monomère",),
    "monomérique": ("monomérique",),
    "monomériques": ("monomérique",),
    "monométallique": ("monométallique",),
    "monométalliques": ("monométallique",),
    "monométalliste": ("monométalliste",),
    "monométallistes": ("monométalliste",),
    "monomètre": ("monomètre",),
    "monomètres": ("monomètre",),
    "monométrique": ("monométrique",),
    "monométriques": ("monométrique",),
    "monomictique": ("monomictique",),
    "monomictiques": ("monomictique",),
    "monomodale": ("monomodal",),
    "monomodales": ("monomodal",),
    "monomodal": ("monomodal",),
    "monomodaux": ("monomodal",),
    "monomoléculaire": ("monomoléculaire",),
    "monomoléculaires": ("monomoléculaire",),
    "monomorphe": ("monomorphe",),
    "monomorphes": ("monomorphe",),
    "monomoteur": ("monomoteur",),
    "monomoteurs": ("monomoteur",),
    "monomotrice": ("monomoteur",),
    "monomotrices": ("monomoteur",),
    "mononucléaire": ("mononucléaire",),
    "mononucléaires": ("mononucléaire",),
    "mononucléosique": ("mononucléosique",),
    "mononucléosiques": ("mononucléosique",),
    "monoparentale": ("monoparental",),
    "monoparentales": ("monoparental",),
    "monoparental": ("monoparental",),
    "monoparentaux": ("monoparental",),
    "monopartiste": ("monopartiste",),
    "monopartistes": ("monopartiste",),
    "monopétale": ("monopétale",),
    "monopétales": ("monopétale",),
    "monophage": ("monophage",),
    "monophages": ("monophage",),
    "monophasique": ("monophasique",),
    "monophasiques": ("monophasique",),
    "monophonématique": ("monophonématique",),
    "monophonématiques": ("monophonématique",),
    "monophonique": ("monophonique",),
    "monophoniques": ("monophonique",),
    "monophosphorique": ("monophosphorique",),
    "monophosphoriques": ("monophosphorique",),
    "monophtalme": ("monophtalme",),
    "monophtalmes": ("monophtalme",),
    "monophylétique": ("monophylétique",),
    "monophylétiques": ("monophylétique",),
    "monophysite": ("monophysite",),
    "monophysites": ("monophysite",),
    "monoplace": ("monoplace",),
    "monoplaces": ("monoplace",),
    "monoplan": ("monoplan",),
    "monoplans": ("monoplan",),
    "monopode": ("monopode",),
    "monopodes": ("monopode",),
    "monopodiale": ("monopodial",),
    "monopodiales": ("monopodial",),
    "monopodial": ("monopodial",),
    "monopodiaux": ("monopodial",),
    "monopoint": ("monopoint",),
    "monopoints": ("monopoint",),
    "monopolaire": ("monopolaire",),
    "monopolaires": ("monopolaire",),
    "monopoleur": ("monopoleur",),
    "monopoleurs": ("monopoleur",),
    "monopoleuse": ("monopoleur",),
    "monopoleuses": ("monopoleur",),
    "monopolisateur": ("monopolisateur",),
    "monopolisateurs": ("monopolisateur",),
    "monopolisatrice": ("monopolisateur",),
    "monopolisatrices": ("monopolisateur",),
    "monopoliste": ("monopoliste",),
    "monopolistes": ("monopoliste",),
    "monopolistique": ("monopolistique",),
    "monopolistiques": ("monopolistique",),
    "monopoutre": ("monopoutre",),
    "monopoutres": ("monopoutre",),
    "monoprocesseur": ("monoprocesseur",),
    "monoprocesseurs": ("monoprocesseur",),
    "monoproducteur": ("monoproducteur",),
    "monoproducteurs": ("monoproducteur",),
    "monoproductrice": ("monoproducteur",),
    "monoproductrices": ("monoproducteur",),
    "monoproduit": ("monoproduit",),
    "monoptère": ("monoptère",),
    "monoptères": ("monoptère",),
    "monopuce": ("monopuce",),
    "monopuces": ("monopuce",),
    "monoradiculaire": ("monoradiculaire",),
    "monoradiculaires": ("monoradiculaire",),
    "monorail": ("monorail",),
    "monorchide": ("monorchide",),
    "monorchides": ("monorchide",),
    "monorime": ("monorime",),
    "monorimes": ("monorime",),
    "monosémique": ("monosémique",),
    "monosémiques": ("monosémique",),
    "monosépale": ("monosépale",),
    "monosépales": ("monosépale",),
    "monosexuelle": ("monosexuel",),
    "monosexuelles": ("monosexuel",),
    "monosexuel": ("monosexuel",),
    "monosexuels": ("monosexuel",),
    "monosoc": ("monosoc",),
    "monosodique": ("monosodique",),
    "monosodiques": ("monosodique",),
    "monosomique": ("monosomique",),
    "monosomiques": ("monosomique",),
    "monosperme": ("monosperme",),
    "monospermes": ("monosperme",),
    "monospermique": ("monospermique",),
    "monospermiques": ("monospermique",),
    "monostable": ("monostable",),
    "monostables": ("monostable",),
    "monostyle": ("monostyle",),
    "monostyles": ("monostyle",),
    "monosulfonique": ("monosulfonique",),
    "monosulfoniques": ("monosulfonique",),
    "monosyllabe": ("monosyllabe",),
    "monosyllabes": ("monosyllabe",),
    "monosyllabique": ("monosyllabique",),
    "monosyllabiques": ("monosyllabique",),
    "monosymptomatique": ("monosymptomatique",),
    "monosymptomatiques": ("monosymptomatique",),
    "monosynaptique": ("monosynaptique",),
    "monosynaptiques": ("monosynaptique",),
    "monotâche": ("monotâche",),
    "monotâches": ("monotâche",),
    "monotectique": ("monotectique",),
    "monotectiques": ("monotectique",),
    "monoterpénique": ("monoterpénique",),
    "monoterpéniques": ("monoterpénique",),
    "monothéique": ("monothéique",),
    "monothéiques": ("monothéique",),
    "monothéiste": ("monothéiste",),
    "monothéistes": ("monothéiste",),
    "monothéistique": ("monothéistique",),
    "monothéistiques": ("monothéistique",),
    "monotherme": ("monotherme",),
    "monothermes": ("monotherme",),
    "monotonale": ("monotonal",),
    "monotonales": ("monotonal",),
    "monotonal": ("monotonal",),
    "monotonaux": ("monotonal",),
    "monotone": ("monotone",),
    "monotones": ("monotone",),
    "monotonique": ("monotonique",),
    "monotoniques": ("monotonique",),
    "monotrace": ("monotrace",),
    "monotraces": ("monotrace",),
    "monotrème": ("monotrème",),
    "monotrèmes": ("monotrème",),
    "monotype": ("monotype",),
    "monotypes": ("monotype",),
    "monotypique": ("monotypique",),
    "monotypiques": ("monotypique",),
    "mono-utilisateurs": ("mono-utilisateur",),
    "monoxène": ("monoxène",),
    "monoxènes": ("monoxène",),
    "monoxyle": ("monoxyle",),
    "monoxyles": ("monoxyle",),
    "monozygote": ("monozygote",),
    "monozygotes": ("monozygote",),
    "monstre": ("monstre",),
    "monstres": ("monstre",),
    "monstrueuse": ("monstrueux",),
    "monstrueuses": ("monstrueux",),
    "monstrueux": ("monstrueux",),
    "montagnaise": ("montagnais",),
    "montagnaises": ("montagnais",),
    "montagnais": ("montagnais",),
    "montagneuse": ("montagneux",),
    "montagneuses": ("montagneux",),
    "montagneux": ("montagneux",),
    "montalbanaise": ("montalbanais",),
    "montalbanaises": ("montalbanais",),
    "montalbanais": ("montalbanais",),
    "montaniste": ("montaniste",),
    "montanistes": ("montaniste",),
    "montbéliarde": ("montbéliarde",),
    "montbéliardes": ("montbéliarde",),
    "monteur": ("monteur",),
    "monteurs": ("monteur",),
    "monteuse": ("monteur",),
    "monteuses": ("monteur",),
    "monticole": ("monticole",),
    "monticoles": ("monticole",),
    "montmartroise": ("montmartrois",),
    "montmartroises": ("montmartrois",),
    "montmartrois": ("montmartrois",),
    "montmorillonitique": ("montmorillonitique",),
    "montmorillonitiques": ("montmorillonitique",),
    "montozonitique": ("montozonitique",),
    "montozonitiques": ("montozonitique",),
    "montparno": ("montparno",),
    "montrable": ("montrable",),
    "montrables": ("montrable",),
    "montréalaise": ("montréalais",),
    "montréalaises": ("montréalais",),
    "montréalais": ("montréalais",),
    "montueuse": ("montueux",),
    "montueuses": ("montueux",),
    "montueux": ("montueux",),
    "monumentale": ("monumental",),
    "monumentales": ("monumental",),
    "monumental": ("monumental",),
    "monumentaux": ("monumental",),
    "monumentalisable": ("monumentalisable",),
    "monumentalisables": ("monumentalisable",),
    "monumentaliste": ("monumentaliste",),
    "monumentalistes": ("monumentaliste",),
    "mooniste": ("mooniste",),
    "moonistes": ("mooniste",),
    "moquable": ("moquable",),
    "moquables": ("moquable",),
    "moqueur": ("moqueur",),
    "moqueurs": ("moqueur",),
    "moqueuse": ("moqueur",),
    "moqueuses": ("moqueur",),
    "morainique": ("morainique",),
    "morainiques": ("morainique",),
    "morale": ("moral",),
    "morales": ("moral",),
    "moral": ("moral",),
    "moraux": ("moral",),
    "moralisateur": ("moralisateur",),
    "moralisateurs": ("moralisateur",),
    "moralisatrice": ("moralisateur",),
    "moralisatrices": ("moralisateur",),
    "moraliste": ("moraliste",),
    "moralistes": ("moraliste",),
    "moratoire": ("moratoire",),
    "moratoires": ("moratoire",),
    "morave": ("morave",),
    "moraves": ("morave",),
    "morbide": ("morbide",),
    "morbides": ("morbide",),
    "morbifique": ("morbifique",),
    "morbifiques": ("morbifique",),
    "morbigène": ("morbigène",),
    "morbigènes": ("morbigène",),
    "morbilleuse": ("morbilleux",),
    "morbilleuses": ("morbilleux",),
    "morbilleux": ("morbilleux",),
    "morbilliforme": ("morbilliforme",),
    "morbilliformes": ("morbilliforme",),
    "morbus": ("morbus",),
    "morcelable": ("morcelable",),
    "morcelables": ("morcelable",),
    "mordeur": ("mordeur",),
    "mordeurs": ("mordeur",),
    "mordeuse": ("mordeur",),
    "mordeuses": ("mordeur",),
    "more": ("more",),
    "mores": ("more",),
    "moresque": ("moresque",),
    "moresques": ("moresque",),
    "moreau": ("moreau",),
    "moreaux": ("moreau",),
    "morelle": ("moreau",),
    "morelles": ("moreau",),
    "morganatique": ("morganatique",),
    "morganatiques": ("morganatique",),
    "morisque": ("morisque",),
    "morisques": ("morisque",),
    "mornée": ("morné",),
    "mornées": ("morné",),
    "morné": ("morné",),
    "morne": ("morne",),
    "mornés": ("morné",),
    "mornes": ("morne",),
    "morose": ("morose",),
    "moroses": ("morose",),
    "morphe": ("morphe",),
    "morphes": ("morphe",),
    "morphéique": ("morphéique",),
    "morphéiques": ("morphéique",),
    "morphématique": ("morphématique",),
    "morphématiques": ("morphématique",),
    "morphémique": ("morphémique",),
    "morphémiques": ("morphémique",),
    "morphinique": ("morphinique",),
    "morphiniques": ("morphinique",),
    "morphinomane": ("morphinomane",),
    "morphinomanes": ("morphinomane",),
    "morphinomimétique": ("morphinomimétique",),
    "morphinomimétiques": ("morphinomimétique",),
    "morphochronologique": ("morphochronologique",),
    "morphochronologiques": ("morphochronologique",),
    "morphoclimatique": ("morphoclimatique",),
    "morphoclimatiques": ("morphoclimatique",),
    "morpho-éco-éthologique": ("morpho-éco-éthologique",),
    "morphogène": ("morphogène",),
    "morphogènes": ("morphogène",),
    "morphogénétique": ("morphogénétique",),
    "morphogénétiques": ("morphogénétique",),
    "morphogénique": ("morphogénique",),
    "morphogéniques": ("morphogénique",),
    "morphologique": ("morphologique",),
    "morphologiques": ("morphologique",),
    "morphométrique": ("morphométrique",),
    "morphométriques": ("morphométrique",),
    "morphonologique": ("morphonologique",),
    "morphonologiques": ("morphonologique",),
    "morphophonologique": ("morphophonologique",),
    "morphophonologiques": ("morphophonologique",),
    "morphopsychologique": ("morphopsychologique",),
    "morphopsychologiques": ("morphopsychologique",),
    "morphoscopique": ("morphoscopique",),
    "morphoscopiques": ("morphoscopique",),
    "morphosémantique": ("morphosémantique",),
    "morphosémantiques": ("morphosémantique",),
    "morphostructurale": ("morphostructural",),
    "morphostructurales": ("morphostructural",),
    "morphostructural": ("morphostructural",),
    "morphostructuraux": ("morphostructural",),
    "morphosyntaxique": ("morphosyntaxique",),
    "morphosyntaxiques": ("morphosyntaxique",),
    "morphotectonique": ("morphotectonique",),
    "morphotectoniques": ("morphotectonique",),
    "morse": ("morse",),
    "morses": ("morse",),
    "mortaillable": ("mortaillable",),
    "mortaillables": ("mortaillable",),
    "mortelle": ("mortel",),
    "mortelles": ("mortel",),
    "mortel": ("mortel",),
    "mortels": ("mortel",),
    "mortifère": ("mortifère",),
    "mortifères": ("mortifère",),
    "mortuaire": ("mortuaire",),
    "mortuaires": ("mortuaire",),
    "morutière": ("morutier",),
    "morutières": ("morutier",),
    "morutier": ("morutier",),
    "morutiers": ("morutier",),
    "morvandeau": ("morvandeau",),
    "morvandeaux": ("morvandeau",),
    "morvandelle": ("morvandeau",),
    "morvandelles": ("morvandeau",),
    "morveuse": ("morveux",),
    "morveuses": ("morveux",),
    "morveux": ("morveux",),
    "mosaïquée": ("mosaïqué",),
    "mosaïquées": ("mosaïqué",),
    "mosaïqué": ("mosaïqué",),
    "mosaïque": ("mosaïque",),
    "mosaïqués": ("mosaïqué",),
    "mosaïques": ("mosaïque",),
    "moscoutaire": ("moscoutaire",),
    "moscoutaires": ("moscoutaire",),
    "moscovite": ("moscovite",),
    "moscovites": ("moscovite",),
    "mosquito": ("mosquito",),
    "mosquitos": ("mosquito",),
    "mossi": ("mossi",),
    "mossis": ("mossi",),
    "moteur": ("moteur",),
    "moteurs": ("moteur",),
    "motrice": ("moteur",),
    "motrices": ("moteur",),
    "motionnaire": ("motionnaire",),
    "motionnaires": ("motionnaire",),
    "motivable": ("motivable",),
    "motivables": ("motivable",),
    "motivationnelle": ("motivationnel",),
    "motivationnelles": ("motivationnel",),
    "motivationnel": ("motivationnel",),
    "motivationnels": ("motivationnel",),
    "motocompresseur": ("motocompresseur",),
    "motocompresseurs": ("motocompresseur",),
    "motocyclable": ("motocyclable",),
    "motocyclables": ("motocyclable",),
    "motocycliste": ("motocycliste",),
    "motocyclistes": ("motocycliste",),
    "motonautique": ("motonautique",),
    "motonautiques": ("motonautique",),
    "motopropulseur": ("motopropulseur",),
    "motopropulseurs": ("motopropulseur",),
    "motoventilateur": ("motoventilateur",),
    "motoventilateurs": ("motoventilateur",),
    "motoventilatrice": ("motoventilateur",),
    "motoventilatrices": ("motoventilateur",),
    "molle": ("mou",),
    "molles": ("mou",),
    "mou": ("mou",),
    "mous": ("mou",),
    "mouillable": ("mouillable",),
    "mouillables": ("mouillable",),
    "mouilleur": ("mouilleur",),
    "mouilleurs": ("mouilleur",),
    "mouilleuse": ("mouilleux",),
    "mouilleuses": ("mouilleux",),
    "mouilleux": ("mouilleux",),
    "moulable": ("moulable",),
    "moulables": ("moulable",),
    "mouride": ("mouride",),
    "mourides": ("mouride",),
    "mousse": ("mousse",),
    "mousses": ("mousse",),
    "mousseau": ("mousseau",),
    "mousseaux": ("mousseau",),
    "mousseuse": ("mousseux",),
    "mousseuses": ("mousseux",),
    "mousseux": ("mousseux",),
    "moussonique": ("moussonique",),
    "moussoniques": ("moussonique",),
    "moussot": ("moussot",),
    "moussots": ("moussot",),
    "moustérien": ("moustérien",),
    "moustérienne": ("moustérien",),
    "moustériennes": ("moustérien",),
    "moustériens": ("moustérien",),
    "moustiérien": ("moustiérien",),
    "moustiérienne": ("moustiérien",),
    "moustiériennes": ("moustiérien",),
    "moustiériens": ("moustiérien",),
    "moutarde": ("moutarde",),
    "mouton": ("mouton",),
    "moutonne": ("mouton",),
    "moutonnes": ("mouton",),
    "moutons": ("mouton",),
    "moutonneuse": ("moutonneux",),
    "moutonneuses": ("moutonneux",),
    "moutonneux": ("moutonneux",),
    "moutonnière": ("moutonnier",),
    "moutonnières": ("moutonnier",),
    "moutonnier": ("moutonnier",),
    "moutonniers": ("moutonnier",),
    "moyenâgeuse": ("moyenâgeux",),
    "moyenâgeuses": ("moyenâgeux",),
    "moyenâgeux": ("moyenâgeux",),
    "moyen": ("moyen",),
    "moyenne": ("moyen",),
    "moyennes": ("moyen",),
    "moyens": ("moyen",),
    "moyen-orientale": ("moyen-oriental",),
    "moyen-orientales": ("moyen-oriental",),
    "moyen-oriental": ("moyen-oriental",),
    "moyen-orientaux": ("moyen-oriental",),
    "moyeuse": ("moyeuse",),
    "moyeuses": ("moyeuse",),
    "mozabite": ("mozabite",),
    "mozabites": ("mozabite",),
    "mozarabe": ("mozarabe",),
    "mozarabes": ("mozarabe",),
    "mozartien": ("mozartien",),
    "mozartienne": ("mozartien",),
    "mozartiennes": ("mozartien",),
    "mozartiens": ("mozartien",),
    "muable": ("muable",),
    "muables": ("muable",),
    "mucilagineuse": ("mucilagineux",),
    "mucilagineuses": ("mucilagineux",),
    "mucilagineux": ("mucilagineux",),
    "mucique": ("mucique",),
    "muciques": ("mucique",),
    "mucoïde": ("mucoïde",),
    "mucoïdes": ("mucoïde",),
    "mucolytique": ("mucolytique",),
    "mucolytiques": ("mucolytique",),
    "mucomembraneuse": ("mucomembraneux",),
    "mucomembraneuses": ("mucomembraneux",),
    "mucomembraneux": ("mucomembraneux",),
    "muconique": ("muconique",),
    "muconiques": ("muconique",),
    "mucopolysaccharidique": ("mucopolysaccharidique",),
    "mucopolysaccharidiques": ("mucopolysaccharidique",),
    "muco-purulent": ("muco-purulent",),
    "muco-purulents": ("muco-purulent",),
    "mudéjar": ("mudéjar",),
    "mudéjare": ("mudéjare",),
    "mudéjares": ("mudéjare",),
    "mue": ("mue",),
    "mues": ("mue",),
    "muet": ("muet",),
    "muets": ("muet",),
    "muette": ("muet",),
    "muettes": ("muet",),
    "mufle": ("mufle",),
    "mufles": ("mufle",),
    "mulassière": ("mulassier",),
    "mulassières": ("mulassier",),
    "mulassier": ("mulassier",),
    "mulassiers": ("mulassier",),
    "mulâtre": ("mulâtre",),
    "mulâtres": ("mulâtre",),
    "mulâtresse": ("mulâtre",),
    "mulâtresses": ("mulâtre",),
    "muletière": ("muletier",),
    "muletières": ("muletier",),
    "muletier": ("muletier",),
    "muletiers": ("muletier",),
    "mullérien": ("mullérien",),
    "mullérienne": ("mullérien",),
    "mullériennes": ("mullérien",),
    "mullériens": ("mullérien",),
    "multibande": ("multibande",),
    "multibandes": ("multibande",),
    "multibranche": ("multibranche",),
    "multibranches": ("multibranche",),
    "multibrin": ("multibrin",),
    "multibrins": ("multibrin",),
    "multibroche": ("multibroche",),
    "multibroches": ("multibroche",),
    "multicâble": ("multicâble",),
    "multicâbles": ("multicâble",),
    "multicanal": ("multicanal",),
    "multicanaux": ("multicanal",),
    "multicarte": ("multicarte",),
    "multicartes": ("multicarte",),
    "multicaule": ("multicaule",),
    "multicaules": ("multicaule",),
    "multicellulaire": ("multicellulaire",),
    "multicellulaires": ("multicellulaire",),
    "multicentrique": ("multicentrique",),
    "multicentriques": ("multicentrique",),
    "multichute": ("multichute",),
    "multichutes": ("multichute",),
    "multicolore": ("multicolore",),
    "multicolores": ("multicolore",),
    "multicompartimentale": ("multicompartimental",),
    "multicompartimentales": ("multicompartimental",),
    "multicompartimental": ("multicompartimental",),
    "multicompartimentaux": ("multicompartimental",),
    "multiconducteur": ("multiconducteur",),
    "multiconducteurs": ("multiconducteur",),
    "multiconductrice": ("multiconducteur",),
    "multiconductrices": ("multiconducteur",),
    "multiconfessionnelle": ("multiconfessionnel",),
    "multiconfessionnelles": ("multiconfessionnel",),
    "multiconfessionnel": ("multiconfessionnel",),
    "multiconfessionnels": ("multiconfessionnel",),
    "multiconstructeur": ("multiconstructeur",),
    "multiconstructeurs": ("multiconstructeur",),
    "multicoque": ("multicoque",),
    "multicoques": ("multicoque",),
    "multicouche": ("multicouche",),
    "multicouches": ("multicouche",),
    "multicritère": ("multicritère",),
    "multicritères": ("multicritère",),
    "multiculturelle": ("multiculturel",),
    "multiculturelles": ("multiculturel",),
    "multiculturel": ("multiculturel",),
    "multiculturels": ("multiculturel",),
    "multicylindre": ("multicylindre",),
    "multicylindres": ("multicylindre",),
    "multidépartementale": ("multidépartemental",),
    "multidépartementales": ("multidépartemental",),
    "multidépartemental": ("multidépartemental",),
    "multidépartementaux": ("multidépartemental",),
    "multidimensionnelle": ("multidimensionnel",),
    "multidimensionnelles": ("multidimensionnel",),
    "multidimensionnel": ("multidimensionnel",),
    "multidimensionnels": ("multidimensionnel",),
    "multidirectionnelle": ("multidirectionnel",),
    "multidirectionnelles": ("multidirectionnel",),
    "multidirectionnel": ("multidirectionnel",),
    "multidirectionnels": ("multidirectionnel",),
    "multidisciplinaire": ("multidisciplinaire",),
    "multidisciplinaires": ("multidisciplinaire",),
    "multidivisionnelle": ("multidivisionnel",),
    "multidivisionnelles": ("multidivisionnel",),
    "multidivisionnel": ("multidivisionnel",),
    "multidivisionnels": ("multidivisionnel",),
    "multiethnique": ("multiethnique",),
    "multiethniques": ("multiethnique",),
    "multifactorielle": ("multifactoriel",),
    "multifactorielles": ("multifactoriel",),
    "multifactoriel": ("multifactoriel",),
    "multifactoriels": ("multifactoriel",),
    "multifaisceaux": ("multifaisceaux",),
    "multifenêtre": ("multifenêtre",),
    "multifenêtres": ("multifenêtre",),
    "multifide": ("multifide",),
    "multifides": ("multifide",),
    "multifilaire": ("multifilaire",),
    "multifilaires": ("multifilaire",),
    "multifilament": ("multifilament",),
    "multifilaments": ("multifilament",),
    "multiflore": ("multiflore",),
    "multiflores": ("multiflore",),
    "multifocale": ("multifocal",),
    "multifocales": ("multifocal",),
    "multifocal": ("multifocal",),
    "multifocaux": ("multifocal",),
    "multifonctionnelle": ("multifonctionnel",),
    "multifonctionnelles": ("multifonctionnel",),
    "multifonctionnel": ("multifonctionnel",),
    "multifonctionnels": ("multifonctionnel",),
    "multifonctions": ("multifonctions",),
    "multiforme": ("multiforme",),
    "multiformes": ("multiforme",),
    "multifruits": ("multifruits",),
    "multigénique": ("multigénique",),
    "multigéniques": ("multigénique",),
    "multigeste": ("multigeste",),
    "multigestes": ("multigeste",),
    "multigrade": ("multigrade",),
    "multigrades": ("multigrade",),
    "multijet": ("multijet",),
    "multijets": ("multijet",),
    "multilatérale": ("multilatéral",),
    "multilatérales": ("multilatéral",),
    "multilatéral": ("multilatéral",),
    "multilatéraux": ("multilatéral",),
    "multilinéaire": ("multilinéaire",),
    "multilinéaires": ("multilinéaire",),
    "multilingue": ("multilingue",),
    "multilingues": ("multilingue",),
    "multiloculaire": ("multiloculaire",),
    "multiloculaires": ("multiloculaire",),
    "multimédia": ("multimédia",),
    "multimédias": ("multimédia",),
    "multimédiatique": ("multimédiatique",),
    "multimédiatiques": ("multimédiatique",),
    "multiméthode": ("multiméthode",),
    "multiméthodes": ("multiméthode",),
    "multimilliardaire": ("multimilliardaire",),
    "multimilliardaires": ("multimilliardaire",),
    "multimillionnaire": ("multimillionnaire",),
    "multimillionnaires": ("multimillionnaire",),
    "multimodale": ("multimodal",),
    "multimodales": ("multimodal",),
    "multimodal": ("multimodal",),
    "multimodaux": ("multimodal",),
    "multimode": ("multimode",),
    "multimodes": ("multimode",),
    "multimoteur": ("multimoteur",),
    "multimoteurs": ("multimoteur",),
    "multinationale": ("multinational",),
    "multinationales": ("multinational",),
    "multinational": ("multinational",),
    "multinationaux": ("multinational",),
    "multinodulaire": ("multinodulaire",),
    "multinodulaires": ("multinodulaire",),
    "multinomiale": ("multinomial",),
    "multinomiales": ("multinomial",),
    "multinomial": ("multinomial",),
    "multinomiaux": ("multinomial",),
    "multinorme": ("multinorme",),
    "multinormes": ("multinorme",),
    "multioculaire": ("multioculaire",),
    "multioculaires": ("multioculaire",),
    "multipare": ("multipare",),
    "multipares": ("multipare",),
    "multiparti": ("multiparti",),
    "multipartis": ("multiparti",),
    "multipartite": ("multiparti",),
    "multipartites": ("multiparti",),
    "multipas": ("multipas",),
    "multipasse": ("multipasse",),
    "multipasses": ("multipasse",),
    "multiphasique": ("multiphasique",),
    "multiphasiques": ("multiphasique",),
    "multiphotonique": ("multiphotonique",),
    "multiphotoniques": ("multiphotonique",),
    "multiplace": ("multiplace",),
    "multiplaces": ("multiplace",),
    "multiplan": ("multiplan",),
    "multiplans": ("multiplan",),
    "multiple": ("multiple",),
    "multiples": ("multiple",),
    "multiplex": ("multiplex",),
    "multipliable": ("multipliable",),
    "multipliables": ("multipliable",),
    "multiplicateur": ("multiplicateur",),
    "multiplicateurs": ("multiplicateur",),
    "multiplicatrice": ("multiplicateur",),
    "multiplicatrices": ("multiplicateur",),
    "multiplicatif": ("multiplicatif",),
    "multiplicatifs": ("multiplicatif",),
    "multiplicative": ("multiplicatif",),
    "multiplicatives": ("multiplicatif",),
    "multipoint": ("multipoint",),
    "multipoints": ("multipoint",),
    "multipolaire": ("multipolaire",),
    "multipolaires": ("multipolaire",),
    "multiposte": ("multiposte",),
    "multipostes": ("multiposte",),
    "multiprise": ("multiprise",),
    "multiprises": ("multiprise",),
    "multiprocesseur": ("multiprocesseur",),
    "multiprocesseurs": ("multiprocesseur",),
    "multiproduits": ("multiproduits",),
    "multiprotocole": ("multiprotocole",),
    "multiprotocoles": ("multiprotocole",),
    "multiraciale": ("multiracial",),
    "multiraciales": ("multiracial",),
    "multiracial": ("multiracial",),
    "multiraciaux": ("multiracial",),
    "multirisque": ("multirisque",),
    "multirisques": ("multirisque",),
    "multirôle": ("multirôle",),
    "multirôles": ("multirôle",),
    "multisalles": ("multisalles",),
    "multisectorielle": ("multisectoriel",),
    "multisectorielles": ("multisectoriel",),
    "multisectoriel": ("multisectoriel",),
    "multisectoriels": ("multisectoriel",),
    "multiséculaire": ("multiséculaire",),
    "multiséculaires": ("multiséculaire",),
    "multisoc": ("multisoc",),
    "multisource": ("multisource",),
    "multisources": ("multisource",),
    "multispectrale": ("multispectral",),
    "multispectrales": ("multispectral",),
    "multispectral": ("multispectral",),
    "multispectraux": ("multispectral",),
    "multistandard": ("multistandard",),
    "multitâche": ("multitâche",),
    "multitâches": ("multitâche",),
    "multitube": ("multitube",),
    "multitubes": ("multitube",),
    "multitubulaire": ("multitubulaire",),
    "multitubulaires": ("multitubulaire",),
    "multi-utilisatrice": ("multi-utilisateur",),
    "multivoie": ("multivoie",),
    "multivoies": ("multivoie",),
    "multizone": ("multizone",),
    "multizones": ("multizone",),
    "munichoise": ("munichois",),
    "munichoises": ("munichois",),
    "munichois": ("munichois",),
    "municipale": ("municipal",),
    "municipales": ("municipal",),
    "municipal": ("municipal",),
    "municipaux": ("municipal",),
    "muonique": ("muonique",),
    "muoniques": ("muonique",),
    "muqueuse": ("muqueux",),
    "muqueuses": ("muqueux",),
    "muqueux": ("muqueux",),
    "murale": ("mural",),
    "murales": ("mural",),
    "mural": ("mural",),
    "muraux": ("mural",),
    "muraliste": ("muraliste",),
    "muralistes": ("muraliste",),
    "murcien": ("murcien",),
    "murcienne": ("murcien",),
    "murciennes": ("murcien",),
    "murciens": ("murcien",),
    "muriatique": ("muriatique",),
    "muriatiques": ("muriatique",),
    "muriforme": ("muriforme",),
    "mûriforme": ("mûriforme",),
    "muriformes": ("muriforme",),
    "mûriformes": ("mûriforme",),
    "musagète": ("musagète",),
    "musagètes": ("musagète",),
    "muscade": ("muscade",),
    "muscades": ("muscade",),
    "muscarinien": ("muscarinien",),
    "muscarinienne": ("muscarinien",),
    "muscariniennes": ("muscarinien",),
    "muscariniens": ("muscarinien",),
    "muscarinique": ("muscarinique",),
    "muscariniques": ("muscarinique",),
    "muscat": ("muscat",),
    "muscinale": ("muscinal",),
    "muscinales": ("muscinal",),
    "muscinal": ("muscinal",),
    "muscinaux": ("muscinal",),
    "musculaire": ("musculaire",),
    "musculaires": ("musculaire",),
    "musculeuse": ("musculeux",),
    "musculeuses": ("musculeux",),
    "musculeux": ("musculeux",),
    "musculo-cartilagineux": ("musculo-cartilagineux",),
    "musculo-cutanées": ("musculo-cutané",),
    "musculo-membraneuses": ("musculo-membraneux",),
    "musculo-tendineuses": ("musculo-tendineux",),
    "muséale": ("muséal",),
    "muséales": ("muséal",),
    "muséal": ("muséal",),
    "muséaux": ("muséal",),
    "muséographique": ("muséographique",),
    "muséographiques": ("muséographique",),
    "muséologique": ("muséologique",),
    "muséologiques": ("muséologique",),
    "musette": ("musette",),
    "musicale": ("musical",),
    "musicales": ("musical",),
    "musical": ("musical",),
    "musicaux": ("musical",),
    "musicaliste": ("musicaliste",),
    "musicalistes": ("musicaliste",),
    "musicien": ("musicien",),
    "musicienne": ("musicien",),
    "musiciennes": ("musicien",),
    "musiciens": ("musicien",),
    "musicographique": ("musicographique",),
    "musicographiques": ("musicographique",),
    "musicologique": ("musicologique",),
    "musicologiques": ("musicologique",),
    "mussif": ("mussif",),
    "mussifs": ("mussif",),
    "mussive": ("mussif",),
    "mussives": ("mussif",),
    "mussolinien": ("mussolinien",),
    "mussolinienne": ("mussolinien",),
    "mussoliniennes": ("mussolinien",),
    "mussoliniens": ("mussolinien",),
    "mutable": ("mutable",),
    "mutables": ("mutable",),
    "mutagène": ("mutagène",),
    "mutagènes": ("mutagène",),
    "mutationnelle": ("mutationnel",),
    "mutationnelles": ("mutationnel",),
    "mutationnel": ("mutationnel",),
    "mutationnels": ("mutationnel",),
    "mutationniste": ("mutationniste",),
    "mutationnistes": ("mutationniste",),
    "mutazilite": ("mutazilite",),
    "mutazilites": ("mutazilite",),
    "mutilateur": ("mutilateur",),
    "mutilateurs": ("mutilateur",),
    "mutilatrice": ("mutilateur",),
    "mutilatrices": ("mutilateur",),
    "mutique": ("mutique",),
    "mutiques": ("mutique",),
    "mutualiste": ("mutualiste",),
    "mutualistes": ("mutualiste",),
    "mutuelle": ("mutuel",),
    "mutuelles": ("mutuel",),
    "mutuel": ("mutuel",),
    "mutuels": ("mutuel",),
    "mutuelliste": ("mutuelliste",),
    "mutuellistes": ("mutuelliste",),
    "mutulaire": ("mutulaire",),
    "mutulaires": ("mutulaire",),
    "myalgique": ("myalgique",),
    "myalgiques": ("myalgique",),
    "myasthénique": ("myasthénique",),
    "myasthéniques": ("myasthénique",),
    "mycélien": ("mycélien",),
    "mycélienne": ("mycélien",),
    "mycéliennes": ("mycélien",),
    "mycéliens": ("mycélien",),
    "mycénien": ("mycénien",),
    "mycénienne": ("mycénien",),
    "mycéniennes": ("mycénien",),
    "mycéniens": ("mycénien",),
    "mycétophage": ("mycétophage",),
    "mycétophages": ("mycétophage",),
    "mycétophile": ("mycétophile",),
    "mycétophiles": ("mycétophile",),
    "mycobactérien": ("mycobactérien",),
    "mycobactérienne": ("mycobactérien",),
    "mycobactériennes": ("mycobactérien",),
    "mycobactériens": ("mycobactérien",),
    "mycodermique": ("mycodermique",),
    "mycodermiques": ("mycodermique",),
    "mycologique": ("mycologique",),
    "mycologiques": ("mycologique",),
    "mycophage": ("mycophage",),
    "mycophages": ("mycophage",),
    "mycoplasmique": ("mycoplasmique",),
    "mycoplasmiques": ("mycoplasmique",),
    "mycorhizateur": ("mycorhizateur",),
    "mycorhizateurs": ("mycorhizateur",),
    "mycorhizatrice": ("mycorhizateur",),
    "mycorhizatrices": ("mycorhizateur",),
    "mycorhizien": ("mycorhizien",),
    "mycorhizienne": ("mycorhizien",),
    "mycorhiziennes": ("mycorhizien",),
    "mycorhiziens": ("mycorhizien",),
    "mycosique": ("mycosique",),
    "mycosiques": ("mycosique",),
    "mycostatique": ("mycostatique",),
    "mycostatiques": ("mycostatique",),
    "mycotique": ("mycotique",),
    "mycotiques": ("mycotique",),
    "mydriatique": ("mydriatique",),
    "mydriatiques": ("mydriatique",),
    "myélencéphalique": ("myélencéphalique",),
    "myélencéphaliques": ("myélencéphalique",),
    "myélinique": ("myélinique",),
    "myéliniques": ("myélinique",),
    "myéloblastique": ("myéloblastique",),
    "myéloblastiques": ("myéloblastique",),
    "myélocytaire": ("myélocytaire",),
    "myélocytaires": ("myélocytaire",),
    "myélodysplasique": ("myélodysplasique",),
    "myélodysplasiques": ("myélodysplasique",),
    "myélogène": ("myélogène",),
    "myélogènes": ("myélogène",),
    "myéloïde": ("myéloïde",),
    "myéloïdes": ("myéloïde",),
    "myélomonocytaire": ("myélomonocytaire",),
    "myélomonocytaires": ("myélomonocytaire",),
    "myélopathique": ("myélopathique",),
    "myélopathiques": ("myélopathique",),
    "myélophtisique": ("myélophtisique",),
    "myélophtisiques": ("myélophtisique",),
    "myéloprolifératif": ("myéloprolifératif",),
    "myéloprolifératifs": ("myéloprolifératif",),
    "myéloproliférative": ("myéloprolifératif",),
    "myéloprolifératives": ("myéloprolifératif",),
    "myélotoxique": ("myélotoxique",),
    "myélotoxiques": ("myélotoxique",),
    "myélotrope": ("myélotrope",),
    "myélotropes": ("myélotrope",),
    "myentérique": ("myentérique",),
    "myentériques": ("myentérique",),
    "mylonitique": ("mylonitique",),
    "mylonitiques": ("mylonitique",),
    "myoblastique": ("myoblastique",),
    "myoblastiques": ("myoblastique",),
    "myocardique": ("myocardique",),
    "myocardiques": ("myocardique",),
    "myoclonique": ("myoclonique",),
    "myocloniques": ("myoclonique",),
    "myodystonique": ("myodystonique",),
    "myodystoniques": ("myodystonique",),
    "myoélectrique": ("myoélectrique",),
    "myoélectriques": ("myoélectrique",),
    "myoépithéliale": ("myoépithélial",),
    "myoépithéliales": ("myoépithélial",),
    "myoépithélial": ("myoépithélial",),
    "myoépithéliaux": ("myoépithélial",),
    "myogène": ("myogène",),
    "myogènes": ("myogène",),
    "myoglobinurique": ("myoglobinurique",),
    "myoglobinuriques": ("myoglobinurique",),
    "myographique": ("myographique",),
    "myographiques": ("myographique",),
    "myoïde": ("myoïde",),
    "myoïdes": ("myoïde",),
    "myologique": ("myologique",),
    "myologiques": ("myologique",),
    "myolytique": ("myolytique",),
    "myolytiques": ("myolytique",),
    "myopathe": ("myopathe",),
    "myopathes": ("myopathe",),
    "myopathique": ("myopathique",),
    "myopathiques": ("myopathique",),
    "myope": ("myope",),
    "myopes": ("myope",),
    "myopique": ("myopique",),
    "myopiques": ("myopique",),
    "myorésolutif": ("myorésolutif",),
    "myorésolutifs": ("myorésolutif",),
    "myorésolutive": ("myorésolutif",),
    "myorésolutives": ("myorésolutif",),
    "myotatique": ("myotatique",),
    "myotatiques": ("myotatique",),
    "myotique": ("myotique",),
    "myotiques": ("myotique",),
    "myotonique": ("myotonique",),
    "myotoniques": ("myotonique",),
    "myotubulaire": ("myotubulaire",),
    "myotubulaires": ("myotubulaire",),
    "myriamétrique": ("myriamétrique",),
    "myriamétriques": ("myriamétrique",),
    "myricique": ("myricique",),
    "myriciques": ("myricique",),
    "myristique": ("myristique",),
    "myristiques": ("myristique",),
    "myrmécologique": ("myrmécologique",),
    "myrmécologiques": ("myrmécologique",),
    "myrmécophage": ("myrmécophage",),
    "myrmécophages": ("myrmécophage",),
    "myrmécophile": ("myrmécophile",),
    "myrmécophiles": ("myrmécophile",),
    "myrmékitique": ("myrmékitique",),
    "myrmékitiques": ("myrmékitique",),
    "myronique": ("myronique",),
    "myroniques": ("myronique",),
    "myrtiforme": ("myrtiforme",),
    "myrtiformes": ("myrtiforme",),
    "mystagogique": ("mystagogique",),
    "mystagogiques": ("mystagogique",),
    "mystère": ("mystère",),
    "mystérieuse": ("mystérieux",),
    "mystérieuses": ("mystérieux",),
    "mystérieux": ("mystérieux",),
    "mystifiable": ("mystifiable",),
    "mystifiables": ("mystifiable",),
    "mystificateur": ("mystificateur",),
    "mystificateurs": ("mystificateur",),
    "mystificatrice": ("mystificateur",),
    "mystificatrices": ("mystificateur",),
    "mystique": ("mystique",),
    "mystiques": ("mystique",),
    "mythique": ("mythique",),
    "mythiques": ("mythique",),
    "mythographique": ("mythographique",),
    "mythographiques": ("mythographique",),
    "mythologique": ("mythologique",),
    "mythologiques": ("mythologique",),
    "mythomane": ("mythomane",),
    "mythomanes": ("mythomane",),
    "mythomaniaque": ("mythomaniaque",),
    "mythomaniaques": ("mythomaniaque",),
    "mytilicole": ("mytilicole",),
    "mytilicoles": ("mytilicole",),
    "myxoedémateuse": ("myxoedémateux",),
    "myxoedémateuses": ("myxoedémateux",),
    "myxoedémateux": ("myxoedémateux",),
    "mzabite": ("mzabite",),
    "mzabites": ("mzabite",),
    "nabatéen": ("nabatéen",),
    "nabatéenne": ("nabatéen",),
    "nabatéennes": ("nabatéen",),
    "nabatéens": ("nabatéen",),
    "nacarat": ("nacarat",),
    "nacrière": ("nacrier",),
    "nacrières": ("nacrier",),
    "nacrier": ("nacrier",),
    "nacriers": ("nacrier",),
    "nacteur": ("nacteur",),
    "nacteurs": ("nacteur",),
    "nadirale": ("nadiral",),
    "nadirales": ("nadiral",),
    "nadiral": ("nadiral",),
    "nadiraux": ("nadiral",),
    "naeviforme": ("naeviforme",),
    "naeviformes": ("naeviforme",),
    "naevique": ("naevique",),
    "naeviques": ("naevique",),
    "naevocellulaire": ("naevocellulaire",),
    "naevocellulaires": ("naevocellulaire",),
    "nagari": ("nagari",),
    "nageur": ("nageur",),
    "nageurs": ("nageur",),
    "nageuse": ("nageur",),
    "nageuses": ("nageur",),
    "nahua": ("nahua",),
    "nahuas": ("nahua",),
    "naïf": ("naïf",),
    "naïfs": ("naïf",),
    "naïve": ("naïf",),
    "naïves": ("naïf",),
    "nalidixique": ("nalidixique",),
    "nalidixiques": ("nalidixique",),
    "namibien": ("namibien",),
    "namibienne": ("namibien",),
    "namibiennes": ("namibien",),
    "namibiens": ("namibien",),
    "namurien": ("namurien",),
    "namurienne": ("namurien",),
    "namuriennes": ("namurien",),
    "namuriens": ("namurien",),
    "nancéien": ("nancéien",),
    "nancéienne": ("nancéien",),
    "nancéiennes": ("nancéien",),
    "nancéiens": ("nancéien",),
    "nanocéphale": ("nanocéphale",),
    "nanocéphales": ("nanocéphale",),
    "nanocorme": ("nanocorme",),
    "nanocormes": ("nanocorme",),
    "nanoélectronique": ("nanoélectronique",),
    "nanoélectroniques": ("nanoélectronique",),
    "nanomèle": ("nanomèle",),
    "nanomèles": ("nanomèle",),
    "nanométrique": ("nanométrique",),
    "nanométriques": ("nanométrique",),
    "nanosome": ("nanosome",),
    "nanosomes": ("nanosome",),
    "nantaise": ("nantais",),
    "nantaises": ("nantais",),
    "nantais": ("nantais",),
    "naphtalènesulfonique": ("naphtalènesulfonique",),
    "naphtalènesulfoniques": ("naphtalènesulfonique",),
    "naphtalénique": ("naphtalénique",),
    "naphtaléniques": ("naphtalénique",),
    "naphtalique": ("naphtalique",),
    "naphtaliques": ("naphtalique",),
    "naphténique": ("naphténique",),
    "naphténiques": ("naphténique",),
    "naphtionique": ("naphtionique",),
    "naphtioniques": ("naphtionique",),
    "naphtoïque": ("naphtoïque",),
    "naphtoïques": ("naphtoïque",),
    "naphtolcarboxylique": ("naphtolcarboxylique",),
    "naphtolcarboxyliques": ("naphtolcarboxylique",),
    "naphtoxyacétique": ("naphtoxyacétique",),
    "naphtoxyacétiques": ("naphtoxyacétique",),
    "naphtylique": ("naphtylique",),
    "naphtyliques": ("naphtylique",),
    "napoléonien": ("napoléonien",),
    "napoléonienne": ("napoléonien",),
    "napoléoniennes": ("napoléonien",),
    "napoléoniens": ("napoléonien",),
    "narcissique": ("narcissique",),
    "narcissiques": ("narcissique",),
    "narcoleptique": ("narcoleptique",),
    "narcoleptiques": ("narcoleptique",),
    "narcomane": ("narcomane",),
    "narcomanes": ("narcomane",),
    "narcotique": ("narcotique",),
    "narcotiques": ("narcotique",),
    "narquoise": ("narquois",),
    "narquoises": ("narquois",),
    "narquois": ("narquois",),
    "narratif": ("narratif",),
    "narratifs": ("narratif",),
    "narrative": ("narratif",),
    "narratives": ("narratif",),
    "nasale": ("nasal",),
    "nasales": ("nasal",),
    "nasal": ("nasal",),
    "nasaux": ("nasal",),
    "nase": ("nase",),
    "nases": ("nase",),
    "nasogastrique": ("nasogastrique",),
    "nasogastriques": ("nasogastrique",),
    "nasolabiale": ("nasolabial",),
    "nasolabiales": ("nasolabial",),
    "nasolabial": ("nasolabial",),
    "nasolabiaux": ("nasolabial",),
    "nasopharyngien": ("nasopharyngien",),
    "nasopharyngienne": ("nasopharyngien",),
    "nasopharyngiennes": ("nasopharyngien",),
    "nasopharyngiens": ("nasopharyngien",),
    "nassérien": ("nassérien",),
    "nassérienne": ("nassérien",),
    "nassériennes": ("nassérien",),
    "nassériens": ("nassérien",),
    "nataliste": ("nataliste",),
    "natalistes": ("nataliste",),
    "natatoire": ("natatoire",),
    "natatoires": ("natatoire",),
    "natif": ("natif",),
    "natifs": ("natif",),
    "native": ("natif",),
    "natives": ("natif",),
    "natiforme": ("natiforme",),
    "natiformes": ("natiforme",),
    "nationale": ("national",),
    "nationales": ("national",),
    "national": ("national",),
    "nationaux": ("national",),
    "nationalisable": ("nationalisable",),
    "nationalisables": ("nationalisable",),
    "nationalisateur": ("nationalisateur",),
    "nationalisateurs": ("nationalisateur",),
    "nationalisatrice": ("nationalisateur",),
    "nationalisatrices": ("nationalisateur",),
    "nationaliste": ("nationaliste",),
    "nationalistes": ("nationaliste",),
    "nationalitaire": ("nationalitaire",),
    "nationalitaires": ("nationalitaire",),
    "national-socialiste": ("national-socialiste",),
    "national-socialistes": ("national-socialiste",),
    "nativiste": ("nativiste",),
    "nativistes": ("nativiste",),
    "natolocale": ("natolocal",),
    "natolocales": ("natolocal",),
    "natolocal": ("natolocal",),
    "natolocaux": ("natolocal",),
    "natrique": ("natrique",),
    "natriques": ("natrique",),
    "natriurétique": ("natriurétique",),
    "natriurétiques": ("natriurétique",),
    "nattier": ("nattier",),
    "naturaliste": ("naturaliste",),
    "naturalistes": ("naturaliste",),
    "naturante": ("naturante",),
    "naturantes": ("naturante",),
    "nature": ("nature",),
    "naturelle": ("naturel",),
    "naturelles": ("naturel",),
    "naturel": ("naturel",),
    "naturels": ("naturel",),
    "naturiste": ("naturiste",),
    "naturistes": ("naturiste",),
    "naupathique": ("naupathique",),
    "naupathiques": ("naupathique",),
    "naupliiforme": ("naupliiforme",),
    "naupliiformes": ("naupliiforme",),
    "nauséeuse": ("nauséeux",),
    "nauséeuses": ("nauséeux",),
    "nauséeux": ("nauséeux",),
    "nautique": ("nautique",),
    "nautiques": ("nautique",),
    "navajo": ("navajo",),
    "navajos": ("navajo",),
    "navarraise": ("navarrais",),
    "navarraises": ("navarrais",),
    "navarrais": ("navarrais",),
    "naviculaire": ("naviculaire",),
    "naviculaires": ("naviculaire",),
    "navigable": ("navigable",),
    "navigables": ("navigable",),
    "navigateur": ("navigateur",),
    "navigateurs": ("navigateur",),
    "navigatrice": ("navigateur",),
    "navigatrices": ("navigateur",),
    "navigationnelle": ("navigationnel",),
    "navigationnelles": ("navigationnel",),
    "navigationnel": ("navigationnel",),
    "navigationnels": ("navigationnel",),
    "nazaréen": ("nazaréen",),
    "nazaréenne": ("nazaréen",),
    "nazaréennes": ("nazaréen",),
    "nazaréens": ("nazaréen",),
    "nazca": ("nazca",),
    "nazcas": ("nazca",),
    "naze": ("naze",),
    "nazes": ("naze",),
    "néandertalien": ("néandertalien",),
    "néandertalienne": ("néandertalien",),
    "néandertaliennes": ("néandertalien",),
    "néandertaliens": ("néandertalien",),
    "néandertaloïde": ("néandertaloïde",),
    "néandertaloïdes": ("néandertaloïde",),
    "néanthropien": ("néanthropien",),
    "néanthropienne": ("néanthropien",),
    "néanthropiennes": ("néanthropien",),
    "néanthropiens": ("néanthropien",),
    "nébulaire": ("nébulaire",),
    "nébulaires": ("nébulaire",),
    "nébuleuse": ("nébuleux",),
    "nébuleuses": ("nébuleux",),
    "nébuleux": ("nébuleux",),
    "nécessaire": ("nécessaire",),
    "nécessaires": ("nécessaire",),
    "nécessiteuse": ("nécessiteux",),
    "nécessiteuses": ("nécessiteux",),
    "nécessiteux": ("nécessiteux",),
    "nécrobiotique": ("nécrobiotique",),
    "nécrobiotiques": ("nécrobiotique",),
    "nécrologique": ("nécrologique",),
    "nécrologiques": ("nécrologique",),
    "nécrophage": ("nécrophage",),
    "nécrophages": ("nécrophage",),
    "nécrophile": ("nécrophile",),
    "nécrophiles": ("nécrophile",),
    "nécrophilique": ("nécrophilique",),
    "nécrophiliques": ("nécrophilique",),
    "nécrophobe": ("nécrophobe",),
    "nécrophobes": ("nécrophobe",),
    "nécrophobique": ("nécrophobique",),
    "nécrophobiques": ("nécrophobique",),
    "nécropsique": ("nécropsique",),
    "nécropsiques": ("nécropsique",),
    "nécrosique": ("nécrosique",),
    "nécrosiques": ("nécrosique",),
    "nécrotique": ("nécrotique",),
    "nécrotiques": ("nécrotique",),
    "nectarifère": ("nectarifère",),
    "nectarifères": ("nectarifère",),
    "néerlandaise": ("néerlandais",),
    "néerlandaises": ("néerlandais",),
    "néerlandais": ("néerlandais",),
    "néerlandophone": ("néerlandophone",),
    "néerlandophones": ("néerlandophone",),
    "néfaste": ("néfaste",),
    "néfastes": ("néfaste",),
    "négateur": ("négateur",),
    "négateurs": ("négateur",),
    "négatrice": ("négateur",),
    "négatrices": ("négateur",),
    "négatif": ("négatif",),
    "négatifs": ("négatif",),
    "négative": ("négatif",),
    "négatives": ("négatif",),
    "négationniste": ("négationniste",),
    "négationnistes": ("négationniste",),
    "négativiste": ("négativiste",),
    "négativistes": ("négativiste",),
    "négligeable": ("négligeable",),
    "négligeables": ("négligeable",),
    "négociable": ("négociable",),
    "négociables": ("négociable",),
    "négociateur": ("négociateur",),
    "négociateurs": ("négociateur",),
    "négociatrice": ("négociateur",),
    "négociatrices": ("négociateur",),
    "nègre": ("nègre",),
    "nègres": ("nègre",),
    "négrière": ("négrier",),
    "négrières": ("négrier",),
    "négrier": ("négrier",),
    "négriers": ("négrier",),
    "négro-américain": ("négro-américain",),
    "négro-américains": ("négro-américain",),
    "négroïde": ("négroïde",),
    "négroïdes": ("négroïde",),
    "néguentropique": ("néguentropique",),
    "néguentropiques": ("néguentropique",),
    "neigeuse": ("neigeux",),
    "neigeuses": ("neigeux",),
    "neigeux": ("neigeux",),
    "neisserien": ("neisserien",),
    "neisserienne": ("neisserien",),
    "neisseriennes": ("neisserien",),
    "neisseriens": ("neisserien",),
    "nématicide": ("nématicide",),
    "nématicides": ("nématicide",),
    "nématique": ("nématique",),
    "nématiques": ("nématique",),
    "nématoblastique": ("nématoblastique",),
    "nématoblastiques": ("nématoblastique",),
    "néméen": ("néméen",),
    "néméenne": ("néméen",),
    "néméennes": ("néméen",),
    "néméens": ("néméen",),
    "néoantique": ("néoantique",),
    "néoantiques": ("néoantique",),
    "néoattique": ("néoattique",),
    "néoattiques": ("néoattique",),
    "néo-babylonien": ("néobabylonien",),
    "néo-calédonien": ("néo-calédonien",),
    "néo-calédonienne": ("néo-calédonien",),
    "néo-calédoniens": ("néo-calédonien",),
    "néo-canadien": ("néocanadien",),
    "néo-canadiens": ("néocanadien",),
    "néo-capitaliste": ("néo-capitaliste",),
    "néocapitaliste": ("néocapitaliste",),
    "néo-capitalistes": ("néocapitaliste",),
    "néocapitalistes": ("néocapitaliste",),
    "néocatholique": ("néocatholique",),
    "néocatholiques": ("néocatholique",),
    "néo-celtique": ("néoceltique",),
    "néoceltique": ("néoceltique",),
    "néoceltiques": ("néoceltique",),
    "néo-chrétienne": ("néochrétien",),
    "néoclassique": ("néoclassique",),
    "néo-classiques": ("néoclassique",),
    "néoclassiques": ("néoclassique",),
    "néocoloniale": ("néocolonial",),
    "néocoloniales": ("néocolonial",),
    "néocolonial": ("néocolonial",),
    "néocoloniaux": ("néocolonial",),
    "néo-colonialiste": ("néocolonialiste",),
    "néocolonialiste": ("néocolonialiste",),
    "néocolonialistes": ("néocolonialiste",),
    "néocomien": ("néocomien",),
    "néocomienne": ("néocomien",),
    "néocomiennes": ("néocomien",),
    "néocomiens": ("néocomien",),
    "néoconfucianiste": ("néoconfucianiste",),
    "néoconfucianistes": ("néoconfucianiste",),
    "néocore": ("néocore",),
    "néocores": ("néocore",),
    "néocorticale": ("néocortical",),
    "néocorticales": ("néocortical",),
    "néocortical": ("néocortical",),
    "néocorticaux": ("néocortical",),
    "néo-criticiste": ("néocriticiste",),
    "néo-cubistes": ("néocubiste",),
    "néo-dadaïste": ("néodadaïste",),
    "néodadaïste": ("néodadaïste",),
    "néo-dadaïstes": ("néodadaïste",),
    "néodadaïstes": ("néodadaïste",),
    "néodarwinien": ("néodarwinien",),
    "néodarwinienne": ("néodarwinien",),
    "néodarwiniennes": ("néodarwinien",),
    "néodarwiniens": ("néodarwinien",),
    "néodarwiniste": ("néodarwiniste",),
    "néodarwinistes": ("néodarwiniste",),
    "néo-fasciste": ("néofasciste",),
    "néofasciste": ("néofasciste",),
    "néo-fascistes": ("néofasciste",),
    "néofascistes": ("néofasciste",),
    "néofolklorique": ("néofolklorique",),
    "néofolkloriques": ("néofolklorique",),
    "néogène": ("néogène",),
    "néogènes": ("néogène",),
    "néognathe": ("néognathe",),
    "néognathes": ("néognathe",),
    "néo-gothique": ("néogothique",),
    "néogothique": ("néogothique",),
    "néo-gothiques": ("néogothique",),
    "néogothiques": ("néogothique",),
    "néogrammairien": ("néogrammairien",),
    "néogrammairienne": ("néogrammairien",),
    "néogrammairiennes": ("néogrammairien",),
    "néogrammairiens": ("néogrammairien",),
    "néogrec": ("néogrec",),
    "néogrecque": ("néogrec",),
    "néo-grecques": ("néogrec",),
    "néogrecques": ("néogrec",),
    "néo-grecs": ("néogrec",),
    "néogrecs": ("néogrec",),
    "néo-guinéennes": ("néo-guinéen",),
    "néo-hébridais": ("néo-hébridais",),
    "néohégélien": ("néohégélien",),
    "néo-hégélienne": ("néohégélien",),
    "néohégélienne": ("néohégélien",),
    "néohégéliennes": ("néohégélien",),
    "néo-hégéliens": ("néohégélien",),
    "néohégéliens": ("néohégélien",),
    "néo-hittite": ("néohittite",),
    "néo-impressionniste": ("néo-impressionniste",),
    "néo-impressionnistes": ("néo-impressionniste",),
    "néo-indienne": ("néo-indien",),
    "néo-kantien": ("néokantien",),
    "néokantien": ("néokantien",),
    "néokantienne": ("néokantien",),
    "néokantiennes": ("néokantien",),
    "néo-kantiens": ("néokantien",),
    "néokantiens": ("néokantien",),
    "néo-keynésien": ("néokeynésien",),
    "néo-keynésienne": ("néokeynésien",),
    "néo-keynésiens": ("néokeynésien",),
    "néolamarckien": ("néolamarckien",),
    "néo-lamarckienne": ("néolamarckien",),
    "néolamarckienne": ("néolamarckien",),
    "néolamarckiennes": ("néolamarckien",),
    "néolamarckiens": ("néolamarckien",),
    "néo-libérale": ("néolibéral",),
    "néolibérale": ("néolibéral",),
    "néo-libérales": ("néolibéral",),
    "néolibérales": ("néolibéral",),
    "néo-libéral": ("néolibéral",),
    "néolibéral": ("néolibéral",),
    "néo-libéraux": ("néolibéral",),
    "néolibéraux": ("néolibéral",),
    "néolithique": ("néolithique",),
    "néolithiques": ("néolithique",),
    "néo-locale": ("néolocal",),
    "néolocale": ("néolocal",),
    "néolocales": ("néolocal",),
    "néolocal": ("néolocal",),
    "néolocaux": ("néolocal",),
    "néologique": ("néologique",),
    "néologiques": ("néologique",),
    "néomalthusien": ("néomalthusien",),
    "néo-malthusienne": ("néomalthusien",),
    "néomalthusienne": ("néomalthusien",),
    "néomalthusiennes": ("néomalthusien",),
    "néomalthusiens": ("néomalthusien",),
    "néo-manichéen": ("néomanichéen",),
    "néo-manichéens": ("néomanichéen",),
    "néomercantiliste": ("néomercantiliste",),
    "néomercantilistes": ("néomercantiliste",),
    "néonatalogique": ("néonatalogique",),
    "néonatalogiques": ("néonatalogique",),
    "néo-nazie": ("néonazi",),
    "néonazie": ("néonazi",),
    "néo-nazies": ("néonazi",),
    "néonazies": ("néonazi",),
    "néo-nazi": ("néonazi",),
    "néonazi": ("néonazi",),
    "néo-nazis": ("néonazi",),
    "néonazis": ("néonazi",),
    "néopentylique": ("néopentylique",),
    "néopentyliques": ("néopentylique",),
    "néophobique": ("néophobique",),
    "néophobiques": ("néophobique",),
    "néophyte": ("néophyte",),
    "néophytes": ("néophyte",),
    "néoplasique": ("néoplasique",),
    "néoplasiques": ("néoplasique",),
    "néoplastique": ("néoplastique",),
    "néoplastiques": ("néoplastique",),
    "néo-platonicien": ("néoplatonicien",),
    "néoplatonicien": ("néoplatonicien",),
    "néo-platonicienne": ("néoplatonicien",),
    "néoplatonicienne": ("néoplatonicien",),
    "néoplatoniciennes": ("néoplatonicien",),
    "néo-platoniciens": ("néoplatonicien",),
    "néoplatoniciens": ("néoplatonicien",),
    "néopositiviste": ("néopositiviste",),
    "néo-positivistes": ("néopositiviste",),
    "néopositivistes": ("néopositiviste",),
    "néoprimitiviste": ("néoprimitiviste",),
    "néoprimitivistes": ("néoprimitiviste",),
    "néoprotectionniste": ("néoprotectionniste",),
    "néo-protectionnistes": ("néo-protectionniste",),
    "néoprotectionnistes": ("néoprotectionniste",),
    "néo-provencales": ("néoprovencal",),
    "néoptère": ("néoptère",),
    "néoptères": ("néoptère",),
    "néoptile": ("néoptile",),
    "néoptiles": ("néoptile",),
    "néopythagoricien": ("néopythagoricien",),
    "néopythagoricienne": ("néopythagoricien",),
    "néo-pythagoriciennes": ("néopythagoricien",),
    "néopythagoriciennes": ("néopythagoricien",),
    "néopythagoriciens": ("néopythagoricien",),
    "néo-réaliste": ("néoréaliste",),
    "néoréaliste": ("néoréaliste",),
    "néoréalistes": ("néoréaliste",),
    "néo-romantique": ("néoromantique",),
    "néoromantique": ("néoromantique",),
    "néoromantiques": ("néoromantique",),
    "néorurale": ("néorural",),
    "néorurales": ("néorural",),
    "néorural": ("néorural",),
    "néoruraux": ("néorural",),
    "néostalinien": ("néostalinien",),
    "néostalinienne": ("néostalinien",),
    "néostaliniennes": ("néostalinien",),
    "néostaliniens": ("néostalinien",),
    "néoténique": ("néoténique",),
    "néoténiques": ("néoténique",),
    "néotestamentaire": ("néotestamentaire",),
    "néotestamentaires": ("néotestamentaire",),
    "néothomiste": ("néothomiste",),
    "néothomistes": ("néothomiste",),
    "néototalitaire": ("néototalitaire",),
    "néototalitaires": ("néototalitaire",),
    "néotropicale": ("néotropical",),
    "néotropicales": ("néotropical",),
    "néotropical": ("néotropical",),
    "néotropicaux": ("néotropical",),
    "néovitaliste": ("néovitaliste",),
    "néovitalistes": ("néovitaliste",),
    "néo-zélandaise": ("néo-zélandais",),
    "néozélandaise": ("néozélandais",),
    "néozélandaises": ("néozélandais",),
    "néo-zélandais": ("néo-zélandais",),
    "néozélandais": ("néozélandais",),
    "néozoïque": ("néozoïque",),
    "néozoïques": ("néozoïque",),
    "népalaise": ("népalais",),
    "népalaises": ("népalais",),
    "népalais": ("népalais",),
    "népérien": ("népérien",),
    "népérienne": ("népérien",),
    "népériennes": ("népérien",),
    "népériens": ("népérien",),
    "néphélinique": ("néphélinique",),
    "néphéliniques": ("néphélinique",),
    "néphrétique": ("néphrétique",),
    "néphrétiques": ("néphrétique",),
    "néphridique": ("néphridique",),
    "néphridiques": ("néphridique",),
    "néphrogène": ("néphrogène",),
    "néphrogènes": ("néphrogène",),
    "néphrologique": ("néphrologique",),
    "néphrologiques": ("néphrologique",),
    "néphropathique": ("néphropathique",),
    "néphropathiques": ("néphropathique",),
    "néphrosclérotique": ("néphrosclérotique",),
    "néphrosclérotiques": ("néphrosclérotique",),
    "néphrotique": ("néphrotique",),
    "néphrotiques": ("néphrotique",),
    "néphrotoxique": ("néphrotoxique",),
    "néphrotoxiques": ("néphrotoxique",),
    "neptuniste": ("neptuniste",),
    "neptunistes": ("neptuniste",),
    "néritique": ("néritique",),
    "néritiques": ("néritique",),
    "néronien": ("néronien",),
    "néronienne": ("néronien",),
    "néroniennes": ("néronien",),
    "néroniens": ("néronien",),
    "nervale": ("nerval",),
    "nervales": ("nerval",),
    "nerval": ("nerval",),
    "nervaux": ("nerval",),
    "nerveuse": ("nerveux",),
    "nerveuses": ("nerveux",),
    "nerveux": ("nerveux",),
    "nervomoteur": ("nervomoteur",),
    "nervomoteurs": ("nervomoteur",),
    "nervomotrice": ("nervomoteur",),
    "nervomotrices": ("nervomoteur",),
    "nestorien": ("nestorien",),
    "nestorienne": ("nestorien",),
    "nestoriennes": ("nestorien",),
    "nestoriens": ("nestorien",),
    "net": ("net",),
    "nets": ("net",),
    "nette": ("net",),
    "nettes": ("net",),
    "nettoyable": ("nettoyable",),
    "nettoyables": ("nettoyable",),
    "nettoyeur": ("nettoyeur",),
    "nettoyeurs": ("nettoyeur",),
    "nettoyeuse": ("nettoyeur",),
    "nettoyeuses": ("nettoyeur",),
    "neuf": ("neuf",),
    "neufs": ("neuf",),
    "neuve": ("neuf",),
    "neuves": ("neuf",),
    "neumatique": ("neumatique",),
    "neumatiques": ("neumatique",),
    "neurale": ("neural",),
    "neurales": ("neural",),
    "neural": ("neural",),
    "neuraux": ("neural",),
    "neuraminique": ("neuraminique",),
    "neuraminiques": ("neuraminique",),
    "neurasthénique": ("neurasthénique",),
    "neurasthéniques": ("neurasthénique",),
    "neuritique": ("neuritique",),
    "neuritiques": ("neuritique",),
    "neuro-analeptique": ("neuro-analeptique",),
    "neuro-anatomique": ("neuroanatomique",),
    "neuroanémique": ("neuroanémique",),
    "neuroanémiques": ("neuroanémique",),
    "neurobiochimique": ("neurobiochimique",),
    "neurobiochimiques": ("neurobiochimique",),
    "neurobiologique": ("neurobiologique",),
    "neurobiologiques": ("neurobiologique",),
    "neurochimique": ("neurochimique",),
    "neurochimiques": ("neurochimique",),
    "neurochirurgicale": ("neurochirurgical",),
    "neurochirurgicales": ("neurochirurgical",),
    "neurochirurgical": ("neurochirurgical",),
    "neurochirurgicaux": ("neurochirurgical",),
    "neurocytologique": ("neurocytologique",),
    "neurocytologiques": ("neurocytologique",),
    "neurodégénératif": ("neurodégénératif",),
    "neurodégénératifs": ("neurodégénératif",),
    "neurodégénérative": ("neurodégénératif",),
    "neurodégénératives": ("neurodégénératif",),
    "neurodépresseur": ("neurodépresseur",),
    "neurodépresseurs": ("neurodépresseur",),
    "neurodysleptique": ("neurodysleptique",),
    "neurodysleptiques": ("neurodysleptique",),
    "neurodysraphique": ("neurodysraphique",),
    "neurodysraphiques": ("neurodysraphique",),
    "neuroectodermique": ("neuroectodermique",),
    "neuroectodermiques": ("neuroectodermique",),
    "neuro-effecteurs": ("neuro-effecteur",),
    "neuro-endocrinien": ("neuroendocrinien",),
    "neuroendocrinien": ("neuroendocrinien",),
    "neuroendocrinienne": ("neuroendocrinien",),
    "neuroendocriniennes": ("neuroendocrinien",),
    "neuro-endocriniens": ("neuroendocrinien",),
    "neuroendocriniens": ("neuroendocrinien",),
    "neuroéthologique": ("neuroéthologique",),
    "neuroéthologiques": ("neuroéthologique",),
    "neurofibrillaire": ("neurofibrillaire",),
    "neurofibrillaires": ("neurofibrillaire",),
    "neurofibromateuse": ("neurofibromateux",),
    "neurofibromateuses": ("neurofibromateux",),
    "neurofibromateux": ("neurofibromateux",),
    "neurogène": ("neurogène",),
    "neurogènes": ("neurogène",),
    "neurogénique": ("neurogénique",),
    "neurogéniques": ("neurogénique",),
    "neurohistologique": ("neurohistologique",),
    "neurohistologiques": ("neurohistologique",),
    "neurohormonale": ("neurohormonal",),
    "neurohormonales": ("neurohormonal",),
    "neurohormonal": ("neurohormonal",),
    "neurohormonaux": ("neurohormonal",),
    "neurohumorale": ("neurohumoral",),
    "neurohumorales": ("neurohumoral",),
    "neuro-humoral": ("neurohumoral",),
    "neurohumoral": ("neurohumoral",),
    "neuro-humoraux": ("neurohumoral",),
    "neurohumoraux": ("neurohumoral",),
    "neuro-immunologiques": ("neuro-immunologique",),
    "neuroleptique": ("neuroleptique",),
    "neuroleptiques": ("neuroleptique",),
    "neurolinguistique": ("neurolinguistique",),
    "neurolinguistiques": ("neurolinguistique",),
    "neurologique": ("neurologique",),
    "neurologiques": ("neurologique",),
    "neurolytique": ("neurolytique",),
    "neurolytiques": ("neurolytique",),
    "neuromimétique": ("neuromimétique",),
    "neuromimétiques": ("neuromimétique",),
    "neuromusculaire": ("neuromusculaire",),
    "neuromusculaires": ("neuromusculaire",),
    "neuronale": ("neuronal",),
    "neuronales": ("neuronal",),
    "neuronal": ("neuronal",),
    "neuronaux": ("neuronal",),
    "neuronique": ("neuronique",),
    "neuroniques": ("neuronique",),
    "neuropathique": ("neuropathique",),
    "neuropathiques": ("neuropathique",),
    "neuropathologique": ("neuropathologique",),
    "neuropathologiques": ("neuropathologique",),
    "neuropeptidique": ("neuropeptidique",),
    "neuropeptidiques": ("neuropeptidique",),
    "neuropharmacologique": ("neuropharmacologique",),
    "neuropharmacologiques": ("neuropharmacologique",),
    "neurophylactique": ("neurophylactique",),
    "neurophylactiques": ("neurophylactique",),
    "neurophysiologique": ("neurophysiologique",),
    "neurophysiologiques": ("neurophysiologique",),
    "neuroplégique": ("neuroplégique",),
    "neuroplégiques": ("neuroplégique",),
    "neuropsychiatrique": ("neuropsychiatrique",),
    "neuropsychiatriques": ("neuropsychiatrique",),
    "neuropsychique": ("neuropsychique",),
    "neuropsychiques": ("neuropsychique",),
    "neuropsychogène": ("neuropsychogène",),
    "neuropsychogènes": ("neuropsychogène",),
    "neuropsychologique": ("neuropsychologique",),
    "neuropsychologiques": ("neuropsychologique",),
    "neuropsychométrique": ("neuropsychométrique",),
    "neuropsychométriques": ("neuropsychométrique",),
    "neuropsychosensorielle": ("neuropsychosensoriel",),
    "neuropsychosensorielles": ("neuropsychosensoriel",),
    "neuropsychosensoriel": ("neuropsychosensoriel",),
    "neuropsychosensoriels": ("neuropsychosensoriel",),
    "neuroradiologique": ("neuroradiologique",),
    "neuroradiologiques": ("neuroradiologique",),
    "neurorécepteur": ("neurorécepteur",),
    "neurorécepteurs": ("neurorécepteur",),
    "neuroréceptrice": ("neurorécepteur",),
    "neuroréceptrices": ("neurorécepteur",),
    "neurosécréteur": ("neurosécréteur",),
    "neurosécréteurs": ("neurosécréteur",),
    "neurosécrétrice": ("neurosécréteur",),
    "neurosécrétrices": ("neurosécréteur",),
    "neurosécrétoire": ("neurosécrétoire",),
    "neurosécrétoires": ("neurosécrétoire",),
    "neurosensorielle": ("neurosensoriel",),
    "neurosensorielles": ("neurosensoriel",),
    "neurosensoriel": ("neurosensoriel",),
    "neurosensoriels": ("neurosensoriel",),
    "neurotachycardique": ("neurotachycardique",),
    "neurotachycardiques": ("neurotachycardique",),
    "neurotendineuse": ("neurotendineux",),
    "neurotendineuses": ("neurotendineux",),
    "neurotendineux": ("neurotendineux",),
    "neurotoninergique": ("neurotoninergique",),
    "neurotoninergiques": ("neurotoninergique",),
    "neurotonique": ("neurotonique",),
    "neurotoniques": ("neurotonique",),
    "neurotoxique": ("neurotoxique",),
    "neurotoxiques": ("neurotoxique",),
    "neurotrope": ("neurotrope",),
    "neurotropes": ("neurotrope",),
    "neurotrophique": ("neurotrophique",),
    "neurotrophiques": ("neurotrophique",),
    "neurotropique": ("neurotropique",),
    "neurotropiques": ("neurotropique",),
    "neurovasculaire": ("neurovasculaire",),
    "neurovasculaires": ("neurovasculaire",),
    "neurovégétatif": ("neurovégétatif",),
    "neurovégétatifs": ("neurovégétatif",),
    "neuro-végétative": ("neurovégétatif",),
    "neurovégétative": ("neurovégétatif",),
    "neurovégétatives": ("neurovégétatif",),
    "neuro-viscéral": ("neuroviscéral",),
    "neustrien": ("neustrien",),
    "neustrienne": ("neustrien",),
    "neustriennes": ("neustrien",),
    "neustriens": ("neustrien",),
    "neutralisable": ("neutralisable",),
    "neutralisables": ("neutralisable",),
    "neutraliste": ("neutraliste",),
    "neutralistes": ("neutraliste",),
    "neutre": ("neutre",),
    "neutres": ("neutre",),
    "neutrinique": ("neutrinique",),
    "neutriniques": ("neutrinique",),
    "neutronique": ("neutronique",),
    "neutroniques": ("neutronique",),
    "neutropénique": ("neutropénique",),
    "neutropéniques": ("neutropénique",),
    "neutrophile": ("neutrophile",),
    "neutrophiles": ("neutrophile",),
    "neuvième": ("neuvième",),
    "neuvièmes": ("neuvième",),
    "neuvien": ("neuvien",),
    "neuvienne": ("neuvien",),
    "neuviennes": ("neuvien",),
    "neuviens": ("neuvien",),
    "neuvier": ("neuvier",),
    "neuviers": ("neuvier",),
    "névralgique": ("névralgique",),
    "névralgiques": ("névralgique",),
    "névraxitique": ("névraxitique",),
    "névraxitiques": ("névraxitique",),
    "névritique": ("névritique",),
    "névritiques": ("névritique",),
    "névrobalistique": ("névrobalistique",),
    "névrobalistiques": ("névrobalistique",),
    "névrogliale": ("névroglial",),
    "névrogliales": ("névroglial",),
    "névroglial": ("névroglial",),
    "névrogliaux": ("névroglial",),
    "névroglique": ("névroglique",),
    "névrogliques": ("névroglique",),
    "névropathe": ("névropathe",),
    "névropathes": ("névropathe",),
    "névropathique": ("névropathique",),
    "névropathiques": ("névropathique",),
    "névroptère": ("névroptère",),
    "névroptères": ("névroptère",),
    "névrosthénique": ("névrosthénique",),
    "névrosthéniques": ("névrosthénique",),
    "névrotique": ("névrotique",),
    "névrotiques": ("névrotique",),
    "newtonien": ("newtonien",),
    "newtonienne": ("newtonien",),
    "newtoniennes": ("newtonien",),
    "newtoniens": ("newtonien",),
    "niable": ("niable",),
    "niables": ("niable",),
    "niagaresque": ("niagaresque",),
    "niagaresques": ("niagaresque",),
    "niaise": ("niais",),
    "niaises": ("niais",),
    "niais": ("niais",),
    "niaiseuse": ("niaiseux",),
    "niaiseuses": ("niaiseux",),
    "niaiseux": ("niaiseux",),
    "nicaraguaise": ("nicaraguais",),
    "nicaraguaises": ("nicaraguais",),
    "nicaraguais": ("nicaraguais",),
    "nicaraguayen": ("nicaraguayen",),
    "nicaraguayenne": ("nicaraguayen",),
    "nicaraguayennes": ("nicaraguayen",),
    "nicaraguayens": ("nicaraguayen",),
    "nicheur": ("nicheur",),
    "nicheurs": ("nicheur",),
    "nicheuse": ("nicheur",),
    "nicheuses": ("nicheur",),
    "nickel": ("nickel",),
    "nickélifère": ("nickélifère",),
    "nickélifères": ("nickélifère",),
    "nickélique": ("nickélique",),
    "nickéliques": ("nickélique",),
    "nicobaraise": ("nicobarais",),
    "nicobaraises": ("nicobarais",),
    "nicobarais": ("nicobarais",),
    "niçoise": ("niçois",),
    "niçoises": ("niçois",),
    "niçois": ("niçois",),
    "nicotinique": ("nicotinique",),
    "nicotiniques": ("nicotinique",),
    "nicotique": ("nicotique",),
    "nicotiques": ("nicotique",),
    "nidamentaire": ("nidamentaire",),
    "nidamentaires": ("nidamentaire",),
    "nidicole": ("nidicole",),
    "nidicoles": ("nidicole",),
    "nidificateur": ("nidificateur",),
    "nidificateurs": ("nidificateur",),
    "nidificatrice": ("nidificateur",),
    "nidificatrices": ("nidificateur",),
    "nidifuge": ("nidifuge",),
    "nidifuges": ("nidifuge",),
    "nidoreuse": ("nidoreux",),
    "nidoreuses": ("nidoreux",),
    "nidoreux": ("nidoreux",),
    "nidorien": ("nidorien",),
    "nidorienne": ("nidorien",),
    "nidoriennes": ("nidorien",),
    "nidoriens": ("nidorien",),
    "nième": ("nième",),
    "nièmes": ("nième",),
    "nietzschéen": ("nietzschéen",),
    "nietzschéenne": ("nietzschéen",),
    "nietzschéennes": ("nietzschéen",),
    "nietzschéens": ("nietzschéen",),
    "niflumique": ("niflumique",),
    "niflumiques": ("niflumique",),
    "nigérien": ("nigérien",),
    "nigérienne": ("nigérien",),
    "nigériennes": ("nigérien",),
    "nigériens": ("nigérien",),
    "nigéro-congolais": ("nigéro-congolais",),
    "nigrique": ("nigrique",),
    "nigriques": ("nigrique",),
    "nigritique": ("nigritique",),
    "nigritiques": ("nigritique",),
    "nihiliste": ("nihiliste",),
    "nihilistes": ("nihiliste",),
    "nilotique": ("nilotique",),
    "nilotiques": ("nilotique",),
    "nîmoise": ("nîmois",),
    "nîmoises": ("nîmois",),
    "nîmois": ("nîmois",),
    "niobique": ("niobique",),
    "niobiques": ("niobique",),
    "niortaise": ("niortais",),
    "niortaises": ("niortais",),
    "niortais": ("niortais",),
    "niquedouille": ("niquedouille",),
    "niquedouilles": ("niquedouille",),
    "nirvanesque": ("nirvanesque",),
    "nirvanesques": ("nirvanesque",),
    "nitreuse": ("nitreux",),
    "nitreuses": ("nitreux",),
    "nitreux": ("nitreux",),
    "nitrificateur": ("nitrificateur",),
    "nitrificateurs": ("nitrificateur",),
    "nitrificatrice": ("nitrificateur",),
    "nitrificatrices": ("nitrificateur",),
    "nitrilotriacétique": ("nitrilotriacétique",),
    "nitrilotriacétiques": ("nitrilotriacétique",),
    "nitrique": ("nitrique",),
    "nitriques": ("nitrique",),
    "nitrobenzoïque": ("nitrobenzoïque",),
    "nitrobenzoïques": ("nitrobenzoïque",),
    "nitrocellulosique": ("nitrocellulosique",),
    "nitrocellulosiques": ("nitrocellulosique",),
    "nitromolybdique": ("nitromolybdique",),
    "nitromolybdiques": ("nitromolybdique",),
    "nitronique": ("nitronique",),
    "nitroniques": ("nitronique",),
    "nitrophile": ("nitrophile",),
    "nitrophiles": ("nitrophile",),
    "nitrosulfonique": ("nitrosulfonique",),
    "nitrosulfoniques": ("nitrosulfonique",),
    "nivale": ("nival",),
    "nivales": ("nival",),
    "nival": ("nival",),
    "nivaux": ("nival",),
    "nivéale": ("nivéal",),
    "nivéales": ("nivéal",),
    "nivéal": ("nivéal",),
    "nivéaux": ("nivéal",),
    "niveleur": ("niveleur",),
    "niveleurs": ("niveleur",),
    "niveleuse": ("niveleur",),
    "niveleuses": ("niveleur",),
    "nivernaise": ("nivernais",),
    "nivernaises": ("nivernais",),
    "nivernais": ("nivernais",),
    "nivoglaciaire": ("nivoglaciaire",),
    "nivo-glaciaires": ("nivo-glaciaire",),
    "nivoglaciaires": ("nivoglaciaire",),
    "nivométrique": ("nivométrique",),
    "nivométriques": ("nivométrique",),
    "nivopluviale": ("nivopluvial",),
    "nivo-pluviales": ("nivo-pluvial",),
    "nivopluviales": ("nivopluvial",),
    "nivo-pluvial": ("nivopluvial",),
    "nivopluvial": ("nivopluvial",),
    "nivo-pluviaux": ("nivopluvial",),
    "nivopluviaux": ("nivopluvial",),
    "nobélisable": ("nobélisable",),
    "nobélisables": ("nobélisable",),
    "nobiliaire": ("nobiliaire",),
    "nobiliaires": ("nobiliaire",),
    "noble": ("noble",),
    "nobles": ("noble",),
    "noceur": ("noceur",),
    "noceurs": ("noceur",),
    "noceuse": ("noceur",),
    "noceuses": ("noceur",),
    "nociceptif": ("nociceptif",),
    "nociceptifs": ("nociceptif",),
    "nociceptive": ("nociceptif",),
    "nociceptives": ("nociceptif",),
    "nocif": ("nocif",),
    "nocifs": ("nocif",),
    "nocive": ("nocif",),
    "nocives": ("nocif",),
    "noctambule": ("noctambule",),
    "noctambules": ("noctambule",),
    "noctiluque": ("noctiluque",),
    "noctiluques": ("noctiluque",),
    "nocturne": ("nocturne",),
    "nocturnes": ("nocturne",),
    "nodale": ("nodal",),
    "nodales": ("nodal",),
    "nodal": ("nodal",),
    "nodaux": ("nodal",),
    "nodo-hissien": ("nodo-hissien",),
    "nodo-hissiens": ("nodo-hissien",),
    "nodulaire": ("nodulaire",),
    "nodulaires": ("nodulaire",),
    "noduleuse": ("noduleux",),
    "noduleuses": ("noduleux",),
    "noduleux": ("noduleux",),
    "noématique": ("noématique",),
    "noématiques": ("noématique",),
    "noétique": ("noétique",),
    "noétiques": ("noétique",),
    "noirâtre": ("noirâtre",),
    "noirâtres": ("noirâtre",),
    "noisette": ("noisette",),
    "nomade": ("nomade",),
    "nomades": ("nomade",),
    "nomadique": ("nomadique",),
    "nomadiques": ("nomadique",),
    "nombrable": ("nombrable",),
    "nombrables": ("nombrable",),
    "nombreuse": ("nombreux",),
    "nombreuses": ("nombreux",),
    "nombreux": ("nombreux",),
    "nombriliste": ("nombriliste",),
    "nombrilistes": ("nombriliste",),
    "nomenclateur": ("nomenclateur",),
    "nomenclateurs": ("nomenclateur",),
    "nomenclatrice": ("nomenclateur",),
    "nomenclatrices": ("nomenclateur",),
    "nomenklaturiste": ("nomenklaturiste",),
    "nomenklaturistes": ("nomenklaturiste",),
    "nominable": ("nominable",),
    "nominables": ("nominable",),
    "nominale": ("nominal",),
    "nominales": ("nominal",),
    "nominal": ("nominal",),
    "nominaux": ("nominal",),
    "nominalisable": ("nominalisable",),
    "nominalisables": ("nominalisable",),
    "nominaliste": ("nominaliste",),
    "nominalistes": ("nominaliste",),
    "nominatif": ("nominatif",),
    "nominatifs": ("nominatif",),
    "nominative": ("nominatif",),
    "nominatives": ("nominatif",),
    "nomographique": ("nomographique",),
    "nomographiques": ("nomographique",),
    "nomologique": ("nomologique",),
    "nomologiques": ("nomologique",),
    "nonagénaire": ("nonagénaire",),
    "nonagénaires": ("nonagénaire",),
    "nonagésime": ("nonagésime",),
    "nonagésimes": ("nonagésime",),
    "non-alignée": ("non-aligné",),
    "nonalignée": ("nonaligné",),
    "nonalignées": ("nonaligné",),
    "non-aligné": ("non-aligné",),
    "nonaligné": ("nonaligné",),
    "non-alignés": ("non-aligné",),
    "nonalignés": ("nonaligné",),
    "non-animées": ("non-animé",),
    "non-animé": ("non-animé",),
    "non-animés": ("non-animé",),
    "nonanoïque": ("nonanoïque",),
    "nonanoïques": ("nonanoïque",),
    "nonantième": ("nonantième",),
    "nonantièmes": ("nonantième",),
    "non-belligérante": ("non-belligérant",),
    "non-combattant": ("non-combattant",),
    "non-combattants": ("non-combattant",),
    "non-comptable": ("non-comptable",),
    "non-conformiste": ("non-conformiste",),
    "non-conformistes": ("non-conformiste",),
    "non-croyantes": ("non-croyant",),
    "non-croyant": ("non-croyant",),
    "non-croyants": ("non-croyant",),
    "non-dénombrables": ("non-dénombrable",),
    "non-dense": ("non-dense",),
    "non-destructifs": ("non-destructif",),
    "non-directif": ("non-directif",),
    "non-directives": ("non-directif",),
    "non-émotive": ("non-émotif",),
    "nonengagée": ("nonengagé",),
    "non-engagées": ("non-engagé",),
    "nonengagées": ("nonengagé",),
    "nonengagé": ("nonengagé",),
    "nonengagés": ("nonengagé",),
    "non-figuratif": ("non-figuratif",),
    "non-figurative": ("non-figuratif",),
    "non-initiées": ("non-initié",),
    "non-initié": ("non-initié",),
    "non-initiés": ("non-initié",),
    "non-inscrite": ("non-inscrit",),
    "non-inscrit": ("non-inscrit",),
    "non-inscrits": ("non-inscrit",),
    "non-logiques": ("non-logique",),
    "non-marchandes": ("non-marchand",),
    "non-marchand": ("non-marchand",),
    "non-nasales": ("non-nasal",),
    "non-officielles": ("non-officiel",),
    "non-officiel": ("non-officiel",),
    "non-officiels": ("non-officiel",),
    "nonpareille": ("nonpareil",),
    "nonpareilles": ("nonpareil",),
    "nonpareil": ("nonpareil",),
    "nonpareils": ("nonpareil",),
    "non-polluant": ("non-polluant",),
    "non-polluants": ("non-polluant",),
    "non-professionnelle": ("non-professionnel",),
    "non-rétroactifs": ("non-rétroactif",),
    "non-sédentaires": ("non-sédentaire",),
    "non-spécialiste": ("non-spécialiste",),
    "non-spécialistes": ("non-spécialiste",),
    "non-syndiquées": ("non-syndiqué",),
    "non-syndiqués": ("non-syndiqué",),
    "non-violente": ("non-violent",),
    "non-violentes": ("non-violent",),
    "non-violent": ("non-violent",),
    "non-violents": ("non-violent",),
    "nonylique": ("nonylique",),
    "nonyliques": ("nonylique",),
    "noo-analeptiques": ("noo-analeptique",),
    "noologique": ("noologique",),
    "noologiques": ("noologique",),
    "nootrope": ("nootrope",),
    "nootropes": ("nootrope",),
    "noradrénergique": ("noradrénergique",),
    "noradrénergiques": ("noradrénergique",),
    "nord-africaine": ("nord-africain",),
    "nord-africain": ("nord-africain",),
    "nord-africains": ("nord-africain",),
    "nord-américaine": ("nord-américain",),
    "nord-américaines": ("nord-américain",),
    "nord-américain": ("nord-américain",),
    "nord-américains": ("nord-américain",),
    "nord": ("nord",),
    "nord-coréen": ("nord-coréen",),
    "nord-coréenne": ("nord-coréen",),
    "nord-coréennes": ("nord-coréen",),
    "nord-coréens": ("nord-coréen",),
    "nordique": ("nordique",),
    "nordiques": ("nordique",),
    "nordiste": ("nordiste",),
    "nordistes": ("nordiste",),
    "nord-vietnamien": ("nord-vietnamien",),
    "nord-vietnamiens": ("nord-vietnamien",),
    "normable": ("normable",),
    "normables": ("normable",),
    "normale": ("normal",),
    "normales": ("normal",),
    "normal": ("normal",),
    "normaux": ("normal",),
    "normalisateur": ("normalisateur",),
    "normalisateurs": ("normalisateur",),
    "normalisatrice": ("normalisateur",),
    "normalisatrices": ("normalisateur",),
    "normannien": ("normannien",),
    "normannienne": ("normannien",),
    "normanniennes": ("normannien",),
    "normanniens": ("normannien",),
    "normatif": ("normatif",),
    "normatifs": ("normatif",),
    "normative": ("normatif",),
    "normatives": ("normatif",),
    "normativiste": ("normativiste",),
    "normativistes": ("normativiste",),
    "normobare": ("normobare",),
    "normobares": ("normobare",),
    "normoblastique": ("normoblastique",),
    "normoblastiques": ("normoblastique",),
    "normochrome": ("normochrome",),
    "normochromes": ("normochrome",),
    "normocytaire": ("normocytaire",),
    "normocytaires": ("normocytaire",),
    "normodrome": ("normodrome",),
    "normodromes": ("normodrome",),
    "normokaliémique": ("normokaliémique",),
    "normokaliémiques": ("normokaliémique",),
    "normopondérale": ("normopondéral",),
    "normopondérales": ("normopondéral",),
    "normopondéral": ("normopondéral",),
    "normopondéraux": ("normopondéral",),
    "normothymique": ("normothymique",),
    "normothymiques": ("normothymique",),
    "normotope": ("normotope",),
    "normotopes": ("normotope",),
    "normovolémique": ("normovolémique",),
    "normovolémiques": ("normovolémique",),
    "norroise": ("norrois",),
    "norroises": ("norrois",),
    "norrois": ("norrois",),
    "norvégien": ("norvégien",),
    "norvégienne": ("norvégien",),
    "norvégiennes": ("norvégien",),
    "norvégiens": ("norvégien",),
    "nosocomiale": ("nosocomial",),
    "nosocomiales": ("nosocomial",),
    "nosocomial": ("nosocomial",),
    "nosocomiaux": ("nosocomial",),
    "nosographique": ("nosographique",),
    "nosographiques": ("nosographique",),
    "nosologique": ("nosologique",),
    "nosologiques": ("nosologique",),
    "nostalgique": ("nostalgique",),
    "nostalgiques": ("nostalgique",),
    "notable": ("notable",),
    "notables": ("notable",),
    "notariale": ("notarial",),
    "notariales": ("notarial",),
    "notarial": ("notarial",),
    "notariaux": ("notarial",),
    "notencéphale": ("notencéphale",),
    "notencéphales": ("notencéphale",),
    "notificateur": ("notificateur",),
    "notificateurs": ("notificateur",),
    "notificatrice": ("notificateur",),
    "notificatrices": ("notificateur",),
    "notificatif": ("notificatif",),
    "notificatifs": ("notificatif",),
    "notificative": ("notificatif",),
    "notificatives": ("notificatif",),
    "notionnelle": ("notionnel",),
    "notionnelles": ("notionnel",),
    "notionnel": ("notionnel",),
    "notionnels": ("notionnel",),
    "notoire": ("notoire",),
    "notoires": ("notoire",),
    "nôtre": ("nôtre",),
    "nôtres": ("nôtre",),
    "noueuse": ("noueux",),
    "noueuses": ("noueux",),
    "noueux": ("noueux",),
    "nouménale": ("nouménal",),
    "nouménales": ("nouménal",),
    "nouménal": ("nouménal",),
    "nouménaux": ("nouménal",),
    "nourricière": ("nourricier",),
    "nourricières": ("nourricier",),
    "nourricier": ("nourricier",),
    "nourriciers": ("nourricier",),
    "nouveau": ("nouveau",),
    "nouveaux": ("nouveau",),
    "nouvelle": ("nouveau",),
    "nouvelles": ("nouveau",),
    "nouvel": ("nouvel",),
    "novateur": ("novateur",),
    "novateurs": ("novateur",),
    "novatrice": ("novateur",),
    "novatrices": ("novateur",),
    "novatoire": ("novatoire",),
    "novatoires": ("novatoire",),
    "novice": ("novice",),
    "novices": ("novice",),
    "noxale": ("noxal",),
    "noxales": ("noxal",),
    "noxal": ("noxal",),
    "noxaux": ("noxal",),
    "nuageuse": ("nuageux",),
    "nuageuses": ("nuageux",),
    "nuageux": ("nuageux",),
    "nubien": ("nubien",),
    "nubienne": ("nubien",),
    "nubiennes": ("nubien",),
    "nubiens": ("nubien",),
    "nubile": ("nubile",),
    "nubiles": ("nubile",),
    "nucale": ("nucal",),
    "nucales": ("nucal",),
    "nucal": ("nucal",),
    "nucaux": ("nucal",),
    "nucellaire": ("nucellaire",),
    "nucellaires": ("nucellaire",),
    "nuchale": ("nuchal",),
    "nuchales": ("nuchal",),
    "nuchal": ("nuchal",),
    "nuchaux": ("nuchal",),
    "nucifère": ("nucifère",),
    "nucifères": ("nucifère",),
    "nuciforme": ("nuciforme",),
    "nuciformes": ("nuciforme",),
    "nucléaire": ("nucléaire",),
    "nucléaires": ("nucléaire",),
    "nucléique": ("nucléique",),
    "nucléiques": ("nucléique",),
    "nucléocytoplasmique": ("nucléocytoplasmique",),
    "nucléocytoplasmiques": ("nucléocytoplasmique",),
    "nucléoélectrique": ("nucléoélectrique",),
    "nucléoélectriques": ("nucléoélectrique",),
    "nucléonique": ("nucléonique",),
    "nucléoniques": ("nucléonique",),
    "nucléophile": ("nucléophile",),
    "nucléophiles": ("nucléophile",),
    "nucléoplasmique": ("nucléoplasmique",),
    "nucléoplasmiques": ("nucléoplasmique",),
    "nucléothermique": ("nucléothermique",),
    "nucléothermiques": ("nucléothermique",),
    "nucléotidique": ("nucléotidique",),
    "nucléotidiques": ("nucléotidique",),
    "nudiste": ("nudiste",),
    "nudistes": ("nudiste",),
    "nuisible": ("nuisible",),
    "nuisibles": ("nuisible",),
    "nulle": ("nul",),
    "nulles": ("nul",),
    "nul": ("nul",),
    "nuls": ("nul",),
    "nullipare": ("nullipare",),
    "nullipares": ("nullipare",),
    "numéraire": ("numéraire",),
    "numéraires": ("numéraire",),
    "numérale": ("numéral",),
    "numérales": ("numéral",),
    "numéral": ("numéral",),
    "numéraux": ("numéral",),
    "numérateur": ("numérateur",),
    "numérateurs": ("numérateur",),
    "numératrice": ("numérateur",),
    "numératrices": ("numérateur",),
    "numératif": ("numératif",),
    "numératifs": ("numératif",),
    "numérative": ("numératif",),
    "numératives": ("numératif",),
    "numérique": ("numérique",),
    "numériques": ("numérique",),
    "numéroteur": ("numéroteur",),
    "numéroteurs": ("numéroteur",),
    "numéroteuse": ("numéroteur",),
    "numéroteuses": ("numéroteur",),
    "numide": ("numide",),
    "numides": ("numide",),
    "numidique": ("numidique",),
    "numidiques": ("numidique",),
    "numineuse": ("numineux",),
    "numineuses": ("numineux",),
    "numineux": ("numineux",),
    "numismatique": ("numismatique",),
    "numismatiques": ("numismatique",),
    "nummulaire": ("nummulaire",),
    "nummulaires": ("nummulaire",),
    "nummulitique": ("nummulitique",),
    "nummulitiques": ("nummulitique",),
    "nuncupatif": ("nuncupatif",),
    "nuncupatifs": ("nuncupatif",),
    "nuncupative": ("nuncupatif",),
    "nuncupatives": ("nuncupatif",),
    "nunuche": ("nunuche",),
    "nunuches": ("nunuche",),
    "nu-pieds": ("nu-pieds",),
    "nuptiale": ("nuptial",),
    "nuptiales": ("nuptial",),
    "nuptial": ("nuptial",),
    "nuptiaux": ("nuptial",),
    "nuragique": ("nuragique",),
    "nuragiques": ("nuragique",),
    "nu-tête": ("nu-tête",),
    "nutricielle": ("nutriciel",),
    "nutricielles": ("nutriciel",),
    "nutriciel": ("nutriciel",),
    "nutriciels": ("nutriciel",),
    "nutricière": ("nutricier",),
    "nutricières": ("nutricier",),
    "nutricier": ("nutricier",),
    "nutriciers": ("nutricier",),
    "nutritif": ("nutritif",),
    "nutritifs": ("nutritif",),
    "nutritive": ("nutritif",),
    "nutritives": ("nutritif",),
    "nutritionnelle": ("nutritionnel",),
    "nutritionnelles": ("nutritionnel",),
    "nutritionnel": ("nutritionnel",),
    "nutritionnels": ("nutritionnel",),
    "nyctalope": ("nyctalope",),
    "nyctalopes": ("nyctalope",),
    "nyctalophobe": ("nyctalophobe",),
    "nyctalophobes": ("nyctalophobe",),
    "nyctalopique": ("nyctalopique",),
    "nyctalopiques": ("nyctalopique",),
    "nycthémérale": ("nycthéméral",),
    "nycthémérales": ("nycthéméral",),
    "nycthéméral": ("nycthéméral",),
    "nycthéméraux": ("nycthéméral",),
    "nymphale": ("nymphal",),
    "nymphales": ("nymphal",),
    "nymphal": ("nymphal",),
    "nymphaux": ("nymphal",),
    "nymphomane": ("nymphomane",),
    "nymphomanes": ("nymphomane",),
    "nymphomaniaque": ("nymphomaniaque",),
    "nymphomaniaques": ("nymphomaniaque",),
    "nystagmiforme": ("nystagmiforme",),
    "nystagmiformes": ("nystagmiforme",),
    "nystagmographique": ("nystagmographique",),
    "nystagmographiques": ("nystagmographique",),
    "oasien": ("oasien",),
    "oasienne": ("oasien",),
    "oasiennes": ("oasien",),
    "oasiens": ("oasien",),
    "oaxaquénien": ("oaxaquénien",),
    "oaxaquénienne": ("oaxaquénien",),
    "oaxaquéniennes": ("oaxaquénien",),
    "oaxaquéniens": ("oaxaquénien",),
    "obédientielle": ("obédientiel",),
    "obédientielles": ("obédientiel",),
    "obédientiel": ("obédientiel",),
    "obédientiels": ("obédientiel",),
    "obèse": ("obèse",),
    "obèses": ("obèse",),
    "obituaire": ("obituaire",),
    "obituaires": ("obituaire",),
    "objectable": ("objectable",),
    "objectables": ("objectable",),
    "objectale": ("objectal",),
    "objectales": ("objectal",),
    "objectal": ("objectal",),
    "objectaux": ("objectal",),
    "objectif": ("objectif",),
    "objectifs": ("objectif",),
    "objective": ("objectif",),
    "objectives": ("objectif",),
    "objectivable": ("objectivable",),
    "objectivables": ("objectivable",),
    "objectiviste": ("objectiviste",),
    "objectivistes": ("objectiviste",),
    "oblatif": ("oblatif",),
    "oblatifs": ("oblatif",),
    "oblative": ("oblatif",),
    "oblatives": ("oblatif",),
    "obligataire": ("obligataire",),
    "obligataires": ("obligataire",),
    "obligatif": ("obligatif",),
    "obligatifs": ("obligatif",),
    "obligative": ("obligatif",),
    "obligatives": ("obligatif",),
    "obligationnelle": ("obligationnel",),
    "obligationnelles": ("obligationnel",),
    "obligationnel": ("obligationnel",),
    "obligationnels": ("obligationnel",),
    "obligatoire": ("obligatoire",),
    "obligatoires": ("obligatoire",),
    "oblique": ("oblique",),
    "obliques": ("oblique",),
    "oblitérateur": ("oblitérateur",),
    "oblitérateurs": ("oblitérateur",),
    "oblitératrice": ("oblitérateur",),
    "oblitératrices": ("oblitérateur",),
    "oblong": ("oblong",),
    "oblongs": ("oblong",),
    "oblongue": ("oblong",),
    "oblongues": ("oblong",),
    "obscène": ("obscène",),
    "obscènes": ("obscène",),
    "obscurantiste": ("obscurantiste",),
    "obscurantistes": ("obscurantiste",),
    "obséquieuse": ("obséquieux",),
    "obséquieuses": ("obséquieux",),
    "obséquieux": ("obséquieux",),
    "observable": ("observable",),
    "observables": ("observable",),
    "observateur": ("observateur",),
    "observateurs": ("observateur",),
    "observatrice": ("observateur",),
    "observatrices": ("observateur",),
    "observationnelle": ("observationnel",),
    "observationnelles": ("observationnel",),
    "observationnel": ("observationnel",),
    "observationnels": ("observationnel",),
    "obsessionnelle": ("obsessionnel",),
    "obsessionnelles": ("obsessionnel",),
    "obsessionnel": ("obsessionnel",),
    "obsessionnels": ("obsessionnel",),
    "obsidionale": ("obsidional",),
    "obsidionales": ("obsidional",),
    "obsidional": ("obsidional",),
    "obsidionaux": ("obsidional",),
    "obsolète": ("obsolète",),
    "obsolètes": ("obsolète",),
    "obstétricale": ("obstétrical",),
    "obstétricales": ("obstétrical",),
    "obstétrical": ("obstétrical",),
    "obstétricaux": ("obstétrical",),
    "obstétrique": ("obstétrique",),
    "obstétriques": ("obstétrique",),
    "obstructif": ("obstructif",),
    "obstructifs": ("obstructif",),
    "obstructive": ("obstructif",),
    "obstructives": ("obstructif",),
    "obstructionnelle": ("obstructionnel",),
    "obstructionnelles": ("obstructionnel",),
    "obstructionnel": ("obstructionnel",),
    "obstructionnels": ("obstructionnel",),
    "obstructionniste": ("obstructionniste",),
    "obstructionnistes": ("obstructionniste",),
    "obtenteur": ("obtenteur",),
    "obtenteurs": ("obtenteur",),
    "obtentrice": ("obtenteur",),
    "obtentrices": ("obtenteur",),
    "obturable": ("obturable",),
    "obturables": ("obturable",),
    "obturateur": ("obturateur",),
    "obturateurs": ("obturateur",),
    "obturatrice": ("obturateur",),
    "obturatrices": ("obturateur",),
    "obtusangle": ("obtusangle",),
    "obtusangles": ("obtusangle",),
    "obtuse": ("obtus",),
    "obtuses": ("obtus",),
    "obtus": ("obtus",),
    "obvie": ("obvie",),
    "obvies": ("obvie",),
    "occamiste": ("occamiste",),
    "occamistes": ("occamiste",),
    "occase": ("occase",),
    "occases": ("occase",),
    "occasionnaliste": ("occasionnaliste",),
    "occasionnalistes": ("occasionnaliste",),
    "occasionnelle": ("occasionnel",),
    "occasionnelles": ("occasionnel",),
    "occasionnel": ("occasionnel",),
    "occasionnels": ("occasionnel",),
    "occidentale": ("occidental",),
    "occidentales": ("occidental",),
    "occidental": ("occidental",),
    "occidentaux": ("occidental",),
    "occidentaliste": ("occidentaliste",),
    "occidentalistes": ("occidentaliste",),
    "occipitale": ("occipital",),
    "occipitales": ("occipital",),
    "occipital": ("occipital",),
    "occipitaux": ("occipital",),
    "occipito-atloïdien": ("occipito-atloïdien",),
    "occipito-atloïdiens": ("occipito-atloïdien",),
    "occipito-frontales": ("occipito-frontal",),
    "occipito-pariétal": ("occipito-pariétal",),
    "occipito-pubiennes": ("occipito-pubien",),
    "occise": ("occis",),
    "occises": ("occis",),
    "occis": ("occis",),
    "occitaniste": ("occitaniste",),
    "occitanistes": ("occitaniste",),
    "occlusale": ("occlusal",),
    "occlusales": ("occlusal",),
    "occlusal": ("occlusal",),
    "occlusaux": ("occlusal",),
    "occlusif": ("occlusif",),
    "occlusifs": ("occlusif",),
    "occlusive": ("occlusif",),
    "occlusives": ("occlusif",),
    "occultable": ("occultable",),
    "occultables": ("occultable",),
    "occulte": ("occulte",),
    "occultes": ("occulte",),
    "occultiste": ("occultiste",),
    "occultistes": ("occultiste",),
    "occupationnelle": ("occupationnel",),
    "occupationnelles": ("occupationnel",),
    "occupationnel": ("occupationnel",),
    "occupationnels": ("occupationnel",),
    "océane": ("océane",),
    "océanes": ("océane",),
    "océanien": ("océanien",),
    "océanienne": ("océanien",),
    "océaniennes": ("océanien",),
    "océaniens": ("océanien",),
    "océanique": ("océanique",),
    "océaniques": ("océanique",),
    "océanographique": ("océanographique",),
    "océanographiques": ("océanographique",),
    "océanologique": ("océanologique",),
    "océanologiques": ("océanologique",),
    "ocrée": ("ocré",),
    "ocrées": ("ocré",),
    "ocré": ("ocré",),
    "ocre": ("ocre",),
    "ocrés": ("ocré",),
    "ocreuse": ("ocreux",),
    "ocreuses": ("ocreux",),
    "ocreux": ("ocreux",),
    "octadécanoïque": ("octadécanoïque",),
    "octadécanoïques": ("octadécanoïque",),
    "octaèdre": ("octaèdre",),
    "octaèdres": ("octaèdre",),
    "octaédrique": ("octaédrique",),
    "octaédriques": ("octaédrique",),
    "octale": ("octal",),
    "octales": ("octal",),
    "octal": ("octal",),
    "octaux": ("octal",),
    "octanoïque": ("octanoïque",),
    "octanoïques": ("octanoïque",),
    "octantième": ("octantième",),
    "octantièmes": ("octantième",),
    "octatomique": ("octatomique",),
    "octatomiques": ("octatomique",),
    "octogénaire": ("octogénaire",),
    "octogénaires": ("octogénaire",),
    "octogonale": ("octogonal",),
    "octogonales": ("octogonal",),
    "octogonal": ("octogonal",),
    "octogonaux": ("octogonal",),
    "octogone": ("octogone",),
    "octogones": ("octogone",),
    "octopode": ("octopode",),
    "octopodes": ("octopode",),
    "octostyle": ("octostyle",),
    "octostyles": ("octostyle",),
    "octosyllabe": ("octosyllabe",),
    "octosyllabes": ("octosyllabe",),
    "octosyllabique": ("octosyllabique",),
    "octosyllabiques": ("octosyllabique",),
    "octuple": ("octuple",),
    "octuples": ("octuple",),
    "octylique": ("octylique",),
    "octyliques": ("octylique",),
    "oculaire": ("oculaire",),
    "oculaires": ("oculaire",),
    "oculiste": ("oculiste",),
    "oculistes": ("oculiste",),
    "oculistique": ("oculistique",),
    "oculistiques": ("oculistique",),
    "oculo-cardiaque": ("oculo-cardiaque",),
    "oculographique": ("oculographique",),
    "oculographiques": ("oculographique",),
    "oculogyre": ("oculogyre",),
    "oculogyres": ("oculogyre",),
    "oculomoteur": ("oculomoteur",),
    "oculomoteurs": ("oculomoteur",),
    "oculomotrice": ("oculomoteur",),
    "oculomotrices": ("oculomoteur",),
    "oculo-palpébral": ("oculo-palpébral",),
    "oculo-palpébraux": ("oculo-palpébral",),
    "oculo-verbal": ("oculoverbal",),
    "oculo-verbaux": ("oculoverbal",),
    "ocytocique": ("ocytocique",),
    "ocytociques": ("ocytocique",),
    "oddien": ("oddien",),
    "oddienne": ("oddien",),
    "oddiennes": ("oddien",),
    "oddiens": ("oddien",),
    "odieuse": ("odieux",),
    "odieuses": ("odieux",),
    "odieux": ("odieux",),
    "odométrique": ("odométrique",),
    "odométriques": ("odométrique",),
    "odontalgique": ("odontalgique",),
    "odontalgiques": ("odontalgique",),
    "odontoblastique": ("odontoblastique",),
    "odontoblastiques": ("odontoblastique",),
    "odontoïde": ("odontoïde",),
    "odontoïdes": ("odontoïde",),
    "odontologique": ("odontologique",),
    "odontologiques": ("odontologique",),
    "odontoplasique": ("odontoplasique",),
    "odontoplasiques": ("odontoplasique",),
    "odontorragique": ("odontorragique",),
    "odontorragiques": ("odontorragique",),
    "odontriteur": ("odontriteur",),
    "odontriteurs": ("odontriteur",),
    "odontritrice": ("odontriteur",),
    "odontritrices": ("odontriteur",),
    "odoratif": ("odoratif",),
    "odoratifs": ("odoratif",),
    "odorative": ("odoratif",),
    "odoratives": ("odoratif",),
    "oecologique": ("oecologique",),
    "oecologiques": ("oecologique",),
    "oecuménique": ("oecuménique",),
    "oecuméniques": ("oecuménique",),
    "oecuméniste": ("oecuméniste",),
    "oecuménistes": ("oecuméniste",),
    "oedémateuse": ("oedémateux",),
    "oedémateuses": ("oedémateux",),
    "oedémateux": ("oedémateux",),
    "oedipien": ("oedipien",),
    "oedipienne": ("oedipien",),
    "oedipiennes": ("oedipien",),
    "oedipiens": ("oedipien",),
    "oedométrique": ("oedométrique",),
    "oedométriques": ("oedométrique",),
    "oenanthique": ("oenanthique",),
    "oenanthiques": ("oenanthique",),
    "oenanthylique": ("oenanthylique",),
    "oenanthyliques": ("oenanthylique",),
    "oenolique": ("oenolique",),
    "oenoliques": ("oenolique",),
    "oenologique": ("oenologique",),
    "oenologiques": ("oenologique",),
    "oenométrique": ("oenométrique",),
    "oenométriques": ("oenométrique",),
    "oesophagien": ("oesophagien",),
    "oesophagienne": ("oesophagien",),
    "oesophagiennes": ("oesophagien",),
    "oesophagiens": ("oesophagien",),
    "oesophagique": ("oesophagique",),
    "oesophagiques": ("oesophagique",),
    "oesophago-salivaires": ("oesophago-salivaire",),
    "oestrale": ("oestral",),
    "oestrales": ("oestral",),
    "oestral": ("oestral",),
    "oestraux": ("oestral",),
    "oestrien": ("oestrien",),
    "oestrienne": ("oestrien",),
    "oestriennes": ("oestrien",),
    "oestriens": ("oestrien",),
    "oestrogène": ("oestrogène",),
    "oestrogènes": ("oestrogène",),
    "oestrogénique": ("oestrogénique",),
    "oestrogéniques": ("oestrogénique",),
    "oestroprogestatif": ("oestroprogestatif",),
    "oestro-progestatifs": ("oestro-progestatif",),
    "oestroprogestatifs": ("oestroprogestatif",),
    "oestro-progestative": ("oestro-progestatif",),
    "oestroprogestative": ("oestroprogestatif",),
    "oestro-progestatives": ("oestro-progestatif",),
    "oestroprogestatives": ("oestroprogestatif",),
    "off": ("off",),
    "offensif": ("offensif",),
    "offensifs": ("offensif",),
    "offensive": ("offensif",),
    "offensives": ("offensif",),
    "officielle": ("officiel",),
    "officielles": ("officiel",),
    "officiel": ("officiel",),
    "officiels": ("officiel",),
    "officieuse": ("officieux",),
    "officieuses": ("officieux",),
    "officieux": ("officieux",),
    "officinale": ("officinal",),
    "officinales": ("officinal",),
    "officinal": ("officinal",),
    "officinaux": ("officinal",),
    "offreur": ("offreur",),
    "offreurs": ("offreur",),
    "offreuse": ("offreur",),
    "offreuses": ("offreur",),
    "offset": ("offset",),
    "offshore": ("offshore",),
    "ogamique": ("ogamique",),
    "ogamiques": ("ogamique",),
    "ogham": ("ogham",),
    "oghamique": ("oghamique",),
    "oghamiques": ("oghamique",),
    "ogivale": ("ogival",),
    "ogivales": ("ogival",),
    "ogival": ("ogival",),
    "ogivaux": ("ogival",),
    "ohmique": ("ohmique",),
    "ohmiques": ("ohmique",),
    "oiseuse": ("oiseux",),
    "oiseuses": ("oiseux",),
    "oiseux": ("oiseux",),
    "oisif": ("oisif",),
    "oisifs": ("oisif",),
    "oisive": ("oisif",),
    "oisives": ("oisif",),
    "oléagineuse": ("oléagineux",),
    "oléagineuses": ("oléagineux",),
    "oléagineux": ("oléagineux",),
    "oléanolique": ("oléanolique",),
    "oléanoliques": ("oléanolique",),
    "olécranien": ("olécranien",),
    "olécrânien": ("olécrânien",),
    "olécranienne": ("olécranien",),
    "olécrânienne": ("olécrânien",),
    "olécraniennes": ("olécranien",),
    "olécrâniennes": ("olécrânien",),
    "olécraniens": ("olécranien",),
    "olécrâniens": ("olécrânien",),
    "oléfinique": ("oléfinique",),
    "oléfiniques": ("oléfinique",),
    "oléicole": ("oléicole",),
    "oléicoles": ("oléicole",),
    "oléifère": ("oléifère",),
    "oléifères": ("oléifère",),
    "oléiforme": ("oléiforme",),
    "oléiformes": ("oléiforme",),
    "oléique": ("oléique",),
    "oléiques": ("oléique",),
    "oléoabiétophtalique": ("oléoabiétophtalique",),
    "oléoabiétophtaliques": ("oléoabiétophtalique",),
    "oléocalcaire": ("oléocalcaire",),
    "oléocalcaires": ("oléocalcaire",),
    "oléopneumatique": ("oléopneumatique",),
    "oléopneumatiques": ("oléopneumatique",),
    "oléorésineuse": ("oléorésineux",),
    "oléorésineuses": ("oléorésineux",),
    "oléorésineux": ("oléorésineux",),
    "oléostéarique": ("oléostéarique",),
    "oléostéariques": ("oléostéarique",),
    "olfactif": ("olfactif",),
    "olfactifs": ("olfactif",),
    "olfactive": ("olfactif",),
    "olfactives": ("olfactif",),
    "olfactogénitale": ("olfactogénital",),
    "olfactogénitales": ("olfactogénital",),
    "olfactogénital": ("olfactogénital",),
    "olfactogénitaux": ("olfactogénital",),
    "oligarchique": ("oligarchique",),
    "oligarchiques": ("oligarchique",),
    "oligiste": ("oligiste",),
    "oligistes": ("oligiste",),
    "oligoblastique": ("oligoblastique",),
    "oligoblastiques": ("oligoblastique",),
    "oligocène": ("oligocène",),
    "oligocènes": ("oligocène",),
    "oligochète": ("oligochète",),
    "oligochètes": ("oligochète",),
    "oligoclonale": ("oligoclonal",),
    "oligoclonales": ("oligoclonal",),
    "oligoclonal": ("oligoclonal",),
    "oligoclonaux": ("oligoclonal",),
    "oligodendrocytaire": ("oligodendrocytaire",),
    "oligodendrocytaires": ("oligodendrocytaire",),
    "oligodynamique": ("oligodynamique",),
    "oligodynamiques": ("oligodynamique",),
    "oligohormonale": ("oligohormonal",),
    "oligohormonales": ("oligohormonal",),
    "oligohormonal": ("oligohormonal",),
    "oligohormonaux": ("oligohormonal",),
    "oligomacronéphronique": ("oligomacronéphronique",),
    "oligomacronéphroniques": ("oligomacronéphronique",),
    "oligométallique": ("oligométallique",),
    "oligométalliques": ("oligométallique",),
    "oligomictique": ("oligomictique",),
    "oligomictiques": ("oligomictique",),
    "oligophrène": ("oligophrène",),
    "oligophrènes": ("oligophrène",),
    "oligopolistique": ("oligopolistique",),
    "oligopolistiques": ("oligopolistique",),
    "oligosaccharidique": ("oligosaccharidique",),
    "oligosaccharidiques": ("oligosaccharidique",),
    "oligurique": ("oligurique",),
    "oliguriques": ("oligurique",),
    "olivaire": ("olivaire",),
    "olivaires": ("olivaire",),
    "olivâtre": ("olivâtre",),
    "olivâtres": ("olivâtre",),
    "olive": ("olive",),
    "ollaire": ("ollaire",),
    "ollaires": ("ollaire",),
    "olmèque": ("olmèque",),
    "olmèques": ("olmèque",),
    "olographe": ("olographe",),
    "olographes": ("olographe",),
    "olympien": ("olympien",),
    "olympienne": ("olympien",),
    "olympiennes": ("olympien",),
    "olympiens": ("olympien",),
    "olympique": ("olympique",),
    "olympiques": ("olympique",),
    "omanaise": ("omanais",),
    "omanaises": ("omanais",),
    "omanais": ("omanais",),
    "ombellifère": ("ombellifère",),
    "ombellifères": ("ombellifère",),
    "ombelliforme": ("ombelliforme",),
    "ombelliformes": ("ombelliforme",),
    "ombilicale": ("ombilical",),
    "ombilicales": ("ombilical",),
    "ombilical": ("ombilical",),
    "ombilicaux": ("ombilical",),
    "ombrageuse": ("ombrageux",),
    "ombrageuses": ("ombrageux",),
    "ombrageux": ("ombrageux",),
    "ombrellaire": ("ombrellaire",),
    "ombrellaires": ("ombrellaire",),
    "ombreuse": ("ombreux",),
    "ombreuses": ("ombreux",),
    "ombreux": ("ombreux",),
    "ombrien": ("ombrien",),
    "ombrienne": ("ombrien",),
    "ombriennes": ("ombrien",),
    "ombriens": ("ombrien",),
    "ombrothermique": ("ombrothermique",),
    "ombrothermiques": ("ombrothermique",),
    "omentale": ("omental",),
    "omentales": ("omental",),
    "omental": ("omental",),
    "omentaux": ("omental",),
    "omissible": ("omissible",),
    "omissibles": ("omissible",),
    "omnibus": ("omnibus",),
    "omnicolore": ("omnicolore",),
    "omnicolores": ("omnicolore",),
    "omnidirectif": ("omnidirectif",),
    "omnidirectifs": ("omnidirectif",),
    "omnidirective": ("omnidirectif",),
    "omnidirectives": ("omnidirectif",),
    "omnidirectionnelle": ("omnidirectionnel",),
    "omnidirectionnelles": ("omnidirectionnel",),
    "omnidirectionnel": ("omnidirectionnel",),
    "omnidirectionnels": ("omnidirectionnel",),
    "omnipolaire": ("omnipolaire",),
    "omnipolaires": ("omnipolaire",),
    "omnipraticien": ("omnipraticien",),
    "omnipraticienne": ("omnipraticien",),
    "omnipraticiennes": ("omnipraticien",),
    "omnipraticiens": ("omnipraticien",),
    "omnisport": ("omnisport",),
    "omnisports": ("omnisports",),
    "omnivore": ("omnivore",),
    "omnivores": ("omnivore",),
    "omphalomésentérique": ("omphalomésentérique",),
    "omphalomésentériques": ("omphalomésentérique",),
    "omphalopage": ("omphalopage",),
    "omphalopages": ("omphalopage",),
    "onaniste": ("onaniste",),
    "onanistes": ("onaniste",),
    "onciale": ("oncial",),
    "onciales": ("oncial",),
    "oncial": ("oncial",),
    "onciaux": ("oncial",),
    "oncogène": ("oncogène",),
    "oncogènes": ("oncogène",),
    "oncologique": ("oncologique",),
    "oncologiques": ("oncologique",),
    "oncostatique": ("oncostatique",),
    "oncostatiques": ("oncostatique",),
    "oncosuppressif": ("oncosuppressif",),
    "oncosuppressifs": ("oncosuppressif",),
    "oncosuppressive": ("oncosuppressif",),
    "oncosuppressives": ("oncosuppressif",),
    "oncotique": ("oncotique",),
    "oncotiques": ("oncotique",),
    "onctueuse": ("onctueux",),
    "onctueuses": ("onctueux",),
    "onctueux": ("onctueux",),
    "ondulatoire": ("ondulatoire",),
    "ondulatoires": ("ondulatoire",),
    "onduleuse": ("onduleux",),
    "onduleuses": ("onduleux",),
    "onduleux": ("onduleux",),
    "onéreuse": ("onéreux",),
    "onéreuses": ("onéreux",),
    "onéreux": ("onéreux",),
    "onguiforme": ("onguiforme",),
    "onguiformes": ("onguiforme",),
    "onguligrade": ("onguligrade",),
    "onguligrades": ("onguligrade",),
    "onirique": ("onirique",),
    "oniriques": ("onirique",),
    "onirocritique": ("onirocritique",),
    "onirocritiques": ("onirocritique",),
    "onirogène": ("onirogène",),
    "onirogènes": ("onirogène",),
    "oniroïde": ("oniroïde",),
    "oniroïdes": ("oniroïde",),
    "onirologique": ("onirologique",),
    "onirologiques": ("onirologique",),
    "oniromancien": ("oniromancien",),
    "oniromancienne": ("oniromancien",),
    "oniromanciennes": ("oniromancien",),
    "oniromanciens": ("oniromancien",),
    "onkotique": ("onkotique",),
    "onkotiques": ("onkotique",),
    "onomasiologique": ("onomasiologique",),
    "onomasiologiques": ("onomasiologique",),
    "onomastique": ("onomastique",),
    "onomastiques": ("onomastique",),
    "onomatopéique": ("onomatopéique",),
    "onomatopéiques": ("onomatopéique",),
    "ontarien": ("ontarien",),
    "ontarienne": ("ontarien",),
    "ontariennes": ("ontarien",),
    "ontariens": ("ontarien",),
    "ontique": ("ontique",),
    "ontiques": ("ontique",),
    "ontogénétique": ("ontogénétique",),
    "ontogénétiques": ("ontogénétique",),
    "ontogénique": ("ontogénique",),
    "ontogéniques": ("ontogénique",),
    "ontologique": ("ontologique",),
    "ontologiques": ("ontologique",),
    "onusien": ("onusien",),
    "onusienne": ("onusien",),
    "onusiennes": ("onusien",),
    "onusiens": ("onusien",),
    "onychogène": ("onychogène",),
    "onychogènes": ("onychogène",),
    "onzième": ("onzième",),
    "onzièmes": ("onzième",),
    "oolithique": ("oolithique",),
    "oolithiques": ("oolithique",),
    "oophage": ("oophage",),
    "oophages": ("oophage",),
    "opale": ("opale",),
    "opaque": ("opaque",),
    "opaques": ("opaque",),
    "opéable": ("opéable",),
    "opéables": ("opéable",),
    "open": ("open",),
    "opérable": ("opérable",),
    "opérables": ("opérable",),
    "opérateur": ("opérateur",),
    "opérateurs": ("opérateur",),
    "opératrice": ("opérateur",),
    "opératrices": ("opérateur",),
    "opératif": ("opératif",),
    "opératifs": ("opératif",),
    "opérative": ("opératif",),
    "opératives": ("opératif",),
    "opérationnelle": ("opérationnel",),
    "opérationnelles": ("opérationnel",),
    "opérationnel": ("opérationnel",),
    "opérationnels": ("opérationnel",),
    "opérationniste": ("opérationniste",),
    "opérationnistes": ("opérationniste",),
    "opératique": ("opératique",),
    "opératiques": ("opératique",),
    "opératoire": ("opératoire",),
    "opératoires": ("opératoire",),
    "operculaire": ("operculaire",),
    "operculaires": ("operculaire",),
    "ophiasique": ("ophiasique",),
    "ophiasiques": ("ophiasique",),
    "ophidien": ("ophidien",),
    "ophidienne": ("ophidien",),
    "ophidiennes": ("ophidien",),
    "ophidiens": ("ophidien",),
    "ophiolitique": ("ophiolitique",),
    "ophiolitiques": ("ophiolitique",),
    "ophiomorphique": ("ophiomorphique",),
    "ophiomorphiques": ("ophiomorphique",),
    "ophitique": ("ophitique",),
    "ophitiques": ("ophitique",),
    "ophryogène": ("ophryogène",),
    "ophryogènes": ("ophryogène",),
    "ophtalmique": ("ophtalmique",),
    "ophtalmiques": ("ophtalmique",),
    "ophtalmologique": ("ophtalmologique",),
    "ophtalmologiques": ("ophtalmologique",),
    "ophtalmométrique": ("ophtalmométrique",),
    "ophtalmométriques": ("ophtalmométrique",),
    "ophtalmoscopique": ("ophtalmoscopique",),
    "ophtalmoscopiques": ("ophtalmoscopique",),
    "opianique": ("opianique",),
    "opianiques": ("opianique",),
    "opimes": ("opimes",),
    "opiniâtre": ("opiniâtre",),
    "opiniâtres": ("opiniâtre",),
    "opioïde": ("opioïde",),
    "opioïdes": ("opioïde",),
    "opiomane": ("opiomane",),
    "opiomanes": ("opiomane",),
    "opisthographe": ("opisthographe",),
    "opisthographes": ("opisthographe",),
    "opothérapique": ("opothérapique",),
    "opothérapiques": ("opothérapique",),
    "opportuniste": ("opportuniste",),
    "opportunistes": ("opportuniste",),
    "opposable": ("opposable",),
    "opposables": ("opposable",),
    "opposite": ("opposite",),
    "opposites": ("opposite",),
    "oppositif": ("oppositif",),
    "oppositifs": ("oppositif",),
    "oppositive": ("oppositif",),
    "oppositives": ("oppositif",),
    "oppositionnelle": ("oppositionnel",),
    "oppositionnelles": ("oppositionnel",),
    "oppositionnel": ("oppositionnel",),
    "oppositionnels": ("oppositionnel",),
    "oppresseur": ("oppresseur",),
    "oppresseurs": ("oppresseur",),
    "oppressif": ("oppressif",),
    "oppressifs": ("oppressif",),
    "oppressive": ("oppressif",),
    "oppressives": ("oppressif",),
    "optatif": ("optatif",),
    "optatifs": ("optatif",),
    "optative": ("optatif",),
    "optatives": ("optatif",),
    "optimale": ("optimal",),
    "optimales": ("optimal",),
    "optimal": ("optimal",),
    "optimaux": ("optimal",),
    "optimisateur": ("optimisateur",),
    "optimisateurs": ("optimisateur",),
    "optimisatrice": ("optimisateur",),
    "optimisatrices": ("optimisateur",),
    "optimiste": ("optimiste",),
    "optimistes": ("optimiste",),
    "optima": ("optimum",),
    "optimum": ("optimum",),
    "optimums": ("optimum",),
    "optionnelle": ("optionnel",),
    "optionnelles": ("optionnel",),
    "optionnel": ("optionnel",),
    "optionnels": ("optionnel",),
    "optique": ("optique",),
    "optiques": ("optique",),
    "optocinétique": ("optocinétique",),
    "optocinétiques": ("optocinétique",),
    "optoélectronique": ("optoélectronique",),
    "opto-électroniques": ("opto-électronique",),
    "optoélectroniques": ("optoélectronique",),
    "optométrique": ("optométrique",),
    "optométriques": ("optométrique",),
    "optomoteur": ("optomoteur",),
    "optomoteurs": ("optomoteur",),
    "optomotrice": ("optomoteur",),
    "optomotrices": ("optomoteur",),
    "opto-striées": ("opto-strié",),
    "opto-strié": ("optostrié",),
    "opto-striés": ("optostrié",),
    "oraculaire": ("oraculaire",),
    "oraculaires": ("oraculaire",),
    "orageuse": ("orageux",),
    "orageuses": ("orageux",),
    "orageux": ("orageux",),
    "orale": ("oral",),
    "orales": ("oral",),
    "oral": ("oral",),
    "oraux": ("oral",),
    "oranaise": ("oranais",),
    "oranaises": ("oranais",),
    "oranais": ("oranais",),
    "orangée": ("orangé",),
    "orangées": ("orangé",),
    "orangé": ("orangé",),
    "orange": ("orange",),
    "orangés": ("orangé",),
    "orangiste": ("orangiste",),
    "orangistes": ("orangiste",),
    "oratoire": ("oratoire",),
    "oratoires": ("oratoire",),
    "oratorien": ("oratorien",),
    "oratorienne": ("oratorien",),
    "oratoriennes": ("oratorien",),
    "oratoriens": ("oratorien",),
    "orbe": ("orbe",),
    "orbes": ("orbe",),
    "orbicole": ("orbicole",),
    "orbicoles": ("orbicole",),
    "orbiculaire": ("orbiculaire",),
    "orbiculaires": ("orbiculaire",),
    "orbitaire": ("orbitaire",),
    "orbitaires": ("orbitaire",),
    "orbitalaire": ("orbitalaire",),
    "orbitalaires": ("orbitalaire",),
    "orbitale": ("orbital",),
    "orbitales": ("orbital",),
    "orbital": ("orbital",),
    "orbitaux": ("orbital",),
    "orbitèle": ("orbitèle",),
    "orbitèles": ("orbitèle",),
    "orchestique": ("orchestique",),
    "orchestiques": ("orchestique",),
    "orchestrale": ("orchestral",),
    "orchestrales": ("orchestral",),
    "orchestral": ("orchestral",),
    "orchestraux": ("orchestral",),
    "orchestrique": ("orchestrique",),
    "orchestriques": ("orchestrique",),
    "ordinaire": ("ordinaire",),
    "ordinaires": ("ordinaire",),
    "ordinale": ("ordinal",),
    "ordinales": ("ordinal",),
    "ordinal": ("ordinal",),
    "ordinaux": ("ordinal",),
    "ordonnable": ("ordonnable",),
    "ordonnables": ("ordonnable",),
    "ordovicien": ("ordovicien",),
    "ordovicienne": ("ordovicien",),
    "ordoviciennes": ("ordovicien",),
    "ordoviciens": ("ordovicien",),
    "ordurière": ("ordurier",),
    "ordurières": ("ordurier",),
    "ordurier": ("ordurier",),
    "orduriers": ("ordurier",),
    "orexigène": ("orexigène",),
    "orexigènes": ("orexigène",),
    "orexique": ("orexique",),
    "orexiques": ("orexique",),
    "organicien": ("organicien",),
    "organicienne": ("organicien",),
    "organiciennes": ("organicien",),
    "organiciens": ("organicien",),
    "organiciste": ("organiciste",),
    "organicistes": ("organiciste",),
    "organique": ("organique",),
    "organiques": ("organique",),
    "organisable": ("organisable",),
    "organisables": ("organisable",),
    "organisateur": ("organisateur",),
    "organisateurs": ("organisateur",),
    "organisatrice": ("organisateur",),
    "organisatrices": ("organisateur",),
    "organisationnelle": ("organisationnel",),
    "organisationnelles": ("organisationnel",),
    "organisationnel": ("organisationnel",),
    "organisationnels": ("organisationnel",),
    "organoaluminique": ("organoaluminique",),
    "organoaluminiques": ("organoaluminique",),
    "organoarsenicale": ("organoarsenical",),
    "organoarsenicales": ("organoarsenical",),
    "organoarsenical": ("organoarsenical",),
    "organoarsenicaux": ("organoarsenical",),
    "organocuivreuse": ("organocuivreux",),
    "organocuivreuses": ("organocuivreux",),
    "organocuivreux": ("organocuivreux",),
    "organocuprique": ("organocuprique",),
    "organocupriques": ("organocuprique",),
    "organodétritique": ("organodétritique",),
    "organodétritiques": ("organodétritique",),
    "organodynamique": ("organodynamique",),
    "organodynamiques": ("organodynamique",),
    "organoferrique": ("organoferrique",),
    "organoferriques": ("organoferrique",),
    "organogénétique": ("organogénétique",),
    "organogénétiques": ("organogénétique",),
    "organoïde": ("organoïde",),
    "organoïdes": ("organoïde",),
    "organoleptique": ("organoleptique",),
    "organoleptiques": ("organoleptique",),
    "organologique": ("organologique",),
    "organologiques": ("organologique",),
    "organomagnésien": ("organomagnésien",),
    "organomagnésienne": ("organomagnésien",),
    "organomagnésiennes": ("organomagnésien",),
    "organomagnésiens": ("organomagnésien",),
    "organomercurique": ("organomercurique",),
    "organomercuriques": ("organomercurique",),
    "organométallique": ("organométallique",),
    "organométalliques": ("organométallique",),
    "organométalloïdique": ("organométalloïdique",),
    "organométalloïdiques": ("organométalloïdique",),
    "organominérale": ("organominéral",),
    "organominérales": ("organominéral",),
    "organominéral": ("organominéral",),
    "organominéraux": ("organominéral",),
    "organoplombique": ("organoplombique",),
    "organoplombiques": ("organoplombique",),
    "organotrope": ("organotrope",),
    "organotropes": ("organotrope",),
    "organotypique": ("organotypique",),
    "organotypiques": ("organotypique",),
    "organozincique": ("organozincique",),
    "organozinciques": ("organozincique",),
    "orgasmique": ("orgasmique",),
    "orgasmiques": ("orgasmique",),
    "orgastique": ("orgastique",),
    "orgastiques": ("orgastique",),
    "orgiaque": ("orgiaque",),
    "orgiaques": ("orgiaque",),
    "orgiastique": ("orgiastique",),
    "orgiastiques": ("orgiastique",),
    "orgueilleuse": ("orgueilleux",),
    "orgueilleuses": ("orgueilleux",),
    "orgueilleux": ("orgueilleux",),
    "orientable": ("orientable",),
    "orientables": ("orientable",),
    "orientale": ("oriental",),
    "orientales": ("oriental",),
    "oriental": ("oriental",),
    "orientaux": ("oriental",),
    "orientaliste": ("orientaliste",),
    "orientalistes": ("orientaliste",),
    "orienteur": ("orienteur",),
    "orienteurs": ("orienteur",),
    "orienteuse": ("orienteur",),
    "orienteuses": ("orienteur",),
    "orificielle": ("orificiel",),
    "orificielles": ("orificiel",),
    "orificiel": ("orificiel",),
    "orificiels": ("orificiel",),
    "origéniste": ("origéniste",),
    "origénistes": ("origéniste",),
    "originaire": ("originaire",),
    "originaires": ("originaire",),
    "originale": ("original",),
    "originales": ("original",),
    "original": ("original",),
    "originaux": ("original",),
    "originelle": ("originel",),
    "originelles": ("originel",),
    "originel": ("originel",),
    "originels": ("originel",),
    "orléanaise": ("orléanais",),
    "orléanaises": ("orléanais",),
    "orléanais": ("orléanais",),
    "orléaniste": ("orléaniste",),
    "orléanistes": ("orléaniste",),
    "ornemaniste": ("ornemaniste",),
    "ornemanistes": ("ornemaniste",),
    "ornementale": ("ornemental",),
    "ornementales": ("ornemental",),
    "ornemental": ("ornemental",),
    "ornementaux": ("ornemental",),
    "ornithologique": ("ornithologique",),
    "ornithologiques": ("ornithologique",),
    "ornithophile": ("ornithophile",),
    "ornithophiles": ("ornithophile",),
    "orogénique": ("orogénique",),
    "orogéniques": ("orogénique",),
    "orographique": ("orographique",),
    "orographiques": ("orographique",),
    "oro-hydrographique": ("oro-hydrographique",),
    "orométrique": ("orométrique",),
    "orométriques": ("orométrique",),
    "orophyte": ("orophyte",),
    "orophytes": ("orophyte",),
    "orotidylique": ("orotidylique",),
    "orotidyliques": ("orotidylique",),
    "orotique": ("orotique",),
    "orotiques": ("orotique",),
    "orotrachéale": ("orotrachéal",),
    "orotrachéales": ("orotrachéal",),
    "orotrachéal": ("orotrachéal",),
    "orotrachéaux": ("orotrachéal",),
    "orphique": ("orphique",),
    "orphiques": ("orphique",),
    "orthoacétique": ("orthoacétique",),
    "orthoacétiques": ("orthoacétique",),
    "orthoarsénique": ("orthoarsénique",),
    "orthoarséniques": ("orthoarsénique",),
    "orthobasophile": ("orthobasophile",),
    "orthobasophiles": ("orthobasophile",),
    "orthoborique": ("orthoborique",),
    "orthoboriques": ("orthoborique",),
    "orthocarbonique": ("orthocarbonique",),
    "orthocarboniques": ("orthocarbonique",),
    "orthocentrique": ("orthocentrique",),
    "orthocentriques": ("orthocentrique",),
    "orthocéphale": ("orthocéphale",),
    "orthocéphales": ("orthocéphale",),
    "orthochromatique": ("orthochromatique",),
    "orthochromatiques": ("orthochromatique",),
    "orthochrome": ("orthochrome",),
    "orthochromes": ("orthochrome",),
    "orthoclinale": ("orthoclinal",),
    "orthoclinales": ("orthoclinal",),
    "orthoclinal": ("orthoclinal",),
    "orthoclinaux": ("orthoclinal",),
    "orthodontique": ("orthodontique",),
    "orthodontiques": ("orthodontique",),
    "orthodoxe": ("orthodoxe",),
    "orthodoxes": ("orthodoxe",),
    "orthodromique": ("orthodromique",),
    "orthodromiques": ("orthodromique",),
    "orthoépique": ("orthoépique",),
    "orthoépiques": ("orthoépique",),
    "orthoformique": ("orthoformique",),
    "orthoformiques": ("orthoformique",),
    "orthogénique": ("orthogénique",),
    "orthogéniques": ("orthogénique",),
    "orthognathe": ("orthognathe",),
    "orthognathes": ("orthognathe",),
    "orthogonale": ("orthogonal",),
    "orthogonales": ("orthogonal",),
    "orthogonal": ("orthogonal",),
    "orthogonaux": ("orthogonal",),
    "orthographique": ("orthographique",),
    "orthographiques": ("orthographique",),
    "orthométrique": ("orthométrique",),
    "orthométriques": ("orthométrique",),
    "orthonormale": ("orthonormal",),
    "orthonormales": ("orthonormal",),
    "orthonormal": ("orthonormal",),
    "orthonormaux": ("orthonormal",),
    "orthopédique": ("orthopédique",),
    "orthopédiques": ("orthopédique",),
    "orthopédiste": ("orthopédiste",),
    "orthopédistes": ("orthopédiste",),
    "orthophonique": ("orthophonique",),
    "orthophoniques": ("orthophonique",),
    "orthophosphorique": ("orthophosphorique",),
    "orthophosphoriques": ("orthophosphorique",),
    "orthoptère": ("orthoptère",),
    "orthoptères": ("orthoptère",),
    "orthoptique": ("orthoptique",),
    "orthoptiques": ("orthoptique",),
    "orthoraphe": ("orthoraphe",),
    "orthoraphes": ("orthoraphe",),
    "orthorhombique": ("orthorhombique",),
    "orthorhombiques": ("orthorhombique",),
    "orthorythmique": ("orthorythmique",),
    "orthorythmiques": ("orthorythmique",),
    "orthoscopique": ("orthoscopique",),
    "orthoscopiques": ("orthoscopique",),
    "orthosémique": ("orthosémique",),
    "orthosémiques": ("orthosémique",),
    "orthosilicique": ("orthosilicique",),
    "orthosiliciques": ("orthosilicique",),
    "orthostatique": ("orthostatique",),
    "orthostatiques": ("orthostatique",),
    "orthosympathique": ("orthosympathique",),
    "orthosympathiques": ("orthosympathique",),
    "orthothymique": ("orthothymique",),
    "orthothymiques": ("orthothymique",),
    "orthotopique": ("orthotopique",),
    "orthotopiques": ("orthotopique",),
    "orthotrope": ("orthotrope",),
    "orthotropes": ("orthotrope",),
    "ortive": ("ortive",),
    "ortives": ("ortive",),
    "oscillateur": ("oscillateur",),
    "oscillateurs": ("oscillateur",),
    "oscillatrice": ("oscillateur",),
    "oscillatrices": ("oscillateur",),
    "oscillatoire": ("oscillatoire",),
    "oscillatoires": ("oscillatoire",),
    "oscillométrique": ("oscillométrique",),
    "oscillométriques": ("oscillométrique",),
    "osculateur": ("osculateur",),
    "osculateurs": ("osculateur",),
    "osculatrice": ("osculateur",),
    "osculatrices": ("osculateur",),
    "osidique": ("osidique",),
    "osidiques": ("osidique",),
    "osiriaque": ("osiriaque",),
    "osiriaques": ("osiriaque",),
    "osmiamique": ("osmiamique",),
    "osmiamiques": ("osmiamique",),
    "osmieuse": ("osmieux",),
    "osmieuses": ("osmieux",),
    "osmieux": ("osmieux",),
    "osmique": ("osmique",),
    "osmiques": ("osmique",),
    "osmométrique": ("osmométrique",),
    "osmométriques": ("osmométrique",),
    "osmorécepteur": ("osmorécepteur",),
    "osmorécepteurs": ("osmorécepteur",),
    "osmoréceptrice": ("osmorécepteur",),
    "osmoréceptrices": ("osmorécepteur",),
    "osmotique": ("osmotique",),
    "osmotiques": ("osmotique",),
    "osque": ("osque",),
    "osques": ("osque",),
    "ossète": ("ossète",),
    "ossètes": ("ossète",),
    "osseuse": ("osseux",),
    "osseuses": ("osseux",),
    "osseux": ("osseux",),
    "ossianique": ("ossianique",),
    "ossianiques": ("ossianique",),
    "ossiculaire": ("ossiculaire",),
    "ossiculaires": ("ossiculaire",),
    "ossifère": ("ossifère",),
    "ossifères": ("ossifère",),
    "ossiforme": ("ossiforme",),
    "ossiformes": ("ossiforme",),
    "ostéalgique": ("ostéalgique",),
    "ostéalgiques": ("ostéalgique",),
    "ostéitique": ("ostéitique",),
    "ostéitiques": ("ostéitique",),
    "ostensible": ("ostensible",),
    "ostensibles": ("ostensible",),
    "ostensif": ("ostensif",),
    "ostensifs": ("ostensif",),
    "ostensive": ("ostensif",),
    "ostensives": ("ostensif",),
    "ostentateur": ("ostentateur",),
    "ostentateurs": ("ostentateur",),
    "ostentatrice": ("ostentateur",),
    "ostentatrices": ("ostentateur",),
    "ostentatoire": ("ostentatoire",),
    "ostentatoires": ("ostentatoire",),
    "ostéo-articulaire": ("ostéo-articulaire",),
    "ostéoarticulaire": ("ostéoarticulaire",),
    "ostéoarticulaires": ("ostéoarticulaire",),
    "ostéoblastique": ("ostéoblastique",),
    "ostéoblastiques": ("ostéoblastique",),
    "ostéocartilagineuse": ("ostéocartilagineux",),
    "ostéocartilagineuses": ("ostéocartilagineux",),
    "ostéocartilagineux": ("ostéocartilagineux",),
    "ostéocope": ("ostéocope",),
    "ostéocopes": ("ostéocope",),
    "ostéo-dermopathiques": ("ostéo-dermopathique",),
    "ostéogène": ("ostéogène",),
    "ostéogènes": ("ostéogène",),
    "ostéogénique": ("ostéogénique",),
    "ostéogéniques": ("ostéogénique",),
    "ostéoglophonique": ("ostéoglophonique",),
    "ostéoglophoniques": ("ostéoglophonique",),
    "ostéoïde": ("ostéoïde",),
    "ostéoïdes": ("ostéoïde",),
    "ostéologique": ("ostéologique",),
    "ostéologiques": ("ostéologique",),
    "ostéolytique": ("ostéolytique",),
    "ostéolytiques": ("ostéolytique",),
    "ostéomalacique": ("ostéomalacique",),
    "ostéomalaciques": ("ostéomalacique",),
    "ostéomusculaire": ("ostéomusculaire",),
    "ostéomusculaires": ("ostéomusculaire",),
    "ostéoplastique": ("ostéoplastique",),
    "ostéoplastiques": ("ostéoplastique",),
    "ostéoporotique": ("ostéoporotique",),
    "ostéoporotiques": ("ostéoporotique",),
    "ostéo-tendineux": ("ostéo-tendineux",),
    "ostéotrope": ("ostéotrope",),
    "ostéotropes": ("ostéotrope",),
    "ostiak": ("ostiak",),
    "ostiaks": ("ostiak",),
    "ostique": ("ostique",),
    "ostiques": ("ostique",),
    "ostréen": ("ostréen",),
    "ostréenne": ("ostréen",),
    "ostréennes": ("ostréen",),
    "ostréens": ("ostréen",),
    "ostréicole": ("ostréicole",),
    "ostréicoles": ("ostréicole",),
    "ostréiforme": ("ostréiforme",),
    "ostréiformes": ("ostréiforme",),
    "ostrogothique": ("ostrogothique",),
    "ostrogothiques": ("ostrogothique",),
    "ostyak": ("ostyak",),
    "ostyaks": ("ostyak",),
    "otalgique": ("otalgique",),
    "otalgiques": ("otalgique",),
    "othtalmoplégique": ("othtalmoplégique",),
    "othtalmoplégiques": ("othtalmoplégique",),
    "otique": ("otique",),
    "otiques": ("otique",),
    "otitique": ("otitique",),
    "otitiques": ("otitique",),
    "otolithique": ("otolithique",),
    "otolithiques": ("otolithique",),
    "otologique": ("otologique",),
    "otologiques": ("otologique",),
    "otorrhéique": ("otorrhéique",),
    "otorrhéiques": ("otorrhéique",),
    "ototoxique": ("ototoxique",),
    "ototoxiques": ("ototoxique",),
    "ottonien": ("ottonien",),
    "ottonienne": ("ottonien",),
    "ottoniennes": ("ottonien",),
    "ottoniens": ("ottonien",),
    "ouateuse": ("ouateux",),
    "ouateuses": ("ouateux",),
    "ouateux": ("ouateux",),
    "oubliable": ("oubliable",),
    "oubliables": ("oubliable",),
    "oublieuse": ("oublieux",),
    "oublieuses": ("oublieux",),
    "oublieux": ("oublieux",),
    "ouest-africaine": ("ouest-africain",),
    "ouest-africaines": ("ouest-africain",),
    "ouest-africain": ("ouest-africain",),
    "ouest-africains": ("ouest-africain",),
    "ouest-allemande": ("ouest-allemand",),
    "ouest-allemandes": ("ouest-allemand",),
    "ouest-allemand": ("ouest-allemand",),
    "ouest-allemands": ("ouest-allemand",),
    "ouest": ("ouest",),
    "ouest-européen": ("ouest-européen",),
    "ouest-européenne": ("ouest-européen",),
    "ouest-européens": ("ouest-européen",),
    "ougandaise": ("ougandais",),
    "ougandaises": ("ougandais",),
    "ougandais": ("ougandais",),
    "ougaritique": ("ougaritique",),
    "ougaritiques": ("ougaritique",),
    "ougrien": ("ougrien",),
    "ougrienne": ("ougrien",),
    "ougriennes": ("ougrien",),
    "ougriens": ("ougrien",),
    "ouïghour": ("ouïghour",),
    "ouïghours": ("ouïghour",),
    "ouïgour": ("ouïgour",),
    "ouïgours": ("ouïgour",),
    "ouolof": ("ouolof",),
    "ouolofs": ("ouolof",),
    "ouralien": ("ouralien",),
    "ouralienne": ("ouralien",),
    "ouraliennes": ("ouralien",),
    "ouraliens": ("ouralien",),
    "ouralo-altaïque": ("ouralo-altaïque",),
    "ourdou": ("ourdou",),
    "ourlien": ("ourlien",),
    "ourlienne": ("ourlien",),
    "ourliennes": ("ourlien",),
    "ourliens": ("ourlien",),
    "ours": ("ours",),
    "outrageuse": ("outrageux",),
    "outrageuses": ("outrageux",),
    "outrageux": ("outrageux",),
    "outrancière": ("outrancier",),
    "outrancières": ("outrancier",),
    "outrancier": ("outrancier",),
    "outranciers": ("outrancier",),
    "outre-atlantique": ("outre-atlantique",),
    "outre-méditerranéen": ("outre-méditerranéen",),
    "outre-mer": ("outre-mer",),
    "outremer": ("outremer",),
    "outre-monts": ("outre-monts",),
    "outre-quiévrain": ("outre-quiévrain",),
    "outre-rhin": ("outre-rhin",),
    "outre-tombe": ("outre-tombe",),
    "ouvrable": ("ouvrable",),
    "ouvrables": ("ouvrable",),
    "ouvrière": ("ouvrier",),
    "ouvrières": ("ouvrier",),
    "ouvrier": ("ouvrier",),
    "ouvriers": ("ouvrier",),
    "ouvriériste": ("ouvriériste",),
    "ouvriéristes": ("ouvriériste",),
    "ouzbek": ("ouzbek",),
    "ouzbeks": ("ouzbek",),
    "ouzbèque": ("ouzbèque",),
    "ouzbèques": ("ouzbèque",),
    "ovalaire": ("ovalaire",),
    "ovalaires": ("ovalaire",),
    "ovale": ("ovale",),
    "ovales": ("ovale",),
    "ovarien": ("ovarien",),
    "ovarienne": ("ovarien",),
    "ovariennes": ("ovarien",),
    "ovariens": ("ovarien",),
    "ovarioprive": ("ovarioprive",),
    "ovarioprives": ("ovarioprive",),
    "ovarique": ("ovarique",),
    "ovariques": ("ovarique",),
    "ovicide": ("ovicide",),
    "ovicides": ("ovicide",),
    "oviforme": ("oviforme",),
    "oviformes": ("oviforme",),
    "ovigène": ("ovigène",),
    "ovigènes": ("ovigène",),
    "ovigère": ("ovigère",),
    "ovigères": ("ovigère",),
    "ovipare": ("ovipare",),
    "ovipares": ("ovipare",),
    "ovoïdale": ("ovoïdal",),
    "ovoïdales": ("ovoïdal",),
    "ovoïdal": ("ovoïdal",),
    "ovoïdaux": ("ovoïdal",),
    "ovoïde": ("ovoïde",),
    "ovoïdes": ("ovoïde",),
    "ovonique": ("ovonique",),
    "ovoniques": ("ovonique",),
    "ovovivipare": ("ovovivipare",),
    "ovovivipares": ("ovovivipare",),
    "ovulaire": ("ovulaire",),
    "ovulaires": ("ovulaire",),
    "ovulatoire": ("ovulatoire",),
    "ovulatoires": ("ovulatoire",),
    "oxalacétique": ("oxalacétique",),
    "oxalacétiques": ("oxalacétique",),
    "oxaligène": ("oxaligène",),
    "oxaligènes": ("oxaligène",),
    "oxalique": ("oxalique",),
    "oxaliques": ("oxalique",),
    "oxalophore": ("oxalophore",),
    "oxalophores": ("oxalophore",),
    "oxalosuccinique": ("oxalosuccinique",),
    "oxalosucciniques": ("oxalosuccinique",),
    "oxamique": ("oxamique",),
    "oxamiques": ("oxamique",),
    "oxazinique": ("oxazinique",),
    "oxaziniques": ("oxazinique",),
    "oxfordien": ("oxfordien",),
    "oxfordienne": ("oxfordien",),
    "oxfordiennes": ("oxfordien",),
    "oxfordiens": ("oxfordien",),
    "oxhydrique": ("oxhydrique",),
    "oxhydriques": ("oxhydrique",),
    "oxo": ("oxo",),
    "oxyacétylénique": ("oxyacétylénique",),
    "oxyacétyléniques": ("oxyacétylénique",),
    "oxycoupeur": ("oxycoupeur",),
    "oxycoupeurs": ("oxycoupeur",),
    "oxydable": ("oxydable",),
    "oxydables": ("oxydable",),
    "oxydasique": ("oxydasique",),
    "oxydasiques": ("oxydasique",),
    "oxydatif": ("oxydatif",),
    "oxydatifs": ("oxydatif",),
    "oxydative": ("oxydatif",),
    "oxydatives": ("oxydatif",),
    "oxydoréducteur": ("oxydoréducteur",),
    "oxydoréducteurs": ("oxydoréducteur",),
    "oxydoréductrice": ("oxydoréducteur",),
    "oxydoréductrices": ("oxydoréducteur",),
    "oxygénable": ("oxygénable",),
    "oxygénables": ("oxygénable",),
    "oxymétrique": ("oxymétrique",),
    "oxymétriques": ("oxymétrique",),
    "oxymorique": ("oxymorique",),
    "oxymoriques": ("oxymorique",),
    "oxyphile": ("oxyphile",),
    "oxyphiles": ("oxyphile",),
    "oxyphilique": ("oxyphilique",),
    "oxyphiliques": ("oxyphilique",),
    "oxyphorique": ("oxyphorique",),
    "oxyphoriques": ("oxyphorique",),
    "oxytocique": ("oxytocique",),
    "oxytociques": ("oxytocique",),
    "oxyton": ("oxyton",),
    "oxytons": ("oxyton",),
    "ozéneuse": ("ozéneux",),
    "ozéneuses": ("ozéneux",),
    "ozéneux": ("ozéneux",),
    "ozobrome": ("ozobrome",),
    "ozobromes": ("ozobrome",),
    "ozonométrique": ("ozonométrique",),
    "ozonométriques": ("ozonométrique",),
    "ozonoscopique": ("ozonoscopique",),
    "ozonoscopiques": ("ozonoscopique",),
    "pachtou": ("pachtou",),
    "pachtous": ("pachtou",),
    "pachyderme": ("pachyderme",),
    "pachydermes": ("pachyderme",),
    "pachydermique": ("pachydermique",),
    "pachydermiques": ("pachydermique",),
    "pachytène": ("pachytène",),
    "pachytènes": ("pachytène",),
    "pacificateur": ("pacificateur",),
    "pacificateurs": ("pacificateur",),
    "pacificatrice": ("pacificateur",),
    "pacificatrices": ("pacificateur",),
    "pacifique": ("pacifique",),
    "pacifiques": ("pacifique",),
    "pacifiste": ("pacifiste",),
    "pacifistes": ("pacifiste",),
    "paf": ("paf",),
    "pagailleur": ("pagailleur",),
    "pagailleurs": ("pagailleur",),
    "pagailleuse": ("pagailleur",),
    "pagailleuses": ("pagailleur",),
    "pagasétique": ("pagasétique",),
    "pagasétiques": ("pagasétique",),
    "pagétique": ("pagétique",),
    "pagétiques": ("pagétique",),
    "pagétoïde": ("pagétoïde",),
    "pagétoïdes": ("pagétoïde",),
    "pagnon": ("pagnon",),
    "pagnons": ("pagnon",),
    "pagode": ("pagode",),
    "pahari": ("pahari",),
    "paharis": ("pahari",),
    "païen": ("païen",),
    "païenne": ("païen",),
    "païennes": ("païen",),
    "païens": ("païen",),
    "paillée": ("paillé",),
    "paillées": ("paillé",),
    "paillé": ("paillé",),
    "paille": ("paille",),
    "paillés": ("paillé",),
    "pailleuse": ("pailleux",),
    "pailleuses": ("pailleux",),
    "pailleux": ("pailleux",),
    "paisible": ("paisible",),
    "paisibles": ("paisible",),
    "pakistanaise": ("pakistanais",),
    "pakistanaises": ("pakistanais",),
    "pakistanais": ("pakistanais",),
    "palamite": ("palamite",),
    "palamites": ("palamite",),
    "palancrier": ("palancrier",),
    "palancriers": ("palancrier",),
    "palangrier": ("palangrier",),
    "palangriers": ("palangrier",),
    "palatable": ("palatable",),
    "palatables": ("palatable",),
    "palatale": ("palatal",),
    "palatales": ("palatal",),
    "palatal": ("palatal",),
    "palataux": ("palatal",),
    "palatiale": ("palatial",),
    "palatiales": ("palatial",),
    "palatial": ("palatial",),
    "palatiaux": ("palatial",),
    "palatoalvéolaire": ("palatoalvéolaire",),
    "palatoalvéolaires": ("palatoalvéolaire",),
    "palatographique": ("palatographique",),
    "palatographiques": ("palatographique",),
    "paléanthropien": ("paléanthropien",),
    "paléanthropienne": ("paléanthropien",),
    "paléanthropiennes": ("paléanthropien",),
    "paléanthropiens": ("paléanthropien",),
    "palée": ("palé",),
    "palées": ("palé",),
    "palé": ("palé",),
    "pâle": ("pâle",),
    "palés": ("palé",),
    "pâles": ("pâle",),
    "paléarctique": ("paléarctique",),
    "paléarctiques": ("paléarctique",),
    "paléoasiatique": ("paléoasiatique",),
    "paléoasiatiques": ("paléoasiatique",),
    "paléobioclimatologique": ("paléobioclimatologique",),
    "paléobioclimatologiques": ("paléobioclimatologique",),
    "paléobotanique": ("paléobotanique",),
    "paléobotaniques": ("paléobotanique",),
    "paléochrétien": ("paléochrétien",),
    "paléo-chrétienne": ("paléo-chrétien",),
    "paléochrétienne": ("paléochrétien",),
    "paléochrétiennes": ("paléochrétien",),
    "paléochrétiens": ("paléochrétien",),
    "paléoclimatique": ("paléoclimatique",),
    "paléoclimatiques": ("paléoclimatique",),
    "paléoclimatologique": ("paléoclimatologique",),
    "paléoclimatologiques": ("paléoclimatologique",),
    "paléoendémique": ("paléoendémique",),
    "paléoendémiques": ("paléoendémique",),
    "paléogéographique": ("paléogéographique",),
    "paléogéographiques": ("paléogéographique",),
    "paléognathe": ("paléognathe",),
    "paléognathes": ("paléognathe",),
    "paléographique": ("paléographique",),
    "paléographiques": ("paléographique",),
    "paléohébraïque": ("paléohébraïque",),
    "paléohébraïques": ("paléohébraïque",),
    "paléolithique": ("paléolithique",),
    "paléolithiques": ("paléolithique",),
    "paléomagnétique": ("paléomagnétique",),
    "paléomagnétiques": ("paléomagnétique",),
    "paléontologique": ("paléontologique",),
    "paléontologiques": ("paléontologique",),
    "paléosibérien": ("paléosibérien",),
    "paléosibérienne": ("paléosibérien",),
    "paléosibériennes": ("paléosibérien",),
    "paléosibériens": ("paléosibérien",),
    "paléotropicale": ("paléotropical",),
    "paléotropicales": ("paléotropical",),
    "paléotropical": ("paléotropical",),
    "paléotropicaux": ("paléotropical",),
    "paléovolcanique": ("paléovolcanique",),
    "paléovolcaniques": ("paléovolcanique",),
    "paléozoïque": ("paléozoïque",),
    "paléozoïques": ("paléozoïque",),
    "paléozoologique": ("paléozoologique",),
    "paléozoologiques": ("paléozoologique",),
    "palestinien": ("palestinien",),
    "palestinienne": ("palestinien",),
    "palestiniennes": ("palestinien",),
    "palestiniens": ("palestinien",),
    "palestrique": ("palestrique",),
    "palestriques": ("palestrique",),
    "palettisable": ("palettisable",),
    "palettisables": ("palettisable",),
    "pâlichon": ("pâlichon",),
    "pâlichonne": ("pâlichon",),
    "pâlichonnes": ("pâlichon",),
    "pâlichons": ("pâlichon",),
    "palière": ("palière",),
    "palières": ("palière",),
    "palindrome": ("palindrome",),
    "palindromes": ("palindrome",),
    "palindromique": ("palindromique",),
    "palindromiques": ("palindromique",),
    "palingénésique": ("palingénésique",),
    "palingénésiques": ("palingénésique",),
    "palingénétique": ("palingénétique",),
    "palingénétiques": ("palingénétique",),
    "palingnostique": ("palingnostique",),
    "palingnostiques": ("palingnostique",),
    "palinodique": ("palinodique",),
    "palinodiques": ("palinodique",),
    "palinspastique": ("palinspastique",),
    "palinspastiques": ("palinspastique",),
    "palissadique": ("palissadique",),
    "palissadiques": ("palissadique",),
    "palissonneur": ("palissonneur",),
    "palissonneurs": ("palissonneur",),
    "palissonneuse": ("palissonneur",),
    "palissonneuses": ("palissonneur",),
    "palladeuse": ("palladeux",),
    "palladeuses": ("palladeux",),
    "palladeux": ("palladeux",),
    "palladien": ("palladien",),
    "palladienne": ("palladien",),
    "palladiennes": ("palladien",),
    "palladiens": ("palladien",),
    "palladique": ("palladique",),
    "palladiques": ("palladique",),
    "palléale": ("palléal",),
    "palléales": ("palléal",),
    "palléal": ("palléal",),
    "palléaux": ("palléal",),
    "palliatif": ("palliatif",),
    "palliatifs": ("palliatif",),
    "palliative": ("palliatif",),
    "palliatives": ("palliatif",),
    "pallidale": ("pallidal",),
    "pallidales": ("pallidal",),
    "pallidal": ("pallidal",),
    "pallidaux": ("pallidal",),
    "palmaire": ("palmaire",),
    "palmaires": ("palmaire",),
    "palmatifide": ("palmatifide",),
    "palmatifides": ("palmatifide",),
    "palmatipartite": ("palmatipartite",),
    "palmatipartites": ("palmatipartite",),
    "palmifide": ("palmifide",),
    "palmifides": ("palmifide",),
    "palmiforme": ("palmiforme",),
    "palmiformes": ("palmiforme",),
    "palmiparti": ("palmiparti",),
    "palmipartis": ("palmiparti",),
    "palmipartite": ("palmipartite",),
    "palmipartites": ("palmipartite",),
    "palmipède": ("palmipède",),
    "palmipèdes": ("palmipède",),
    "palmiste": ("palmiste",),
    "palmistes": ("palmiste",),
    "palmitique": ("palmitique",),
    "palmitiques": ("palmitique",),
    "palmitoléique": ("palmitoléique",),
    "palmitoléiques": ("palmitoléique",),
    "palmyrénien": ("palmyrénien",),
    "palmyrénienne": ("palmyrénien",),
    "palmyréniennes": ("palmyrénien",),
    "palmyréniens": ("palmyrénien",),
    "paloise": ("palois",),
    "paloises": ("palois",),
    "palois": ("palois",),
    "pâlot": ("pâlot",),
    "pâlots": ("pâlot",),
    "pâlotte": ("pâlot",),
    "pâlottes": ("pâlot",),
    "palpable": ("palpable",),
    "palpables": ("palpable",),
    "palpébrale": ("palpébral",),
    "palpébrales": ("palpébral",),
    "palpébral": ("palpébral",),
    "palpébraux": ("palpébral",),
    "palpicorne": ("palpicorne",),
    "palpicornes": ("palpicorne",),
    "palpiforme": ("palpiforme",),
    "palpiformes": ("palpiforme",),
    "paludéen": ("paludéen",),
    "paludéenne": ("paludéen",),
    "paludéennes": ("paludéen",),
    "paludéens": ("paludéen",),
    "paludicole": ("paludicole",),
    "paludicoles": ("paludicole",),
    "paludique": ("paludique",),
    "paludiques": ("paludique",),
    "paludologique": ("paludologique",),
    "paludologiques": ("paludologique",),
    "paludométrique": ("paludométrique",),
    "paludométriques": ("paludométrique",),
    "palustre": ("palustre",),
    "palustres": ("palustre",),
    "palynologique": ("palynologique",),
    "palynologiques": ("palynologique",),
    "pampéen": ("pampéen",),
    "pampéenne": ("pampéen",),
    "pampéennes": ("pampéen",),
    "pampéens": ("pampéen",),
    "panacinaire": ("panacinaire",),
    "panacinaires": ("panacinaire",),
    "pan-africaine": ("pan-africain",),
    "panafricaniste": ("panafricaniste",),
    "panafricanistes": ("panafricaniste",),
    "panaire": ("panaire",),
    "panaires": ("panaire",),
    "pan-allemand": ("pan-allemand",),
    "pan-allemands": ("pan-allemand",),
    "panaméen": ("panaméen",),
    "panaméenne": ("panaméen",),
    "panaméennes": ("panaméen",),
    "panaméens": ("panaméen",),
    "panaméricaine": ("panaméricain",),
    "pan-américaines": ("pan-américain",),
    "panaméricaines": ("panaméricain",),
    "panaméricain": ("panaméricain",),
    "panaméricains": ("panaméricain",),
    "panaméricaniste": ("panaméricaniste",),
    "panaméricanistes": ("panaméricaniste",),
    "panamien": ("panamien",),
    "panamienne": ("panamien",),
    "panamiennes": ("panamien",),
    "panamiens": ("panamien",),
    "panarabe": ("panarabe",),
    "panarabes": ("panarabe",),
    "panasiatique": ("panasiatique",),
    "panasiatiques": ("panasiatique",),
    "panathénaïque": ("panathénaïque",),
    "panathénaïques": ("panathénaïque",),
    "pancanadien": ("pancanadien",),
    "pancanadienne": ("pancanadien",),
    "pancanadiennes": ("pancanadien",),
    "pancanadiens": ("pancanadien",),
    "panchromatique": ("panchromatique",),
    "panchromatiques": ("panchromatique",),
    "panchronique": ("panchronique",),
    "panchroniques": ("panchronique",),
    "pancratique": ("pancratique",),
    "pancratiques": ("pancratique",),
    "pancréaticosolaire": ("pancréaticosolaire",),
    "pancréaticosolaires": ("pancréaticosolaire",),
    "pancréatique": ("pancréatique",),
    "pancréatiques": ("pancréatique",),
    "pancréatogène": ("pancréatogène",),
    "pancréatogènes": ("pancréatogène",),
    "pancréatoprive": ("pancréatoprive",),
    "pancréatoprives": ("pancréatoprive",),
    "pancréatotrope": ("pancréatotrope",),
    "pancréatotropes": ("pancréatotrope",),
    "pandémique": ("pandémique",),
    "pandémiques": ("pandémique",),
    "panégyrique": ("panégyrique",),
    "panégyriques": ("panégyrique",),
    "pan-européen": ("pan-européen",),
    "paneuropéen": ("paneuropéen",),
    "pan-européenne": ("pan-européen",),
    "paneuropéenne": ("paneuropéen",),
    "paneuropéennes": ("paneuropéen",),
    "paneuropéens": ("paneuropéen",),
    "pangermanique": ("pangermanique",),
    "pangermaniques": ("pangermanique",),
    "pangermaniste": ("pangermaniste",),
    "pangermanistes": ("pangermaniste",),
    "panhellénique": ("panhellénique",),
    "panhelléniques": ("panhellénique",),
    "panifiable": ("panifiable",),
    "panifiables": ("panifiable",),
    "panique": ("panique",),
    "paniques": ("panique",),
    "panislamique": ("panislamique",),
    "panislamiques": ("panislamique",),
    "panjabi": ("panjabi",),
    "panjabis": ("panjabi",),
    "panlobulaire": ("panlobulaire",),
    "panlobulaires": ("panlobulaire",),
    "panmictique": ("panmictique",),
    "panmictiques": ("panmictique",),
    "panneuse": ("panneux",),
    "panneuses": ("panneux",),
    "panneux": ("panneux",),
    "pannonien": ("pannonien",),
    "pannonienne": ("pannonien",),
    "pannoniennes": ("pannonien",),
    "pannoniens": ("pannonien",),
    "panoïstique": ("panoïstique",),
    "panoïstiques": ("panoïstique",),
    "panoptique": ("panoptique",),
    "panoptiques": ("panoptique",),
    "panoramique": ("panoramique",),
    "panoramiques": ("panoramique",),
    "panrétinien": ("panrétinien",),
    "panrétinienne": ("panrétinien",),
    "panrétiniennes": ("panrétinien",),
    "panrétiniens": ("panrétinien",),
    "panserbe": ("panserbe",),
    "panserbes": ("panserbe",),
    "pansexualiste": ("pansexualiste",),
    "pansexualistes": ("pansexualiste",),
    "panslave": ("panslave",),
    "panslaves": ("panslave",),
    "panslaviste": ("panslaviste",),
    "panslavistes": ("panslaviste",),
    "pantagruélique": ("pantagruélique",),
    "pantagruéliques": ("pantagruélique",),
    "panthéiste": ("panthéiste",),
    "panthéistes": ("panthéiste",),
    "panthéistique": ("panthéistique",),
    "panthéistiques": ("panthéistique",),
    "pantocrator": ("pantocrator",),
    "pantographique": ("pantographique",),
    "pantographiques": ("pantographique",),
    "pantoise": ("pantois",),
    "pantoises": ("pantois",),
    "pantois": ("pantois",),
    "pantomime": ("pantomime",),
    "pantomimes": ("pantomime",),
    "pantos": ("pantos",),
    "pantothénique": ("pantothénique",),
    "pantothéniques": ("pantothénique",),
    "pantropicale": ("pantropical",),
    "pantropicales": ("pantropical",),
    "pantropical": ("pantropical",),
    "pantropicaux": ("pantropical",),
    "papable": ("papable",),
    "papables": ("papable",),
    "papale": ("papal",),
    "papales": ("papal",),
    "papal": ("papal",),
    "papaux": ("papal",),
    "paperassière": ("paperassier",),
    "paperassières": ("paperassier",),
    "paperassier": ("paperassier",),
    "paperassiers": ("paperassier",),
    "papetière": ("papetier",),
    "papetières": ("papetier",),
    "papetier": ("papetier",),
    "papetiers": ("papetier",),
    "papillaire": ("papillaire",),
    "papillaires": ("papillaire",),
    "papilleuse": ("papilleux",),
    "papilleuses": ("papilleux",),
    "papilleux": ("papilleux",),
    "papillifère": ("papillifère",),
    "papillifères": ("papillifère",),
    "papilliforme": ("papilliforme",),
    "papilliformes": ("papilliforme",),
    "papillomateuse": ("papillomateux",),
    "papillomateuses": ("papillomateux",),
    "papillomateux": ("papillomateux",),
    "papillon": ("papillon",),
    "papiste": ("papiste",),
    "papistes": ("papiste",),
    "papuleuse": ("papuleux",),
    "papuleuses": ("papuleux",),
    "papuleux": ("papuleux",),
    "papulonécrotique": ("papulonécrotique",),
    "papulonécrotiques": ("papulonécrotique",),
    "papyriforme": ("papyriforme",),
    "papyriformes": ("papyriforme",),
    "papyrologique": ("papyrologique",),
    "papyrologiques": ("papyrologique",),
    "parabancaire": ("parabancaire",),
    "parabancaires": ("parabancaire",),
    "parabasale": ("parabasal",),
    "parabasales": ("parabasal",),
    "parabasal": ("parabasal",),
    "parabasaux": ("parabasal",),
    "parabasedowien": ("parabasedowien",),
    "parabasedowienne": ("parabasedowien",),
    "parabasedowiennes": ("parabasedowien",),
    "parabasedowiens": ("parabasedowien",),
    "parable": ("parable",),
    "parables": ("parable",),
    "parabolique": ("parabolique",),
    "paraboliques": ("parabolique",),
    "paraboloïdale": ("paraboloïdal",),
    "paraboloïdales": ("paraboloïdal",),
    "paraboloïdal": ("paraboloïdal",),
    "paraboloïdaux": ("paraboloïdal",),
    "paraboloïde": ("paraboloïde",),
    "paraboloïdes": ("paraboloïde",),
    "parabrachiale": ("parabrachial",),
    "parabrachiales": ("parabrachial",),
    "parabrachial": ("parabrachial",),
    "parabrachiaux": ("parabrachial",),
    "parabutoxyphénylacéthydroxamique": ("parabutoxyphénylacéthydroxamique",),
    "parabutoxyphénylacéthydroxamiques": ("parabutoxyphénylacéthydroxamique",),
    "paracentrale": ("paracentral",),
    "paracentrales": ("paracentral",),
    "paracentral": ("paracentral",),
    "paracentraux": ("paracentral",),
    "paracentrique": ("paracentrique",),
    "paracentriques": ("paracentrique",),
    "paracervicale": ("paracervical",),
    "paracervicales": ("paracervical",),
    "paracervical": ("paracervical",),
    "paracervicaux": ("paracervical",),
    "parachevable": ("parachevable",),
    "parachevables": ("parachevable",),
    "parachimique": ("parachimique",),
    "parachimiques": ("parachimique",),
    "parachutable": ("parachutable",),
    "parachutables": ("parachutable",),
    "parachutiste": ("parachutiste",),
    "parachutistes": ("parachutiste",),
    "paraclinique": ("paraclinique",),
    "paracliniques": ("paraclinique",),
    "paracoccidioïdale": ("paracoccidioïdal",),
    "paracoccidioïdales": ("paracoccidioïdal",),
    "paracoccidioïdal": ("paracoccidioïdal",),
    "paracoccidioïdaux": ("paracoccidioïdal",),
    "paracommerciale": ("paracommercial",),
    "paracommerciales": ("paracommercial",),
    "paracommercial": ("paracommercial",),
    "paracommerciaux": ("paracommercial",),
    "paraconique": ("paraconique",),
    "paraconiques": ("paraconique",),
    "paradentaire": ("paradentaire",),
    "paradentaires": ("paradentaire",),
    "paradiabétique": ("paradiabétique",),
    "paradiabétiques": ("paradiabétique",),
    "paradigmatique": ("paradigmatique",),
    "paradigmatiques": ("paradigmatique",),
    "paradisiaque": ("paradisiaque",),
    "paradisiaques": ("paradisiaque",),
    "paradoxale": ("paradoxal",),
    "paradoxales": ("paradoxal",),
    "paradoxal": ("paradoxal",),
    "paradoxaux": ("paradoxal",),
    "paraesthésique": ("paraesthésique",),
    "paraesthésiques": ("paraesthésique",),
    "paraétatique": ("paraétatique",),
    "paraétatiques": ("paraétatique",),
    "paraffineuse": ("paraffineux",),
    "paraffineuses": ("paraffineux",),
    "paraffineux": ("paraffineux",),
    "paraffinique": ("paraffinique",),
    "paraffiniques": ("paraffinique",),
    "parafiscale": ("parafiscal",),
    "parafiscales": ("parafiscal",),
    "parafiscal": ("parafiscal",),
    "parafiscaux": ("parafiscal",),
    "paragénésique": ("paragénésique",),
    "paragénésiques": ("paragénésique",),
    "paragogique": ("paragogique",),
    "paragogiques": ("paragogique",),
    "paragrêle": ("paragrêle",),
    "paragrêles": ("paragrêle",),
    "paraguayen": ("paraguayen",),
    "paraguayenne": ("paraguayen",),
    "paraguayennes": ("paraguayen",),
    "paraguayens": ("paraguayen",),
    "parahôtelière": ("parahôtelier",),
    "parahôtelières": ("parahôtelier",),
    "parahôtelier": ("parahôtelier",),
    "parahôteliers": ("parahôtelier",),
    "parahypnique": ("parahypnique",),
    "parahypniques": ("parahypnique",),
    "paraleucémique": ("paraleucémique",),
    "paraleucémiques": ("paraleucémique",),
    "paralinguistique": ("paralinguistique",),
    "paralinguistiques": ("paralinguistique",),
    "paralittéraire": ("paralittéraire",),
    "paralittéraires": ("paralittéraire",),
    "paraliturgique": ("paraliturgique",),
    "paraliturgiques": ("paraliturgique",),
    "parallactique": ("parallactique",),
    "parallactiques": ("parallactique",),
    "parallèle": ("parallèle",),
    "parallèles": ("parallèle",),
    "parallélépipédique": ("parallélépipédique",),
    "parallélépipédiques": ("parallélépipédique",),
    "parallélisable": ("parallélisable",),
    "parallélisables": ("parallélisable",),
    "paralogique": ("paralogique",),
    "paralogiques": ("paralogique",),
    "paralytique": ("paralytique",),
    "paralytiques": ("paralytique",),
    "paramagnétique": ("paramagnétique",),
    "paramagnétiques": ("paramagnétique",),
    "paramédicale": ("paramédical",),
    "paramédicales": ("paramédical",),
    "paramédical": ("paramédical",),
    "paramédicaux": ("paramédical",),
    "paramétrable": ("paramétrable",),
    "paramétrables": ("paramétrable",),
    "paramétrique": ("paramétrique",),
    "paramétriques": ("paramétrique",),
    "paramigraineuse": ("paramigraineux",),
    "paramigraineuses": ("paramigraineux",),
    "paramigraineux": ("paramigraineux",),
    "paramilitaire": ("paramilitaire",),
    "paramilitaires": ("paramilitaire",),
    "paramunicipale": ("paramunicipal",),
    "paramunicipales": ("paramunicipal",),
    "paramunicipal": ("paramunicipal",),
    "paramunicipaux": ("paramunicipal",),
    "paranéoplasique": ("paranéoplasique",),
    "paranéoplasiques": ("paranéoplasique",),
    "paranéoplastique": ("paranéoplastique",),
    "paranéoplastiques": ("paranéoplastique",),
    "paranéphrétique": ("paranéphrétique",),
    "paranéphrétiques": ("paranéphrétique",),
    "parano": ("parano",),
    "paranos": ("parano",),
    "paranoïaque": ("paranoïaque",),
    "paranoïaques": ("paranoïaque",),
    "paranoïde": ("paranoïde",),
    "paranoïdes": ("paranoïde",),
    "paranormale": ("paranormal",),
    "paranormales": ("paranormal",),
    "paranormal": ("paranormal",),
    "paranormaux": ("paranormal",),
    "paranthélique": ("paranthélique",),
    "paranthéliques": ("paranthélique",),
    "paranucléaire": ("paranucléaire",),
    "paranucléaires": ("paranucléaire",),
    "paraovarien": ("paraovarien",),
    "paraovarienne": ("paraovarien",),
    "paraovariennes": ("paraovarien",),
    "paraovariens": ("paraovarien",),
    "parapétrolière": ("parapétrolier",),
    "parapétrolières": ("parapétrolier",),
    "parapétrolier": ("parapétrolier",),
    "parapétroliers": ("parapétrolier",),
    "parapexien": ("parapexien",),
    "parapexienne": ("parapexien",),
    "parapexiennes": ("parapexien",),
    "parapexiens": ("parapexien",),
    "parapharmaceutique": ("parapharmaceutique",),
    "parapharmaceutiques": ("parapharmaceutique",),
    "paraphasique": ("paraphasique",),
    "paraphasiques": ("paraphasique",),
    "paraphernale": ("paraphernal",),
    "paraphernales": ("paraphernal",),
    "paraphernal": ("paraphernal",),
    "paraphernaux": ("paraphernal",),
    "paraphrasable": ("paraphrasable",),
    "paraphrasables": ("paraphrasable",),
    "paraphrastique": ("paraphrastique",),
    "paraphrastiques": ("paraphrastique",),
    "paraphrène": ("paraphrène",),
    "paraphrènes": ("paraphrène",),
    "paraphrénique": ("paraphrénique",),
    "paraphréniques": ("paraphrénique",),
    "paraphronique": ("paraphronique",),
    "paraphroniques": ("paraphronique",),
    "paraphysiothérapique": ("paraphysiothérapique",),
    "paraphysiothérapiques": ("paraphysiothérapique",),
    "paraphysique": ("paraphysique",),
    "paraphysiques": ("paraphysique",),
    "parapinéale": ("parapinéal",),
    "parapinéales": ("parapinéal",),
    "parapinéal": ("parapinéal",),
    "parapinéaux": ("parapinéal",),
    "paraplégique": ("paraplégique",),
    "paraplégiques": ("paraplégique",),
    "parapneumonique": ("parapneumonique",),
    "parapneumoniques": ("parapneumonique",),
    "parapolicière": ("parapolicier",),
    "parapolicières": ("parapolicier",),
    "parapolicier": ("parapolicier",),
    "parapoliciers": ("parapolicier",),
    "paraprotéinémique": ("paraprotéinémique",),
    "paraprotéinémiques": ("paraprotéinémique",),
    "parapsychique": ("parapsychique",),
    "parapsychiques": ("parapsychique",),
    "parapsychologique": ("parapsychologique",),
    "parapsychologiques": ("parapsychologique",),
    "parapublic": ("parapublic",),
    "parapublics": ("parapublic",),
    "parapublique": ("parapublic",),
    "parapubliques": ("parapublic",),
    "pararénale": ("pararénal",),
    "pararénales": ("pararénal",),
    "pararénal": ("pararénal",),
    "pararénaux": ("pararénal",),
    "pararosolique": ("pararosolique",),
    "pararosoliques": ("pararosolique",),
    "parasagittale": ("parasagittal",),
    "parasagittales": ("parasagittal",),
    "parasagittal": ("parasagittal",),
    "parasagittaux": ("parasagittal",),
    "parascientifique": ("parascientifique",),
    "parascientifiques": ("parascientifique",),
    "parascolaire": ("parascolaire",),
    "parascolaires": ("parascolaire",),
    "parasismique": ("parasismique",),
    "parasismiques": ("parasismique",),
    "parasitaire": ("parasitaire",),
    "parasitaires": ("parasitaire",),
    "parasite": ("parasite",),
    "parasites": ("parasite",),
    "parasiticide": ("parasiticide",),
    "parasiticides": ("parasiticide",),
    "parasitique": ("parasitique",),
    "parasitiques": ("parasitique",),
    "parasitotrope": ("parasitotrope",),
    "parasitotropes": ("parasitotrope",),
    "parasorbique": ("parasorbique",),
    "parasorbiques": ("parasorbique",),
    "parastatale": ("parastatal",),
    "parastatales": ("parastatal",),
    "parastatal": ("parastatal",),
    "parastataux": ("parastatal",),
    "parasternale": ("parasternal",),
    "parasternales": ("parasternal",),
    "parasternal": ("parasternal",),
    "parasternaux": ("parasternal",),
    "parastremmatique": ("parastremmatique",),
    "parastremmatiques": ("parastremmatique",),
    "parasympathicolytique": ("parasympathicolytique",),
    "parasympathicolytiques": ("parasympathicolytique",),
    "parasympathicomimétique": ("parasympathicomimétique",),
    "parasympathicomimétiques": ("parasympathicomimétique",),
    "parasympathique": ("parasympathique",),
    "parasympathiques": ("parasympathique",),
    "parasympatholytique": ("parasympatholytique",),
    "parasympatholytiques": ("parasympatholytique",),
    "parasympathomimétique": ("parasympathomimétique",),
    "parasympathomimétiques": ("parasympathomimétique",),
    "parasynthétique": ("parasynthétique",),
    "parasynthétiques": ("parasynthétique",),
    "paratactique": ("paratactique",),
    "paratactiques": ("paratactique",),
    "paraténique": ("paraténique",),
    "paraténiques": ("paraténique",),
    "paratesticulaire": ("paratesticulaire",),
    "paratesticulaires": ("paratesticulaire",),
    "parathyréoprive": ("parathyréoprive",),
    "parathyréoprives": ("parathyréoprive",),
    "parathyréotrope": ("parathyréotrope",),
    "parathyréotropes": ("parathyréotrope",),
    "parathyroïde": ("parathyroïde",),
    "parathyroïdes": ("parathyroïde",),
    "parathyroïdien": ("parathyroïdien",),
    "parathyroïdienne": ("parathyroïdien",),
    "parathyroïdiennes": ("parathyroïdien",),
    "parathyroïdiens": ("parathyroïdien",),
    "paratrigéminale": ("paratrigéminal",),
    "paratrigéminales": ("paratrigéminal",),
    "paratrigéminal": ("paratrigéminal",),
    "paratrigéminaux": ("paratrigéminal",),
    "paratuberculeuse": ("paratuberculeux",),
    "paratuberculeuses": ("paratuberculeux",),
    "paratuberculeux": ("paratuberculeux",),
    "paratyphique": ("paratyphique",),
    "paratyphiques": ("paratyphique",),
    "paratyphoïde": ("paratyphoïde",),
    "paratyphoïdes": ("paratyphoïde",),
    "parautochtone": ("parautochtone",),
    "parautochtones": ("parautochtone",),
    "paravalanche": ("paravalanche",),
    "paravalanches": ("paravalanche",),
    "paravertébrale": ("paravertébral",),
    "paravertébrales": ("paravertébral",),
    "paravertébral": ("paravertébral",),
    "paravertébraux": ("paravertébral",),
    "paravivipare": ("paravivipare",),
    "paravivipares": ("paravivipare",),
    "paraxiale": ("paraxial",),
    "paraxiales": ("paraxial",),
    "paraxial": ("paraxial",),
    "paraxiaux": ("paraxial",),
    "paraxonien": ("paraxonien",),
    "paraxoniens": ("paraxonien",),
    "parcellaire": ("parcellaire",),
    "parcellaires": ("parcellaire",),
    "parchemineuse": ("parchemineux",),
    "parchemineuses": ("parchemineux",),
    "parchemineux": ("parchemineux",),
    "parcimonieuse": ("parcimonieux",),
    "parcimonieuses": ("parcimonieux",),
    "parcimonieux": ("parcimonieux",),
    "parcoureur": ("parcoureur",),
    "parcoureurs": ("parcoureur",),
    "parcoureuse": ("parcoureur",),
    "parcoureuses": ("parcoureur",),
    "pardonnable": ("pardonnable",),
    "pardonnables": ("pardonnable",),
    "parèdre": ("parèdre",),
    "parèdres": ("parèdre",),
    "parégorique": ("parégorique",),
    "parégoriques": ("parégorique",),
    "pareille": ("pareil",),
    "pareilles": ("pareil",),
    "pareil": ("pareil",),
    "pareils": ("pareil",),
    "parenchymateuse": ("parenchymateux",),
    "parenchymateuses": ("parenchymateux",),
    "parenchymateux": ("parenchymateux",),
    "parentale": ("parental",),
    "parentales": ("parental",),
    "parental": ("parental",),
    "parentaux": ("parental",),
    "parentérale": ("parentéral",),
    "parentérales": ("parentéral",),
    "parentéral": ("parentéral",),
    "parentéraux": ("parentéral",),
    "parenthétique": ("parenthétique",),
    "parenthétiques": ("parenthétique",),
    "paresseuse": ("paresseux",),
    "paresseuses": ("paresseux",),
    "paresseux": ("paresseux",),
    "paresthésique": ("paresthésique",),
    "paresthésiques": ("paresthésique",),
    "parétique": ("parétique",),
    "parétiques": ("parétique",),
    "parhélique": ("parhélique",),
    "parhéliques": ("parhélique",),
    "paria": ("paria",),
    "parias": ("paria",),
    "pariétale": ("pariétal",),
    "pariétales": ("pariétal",),
    "pariétal": ("pariétal",),
    "pariétaux": ("pariétal",),
    "parisien": ("parisien",),
    "parisienne": ("parisien",),
    "parisiennes": ("parisien",),
    "parisiens": ("parisien",),
    "parisis": ("parisis",),
    "parisyllabe": ("parisyllabe",),
    "parisyllabes": ("parisyllabe",),
    "parisyllabique": ("parisyllabique",),
    "parisyllabiques": ("parisyllabique",),
    "paritaire": ("paritaire",),
    "paritaires": ("paritaire",),
    "parjure": ("parjure",),
    "parjures": ("parjure",),
    "parkinsonien": ("parkinsonien",),
    "parkinsonienne": ("parkinsonien",),
    "parkinsoniennes": ("parkinsonien",),
    "parkinsoniens": ("parkinsonien",),
    "parlementaire": ("parlementaire",),
    "parlementaires": ("parlementaire",),
    "parlementariste": ("parlementariste",),
    "parlementaristes": ("parlementariste",),
    "parleur": ("parleur",),
    "parleurs": ("parleur",),
    "parleuse": ("parleur",),
    "parleuses": ("parleur",),
    "parme": ("parme",),
    "parnassien": ("parnassien",),
    "parnassienne": ("parnassien",),
    "parnassiennes": ("parnassien",),
    "parnassiens": ("parnassien",),
    "parochiale": ("parochial",),
    "parochiales": ("parochial",),
    "parochial": ("parochial",),
    "parochiaux": ("parochial",),
    "parodique": ("parodique",),
    "parodiques": ("parodique",),
    "parodontale": ("parodontal",),
    "parodontales": ("parodontal",),
    "parodontal": ("parodontal",),
    "parodontaux": ("parodontal",),
    "paroissiale": ("paroissial",),
    "paroissiales": ("paroissial",),
    "paroissial": ("paroissial",),
    "paroissiaux": ("paroissial",),
    "parolfactif": ("parolfactif",),
    "parolfactifs": ("parolfactif",),
    "parolfactive": ("parolfactif",),
    "parolfactives": ("parolfactif",),
    "paronyme": ("paronyme",),
    "paronymes": ("paronyme",),
    "paronymique": ("paronymique",),
    "paronymiques": ("paronymique",),
    "parostale": ("parostal",),
    "parostales": ("parostal",),
    "parostal": ("parostal",),
    "parostaux": ("parostal",),
    "parostéale": ("parostéal",),
    "parostéales": ("parostéal",),
    "parostéal": ("parostéal",),
    "parostéaux": ("parostéal",),
    "parotide": ("parotide",),
    "parotides": ("parotide",),
    "parotidien": ("parotidien",),
    "parotidienne": ("parotidien",),
    "parotidiennes": ("parotidien",),
    "parotidiens": ("parotidien",),
    "parotique": ("parotique",),
    "parotiques": ("parotique",),
    "parotoïde": ("parotoïde",),
    "parotoïdes": ("parotoïde",),
    "paroxysmale": ("paroxysmal",),
    "paroxysmales": ("paroxysmal",),
    "paroxysmal": ("paroxysmal",),
    "paroxysmaux": ("paroxysmal",),
    "paroxysmique": ("paroxysmique",),
    "paroxysmiques": ("paroxysmique",),
    "paroxystique": ("paroxystique",),
    "paroxystiques": ("paroxystique",),
    "paroxyton": ("paroxyton",),
    "paroxytons": ("paroxyton",),
    "paroxytonique": ("paroxytonique",),
    "paroxytoniques": ("paroxytonique",),
    "parpaigne": ("parpaigne",),
    "parpaignes": ("parpaigne",),
    "parraineur": ("parraineur",),
    "parraineurs": ("parraineur",),
    "parraineuse": ("parraineur",),
    "parraineuses": ("parraineur",),
    "parricide": ("parricide",),
    "parricides": ("parricide",),
    "parse": ("parse",),
    "parses": ("parse",),
    "partageable": ("partageable",),
    "partageables": ("partageable",),
    "partageur": ("partageur",),
    "partageurs": ("partageur",),
    "partageuse": ("partageux",),
    "partageuses": ("partageux",),
    "partageux": ("partageux",),
    "partenariale": ("partenarial",),
    "partenariales": ("partenarial",),
    "partenarial": ("partenarial",),
    "partenariaux": ("partenarial",),
    "par-terre": ("par-terre",),
    "parthe": ("parthe",),
    "parthes": ("parthe",),
    "parthenaise": ("parthenais",),
    "parthenaises": ("parthenais",),
    "parthenais": ("parthenais",),
    "parthénocarpique": ("parthénocarpique",),
    "parthénocarpiques": ("parthénocarpique",),
    "parthénogénétique": ("parthénogénétique",),
    "parthénogénétiques": ("parthénogénétique",),
    "partiaire": ("partiaire",),
    "partiaires": ("partiaire",),
    "partiale": ("partial",),
    "partiales": ("partial",),
    "partial": ("partial",),
    "partiaux": ("partial",),
    "participable": ("participable",),
    "participables": ("participable",),
    "participateur": ("participateur",),
    "participateurs": ("participateur",),
    "participatrice": ("participateur",),
    "participatrices": ("participateur",),
    "participatif": ("participatif",),
    "participatifs": ("participatif",),
    "participative": ("participatif",),
    "participatives": ("participatif",),
    "participationniste": ("participationniste",),
    "participationnistes": ("participationniste",),
    "participiale": ("participial",),
    "participiales": ("participial",),
    "participial": ("participial",),
    "participiaux": ("participial",),
    "particulaire": ("particulaire",),
    "particulaires": ("particulaire",),
    "particulariste": ("particulariste",),
    "particularistes": ("particulariste",),
    "particulière": ("particulier",),
    "particulières": ("particulier",),
    "particulier": ("particulier",),
    "particuliers": ("particulier",),
    "partielle": ("partiel",),
    "partielles": ("partiel",),
    "partiel": ("partiel",),
    "partiels": ("partiel",),
    "partite": ("partite",),
    "partites": ("partite",),
    "partitif": ("partitif",),
    "partitifs": ("partitif",),
    "partitive": ("partitif",),
    "partitives": ("partitif",),
    "partitocratique": ("partitocratique",),
    "partitocratiques": ("partitocratique",),
    "partouseur": ("partouseur",),
    "partouseurs": ("partouseur",),
    "partouseuse": ("partouseur",),
    "partouseuses": ("partouseur",),
    "partouzeur": ("partouzeur",),
    "partouzeurs": ("partouzeur",),
    "partouzeuse": ("partouzeur",),
    "partouzeuses": ("partouzeur",),
    "parvocellulaire": ("parvocellulaire",),
    "parvocellulaires": ("parvocellulaire",),
    "parvovirale": ("parvoviral",),
    "parvovirales": ("parvoviral",),
    "parvoviral": ("parvoviral",),
    "parvoviraux": ("parvoviral",),
    "pascale": ("pascal",),
    "pascales": ("pascal",),
    "pascal": ("pascal",),
    "pascaux": ("pascal",),
    "pascalien": ("pascalien",),
    "pascalienne": ("pascalien",),
    "pascaliennes": ("pascalien",),
    "pascaliens": ("pascalien",),
    "pasolinien": ("pasolinien",),
    "pasolinienne": ("pasolinien",),
    "pasoliniennes": ("pasolinien",),
    "pasoliniens": ("pasolinien",),
    "passable": ("passable",),
    "passables": ("passable",),
    "passagère": ("passager",),
    "passagères": ("passager",),
    "passager": ("passager",),
    "passagers": ("passager",),
    "passéiste": ("passéiste",),
    "passéistes": ("passéiste",),
    "passementière": ("passementier",),
    "passementières": ("passementier",),
    "passementier": ("passementier",),
    "passementiers": ("passementier",),
    "passible": ("passible",),
    "passibles": ("passible",),
    "passif": ("passif",),
    "passifs": ("passif",),
    "passive": ("passif",),
    "passives": ("passif",),
    "passionnelle": ("passionnel",),
    "passionnelles": ("passionnel",),
    "passionnel": ("passionnel",),
    "passionnels": ("passionnel",),
    "passivable": ("passivable",),
    "passivables": ("passivable",),
    "pastel": ("pastel",),
    "pasteurien": ("pasteurien",),
    "pasteurienne": ("pasteurien",),
    "pasteuriennes": ("pasteurien",),
    "pasteuriens": ("pasteurien",),
    "pastorale": ("pastoral",),
    "pastorales": ("pastoral",),
    "pastoral": ("pastoral",),
    "pastoraux": ("pastoral",),
    "pastorien": ("pastorien",),
    "pastorienne": ("pastorien",),
    "pastoriennes": ("pastorien",),
    "pastoriens": ("pastorien",),
    "pat": ("pat",),
    "pataphysique": ("pataphysique",),
    "pataphysiques": ("pataphysique",),
    "patatoïde": ("patatoïde",),
    "patatoïdes": ("patatoïde",),
    "pataugeur": ("pataugeur",),
    "pataugeurs": ("pataugeur",),
    "pataugeuse": ("pataugeur",),
    "pataugeuses": ("pataugeur",),
    "patellaire": ("patellaire",),
    "patellaires": ("patellaire",),
    "patentable": ("patentable",),
    "patentables": ("patentable",),
    "paternaliste": ("paternaliste",),
    "paternalistes": ("paternaliste",),
    "paterne": ("paterne",),
    "paternes": ("paterne",),
    "paternelle": ("paternel",),
    "paternelles": ("paternel",),
    "paternel": ("paternel",),
    "paternels": ("paternel",),
    "pâteuse": ("pâteux",),
    "pâteuses": ("pâteux",),
    "pâteux": ("pâteux",),
    "pathétique": ("pathétique",),
    "pathétiques": ("pathétique",),
    "pathique": ("pathique",),
    "pathiques": ("pathique",),
    "pathogène": ("pathogène",),
    "pathogènes": ("pathogène",),
    "pathogénétique": ("pathogénétique",),
    "pathogénétiques": ("pathogénétique",),
    "pathogénique": ("pathogénique",),
    "pathogéniques": ("pathogénique",),
    "pathognomonique": ("pathognomonique",),
    "pathognomoniques": ("pathognomonique",),
    "pathologique": ("pathologique",),
    "pathologiques": ("pathologique",),
    "pathologiste": ("pathologiste",),
    "pathologistes": ("pathologiste",),
    "pathomimique": ("pathomimique",),
    "pathomimiques": ("pathomimique",),
    "patibulaire": ("patibulaire",),
    "patibulaires": ("patibulaire",),
    "pâtissière": ("pâtissier",),
    "pâtissières": ("pâtissier",),
    "pâtissier": ("pâtissier",),
    "pâtissiers": ("pâtissier",),
    "patoise": ("patois",),
    "patoises": ("patois",),
    "patois": ("patois",),
    "patraque": ("patraque",),
    "patraques": ("patraque",),
    "patriarcale": ("patriarcal",),
    "patriarcales": ("patriarcal",),
    "patriarcal": ("patriarcal",),
    "patriarcaux": ("patriarcal",),
    "patriciale": ("patricial",),
    "patriciales": ("patricial",),
    "patricial": ("patricial",),
    "patriciaux": ("patricial",),
    "patricien": ("patricien",),
    "patricienne": ("patricien",),
    "patriciennes": ("patricien",),
    "patriciens": ("patricien",),
    "patride": ("patride",),
    "patrides": ("patride",),
    "patrilinéaire": ("patrilinéaire",),
    "patrilinéaires": ("patrilinéaire",),
    "patrilocale": ("patrilocal",),
    "patrilocales": ("patrilocal",),
    "patrilocal": ("patrilocal",),
    "patrilocaux": ("patrilocal",),
    "patrimoniale": ("patrimonial",),
    "patrimoniales": ("patrimonial",),
    "patrimonial": ("patrimonial",),
    "patrimoniaux": ("patrimonial",),
    "patriote": ("patriote",),
    "patriotes": ("patriote",),
    "patriotique": ("patriotique",),
    "patriotiques": ("patriotique",),
    "patristique": ("patristique",),
    "patristiques": ("patristique",),
    "patrocline": ("patrocline",),
    "patroclines": ("patrocline",),
    "patronale": ("patronal",),
    "patronales": ("patronal",),
    "patronal": ("patronal",),
    "patronaux": ("patronal",),
    "patron": ("patron",),
    "patronne": ("patronne",),
    "patronnes": ("patronne",),
    "patronnesse": ("patronnesse",),
    "patronnesses": ("patronnesse",),
    "patronymique": ("patronymique",),
    "patronymiques": ("patronymique",),
    "patrouilleur": ("patrouilleur",),
    "patrouilleurs": ("patrouilleur",),
    "patrouilleuse": ("patrouilleur",),
    "patrouilleuses": ("patrouilleur",),
    "pâturable": ("pâturable",),
    "pâturables": ("pâturable",),
    "pauciflore": ("pauciflore",),
    "pauciflores": ("pauciflore",),
    "paucisymptomatique": ("paucisymptomatique",),
    "paucisymptomatiques": ("paucisymptomatique",),
    "paulien": ("paulien",),
    "paulienne": ("paulien",),
    "pauliennes": ("paulien",),
    "pauliens": ("paulien",),
    "paulinien": ("paulinien",),
    "paulinienne": ("paulinien",),
    "pauliniennes": ("paulinien",),
    "pauliniens": ("paulinien",),
    "pauliste": ("pauliste",),
    "paulistes": ("pauliste",),
    "pauvre": ("pauvre",),
    "pauvres": ("pauvre",),
    "pauvret": ("pauvret",),
    "pauvrets": ("pauvret",),
    "pauvrette": ("pauvret",),
    "pauvrettes": ("pauvret",),
    "pavillonnaire": ("pavillonnaire",),
    "pavillonnaires": ("pavillonnaire",),
    "pavimentaire": ("pavimentaire",),
    "pavimentaires": ("pavimentaire",),
    "pavimenteuse": ("pavimenteux",),
    "pavimenteuses": ("pavimenteux",),
    "pavimenteux": ("pavimenteux",),
    "pavlovien": ("pavlovien",),
    "pavlovienne": ("pavlovien",),
    "pavloviennes": ("pavlovien",),
    "pavloviens": ("pavlovien",),
    "payable": ("payable",),
    "payables": ("payable",),
    "payeur": ("payeur",),
    "payeurs": ("payeur",),
    "payeuse": ("payeur",),
    "payeuses": ("payeur",),
    "paysagère": ("paysager",),
    "paysagères": ("paysager",),
    "paysager": ("paysager",),
    "paysagers": ("paysager",),
    "paysagiste": ("paysagiste",),
    "paysagistes": ("paysagiste",),
    "paysan": ("paysan",),
    "paysanne": ("paysan",),
    "paysannes": ("paysan",),
    "paysans": ("paysan",),
    "péagère": ("péager",),
    "péagères": ("péager",),
    "péager": ("péager",),
    "péagers": ("péager",),
    "peaucier": ("peaucier",),
    "peauciers": ("peaucier",),
    "peaussière": ("peaussier",),
    "peaussières": ("peaussier",),
    "peaussier": ("peaussier",),
    "peaussiers": ("peaussier",),
    "pec": ("pec",),
    "pecs": ("pec",),
    "peccable": ("peccable",),
    "peccables": ("peccable",),
    "peccante": ("peccante",),
    "peccantes": ("peccante",),
    "pêchable": ("pêchable",),
    "pêchables": ("pêchable",),
    "pêche": ("pêche",),
    "pécheresse": ("pécheur",),
    "pécheresses": ("pécheur",),
    "pécheur": ("pécheur",),
    "pêcheur": ("pêcheur",),
    "pécheurs": ("pécheur",),
    "pêcheurs": ("pêcheur",),
    "pêcheuse": ("pêcheur",),
    "pêcheuses": ("pêcheur",),
    "peckhamien": ("peckhamien",),
    "peckhamienne": ("peckhamien",),
    "peckhamiennes": ("peckhamien",),
    "peckhamiens": ("peckhamien",),
    "pectinéale": ("pectinéal",),
    "pectinéales": ("pectinéal",),
    "pectinéal": ("pectinéal",),
    "pectinéaux": ("pectinéal",),
    "pectique": ("pectique",),
    "pectiques": ("pectique",),
    "pectocellulosique": ("pectocellulosique",),
    "pectocellulosiques": ("pectocellulosique",),
    "pectolytique": ("pectolytique",),
    "pectolytiques": ("pectolytique",),
    "pectorale": ("pectoral",),
    "pectorales": ("pectoral",),
    "pectoral": ("pectoral",),
    "pectoraux": ("pectoral",),
    "pécuniaire": ("pécuniaire",),
    "pécuniaires": ("pécuniaire",),
    "pécunière": ("pécunier",),
    "pécunières": ("pécunier",),
    "pécunier": ("pécunier",),
    "pécuniers": ("pécunier",),
    "pédagogique": ("pédagogique",),
    "pédagogiques": ("pédagogique",),
    "pédagolinguistique": ("pédagolinguistique",),
    "pédagolinguistiques": ("pédagolinguistique",),
    "pédale": ("pédal",),
    "pédales": ("pédal",),
    "pédal": ("pédal",),
    "pédaux": ("pédal",),
    "pédantesque": ("pédantesque",),
    "pédantesques": ("pédantesque",),
    "pédérastique": ("pédérastique",),
    "pédérastiques": ("pédérastique",),
    "pédestre": ("pédestre",),
    "pédestres": ("pédestre",),
    "pédiatrique": ("pédiatrique",),
    "pédiatriques": ("pédiatrique",),
    "pédiculaire": ("pédiculaire",),
    "pédiculaires": ("pédiculaire",),
    "pédicurale": ("pédicural",),
    "pédicurales": ("pédicural",),
    "pédicural": ("pédicural",),
    "pédicuraux": ("pédicural",),
    "pédieuse": ("pédieux",),
    "pédieuses": ("pédieux",),
    "pédieux": ("pédieux",),
    "pédimane": ("pédimane",),
    "pédimanes": ("pédimane",),
    "pédoclimatique": ("pédoclimatique",),
    "pédoclimatiques": ("pédoclimatique",),
    "pédogénétique": ("pédogénétique",),
    "pédogénétiques": ("pédogénétique",),
    "pédologique": ("pédologique",),
    "pédologiques": ("pédologique",),
    "pédonculaire": ("pédonculaire",),
    "pédonculaires": ("pédonculaire",),
    "pédophile": ("pédophile",),
    "pédophiles": ("pédophile",),
    "pédophilique": ("pédophilique",),
    "pédophiliques": ("pédophilique",),
    "pegmatitique": ("pegmatitique",),
    "pegmatitiques": ("pegmatitique",),
    "péguyste": ("péguyste",),
    "péguystes": ("péguyste",),
    "peigneur": ("peigneur",),
    "peigneurs": ("peigneur",),
    "peigneuse": ("peigneur",),
    "peigneuses": ("peigneur",),
    "peignière": ("peignier",),
    "peignières": ("peignier",),
    "peignier": ("peignier",),
    "peigniers": ("peignier",),
    "péjoratif": ("péjoratif",),
    "péjoratifs": ("péjoratif",),
    "péjorative": ("péjoratif",),
    "péjoratives": ("péjoratif",),
    "pékinoise": ("pékinois",),
    "pékinoises": ("pékinois",),
    "pékinois": ("pékinois",),
    "pelable": ("pelable",),
    "pelables": ("pelable",),
    "peladique": ("peladique",),
    "peladiques": ("peladique",),
    "pélagien": ("pélagien",),
    "pélagienne": ("pélagien",),
    "pélagiennes": ("pélagien",),
    "pélagiens": ("pélagien",),
    "pélagique": ("pélagique",),
    "pélagiques": ("pélagique",),
    "pelard": ("pelard",),
    "pelards": ("pelard",),
    "pélargonique": ("pélargonique",),
    "pélargoniques": ("pélargonique",),
    "pélasgien": ("pélasgien",),
    "pélasgienne": ("pélasgien",),
    "pélasgiennes": ("pélasgien",),
    "pélasgiens": ("pélasgien",),
    "pélasgique": ("pélasgique",),
    "pélasgiques": ("pélasgique",),
    "peléen": ("peléen",),
    "péléen": ("péléen",),
    "peléenne": ("peléen",),
    "péléenne": ("péléen",),
    "peléennes": ("peléen",),
    "péléennes": ("péléen",),
    "peléens": ("peléen",),
    "péléens": ("péléen",),
    "pèlerin": ("pèlerin",),
    "pèlerins": ("pèlerin",),
    "pellagreuse": ("pellagreux",),
    "pellagreuses": ("pellagreux",),
    "pellagreux": ("pellagreux",),
    "pellagroïde": ("pellagroïde",),
    "pellagroïdes": ("pellagroïde",),
    "pelleteur": ("pelleteur",),
    "pelleteurs": ("pelleteur",),
    "pelleteuse": ("pelleteur",),
    "pelleteuses": ("pelleteur",),
    "pelletière": ("pelletier",),
    "pelletières": ("pelletier",),
    "pelletier": ("pelletier",),
    "pelletiers": ("pelletier",),
    "pelliculable": ("pelliculable",),
    "pelliculables": ("pelliculable",),
    "pelliculaire": ("pelliculaire",),
    "pelliculaires": ("pelliculaire",),
    "pelliculeuse": ("pelliculeux",),
    "pelliculeuses": ("pelliculeux",),
    "pelliculeux": ("pelliculeux",),
    "pellucide": ("pellucide",),
    "pellucides": ("pellucide",),
    "péloponnésien": ("péloponnésien",),
    "péloponnésienne": ("péloponnésien",),
    "péloponnésiennes": ("péloponnésien",),
    "péloponnésiens": ("péloponnésien",),
    "pélorique": ("pélorique",),
    "péloriques": ("pélorique",),
    "peloteur": ("peloteur",),
    "peloteurs": ("peloteur",),
    "peloteuse": ("peloteur",),
    "peloteuses": ("peloteur",),
    "pelucheuse": ("pelucheux",),
    "pelucheuses": ("pelucheux",),
    "pelucheux": ("pelucheux",),
    "pelure": ("pelure",),
    "pelures": ("pelure",),
    "pélusiaque": ("pélusiaque",),
    "pélusiaques": ("pélusiaque",),
    "pelvien": ("pelvien",),
    "pelvienne": ("pelvien",),
    "pelviennes": ("pelvien",),
    "pelviens": ("pelvien",),
    "pelvipédieuse": ("pelvipédieux",),
    "pelvipédieuses": ("pelvipédieux",),
    "pelvipédieux": ("pelvipédieux",),
    "pélycogène": ("pélycogène",),
    "pélycogènes": ("pélycogène",),
    "pénale": ("pénal",),
    "pénales": ("pénal",),
    "pénal": ("pénal",),
    "pénaux": ("pénal",),
    "pendable": ("pendable",),
    "pendables": ("pendable",),
    "pendjhabi": ("pendjhabi",),
    "pendjhabis": ("pendjhabi",),
    "pendulaire": ("pendulaire",),
    "pendulaires": ("pendulaire",),
    "pénétrable": ("pénétrable",),
    "pénétrables": ("pénétrable",),
    "pénétratif": ("pénétratif",),
    "pénétratifs": ("pénétratif",),
    "pénétrative": ("pénétratif",),
    "pénétratives": ("pénétratif",),
    "pénétropicale": ("pénétropical",),
    "pénétropicales": ("pénétropical",),
    "pénétropical": ("pénétropical",),
    "pénétropicaux": ("pénétropical",),
    "pénible": ("pénible",),
    "pénibles": ("pénible",),
    "pénicillanique": ("pénicillanique",),
    "pénicillaniques": ("pénicillanique",),
    "pénicillinorésistante": ("pénicillinorésistant",),
    "pénicillinorésistantes": ("pénicillinorésistant",),
    "pénicillino-résistant": ("pénicillino-résistant",),
    "pénicillinorésistant": ("pénicillinorésistant",),
    "pénicillinorésistants": ("pénicillinorésistant",),
    "pénien": ("pénien",),
    "pénienne": ("pénien",),
    "péniennes": ("pénien",),
    "péniens": ("pénien",),
    "péninsulaire": ("péninsulaire",),
    "péninsulaires": ("péninsulaire",),
    "pénitencière": ("pénitencier",),
    "pénitencières": ("pénitencier",),
    "pénitencier": ("pénitencier",),
    "pénitenciers": ("pénitencier",),
    "pénitentiaire": ("pénitentiaire",),
    "pénitentiaires": ("pénitentiaire",),
    "pénitentiale": ("pénitential",),
    "pénitentiales": ("pénitential",),
    "pénitential": ("pénitential",),
    "pénitentiaux": ("pénitential",),
    "pénitentielle": ("pénitentiel",),
    "pénitentielles": ("pénitentiel",),
    "pénitentiel": ("pénitentiel",),
    "pénitentiels": ("pénitentiel",),
    "penniforme": ("penniforme",),
    "penniformes": ("penniforme",),
    "pennine": ("pennine",),
    "pennines": ("pennine",),
    "pennique": ("pennique",),
    "penniques": ("pennique",),
    "pennsylvanien": ("pennsylvanien",),
    "pennsylvanienne": ("pennsylvanien",),
    "pennsylvaniennes": ("pennsylvanien",),
    "pennsylvaniens": ("pennsylvanien",),
    "pensable": ("pensable",),
    "pensables": ("pensable",),
    "pensif": ("pensif",),
    "pensifs": ("pensif",),
    "pensive": ("pensif",),
    "pensives": ("pensif",),
    "pensionnale": ("pensionnal",),
    "pensionnales": ("pensionnal",),
    "pensionnal": ("pensionnal",),
    "pensionnaux": ("pensionnal",),
    "pentadactyle": ("pentadactyle",),
    "pentadactyles": ("pentadactyle",),
    "pentadécagone": ("pentadécagone",),
    "pentadécagones": ("pentadécagone",),
    "pentaèdre": ("pentaèdre",),
    "pentaèdres": ("pentaèdre",),
    "pentagonale": ("pentagonal",),
    "pentagonales": ("pentagonal",),
    "pentagonal": ("pentagonal",),
    "pentagonaux": ("pentagonal",),
    "pentagone": ("pentagone",),
    "pentagones": ("pentagone",),
    "pentamère": ("pentamère",),
    "pentamères": ("pentamère",),
    "pentamètre": ("pentamètre",),
    "pentamètres": ("pentamètre",),
    "pentanoïque": ("pentanoïque",),
    "pentanoïques": ("pentanoïque",),
    "pentapétale": ("pentapétale",),
    "pentapétales": ("pentapétale",),
    "pentaploïde": ("pentaploïde",),
    "pentaploïdes": ("pentaploïde",),
    "pentarchique": ("pentarchique",),
    "pentarchiques": ("pentarchique",),
    "pentasphérique": ("pentasphérique",),
    "pentasphériques": ("pentasphérique",),
    "pentastyle": ("pentastyle",),
    "pentastyles": ("pentastyle",),
    "pentasyllabe": ("pentasyllabe",),
    "pentasyllabes": ("pentasyllabe",),
    "pentathionique": ("pentathionique",),
    "pentathioniques": ("pentathionique",),
    "pentatomique": ("pentatomique",),
    "pentatomiques": ("pentatomique",),
    "pentatonique": ("pentatonique",),
    "pentatoniques": ("pentatonique",),
    "pentécostaire": ("pentécostaire",),
    "pentécostaires": ("pentécostaire",),
    "pentecôtiste": ("pentecôtiste",),
    "pentecôtistes": ("pentecôtiste",),
    "pentédécagone": ("pentédécagone",),
    "pentédécagones": ("pentédécagone",),
    "pentélique": ("pentélique",),
    "pentéliques": ("pentélique",),
    "pentétérique": ("pentétérique",),
    "pentétériques": ("pentétérique",),
    "pentylique": ("pentylique",),
    "pentyliques": ("pentylique",),
    "pénultième": ("pénultième",),
    "pénultièmes": ("pénultième",),
    "péonique": ("péonique",),
    "péoniques": ("péonique",),
    "pépère": ("pépère",),
    "pépères": ("pépère",),
    "pépéritique": ("pépéritique",),
    "pépéritiques": ("pépéritique",),
    "pépiniériste": ("pépiniériste",),
    "pépiniéristes": ("pépiniériste",),
    "pepsique": ("pepsique",),
    "pepsiques": ("pepsique",),
    "peptidique": ("peptidique",),
    "peptidiques": ("peptidique",),
    "peptique": ("peptique",),
    "peptiques": ("peptique",),
    "peptisable": ("peptisable",),
    "peptisables": ("peptisable",),
    "peptogène": ("peptogène",),
    "peptogènes": ("peptogène",),
    "peptonisable": ("peptonisable",),
    "peptonisables": ("peptonisable",),
    "péquiste": ("péquiste",),
    "péquistes": ("péquiste",),
    "peracétique": ("peracétique",),
    "peracétiques": ("peracétique",),
    "percepteur": ("percepteur",),
    "percepteurs": ("percepteur",),
    "perceptrice": ("percepteur",),
    "perceptrices": ("percepteur",),
    "perceptible": ("perceptible",),
    "perceptibles": ("perceptible",),
    "perceptif": ("perceptif",),
    "perceptifs": ("perceptif",),
    "perceptive": ("perceptif",),
    "perceptives": ("perceptif",),
    "perceptionniste": ("perceptionniste",),
    "perceptionnistes": ("perceptionniste",),
    "perceptuelle": ("perceptuel",),
    "perceptuelles": ("perceptuel",),
    "perceptuel": ("perceptuel",),
    "perceptuels": ("perceptuel",),
    "perceur": ("perceur",),
    "perceurs": ("perceur",),
    "perceuse": ("perceur",),
    "perceuses": ("perceur",),
    "percevable": ("percevable",),
    "percevables": ("percevable",),
    "percheron": ("percheron",),
    "percheronne": ("percheron",),
    "percheronnes": ("percheron",),
    "percherons": ("percheron",),
    "percheur": ("percheur",),
    "percheurs": ("percheur",),
    "percheuse": ("percheur",),
    "percheuses": ("percheur",),
    "perchlorique": ("perchlorique",),
    "perchloriques": ("perchlorique",),
    "perchromique": ("perchromique",),
    "perchromiques": ("perchromique",),
    "percluse": ("perclus",),
    "percluses": ("perclus",),
    "perclus": ("perclus",),
    "percoelioscopique": ("percoelioscopique",),
    "percoelioscopiques": ("percoelioscopique",),
    "percutatoire": ("percutatoire",),
    "percutatoires": ("percutatoire",),
    "perdable": ("perdable",),
    "perdables": ("perdable",),
    "perdurable": ("perdurable",),
    "perdurables": ("perdurable",),
    "péremptoire": ("péremptoire",),
    "péremptoires": ("péremptoire",),
    "pérenne": ("pérenne",),
    "pérennes": ("pérenne",),
    "perfectible": ("perfectible",),
    "perfectibles": ("perfectible",),
    "perfectif": ("perfectif",),
    "perfectifs": ("perfectif",),
    "perfective": ("perfectif",),
    "perfectives": ("perfectif",),
    "perfectionniste": ("perfectionniste",),
    "perfectionnistes": ("perfectionniste",),
    "perfectissime": ("perfectissime",),
    "perfectissimes": ("perfectissime",),
    "perfide": ("perfide",),
    "perfides": ("perfide",),
    "perforateur": ("perforateur",),
    "perforateurs": ("perforateur",),
    "perforatrice": ("perforateur",),
    "perforatrices": ("perforateur",),
    "perforeur": ("perforeur",),
    "perforeurs": ("perforeur",),
    "perforeuse": ("perforeur",),
    "perforeuses": ("perforeur",),
    "performatif": ("performatif",),
    "performatifs": ("performatif",),
    "performative": ("performatif",),
    "performatives": ("performatif",),
    "performique": ("performique",),
    "performiques": ("performique",),
    "perfringens": ("perfringens",),
    "périamygdalien": ("périamygdalien",),
    "périamygdalienne": ("périamygdalien",),
    "périamygdaliennes": ("périamygdalien",),
    "périamygdaliens": ("périamygdalien",),
    "périanale": ("périanal",),
    "périanales": ("périanal",),
    "périanal": ("périanal",),
    "périanaux": ("périanal",),
    "périanastomotique": ("périanastomotique",),
    "périanastomotiques": ("périanastomotique",),
    "périanthaire": ("périanthaire",),
    "périanthaires": ("périanthaire",),
    "péri": ("péri",),
    "péris": ("péri",),
    "périapicale": ("périapical",),
    "périapicales": ("périapical",),
    "périapical": ("périapical",),
    "périapicaux": ("périapical",),
    "périaqueducale": ("périaqueducal",),
    "périaqueducales": ("périaqueducal",),
    "périaqueducal": ("périaqueducal",),
    "périaqueducaux": ("périaqueducal",),
    "périarctique": ("périarctique",),
    "périarctiques": ("périarctique",),
    "périaréolaire": ("périaréolaire",),
    "périaréolaires": ("périaréolaire",),
    "périarticulaire": ("périarticulaire",),
    "périarticulaires": ("périarticulaire",),
    "péribronchique": ("péribronchique",),
    "péribronchiques": ("péribronchique",),
    "péribuccale": ("péribuccal",),
    "péribuccales": ("péribuccal",),
    "péribuccal": ("péribuccal",),
    "péribuccaux": ("péribuccal",),
    "péricardiale": ("péricardial",),
    "péricardiales": ("péricardial",),
    "péricardial": ("péricardial",),
    "péricardiaux": ("péricardial",),
    "péricardique": ("péricardique",),
    "péricardiques": ("péricardique",),
    "péricarpique": ("péricarpique",),
    "péricarpiques": ("péricarpique",),
    "péricellulaire": ("péricellulaire",),
    "péricellulaires": ("péricellulaire",),
    "péricentrique": ("péricentrique",),
    "péricentriques": ("péricentrique",),
    "périclinale": ("périclinal",),
    "périclinales": ("périclinal",),
    "périclinal": ("périclinal",),
    "périclinaux": ("périclinal",),
    "péricontinentale": ("péricontinental",),
    "péricontinentales": ("péricontinental",),
    "péricontinental": ("péricontinental",),
    "péricontinentaux": ("péricontinental",),
    "péricornéale": ("péricornéal",),
    "péricornéales": ("péricornéal",),
    "péricornéal": ("péricornéal",),
    "péricornéaux": ("péricornéal",),
    "péricoronaire": ("péricoronaire",),
    "péricoronaires": ("péricoronaire",),
    "péricratonique": ("péricratonique",),
    "péricratoniques": ("péricratonique",),
    "péricyclique": ("péricyclique",),
    "péricycliques": ("péricyclique",),
    "péridentaire": ("péridentaire",),
    "péridentaires": ("péridentaire",),
    "péridermique": ("péridermique",),
    "péridermiques": ("péridermique",),
    "péridigestif": ("péridigestif",),
    "péridigestifs": ("péridigestif",),
    "péridigestive": ("péridigestif",),
    "péridigestives": ("péridigestif",),
    "péridotitique": ("péridotitique",),
    "péridotitiques": ("péridotitique",),
    "péridurale": ("péridural",),
    "péridurales": ("péridural",),
    "péridural": ("péridural",),
    "périduraux": ("péridural",),
    "périfolliculaire": ("périfolliculaire",),
    "périfolliculaires": ("périfolliculaire",),
    "périgastrique": ("périgastrique",),
    "périgastriques": ("périgastrique",),
    "périglaciaire": ("périglaciaire",),
    "périglaciaires": ("périglaciaire",),
    "périglandulaire": ("périglandulaire",),
    "périglandulaires": ("périglandulaire",),
    "périglomérulaire": ("périglomérulaire",),
    "périglomérulaires": ("périglomérulaire",),
    "périgordien": ("périgordien",),
    "périgordienne": ("périgordien",),
    "périgordiennes": ("périgordien",),
    "périgordiens": ("périgordien",),
    "périhélique": ("périhélique",),
    "périhéliques": ("périhélique",),
    "périkératique": ("périkératique",),
    "périkératiques": ("périkératique",),
    "périlleuse": ("périlleux",),
    "périlleuses": ("périlleux",),
    "périlleux": ("périlleux",),
    "périlobulaire": ("périlobulaire",),
    "périlobulaires": ("périlobulaire",),
    "périlymphatique": ("périlymphatique",),
    "périlymphatiques": ("périlymphatique",),
    "périmalléolaire": ("périmalléolaire",),
    "périmalléolaires": ("périmalléolaire",),
    "périmammaire": ("périmammaire",),
    "périmammaires": ("périmammaire",),
    "périmétrale": ("périmétral",),
    "périmétrales": ("périmétral",),
    "périmétral": ("périmétral",),
    "périmétraux": ("périmétral",),
    "périmétrique": ("périmétrique",),
    "périmétriques": ("périmétrique",),
    "périnéale": ("périnéal",),
    "périnéales": ("périnéal",),
    "périnéal": ("périnéal",),
    "périnéaux": ("périnéal",),
    "périnéphrétique": ("périnéphrétique",),
    "périnéphrétiques": ("périnéphrétique",),
    "periodique": ("periodique",),
    "périodique": ("périodique",),
    "periodiques": ("periodique",),
    "périodiques": ("périodique",),
    "périopératoire": ("périopératoire",),
    "périopératoires": ("périopératoire",),
    "périorbitaire": ("périorbitaire",),
    "périorbitaires": ("périorbitaire",),
    "périostale": ("périostal",),
    "périostales": ("périostal",),
    "périostal": ("périostal",),
    "périostaux": ("périostal",),
    "périostéale": ("périostéal",),
    "périostéales": ("périostéal",),
    "périostéal": ("périostéal",),
    "périostéaux": ("périostéal",),
    "périostéocytaire": ("périostéocytaire",),
    "périostéocytaires": ("périostéocytaire",),
    "périostique": ("périostique",),
    "périostiques": ("périostique",),
    "périovulaire": ("périovulaire",),
    "périovulaires": ("périovulaire",),
    "péripacifique": ("péripacifique",),
    "péripacifiques": ("péripacifique",),
    "péripatéticien": ("péripatéticien",),
    "péripatéticienne": ("péripatéticien",),
    "péripatéticiennes": ("péripatéticien",),
    "péripatéticiens": ("péripatéticien",),
    "péripatétique": ("péripatétique",),
    "péripatétiques": ("péripatétique",),
    "péripelvien": ("péripelvien",),
    "péripelvienne": ("péripelvien",),
    "péripelviennes": ("péripelvien",),
    "péripelviens": ("péripelvien",),
    "périphérique": ("périphérique",),
    "périphériques": ("périphérique",),
    "périphotographique": ("périphotographique",),
    "périphotographiques": ("périphotographique",),
    "périphrastique": ("périphrastique",),
    "périphrastiques": ("périphrastique",),
    "péripilaire": ("péripilaire",),
    "péripilaires": ("péripilaire",),
    "périplanaire": ("périplanaire",),
    "périplanaires": ("périplanaire",),
    "péripneustique": ("péripneustique",),
    "péripneustiques": ("péripneustique",),
    "périportale": ("périportal",),
    "périportales": ("périportal",),
    "périportal": ("périportal",),
    "périportaux": ("périportal",),
    "périprostatique": ("périprostatique",),
    "périprostatiques": ("périprostatique",),
    "périprothétique": ("périprothétique",),
    "périprothétiques": ("périprothétique",),
    "périptère": ("périptère",),
    "périptères": ("périptère",),
    "péripubertaire": ("péripubertaire",),
    "péripubertaires": ("péripubertaire",),
    "périrénale": ("périrénal",),
    "périrénales": ("périrénal",),
    "périrénal": ("périrénal",),
    "périrénaux": ("périrénal",),
    "périscolaire": ("périscolaire",),
    "périscolaires": ("périscolaire",),
    "périscopique": ("périscopique",),
    "périscopiques": ("périscopique",),
    "périssable": ("périssable",),
    "périssables": ("périssable",),
    "périssoploïde": ("périssoploïde",),
    "périssoploïdes": ("périssoploïde",),
    "péristaltique": ("péristaltique",),
    "péristaltiques": ("péristaltique",),
    "péristaltogène": ("péristaltogène",),
    "péristaltogènes": ("péristaltogène",),
    "péristéronique": ("péristéronique",),
    "péristéroniques": ("péristéronique",),
    "péristyle": ("péristyle",),
    "péristyles": ("péristyle",),
    "péritectique": ("péritectique",),
    "péritectiques": ("péritectique",),
    "péritel": ("péritel",),
    "péritendineuse": ("péritendineux",),
    "péritendineuses": ("péritendineux",),
    "péritendineux": ("péritendineux",),
    "péritonéale": ("péritonéal",),
    "péritonéales": ("péritonéal",),
    "péritonéal": ("péritonéal",),
    "péritonéaux": ("péritonéal",),
    "péritrophique": ("péritrophique",),
    "péritrophiques": ("péritrophique",),
    "péritumorale": ("péritumoral",),
    "péritumorales": ("péritumoral",),
    "péritumoral": ("péritumoral",),
    "péritumoraux": ("péritumoral",),
    "périunguéale": ("périunguéal",),
    "périunguéales": ("périunguéal",),
    "périunguéal": ("périunguéal",),
    "périunguéaux": ("périunguéal",),
    "péri-urbaine": ("péri-urbain",),
    "périurbaine": ("périurbain",),
    "péri-urbaines": ("péri-urbain",),
    "périurbaines": ("périurbain",),
    "péri-urbain": ("péri-urbain",),
    "périurbain": ("périurbain",),
    "péri-urbains": ("péri-urbain",),
    "périurbains": ("périurbain",),
    "périurétérale": ("périurétéral",),
    "périurétérales": ("périurétéral",),
    "périurétéral": ("périurétéral",),
    "périurétéraux": ("périurétéral",),
    "périvasculaire": ("périvasculaire",),
    "périvasculaires": ("périvasculaire",),
    "périveineuse": ("périveineux",),
    "périveineuses": ("périveineux",),
    "périveineux": ("périveineux",),
    "périventriculaire": ("périventriculaire",),
    "périventriculaires": ("périventriculaire",),
    "périviscérale": ("périviscéral",),
    "périviscérales": ("périviscéral",),
    "périviscéral": ("périviscéral",),
    "périviscéraux": ("périviscéral",),
    "perleur": ("perleur",),
    "perleurs": ("perleur",),
    "perleuse": ("perleur",),
    "perleuses": ("perleur",),
    "perlière": ("perlier",),
    "perlières": ("perlier",),
    "perlier": ("perlier",),
    "perliers": ("perlier",),
    "perlinguale": ("perlingual",),
    "perlinguales": ("perlingual",),
    "perlingual": ("perlingual",),
    "perlinguaux": ("perlingual",),
    "perlitique": ("perlitique",),
    "perlitiques": ("perlitique",),
    "perlocutoire": ("perlocutoire",),
    "perlocutoires": ("perlocutoire",),
    "permanganique": ("permanganique",),
    "permanganiques": ("permanganique",),
    "perméable": ("perméable",),
    "perméables": ("perméable",),
    "permettable": ("permettable",),
    "permettables": ("permettable",),
    "permictionnelle": ("permictionnel",),
    "permictionnelles": ("permictionnel",),
    "permictionnel": ("permictionnel",),
    "permictionnels": ("permictionnel",),
    "permien": ("permien",),
    "permienne": ("permien",),
    "permiennes": ("permien",),
    "permiens": ("permien",),
    "permissible": ("permissible",),
    "permissibles": ("permissible",),
    "permissif": ("permissif",),
    "permissifs": ("permissif",),
    "permissive": ("permissif",),
    "permissives": ("permissif",),
    "permsélectif": ("permsélectif",),
    "permsélectifs": ("permsélectif",),
    "permsélective": ("permsélectif",),
    "permsélectives": ("permsélectif",),
    "permutable": ("permutable",),
    "permutables": ("permutable",),
    "pernicieuse": ("pernicieux",),
    "pernicieuses": ("pernicieux",),
    "pernicieux": ("pernicieux",),
    "péronéo-tibial": ("péronéotibial",),
    "péronière": ("péronier",),
    "péronières": ("péronier",),
    "péronier": ("péronier",),
    "péroniers": ("péronier",),
    "péroniste": ("péroniste",),
    "péronistes": ("péroniste",),
    "peropératoire": ("peropératoire",),
    "peropératoires": ("peropératoire",),
    "péroreur": ("péroreur",),
    "péroreurs": ("péroreur",),
    "péroreuse": ("péroreur",),
    "péroreuses": ("péroreur",),
    "peroxydasique": ("peroxydasique",),
    "peroxydasiques": ("peroxydasique",),
    "peroxysomale": ("peroxysomal",),
    "peroxysomales": ("peroxysomal",),
    "peroxysomal": ("peroxysomal",),
    "peroxysomaux": ("peroxysomal",),
    "perpendiculaire": ("perpendiculaire",),
    "perpendiculaires": ("perpendiculaire",),
    "perpétuelle": ("perpétuel",),
    "perpétuelles": ("perpétuel",),
    "perpétuel": ("perpétuel",),
    "perpétuels": ("perpétuel",),
    "perplexe": ("perplexe",),
    "perplexes": ("perplexe",),
    "perquisiteur": ("perquisiteur",),
    "perquisiteurs": ("perquisiteur",),
    "perquisitrice": ("perquisiteur",),
    "perquisitrices": ("perquisiteur",),
    "perronnée": ("perronnée",),
    "perronnées": ("perronnée",),
    "perse": ("perse",),
    "perses": ("perse",),
    "pers": ("pers",),
    "persécuteur": ("persécuteur",),
    "persécuteurs": ("persécuteur",),
    "persécutrice": ("persécuteur",),
    "persécutrices": ("persécuteur",),
    "persécutif": ("persécutif",),
    "persécutifs": ("persécutif",),
    "persécutive": ("persécutif",),
    "persécutives": ("persécutif",),
    "persécutoire": ("persécutoire",),
    "persécutoires": ("persécutoire",),
    "persévératif": ("persévératif",),
    "persévératifs": ("persévératif",),
    "persévérative": ("persévératif",),
    "persévératives": ("persévératif",),
    "persifleur": ("persifleur",),
    "persifleurs": ("persifleur",),
    "persifleuse": ("persifleur",),
    "persifleuses": ("persifleur",),
    "persique": ("persique",),
    "persiques": ("persique",),
    "personnaliste": ("personnaliste",),
    "personnalistes": ("personnaliste",),
    "personnelle": ("personnel",),
    "personnelles": ("personnel",),
    "personnel": ("personnel",),
    "personnels": ("personnel",),
    "perspectif": ("perspectif",),
    "perspectifs": ("perspectif",),
    "perspective": ("perspectif",),
    "perspectives": ("perspectif",),
    "perspicace": ("perspicace",),
    "perspicaces": ("perspicace",),
    "persuasif": ("persuasif",),
    "persuasifs": ("persuasif",),
    "persuasive": ("persuasif",),
    "persuasives": ("persuasif",),
    "persulfurique": ("persulfurique",),
    "persulfuriques": ("persulfurique",),
    "perthitique": ("perthitique",),
    "perthitiques": ("perthitique",),
    "perturbateur": ("perturbateur",),
    "perturbateurs": ("perturbateur",),
    "perturbatrice": ("perturbateur",),
    "perturbatrices": ("perturbateur",),
    "péruginesque": ("péruginesque",),
    "péruginesques": ("péruginesque",),
    "péruvien": ("péruvien",),
    "péruvienne": ("péruvien",),
    "péruviennes": ("péruvien",),
    "péruviens": ("péruvien",),
    "pervenche": ("pervenche",),
    "perverse": ("pervers",),
    "perverses": ("pervers",),
    "pervers": ("pervers",),
    "pervertisseur": ("pervertisseur",),
    "pervertisseurs": ("pervertisseur",),
    "pervertisseuse": ("pervertisseur",),
    "pervertisseuses": ("pervertisseur",),
    "pesable": ("pesable",),
    "pesables": ("pesable",),
    "peseur": ("peseur",),
    "peseurs": ("peseur",),
    "peseuse": ("peseur",),
    "peseuses": ("peseur",),
    "pessimiste": ("pessimiste",),
    "pessimistes": ("pessimiste",),
    "pesteuse": ("pesteux",),
    "pesteuses": ("pesteux",),
    "pesteux": ("pesteux",),
    "pesticide": ("pesticide",),
    "pesticides": ("pesticide",),
    "pestilentielle": ("pestilentiel",),
    "pestilentielles": ("pestilentiel",),
    "pestilentiel": ("pestilentiel",),
    "pestilentiels": ("pestilentiel",),
    "pétainiste": ("pétainiste",),
    "pétainistes": ("pétainiste",),
    "pétaloïde": ("pétaloïde",),
    "pétaloïdes": ("pétaloïde",),
    "pétardière": ("pétardier",),
    "pétardières": ("pétardier",),
    "pétardier": ("pétardier",),
    "pétardiers": ("pétardier",),
    "pétéchiale": ("pétéchial",),
    "pétéchiales": ("pétéchial",),
    "pétéchial": ("pétéchial",),
    "pétéchiaux": ("pétéchial",),
    "pétersbourgeoise": ("pétersbourgeois",),
    "pétersbourgeoises": ("pétersbourgeois",),
    "pétersbourgeois": ("pétersbourgeois",),
    "pètesec": ("pètesec",),
    "péteur": ("péteur",),
    "péteurs": ("péteur",),
    "péteuse": ("péteux",),
    "péteuses": ("péteux",),
    "péteux": ("péteux",),
    "pétiniste": ("pétiniste",),
    "pétinistes": ("pétiniste",),
    "pétiolaire": ("pétiolaire",),
    "pétiolaires": ("pétiolaire",),
    "pétitoire": ("pétitoire",),
    "pétitoires": ("pétitoire",),
    "petit-russe": ("petit-russe",),
    "petit-russien": ("petit-russien",),
    "petit-russiens": ("petit-russien",),
    "pétrarquiste": ("pétrarquiste",),
    "pétrarquistes": ("pétrarquiste",),
    "pétreuse": ("pétreux",),
    "pétreuses": ("pétreux",),
    "pétreux": ("pétreux",),
    "pétrissable": ("pétrissable",),
    "pétrissables": ("pétrissable",),
    "pétrisseur": ("pétrisseur",),
    "pétrisseurs": ("pétrisseur",),
    "pétrisseuse": ("pétrisseur",),
    "pétrisseuses": ("pétrisseur",),
    "pétrochimique": ("pétrochimique",),
    "pétrochimiques": ("pétrochimique",),
    "pétrogénétique": ("pétrogénétique",),
    "pétrogénétiques": ("pétrogénétique",),
    "pétrographique": ("pétrographique",),
    "pétrographiques": ("pétrographique",),
    "pétroléochimique": ("pétroléochimique",),
    "pétroléochimiques": ("pétroléochimique",),
    "pétrolière": ("pétrolier",),
    "pétrolières": ("pétrolier",),
    "pétrolier": ("pétrolier",),
    "pétroliers": ("pétrolier",),
    "pétrolifère": ("pétrolifère",),
    "pétrolifères": ("pétrolifère",),
    "pétrolochimique": ("pétrolochimique",),
    "pétrolochimiques": ("pétrolochimique",),
    "pétrologique": ("pétrologique",),
    "pétrologiques": ("pétrologique",),
    "pétromastoïdien": ("pétromastoïdien",),
    "pétromastoïdienne": ("pétromastoïdien",),
    "pétromastoïdiennes": ("pétromastoïdien",),
    "pétromastoïdiens": ("pétromastoïdien",),
    "pétrosélinique": ("pétrosélinique",),
    "pétroséliniques": ("pétrosélinique",),
    "peuplée": ("peuplé",),
    "peuplées": ("peuplé",),
    "peuplé": ("peuplé",),
    "peuple": ("peuple",),
    "peuplés": ("peuplé",),
    "peureuse": ("peureux",),
    "peureuses": ("peureux",),
    "peureux": ("peureux",),
    "phagédénique": ("phagédénique",),
    "phagédéniques": ("phagédénique",),
    "phagocytaire": ("phagocytaire",),
    "phagocytaires": ("phagocytaire",),
    "phagotrophe": ("phagotrophe",),
    "phagotrophes": ("phagotrophe",),
    "phalangéale": ("phalangéal",),
    "phalangéales": ("phalangéal",),
    "phalangéal": ("phalangéal",),
    "phalangéaux": ("phalangéal",),
    "phalangien": ("phalangien",),
    "phalangienne": ("phalangien",),
    "phalangiennes": ("phalangien",),
    "phalangiens": ("phalangien",),
    "phalangiste": ("phalangiste",),
    "phalangistes": ("phalangiste",),
    "phalanstérien": ("phalanstérien",),
    "phalanstérienne": ("phalanstérien",),
    "phalanstériennes": ("phalanstérien",),
    "phalanstériens": ("phalanstérien",),
    "phallique": ("phallique",),
    "phalliques": ("phallique",),
    "phallo": ("phallo",),
    "phallos": ("phallo",),
    "phallocentrique": ("phallocentrique",),
    "phallocentriques": ("phallocentrique",),
    "phallocrate": ("phallocrate",),
    "phallocrates": ("phallocrate",),
    "phallocratique": ("phallocratique",),
    "phallocratiques": ("phallocratique",),
    "phalloïde": ("phalloïde",),
    "phalloïdes": ("phalloïde",),
    "phalloïdien": ("phalloïdien",),
    "phalloïdienne": ("phalloïdien",),
    "phalloïdiennes": ("phalloïdien",),
    "phalloïdiens": ("phalloïdien",),
    "phanéritique": ("phanéritique",),
    "phanéritiques": ("phanéritique",),
    "phanérogame": ("phanérogame",),
    "phanérogames": ("phanérogame",),
    "pharamineuse": ("pharamineux",),
    "pharamineuses": ("pharamineux",),
    "pharamineux": ("pharamineux",),
    "pharaonien": ("pharaonien",),
    "pharaonienne": ("pharaonien",),
    "pharaoniennes": ("pharaonien",),
    "pharaoniens": ("pharaonien",),
    "pharaonique": ("pharaonique",),
    "pharaoniques": ("pharaonique",),
    "phare": ("phare",),
    "pharisaïque": ("pharisaïque",),
    "pharisaïques": ("pharisaïque",),
    "pharisien": ("pharisien",),
    "pharisienne": ("pharisien",),
    "pharisiennes": ("pharisien",),
    "pharisiens": ("pharisien",),
    "pharmaceutique": ("pharmaceutique",),
    "pharmaceutiques": ("pharmaceutique",),
    "pharmaco-cinétiques": ("pharmacocinétique",),
    "pharmacoclinique": ("pharmacoclinique",),
    "pharmacocliniques": ("pharmacoclinique",),
    "pharmacodynamique": ("pharmacodynamique",),
    "pharmacodynamiques": ("pharmacodynamique",),
    "pharmacogénétique": ("pharmacogénétique",),
    "pharmacogénétiques": ("pharmacogénétique",),
    "pharmacologique": ("pharmacologique",),
    "pharmacologiques": ("pharmacologique",),
    "pharmacotoxicologique": ("pharmacotoxicologique",),
    "pharmacotoxicologiques": ("pharmacotoxicologique",),
    "pharmocologique": ("pharmocologique",),
    "pharmocologiques": ("pharmocologique",),
    "pharyngale": ("pharyngal",),
    "pharyngales": ("pharyngal",),
    "pharyngal": ("pharyngal",),
    "pharyngaux": ("pharyngal",),
    "pharyngien": ("pharyngien",),
    "pharyngienne": ("pharyngien",),
    "pharyngiennes": ("pharyngien",),
    "pharyngiens": ("pharyngien",),
    "pharyngotrème": ("pharyngotrème",),
    "pharyngotrèmes": ("pharyngotrème",),
    "phasique": ("phasique",),
    "phasiques": ("phasique",),
    "phatique": ("phatique",),
    "phatiques": ("phatique",),
    "phellogène": ("phellogène",),
    "phellogènes": ("phellogène",),
    "phénanthrénique": ("phénanthrénique",),
    "phénanthréniques": ("phénanthrénique",),
    "phénicien": ("phénicien",),
    "phénicienne": ("phénicien",),
    "phéniciennes": ("phénicien",),
    "phéniciens": ("phénicien",),
    "phéniquée": ("phéniqué",),
    "phéniquées": ("phéniqué",),
    "phéniqué": ("phéniqué",),
    "phénique": ("phénique",),
    "phéniqués": ("phéniqué",),
    "phéniques": ("phénique",),
    "phénogénétique": ("phénogénétique",),
    "phénogénétiques": ("phénogénétique",),
    "phénolique": ("phénolique",),
    "phénoliques": ("phénolique",),
    "phénologique": ("phénologique",),
    "phénologiques": ("phénologique",),
    "phénoménale": ("phénoménal",),
    "phénoménales": ("phénoménal",),
    "phénoménal": ("phénoménal",),
    "phénoménaux": ("phénoménal",),
    "phénoménaliste": ("phénoménaliste",),
    "phénoménalistes": ("phénoménaliste",),
    "phénoméniste": ("phénoméniste",),
    "phénoménistes": ("phénoméniste",),
    "phénoménologique": ("phénoménologique",),
    "phénoménologiques": ("phénoménologique",),
    "phénoplaste": ("phénoplaste",),
    "phénoplastes": ("phénoplaste",),
    "phénothiazinique": ("phénothiazinique",),
    "phénothiaziniques": ("phénothiazinique",),
    "phénotypique": ("phénotypique",),
    "phénotypiques": ("phénotypique",),
    "phénoxyacétique": ("phénoxyacétique",),
    "phénoxyacétiques": ("phénoxyacétique",),
    "phényglycolique": ("phényglycolique",),
    "phényglycoliques": ("phényglycolique",),
    "phénylacétique": ("phénylacétique",),
    "phénylacétiques": ("phénylacétique",),
    "phénylacrylique": ("phénylacrylique",),
    "phénylacryliques": ("phénylacrylique",),
    "phényléthylénique": ("phényléthylénique",),
    "phényléthyléniques": ("phényléthylénique",),
    "phénylhydracrylique": ("phénylhydracrylique",),
    "phénylhydracryliques": ("phénylhydracrylique",),
    "phénylique": ("phénylique",),
    "phényliques": ("phénylique",),
    "phénylpyruvique": ("phénylpyruvique",),
    "phénylpyruviques": ("phénylpyruvique",),
    "phéromonale": ("phéromonal",),
    "phéromonales": ("phéromonal",),
    "phéromonal": ("phéromonal",),
    "phéromonaux": ("phéromonal",),
    "philanthropique": ("philanthropique",),
    "philanthropiques": ("philanthropique",),
    "philatélique": ("philatélique",),
    "philatéliques": ("philatélique",),
    "philharmonique": ("philharmonique",),
    "philharmoniques": ("philharmonique",),
    "philhellène": ("philhellène",),
    "philhellènes": ("philhellène",),
    "philocalien": ("philocalien",),
    "philocalienne": ("philocalien",),
    "philocaliennes": ("philocalien",),
    "philocaliens": ("philocalien",),
    "philocalique": ("philocalique",),
    "philocaliques": ("philocalique",),
    "philologique": ("philologique",),
    "philologiques": ("philologique",),
    "philomatique": ("philomatique",),
    "philomatiques": ("philomatique",),
    "philosémite": ("philosémite",),
    "philosémites": ("philosémite",),
    "philosophale": ("philosophale",),
    "philosophales": ("philosophale",),
    "philosophe": ("philosophe",),
    "philosophes": ("philosophe",),
    "philosopheur": ("philosopheur",),
    "philosopheurs": ("philosopheur",),
    "philosopheuse": ("philosopheur",),
    "philosopheuses": ("philosopheur",),
    "philosophico-religieuse": ("philosophico-religieux",),
    "philosophico-religieux": ("philosophico-religieux",),
    "philosophico-social": ("philosophico-social",),
    "philosophico-sociaux": ("philosophico-social",),
    "philosophique": ("philosophique",),
    "philosophiques": ("philosophique",),
    "philotechnique": ("philotechnique",),
    "philotechniques": ("philotechnique",),
    "phlébographique": ("phlébographique",),
    "phlébographiques": ("phlébographique",),
    "phlébotonique": ("phlébotonique",),
    "phlébotoniques": ("phlébotonique",),
    "phlébotrope": ("phlébotrope",),
    "phlébotropes": ("phlébotrope",),
    "phlegmasique": ("phlegmasique",),
    "phlegmasiques": ("phlegmasique",),
    "phlegmoneuse": ("phlegmoneux",),
    "phlegmoneuses": ("phlegmoneux",),
    "phlegmoneux": ("phlegmoneux",),
    "phlegmorragique": ("phlegmorragique",),
    "phlegmorragiques": ("phlegmorragique",),
    "phloïonique": ("phloïonique",),
    "phloïoniques": ("phloïonique",),
    "phlorétique": ("phlorétique",),
    "phlorétiques": ("phlorétique",),
    "phloridzique": ("phloridzique",),
    "phloridziques": ("phloridzique",),
    "phlycténoïde": ("phlycténoïde",),
    "phlycténoïdes": ("phlycténoïde",),
    "phlycténulaire": ("phlycténulaire",),
    "phlycténulaires": ("phlycténulaire",),
    "phobique": ("phobique",),
    "phobiques": ("phobique",),
    "phobogène": ("phobogène",),
    "phobogènes": ("phobogène",),
    "phocéen": ("phocéen",),
    "phocéenne": ("phocéen",),
    "phocéennes": ("phocéen",),
    "phocéens": ("phocéen",),
    "phocidien": ("phocidien",),
    "phocidienne": ("phocidien",),
    "phocidiennes": ("phocidien",),
    "phocidiens": ("phocidien",),
    "phocomèle": ("phocomèle",),
    "phocomèles": ("phocomèle",),
    "phonateur": ("phonateur",),
    "phonateurs": ("phonateur",),
    "phonatrice": ("phonateur",),
    "phonatrices": ("phonateur",),
    "phonatoire": ("phonatoire",),
    "phonatoires": ("phonatoire",),
    "phonématique": ("phonématique",),
    "phonématiques": ("phonématique",),
    "phonémique": ("phonémique",),
    "phonémiques": ("phonémique",),
    "phonétique": ("phonétique",),
    "phonétiques": ("phonétique",),
    "phonique": ("phonique",),
    "phoniques": ("phonique",),
    "phonocapteur": ("phonocapteur",),
    "phonocapteurs": ("phonocapteur",),
    "phonocaptrice": ("phonocapteur",),
    "phonocaptrices": ("phonocapteur",),
    "phonocinétique": ("phonocinétique",),
    "phonocinétiques": ("phonocinétique",),
    "phonogénique": ("phonogénique",),
    "phonogéniques": ("phonogénique",),
    "phonographique": ("phonographique",),
    "phonographiques": ("phonographique",),
    "phonolithique": ("phonolithique",),
    "phonolithiques": ("phonolithique",),
    "phonolitique": ("phonolitique",),
    "phonolitiques": ("phonolitique",),
    "phonologique": ("phonologique",),
    "phonologiques": ("phonologique",),
    "phonostylistique": ("phonostylistique",),
    "phonostylistiques": ("phonostylistique",),
    "phonotactique": ("phonotactique",),
    "phonotactiques": ("phonotactique",),
    "phosphamique": ("phosphamique",),
    "phosphamiques": ("phosphamique",),
    "phosphatidique": ("phosphatidique",),
    "phosphatidiques": ("phosphatidique",),
    "phosphatique": ("phosphatique",),
    "phosphatiques": ("phosphatique",),
    "phosphaturique": ("phosphaturique",),
    "phosphaturiques": ("phosphaturique",),
    "phosphinique": ("phosphinique",),
    "phosphiniques": ("phosphinique",),
    "phosphocalcique": ("phosphocalcique",),
    "phosphocalciques": ("phosphocalcique",),
    "phosphofluorhydrique": ("phosphofluorhydrique",),
    "phosphofluorhydriques": ("phosphofluorhydrique",),
    "phosphofluorique": ("phosphofluorique",),
    "phosphofluoriques": ("phosphofluorique",),
    "phosphoglycérique": ("phosphoglycérique",),
    "phosphoglycériques": ("phosphoglycérique",),
    "phospholipidique": ("phospholipidique",),
    "phospholipidiques": ("phospholipidique",),
    "phosphomolybdique": ("phosphomolybdique",),
    "phosphomolybdiques": ("phosphomolybdique",),
    "phosphonique": ("phosphonique",),
    "phosphoniques": ("phosphonique",),
    "phosphonitrilique": ("phosphonitrilique",),
    "phosphonitriliques": ("phosphonitrilique",),
    "phosphoreuse": ("phosphoreux",),
    "phosphoreuses": ("phosphoreux",),
    "phosphoreux": ("phosphoreux",),
    "phosphorique": ("phosphorique",),
    "phosphoriques": ("phosphorique",),
    "phosphoriste": ("phosphoriste",),
    "phosphoristes": ("phosphoriste",),
    "phosphoritique": ("phosphoritique",),
    "phosphoritiques": ("phosphoritique",),
    "photique": ("photique",),
    "photiques": ("photique",),
    "photo": ("photo",),
    "photocéramique": ("photocéramique",),
    "photocéramiques": ("photocéramique",),
    "photochimiothérapique": ("photochimiothérapique",),
    "photochimiothérapiques": ("photochimiothérapique",),
    "photochimique": ("photochimique",),
    "photochimiques": ("photochimique",),
    "photochlorophyllien": ("photochlorophyllien",),
    "photochlorophyllienne": ("photochlorophyllien",),
    "photochlorophylliennes": ("photochlorophyllien",),
    "photochlorophylliens": ("photochlorophyllien",),
    "photochrome": ("photochrome",),
    "photochromes": ("photochrome",),
    "photochromique": ("photochromique",),
    "photochromiques": ("photochromique",),
    "photoconducteur": ("photoconducteur",),
    "photoconducteurs": ("photoconducteur",),
    "photoconductrice": ("photoconducteur",),
    "photoconductrices": ("photoconducteur",),
    "photoconvulsif": ("photoconvulsif",),
    "photoconvulsifs": ("photoconvulsif",),
    "photoconvulsive": ("photoconvulsif",),
    "photoconvulsives": ("photoconvulsif",),
    "photodégradable": ("photodégradable",),
    "photodégradables": ("photodégradable",),
    "photodétecteur": ("photodétecteur",),
    "photodétecteurs": ("photodétecteur",),
    "photodétectrice": ("photodétecteur",),
    "photodétectrices": ("photodétecteur",),
    "photodynamique": ("photodynamique",),
    "photodynamiques": ("photodynamique",),
    "photoélastique": ("photoélastique",),
    "photoélastiques": ("photoélastique",),
    "photo-électrique": ("photoélectrique",),
    "photoélectrique": ("photoélectrique",),
    "photoélectriques": ("photoélectrique",),
    "photoémetteur": ("photoémetteur",),
    "photoémetteurs": ("photoémetteur",),
    "photoémettrice": ("photoémetteur",),
    "photoémettrices": ("photoémetteur",),
    "photoémissif": ("photoémissif",),
    "photoémissifs": ("photoémissif",),
    "photoémissive": ("photoémissif",),
    "photoémissives": ("photoémissif",),
    "photofragmentable": ("photofragmentable",),
    "photofragmentables": ("photofragmentable",),
    "photogène": ("photogène",),
    "photogènes": ("photogène",),
    "photogénique": ("photogénique",),
    "photogéniques": ("photogénique",),
    "photogrammétrique": ("photogrammétrique",),
    "photogrammétriques": ("photogrammétrique",),
    "photographiable": ("photographiable",),
    "photographiables": ("photographiable",),
    "photographique": ("photographique",),
    "photographiques": ("photographique",),
    "photograveur": ("photograveur",),
    "photograveurs": ("photograveur",),
    "photograveuse": ("photograveur",),
    "photograveuses": ("photograveur",),
    "photojetable": ("photojetable",),
    "photojetables": ("photojetable",),
    "photolithographique": ("photolithographique",),
    "photolithographiques": ("photolithographique",),
    "photomagnétique": ("photomagnétique",),
    "photomagnétiques": ("photomagnétique",),
    "photomécanique": ("photomécanique",),
    "photomécaniques": ("photomécanique",),
    "photométrique": ("photométrique",),
    "photométriques": ("photométrique",),
    "photomicrographique": ("photomicrographique",),
    "photomicrographiques": ("photomicrographique",),
    "photomoteur": ("photomoteur",),
    "photomoteurs": ("photomoteur",),
    "photomotrice": ("photomoteur",),
    "photomotrices": ("photomoteur",),
    "photomultiplicateur": ("photomultiplicateur",),
    "photomultiplicateurs": ("photomultiplicateur",),
    "photomultiplicatrice": ("photomultiplicateur",),
    "photomultiplicatrices": ("photomultiplicateur",),
    "photomyoclonique": ("photomyoclonique",),
    "photomyocloniques": ("photomyoclonique",),
    "photonique": ("photonique",),
    "photoniques": ("photonique",),
    "photonucléaire": ("photonucléaire",),
    "photonucléaires": ("photonucléaire",),
    "photopathique": ("photopathique",),
    "photopathiques": ("photopathique",),
    "photopériodique": ("photopériodique",),
    "photopériodiques": ("photopériodique",),
    "photophobe": ("photophobe",),
    "photophobes": ("photophobe",),
    "photophobique": ("photophobique",),
    "photophobiques": ("photophobique",),
    "photophore": ("photophore",),
    "photophores": ("photophore",),
    "photophysique": ("photophysique",),
    "photophysiques": ("photophysique",),
    "photopique": ("photopique",),
    "photopiques": ("photopique",),
    "photopolymère": ("photopolymère",),
    "photopolymères": ("photopolymère",),
    "photoprotecteur": ("photoprotecteur",),
    "photoprotecteurs": ("photoprotecteur",),
    "photoprotectrice": ("photoprotecteur",),
    "photoprotectrices": ("photoprotecteur",),
    "photoptique": ("photoptique",),
    "photoptiques": ("photoptique",),
    "photoréactif": ("photoréactif",),
    "photoréactifs": ("photoréactif",),
    "photoréactive": ("photoréactif",),
    "photoréactives": ("photoréactif",),
    "photorécepteur": ("photorécepteur",),
    "photorécepteurs": ("photorécepteur",),
    "photoréceptrice": ("photorécepteur",),
    "photoréceptrices": ("photorécepteur",),
    "photorésistif": ("photorésistif",),
    "photorésistifs": ("photorésistif",),
    "photorésistive": ("photorésistif",),
    "photorésistives": ("photorésistif",),
    "photorespiratoire": ("photorespiratoire",),
    "photorespiratoires": ("photorespiratoire",),
    "photoréticulable": ("photoréticulable",),
    "photoréticulables": ("photoréticulable",),
    "photoscopique": ("photoscopique",),
    "photoscopiques": ("photoscopique",),
    "photosensible": ("photosensible",),
    "photosensibles": ("photosensible",),
    "photosphérique": ("photosphérique",),
    "photosphériques": ("photosphérique",),
    "photosynthétique": ("photosynthétique",),
    "photosynthétiques": ("photosynthétique",),
    "photothérapique": ("photothérapique",),
    "photothérapiques": ("photothérapique",),
    "phototrophe": ("phototrophe",),
    "phototrophes": ("phototrophe",),
    "phototropique": ("phototropique",),
    "phototropiques": ("phototropique",),
    "photovisuelle": ("photovisuel",),
    "photovisuelles": ("photovisuel",),
    "photovisuel": ("photovisuel",),
    "photovisuels": ("photovisuel",),
    "photovoltaïque": ("photovoltaïque",),
    "photovoltaïques": ("photovoltaïque",),
    "phraséologique": ("phraséologique",),
    "phraséologiques": ("phraséologique",),
    "phrastique": ("phrastique",),
    "phrastiques": ("phrastique",),
    "phréatique": ("phréatique",),
    "phréatiques": ("phréatique",),
    "phrénique": ("phrénique",),
    "phréniques": ("phrénique",),
    "phrénoglottique": ("phrénoglottique",),
    "phrénoglottiques": ("phrénoglottique",),
    "phrénologique": ("phrénologique",),
    "phrénologiques": ("phrénologique",),
    "phrygien": ("phrygien",),
    "phrygienne": ("phrygien",),
    "phrygiennes": ("phrygien",),
    "phrygiens": ("phrygien",),
    "phtalique": ("phtalique",),
    "phtaliques": ("phtalique",),
    "phtiriasique": ("phtiriasique",),
    "phtiriasiques": ("phtiriasique",),
    "phtisiogène": ("phtisiogène",),
    "phtisiogènes": ("phtisiogène",),
    "phtisiologique": ("phtisiologique",),
    "phtisiologiques": ("phtisiologique",),
    "phtisique": ("phtisique",),
    "phtisiques": ("phtisique",),
    "phycologique": ("phycologique",),
    "phycologiques": ("phycologique",),
    "phylétique": ("phylétique",),
    "phylétiques": ("phylétique",),
    "phyllode": ("phyllode",),
    "phyllodes": ("phyllode",),
    "phyllophage": ("phyllophage",),
    "phyllophages": ("phyllophage",),
    "phylloxérien": ("phylloxérien",),
    "phylloxérienne": ("phylloxérien",),
    "phylloxériennes": ("phylloxérien",),
    "phylloxériens": ("phylloxérien",),
    "phylloxérique": ("phylloxérique",),
    "phylloxériques": ("phylloxérique",),
    "phylogénétique": ("phylogénétique",),
    "phylogénétiques": ("phylogénétique",),
    "phylogénique": ("phylogénique",),
    "phylogéniques": ("phylogénique",),
    "physicaliste": ("physicaliste",),
    "physicalistes": ("physicaliste",),
    "physiciste": ("physiciste",),
    "physicistes": ("physiciste",),
    "physico-chimique": ("physico-chimique",),
    "physicochimique": ("physicochimique",),
    "physico-chimiques": ("physico-chimique",),
    "physicochimiques": ("physicochimique",),
    "physico-mathématique": ("physico-mathématique",),
    "physiocrate": ("physiocrate",),
    "physiocrates": ("physiocrate",),
    "physiocratique": ("physiocratique",),
    "physiocratiques": ("physiocratique",),
    "physiogène": ("physiogène",),
    "physiogènes": ("physiogène",),
    "physiognomonique": ("physiognomonique",),
    "physiognomoniques": ("physiognomonique",),
    "physiographique": ("physiographique",),
    "physiographiques": ("physiographique",),
    "physiologique": ("physiologique",),
    "physiologiques": ("physiologique",),
    "physionomique": ("physionomique",),
    "physionomiques": ("physionomique",),
    "physionomiste": ("physionomiste",),
    "physionomistes": ("physionomiste",),
    "physiopathique": ("physiopathique",),
    "physiopathiques": ("physiopathique",),
    "physiopathogénique": ("physiopathogénique",),
    "physiopathogéniques": ("physiopathogénique",),
    "physiopathologique": ("physiopathologique",),
    "physiopathologiques": ("physiopathologique",),
    "physiothérapique": ("physiothérapique",),
    "physiothérapiques": ("physiothérapique",),
    "physique": ("physique",),
    "physiques": ("physique",),
    "physostome": ("physostome",),
    "physostomes": ("physostome",),
    "phytale": ("phytal",),
    "phytales": ("phytal",),
    "phytal": ("phytal",),
    "phytaux": ("phytal",),
    "phytinique": ("phytinique",),
    "phytiniques": ("phytinique",),
    "phytique": ("phytique",),
    "phytiques": ("phytique",),
    "phytocide": ("phytocide",),
    "phytocides": ("phytocide",),
    "phytocosmétique": ("phytocosmétique",),
    "phytocosmétiques": ("phytocosmétique",),
    "phytogénétique": ("phytogénétique",),
    "phytogénétiques": ("phytogénétique",),
    "phytogéographique": ("phytogéographique",),
    "phytogéographiques": ("phytogéographique",),
    "phytomitogène": ("phytomitogène",),
    "phytomitogènes": ("phytomitogène",),
    "phytopathogène": ("phytopathogène",),
    "phytopathogènes": ("phytopathogène",),
    "phytopathologique": ("phytopathologique",),
    "phytopathologiques": ("phytopathologique",),
    "phytophage": ("phytophage",),
    "phytophages": ("phytophage",),
    "phytopharmaceutique": ("phytopharmaceutique",),
    "phytopharmaceutiques": ("phytopharmaceutique",),
    "phytoplanctonique": ("phytoplanctonique",),
    "phytoplanctoniques": ("phytoplanctonique",),
    "phytosanitaire": ("phytosanitaire",),
    "phytosanitaires": ("phytosanitaire",),
    "phytosociologique": ("phytosociologique",),
    "phytosociologiques": ("phytosociologique",),
    "phytotechnique": ("phytotechnique",),
    "phytotechniques": ("phytotechnique",),
    "phytothérapique": ("phytothérapique",),
    "phytothérapiques": ("phytothérapique",),
    "phytotoxique": ("phytotoxique",),
    "phytotoxiques": ("phytotoxique",),
    "phytotronique": ("phytotronique",),
    "phytotroniques": ("phytotronique",),
    "piaculaire": ("piaculaire",),
    "piaculaires": ("piaculaire",),
    "piaffeur": ("piaffeur",),
    "piaffeurs": ("piaffeur",),
    "piaffeuse": ("piaffeur",),
    "piaffeuses": ("piaffeur",),
    "piailleur": ("piailleur",),
    "piailleurs": ("piailleur",),
    "piailleuse": ("piailleur",),
    "piailleuses": ("piailleur",),
    "pianique": ("pianique",),
    "pianiques": ("pianique",),
    "pianistique": ("pianistique",),
    "pianistiques": ("pianistique",),
    "picaresque": ("picaresque",),
    "picaresques": ("picaresque",),
    "pickwickien": ("pickwickien",),
    "pickwickienne": ("pickwickien",),
    "pickwickiennes": ("pickwickien",),
    "pickwickiens": ("pickwickien",),
    "picolique": ("picolique",),
    "picoliques": ("picolique",),
    "picrique": ("picrique",),
    "picriques": ("picrique",),
    "picritique": ("picritique",),
    "picritiques": ("picritique",),
    "picrocholine": ("picrocholine",),
    "picrocholines": ("picrocholine",),
    "picrolonique": ("picrolonique",),
    "picroloniques": ("picrolonique",),
    "pictographique": ("pictographique",),
    "pictographiques": ("pictographique",),
    "pictorialiste": ("pictorialiste",),
    "pictorialistes": ("pictorialiste",),
    "picturale": ("pictural",),
    "picturales": ("pictural",),
    "pictural": ("pictural",),
    "picturaux": ("pictural",),
    "pie": ("pie",),
    "pies": ("pie",),
    "pie-mériennes": ("pie-mérien",),
    "piémontaise": ("piémontais",),
    "piémontaises": ("piémontais",),
    "piémontais": ("piémontais",),
    "pierreuse": ("pierreux",),
    "pierreuses": ("pierreux",),
    "pierreux": ("pierreux",),
    "piéteur": ("piéteur",),
    "piéteurs": ("piéteur",),
    "piéteuse": ("piéteur",),
    "piéteuses": ("piéteur",),
    "piétiste": ("piétiste",),
    "piétistes": ("piétiste",),
    "piétonne": ("piétonne",),
    "piétonnes": ("piétonne",),
    "piétonnière": ("piétonnier",),
    "piétonnières": ("piétonnier",),
    "piétonnier": ("piétonnier",),
    "piétonniers": ("piétonnier",),
    "piétrain": ("piétrain",),
    "piétrains": ("piétrain",),
    "piètre": ("piètre",),
    "piètres": ("piètre",),
    "pieuse": ("pieux",),
    "pieuses": ("pieux",),
    "pieux": ("pieux",),
    "piézo-électrique": ("piézo-électrique",),
    "piézoélectrique": ("piézoélectrique",),
    "piézoélectriques": ("piézoélectrique",),
    "piézométrique": ("piézométrique",),
    "piézométriques": ("piézométrique",),
    "piézorésistif": ("piézorésistif",),
    "piézorésistifs": ("piézorésistif",),
    "piézorésistive": ("piézorésistif",),
    "piézorésistives": ("piézorésistif",),
    "pifométrique": ("pifométrique",),
    "pifométriques": ("pifométrique",),
    "pigache": ("pigache",),
    "pigaches": ("pigache",),
    "pigmée": ("pigmée",),
    "pigmées": ("pigmée",),
    "pigmentaire": ("pigmentaire",),
    "pigmentaires": ("pigmentaire",),
    "pignoratif": ("pignoratif",),
    "pignoratifs": ("pignoratif",),
    "pignorative": ("pignoratif",),
    "pignoratives": ("pignoratif",),
    "pilaire": ("pilaire",),
    "pilaires": ("pilaire",),
    "pileuse": ("pileux",),
    "pileuses": ("pileux",),
    "pileux": ("pileux",),
    "pilifère": ("pilifère",),
    "pilifères": ("pilifère",),
    "pilleur": ("pilleur",),
    "pilleurs": ("pilleur",),
    "pilleuse": ("pilleur",),
    "pilleuses": ("pilleur",),
    "pilomoteur": ("pilomoteur",),
    "pilomoteurs": ("pilomoteur",),
    "pilomotrice": ("pilomoteur",),
    "pilomotrices": ("pilomoteur",),
    "pilonidale": ("pilonidal",),
    "pilonidales": ("pilonidal",),
    "pilonidal": ("pilonidal",),
    "pilonidaux": ("pilonidal",),
    "pilo-sébacée": ("pilo-sébacé",),
    "pilotable": ("pilotable",),
    "pilotables": ("pilotable",),
    "pilulaire": ("pilulaire",),
    "pilulaires": ("pilulaire",),
    "pimarique": ("pimarique",),
    "pimariques": ("pimarique",),
    "pimélique": ("pimélique",),
    "piméliques": ("pimélique",),
    "pinacolique": ("pinacolique",),
    "pinacoliques": ("pinacolique",),
    "pinailleur": ("pinailleur",),
    "pinailleurs": ("pinailleur",),
    "pinailleuse": ("pinailleur",),
    "pinailleuses": ("pinailleur",),
    "pinceur": ("pinceur",),
    "pinceurs": ("pinceur",),
    "pinceuse": ("pinceur",),
    "pinceuses": ("pinceur",),
    "pindarique": ("pindarique",),
    "pindariques": ("pindarique",),
    "pindique": ("pindique",),
    "pindiques": ("pindique",),
    "pinéale": ("pinéal",),
    "pinéales": ("pinéal",),
    "pinéal": ("pinéal",),
    "pinéaux": ("pinéal",),
    "pingre": ("pingre",),
    "pingres": ("pingre",),
    "piocheur": ("piocheur",),
    "piocheurs": ("piocheur",),
    "piocheuse": ("piocheur",),
    "piocheuses": ("piocheur",),
    "pionnière": ("pionnier",),
    "pionnières": ("pionnier",),
    "pionnier": ("pionnier",),
    "pionniers": ("pionnier",),
    "pipémidique": ("pipémidique",),
    "pipémidiques": ("pipémidique",),
    "pipérique": ("pipérique",),
    "pipériques": ("pipérique",),
    "pipéronylique": ("pipéronylique",),
    "pipéronyliques": ("pipéronylique",),
    "pipière": ("pipier",),
    "pipières": ("pipier",),
    "pipier": ("pipier",),
    "pipiers": ("pipier",),
    "piqueur": ("piqueur",),
    "piqueurs": ("piqueur",),
    "piqueuse": ("piqueur",),
    "piqueuses": ("piqueur",),
    "piratable": ("piratable",),
    "piratables": ("piratable",),
    "pirate": ("pirate",),
    "pirates": ("pirate",),
    "pire": ("pire",),
    "pires": ("pire",),
    "piriforme": ("piriforme",),
    "piriformes": ("piriforme",),
    "piromidique": ("piromidique",),
    "piromidiques": ("piromidique",),
    "piscatoire": ("piscatoire",),
    "piscatoires": ("piscatoire",),
    "pisciaire": ("pisciaire",),
    "pisciaires": ("pisciaire",),
    "piscicole": ("piscicole",),
    "piscicoles": ("piscicole",),
    "pisciforme": ("pisciforme",),
    "pisciformes": ("pisciforme",),
    "piscivore": ("piscivore",),
    "piscivores": ("piscivore",),
    "pisiforme": ("pisiforme",),
    "pisiformes": ("pisiforme",),
    "pisolithique": ("pisolithique",),
    "pisolithiques": ("pisolithique",),
    "pisolitique": ("pisolitique",),
    "pisolitiques": ("pisolitique",),
    "pisseuse": ("pisseux",),
    "pisseuses": ("pisseux",),
    "pisseux": ("pisseux",),
    "pistache": ("pistache",),
    "pistillaire": ("pistillaire",),
    "pistillaires": ("pistillaire",),
    "pitchounet": ("pitchounet",),
    "pitchounets": ("pitchounet",),
    "pitchounette": ("pitchounet",),
    "pitchounettes": ("pitchounet",),
    "piteuse": ("piteux",),
    "piteuses": ("piteux",),
    "piteux": ("piteux",),
    "pithécanthropien": ("pithécanthropien",),
    "pithécanthropienne": ("pithécanthropien",),
    "pithécanthropiennes": ("pithécanthropien",),
    "pithécanthropiens": ("pithécanthropien",),
    "pithécoïde": ("pithécoïde",),
    "pithécoïdes": ("pithécoïde",),
    "pithiatique": ("pithiatique",),
    "pithiatiques": ("pithiatique",),
    "pithométrique": ("pithométrique",),
    "pithométriques": ("pithométrique",),
    "pitoyable": ("pitoyable",),
    "pitoyables": ("pitoyable",),
    "pittoresque": ("pittoresque",),
    "pittoresques": ("pittoresque",),
    "pituitaire": ("pituitaire",),
    "pituitaires": ("pituitaire",),
    "pituitarien": ("pituitarien",),
    "pituitarienne": ("pituitarien",),
    "pituitariennes": ("pituitarien",),
    "pituitariens": ("pituitarien",),
    "pituiteuse": ("pituiteux",),
    "pituiteuses": ("pituiteux",),
    "pituiteux": ("pituiteux",),
    "pituitoprive": ("pituitoprive",),
    "pituitoprives": ("pituitoprive",),
    "pityriasique": ("pityriasique",),
    "pityriasiques": ("pityriasique",),
    "pivalique": ("pivalique",),
    "pivaliques": ("pivalique",),
    "plaçable": ("plaçable",),
    "plaçables": ("plaçable",),
    "placentaire": ("placentaire",),
    "placentaires": ("placentaire",),
    "placide": ("placide",),
    "placides": ("placide",),
    "placoïde": ("placoïde",),
    "placoïdes": ("placoïde",),
    "plafonneur": ("plafonneur",),
    "plafonneurs": ("plafonneur",),
    "plafonneuse": ("plafonneur",),
    "plafonneuses": ("plafonneur",),
    "plagale": ("plagal",),
    "plagales": ("plagal",),
    "plagal": ("plagal",),
    "plagaux": ("plagal",),
    "plagiaire": ("plagiaire",),
    "plagiaires": ("plagiaire",),
    "plagiocéphale": ("plagiocéphale",),
    "plagiocéphales": ("plagiocéphale",),
    "plagiotrope": ("plagiotrope",),
    "plagiotropes": ("plagiotrope",),
    "plaidable": ("plaidable",),
    "plaidables": ("plaidable",),
    "plaintif": ("plaintif",),
    "plaintifs": ("plaintif",),
    "plaintive": ("plaintif",),
    "plaintives": ("plaintif",),
    "planaire": ("planaire",),
    "planaires": ("planaire",),
    "planctonique": ("planctonique",),
    "planctoniques": ("planctonique",),
    "planctonivore": ("planctonivore",),
    "planctonivores": ("planctonivore",),
    "planctonologique": ("planctonologique",),
    "planctonologiques": ("planctonologique",),
    "planctophage": ("planctophage",),
    "planctophages": ("planctophage",),
    "planétaire": ("planétaire",),
    "planétaires": ("planétaire",),
    "planétologique": ("planétologique",),
    "planétologiques": ("planétologique",),
    "planeur": ("planeur",),
    "planeurs": ("planeur",),
    "planeuse": ("planeur",),
    "planeuses": ("planeur",),
    "planifiable": ("planifiable",),
    "planifiables": ("planifiable",),
    "planificateur": ("planificateur",),
    "planificateurs": ("planificateur",),
    "planificatrice": ("planificateur",),
    "planificatrices": ("planificateur",),
    "planimétrique": ("planimétrique",),
    "planimétriques": ("planimétrique",),
    "planiste": ("planiste",),
    "planistes": ("planiste",),
    "plantaire": ("plantaire",),
    "plantaires": ("plantaire",),
    "plantigrade": ("plantigrade",),
    "plantigrades": ("plantigrade",),
    "plantureuse": ("plantureux",),
    "plantureuses": ("plantureux",),
    "plantureux": ("plantureux",),
    "plaquettaire": ("plaquettaire",),
    "plaquettaires": ("plaquettaire",),
    "plasmagène": ("plasmagène",),
    "plasmagènes": ("plasmagène",),
    "plasmatique": ("plasmatique",),
    "plasmatiques": ("plasmatique",),
    "plasmique": ("plasmique",),
    "plasmiques": ("plasmique",),
    "plasmocytaire": ("plasmocytaire",),
    "plasmocytaires": ("plasmocytaire",),
    "plasmocytoïde": ("plasmocytoïde",),
    "plasmocytoïdes": ("plasmocytoïde",),
    "plasmodicide": ("plasmodicide",),
    "plasmodicides": ("plasmodicide",),
    "plasmodique": ("plasmodique",),
    "plasmodiques": ("plasmodique",),
    "plasmotomique": ("plasmotomique",),
    "plasmotomiques": ("plasmotomique",),
    "plastidiale": ("plastidial",),
    "plastidiales": ("plastidial",),
    "plastidial": ("plastidial",),
    "plastidiaux": ("plastidial",),
    "plastique": ("plastique",),
    "plastiques": ("plastique",),
    "plateresque": ("plateresque",),
    "plateresques": ("plateresque",),
    "platicurtique": ("platicurtique",),
    "platicurtiques": ("platicurtique",),
    "platinée": ("platiné",),
    "platinées": ("platiné",),
    "platiné": ("platiné",),
    "platine": ("platine",),
    "platinés": ("platiné",),
    "platineuse": ("platineux",),
    "platineuses": ("platineux",),
    "platineux": ("platineux",),
    "platinifère": ("platinifère",),
    "platinifères": ("platinifère",),
    "platinique": ("platinique",),
    "platiniques": ("platinique",),
    "platonicien": ("platonicien",),
    "platonicienne": ("platonicien",),
    "platoniciennes": ("platonicien",),
    "platoniciens": ("platonicien",),
    "platonique": ("platonique",),
    "platoniques": ("platonique",),
    "plâtreuse": ("plâtreux",),
    "plâtreuses": ("plâtreux",),
    "plâtreux": ("plâtreux",),
    "plâtrière": ("plâtrier",),
    "plâtrières": ("plâtrier",),
    "plâtrier": ("plâtrier",),
    "plâtriers": ("plâtrier",),
    "platybasique": ("platybasique",),
    "platybasiques": ("platybasique",),
    "platyrhinien": ("platyrhinien",),
    "platyrhinienne": ("platyrhinien",),
    "platyrhiniennes": ("platyrhinien",),
    "platyrhiniens": ("platyrhinien",),
    "platyrrhinien": ("platyrrhinien",),
    "platyrrhinienne": ("platyrrhinien",),
    "platyrrhiniennes": ("platyrrhinien",),
    "platyrrhiniens": ("platyrrhinien",),
    "plausible": ("plausible",),
    "plausibles": ("plausible",),
    "plébéien": ("plébéien",),
    "plébéienne": ("plébéien",),
    "plébéiennes": ("plébéien",),
    "plébéiens": ("plébéien",),
    "plébiscitaire": ("plébiscitaire",),
    "plébiscitaires": ("plébiscitaire",),
    "pleinairiste": ("pleinairiste",),
    "pleinairistes": ("pleinairiste",),
    "pléiochromique": ("pléiochromique",),
    "pléiochromiques": ("pléiochromique",),
    "pléiotrope": ("pléiotrope",),
    "pléiotropes": ("pléiotrope",),
    "pléiotropique": ("pléiotropique",),
    "pléiotropiques": ("pléiotropique",),
    "pléistocène": ("pléistocène",),
    "pléistocènes": ("pléistocène",),
    "plénière": ("plénier",),
    "plénières": ("plénier",),
    "plénier": ("plénier",),
    "pléniers": ("plénier",),
    "plénipotentiaire": ("plénipotentiaire",),
    "plénipotentiaires": ("plénipotentiaire",),
    "pléobare": ("pléobare",),
    "pléobares": ("pléobare",),
    "pléochroïque": ("pléochroïque",),
    "pléochroïques": ("pléochroïque",),
    "pléonastique": ("pléonastique",),
    "pléonastiques": ("pléonastique",),
    "pléthorique": ("pléthorique",),
    "pléthoriques": ("pléthorique",),
    "pléthysmographique": ("pléthysmographique",),
    "pléthysmographiques": ("pléthysmographique",),
    "pleurale": ("pleural",),
    "pleurales": ("pleural",),
    "pleural": ("pleural",),
    "pleuraux": ("pleural",),
    "pleurétique": ("pleurétique",),
    "pleurétiques": ("pleurétique",),
    "pleureur": ("pleureur",),
    "pleureurs": ("pleureur",),
    "pleureuse": ("pleureur",),
    "pleureuses": ("pleureur",),
    "pleurnicheur": ("pleurnicheur",),
    "pleurnicheurs": ("pleurnicheur",),
    "pleurnicheuse": ("pleurnicheur",),
    "pleurnicheuses": ("pleurnicheur",),
    "pleuropéritonéale": ("pleuropéritonéal",),
    "pleuropéritonéales": ("pleuropéritonéal",),
    "pleuropéritonéal": ("pleuropéritonéal",),
    "pleuropéritonéaux": ("pleuropéritonéal",),
    "pleuropneumonia-like": ("pleuropneumonia-like",),
    "pleuropulmonaire": ("pleuropulmonaire",),
    "pleuropulmonaires": ("pleuropulmonaire",),
    "pleutre": ("pleutre",),
    "pleutres": ("pleutre",),
    "plexiforme": ("plexiforme",),
    "plexiformes": ("plexiforme",),
    "plexulaire": ("plexulaire",),
    "plexulaires": ("plexulaire",),
    "pliable": ("pliable",),
    "pliables": ("pliable",),
    "plicatif": ("plicatif",),
    "plicatifs": ("plicatif",),
    "plicative": ("plicatif",),
    "plicatives": ("plicatif",),
    "plieur": ("plieur",),
    "plieurs": ("plieur",),
    "plieuse": ("plieur",),
    "plieuses": ("plieur",),
    "plinien": ("plinien",),
    "plinienne": ("plinien",),
    "pliniennes": ("plinien",),
    "pliniens": ("plinien",),
    "pliocène": ("pliocène",),
    "pliocènes": ("pliocène",),
    "plombeur": ("plombeur",),
    "plombeurs": ("plombeur",),
    "plombeuse": ("plombeux",),
    "plombeuses": ("plombeux",),
    "plombeux": ("plombeux",),
    "plombière": ("plombier",),
    "plombières": ("plombier",),
    "plombier": ("plombier",),
    "plombiers": ("plombier",),
    "plombifère": ("plombifère",),
    "plombifères": ("plombifère",),
    "plombique": ("plombique",),
    "plombiques": ("plombique",),
    "plomboargentifère": ("plomboargentifère",),
    "plomboargentifères": ("plomboargentifère",),
    "plongeur": ("plongeur",),
    "plongeurs": ("plongeur",),
    "plongeuse": ("plongeur",),
    "plongeuses": ("plongeur",),
    "plouc": ("plouc",),
    "ploucs": ("plouc",),
    "plouk": ("plouk",),
    "plouks": ("plouk",),
    "ploutocratique": ("ploutocratique",),
    "ploutocratiques": ("ploutocratique",),
    "ployable": ("ployable",),
    "ployables": ("ployable",),
    "plucheuse": ("plucheux",),
    "plucheuses": ("plucheux",),
    "plucheux": ("plucheux",),
    "plumassière": ("plumassier",),
    "plumassières": ("plumassier",),
    "plumassier": ("plumassier",),
    "plumassiers": ("plumassier",),
    "plumeuse": ("plumeux",),
    "plumeuses": ("plumeux",),
    "plumeux": ("plumeux",),
    "plurale": ("plural",),
    "plurales": ("plural",),
    "plural": ("plural",),
    "pluraux": ("plural",),
    "pluraliste": ("pluraliste",),
    "pluralistes": ("pluraliste",),
    "pluriannuelle": ("pluriannuel",),
    "pluriannuelles": ("pluriannuel",),
    "pluriannuel": ("pluriannuel",),
    "pluriannuels": ("pluriannuel",),
    "pluricarpellaire": ("pluricarpellaire",),
    "pluricarpellaires": ("pluricarpellaire",),
    "pluricausale": ("pluricausal",),
    "pluricausales": ("pluricausal",),
    "pluricausal": ("pluricausal",),
    "pluricausaux": ("pluricausal",),
    "pluricellulaire": ("pluricellulaire",),
    "pluricellulaires": ("pluricellulaire",),
    "pluridimensionnelle": ("pluridimensionnel",),
    "pluridimensionnelles": ("pluridimensionnel",),
    "pluridimensionnel": ("pluridimensionnel",),
    "pluridimensionnels": ("pluridimensionnel",),
    "pluri-disciplinaire": ("pluri-disciplinaire",),
    "pluridisciplinaire": ("pluridisciplinaire",),
    "pluridisciplinaires": ("pluridisciplinaire",),
    "plurielle": ("pluriel",),
    "plurielles": ("pluriel",),
    "pluriel": ("pluriel",),
    "pluriels": ("pluriel",),
    "plurifactorielle": ("plurifactoriel",),
    "plurifactorielles": ("plurifactoriel",),
    "plurifactoriel": ("plurifactoriel",),
    "plurifactoriels": ("plurifactoriel",),
    "pluriflore": ("pluriflore",),
    "pluriflores": ("pluriflore",),
    "plurifocale": ("plurifocal",),
    "plurifocales": ("plurifocal",),
    "plurifocal": ("plurifocal",),
    "plurifocaux": ("plurifocal",),
    "pluriglandulaire": ("pluriglandulaire",),
    "pluriglandulaires": ("pluriglandulaire",),
    "plurilatérale": ("plurilatéral",),
    "plurilatérales": ("plurilatéral",),
    "plurilatéral": ("plurilatéral",),
    "plurilatéraux": ("plurilatéral",),
    "plurilingue": ("plurilingue",),
    "plurilingues": ("plurilingue",),
    "pluriloculaire": ("pluriloculaire",),
    "pluriloculaires": ("pluriloculaire",),
    "plurimillénaire": ("plurimillénaire",),
    "plurimillénaires": ("plurimillénaire",),
    "plurimodale": ("plurimodal",),
    "plurimodales": ("plurimodal",),
    "plurimodal": ("plurimodal",),
    "plurimodaux": ("plurimodal",),
    "plurimoléculaire": ("plurimoléculaire",),
    "plurimoléculaires": ("plurimoléculaire",),
    "plurinationale": ("plurinational",),
    "plurinationales": ("plurinational",),
    "plurinational": ("plurinational",),
    "plurinationaux": ("plurinational",),
    "plurinominale": ("plurinominal",),
    "plurinominales": ("plurinominal",),
    "plurinominal": ("plurinominal",),
    "plurinominaux": ("plurinominal",),
    "pluripartiste": ("pluripartiste",),
    "pluripartistes": ("pluripartiste",),
    "pluriséculaire": ("pluriséculaire",),
    "pluriséculaires": ("pluriséculaire",),
    "pluriviscérale": ("pluriviscéral",),
    "pluriviscérales": ("pluriviscéral",),
    "pluriviscéral": ("pluriviscéral",),
    "pluriviscéraux": ("pluriviscéral",),
    "plurivoque": ("plurivoque",),
    "plurivoques": ("plurivoque",),
    "plutonien": ("plutonien",),
    "plutonienne": ("plutonien",),
    "plutoniennes": ("plutonien",),
    "plutoniens": ("plutonien",),
    "plutonigène": ("plutonigène",),
    "plutonigènes": ("plutonigène",),
    "plutonique": ("plutonique",),
    "plutoniques": ("plutonique",),
    "plutoniste": ("plutoniste",),
    "plutonistes": ("plutoniste",),
    "pluviale": ("pluvial",),
    "pluviales": ("pluvial",),
    "pluvial": ("pluvial",),
    "pluviaux": ("pluvial",),
    "pluvieuse": ("pluvieux",),
    "pluvieuses": ("pluvieux",),
    "pluvieux": ("pluvieux",),
    "pluviométrique": ("pluviométrique",),
    "pluviométriques": ("pluviométrique",),
    "pluvio-nival": ("pluvio-nival",),
    "pluvio-nivaux": ("pluvio-nival",),
    "pluviothermique": ("pluviothermique",),
    "pluviothermiques": ("pluviothermique",),
    "pnéodynamique": ("pnéodynamique",),
    "pnéodynamiques": ("pnéodynamique",),
    "pneumatique": ("pneumatique",),
    "pneumatiques": ("pneumatique",),
    "pneumatolytique": ("pneumatolytique",),
    "pneumatolytiques": ("pneumatolytique",),
    "pneumique": ("pneumique",),
    "pneumiques": ("pneumique",),
    "pneumococcique": ("pneumococcique",),
    "pneumococciques": ("pneumococcique",),
    "pneumoconiosique": ("pneumoconiosique",),
    "pneumoconiosiques": ("pneumoconiosique",),
    "pneumoconiotique": ("pneumoconiotique",),
    "pneumoconiotiques": ("pneumoconiotique",),
    "pneumoganglionnaire": ("pneumoganglionnaire",),
    "pneumoganglionnaires": ("pneumoganglionnaire",),
    "pneumogastrique": ("pneumogastrique",),
    "pneumogastriques": ("pneumogastrique",),
    "pneumologique": ("pneumologique",),
    "pneumologiques": ("pneumologique",),
    "pneumolymphocytaire": ("pneumolymphocytaire",),
    "pneumolymphocytaires": ("pneumolymphocytaire",),
    "pneumonique": ("pneumonique",),
    "pneumoniques": ("pneumonique",),
    "pneumotaxique": ("pneumotaxique",),
    "pneumotaxiques": ("pneumotaxique",),
    "pneumotrope": ("pneumotrope",),
    "pneumotropes": ("pneumotrope",),
    "pneumotyphoïde": ("pneumotyphoïde",),
    "pneumotyphoïdes": ("pneumotyphoïde",),
    "podagrale": ("podagral",),
    "podagrales": ("podagral",),
    "podagral": ("podagral",),
    "podagraux": ("podagral",),
    "podagre": ("podagre",),
    "podagres": ("podagre",),
    "podaire": ("podaire",),
    "podaires": ("podaire",),
    "podalique": ("podalique",),
    "podaliques": ("podalique",),
    "podencéphale": ("podencéphale",),
    "podencéphales": ("podencéphale",),
    "podologique": ("podologique",),
    "podologiques": ("podologique",),
    "podophylleuse": ("podophylleux",),
    "podophylleuses": ("podophylleux",),
    "podophylleux": ("podophylleux",),
    "podzolique": ("podzolique",),
    "podzoliques": ("podzolique",),
    "poecilitique": ("poecilitique",),
    "poecilitiques": ("poecilitique",),
    "poeciloblastique": ("poeciloblastique",),
    "poeciloblastiques": ("poeciloblastique",),
    "poecilotherme": ("poecilotherme",),
    "poecilothermes": ("poecilotherme",),
    "poète": ("poète",),
    "poètes": ("poète",),
    "poétique": ("poétique",),
    "poétiques": ("poétique",),
    "poétisable": ("poétisable",),
    "poétisables": ("poétisable",),
    "poïkilodermique": ("poïkilodermique",),
    "poïkilodermiques": ("poïkilodermique",),
    "poïkilotherme": ("poïkilotherme",),
    "poïkilothermes": ("poïkilotherme",),
    "pointeur": ("pointeur",),
    "pointeurs": ("pointeur",),
    "pointeuse": ("pointeur",),
    "pointeuses": ("pointeur",),
    "pointilleuse": ("pointilleux",),
    "pointilleuses": ("pointilleux",),
    "pointilleux": ("pointilleux",),
    "pointilliste": ("pointilliste",),
    "pointillistes": ("pointilliste",),
    "poire": ("poire",),
    "poires": ("poire",),
    "poisseuse": ("poisseux",),
    "poisseuses": ("poisseux",),
    "poisseux": ("poisseux",),
    "poissonneuse": ("poissonneux",),
    "poissonneuses": ("poissonneux",),
    "poissonneux": ("poissonneux",),
    "poissonnière": ("poissonnier",),
    "poissonnières": ("poissonnier",),
    "poissonnier": ("poissonnier",),
    "poissonniers": ("poissonnier",),
    "poitrinaire": ("poitrinaire",),
    "poitrinaires": ("poitrinaire",),
    "polack": ("polack",),
    "polacks": ("polack",),
    "polaire": ("polaire",),
    "polaires": ("polaire",),
    "polarimétrique": ("polarimétrique",),
    "polarimétriques": ("polarimétrique",),
    "polarisable": ("polarisable",),
    "polarisables": ("polarisable",),
    "polarisateur": ("polarisateur",),
    "polarisateurs": ("polarisateur",),
    "polarisatrice": ("polarisateur",),
    "polarisatrices": ("polarisateur",),
    "polariseur": ("polariseur",),
    "polariseurs": ("polariseur",),
    "polariseuse": ("polariseur",),
    "polariseuses": ("polariseur",),
    "polarographique": ("polarographique",),
    "polarographiques": ("polarographique",),
    "polémique": ("polémique",),
    "polémiques": ("polémique",),
    "polémologique": ("polémologique",),
    "polémologiques": ("polémologique",),
    "policière": ("policier",),
    "policières": ("policier",),
    "policier": ("policier",),
    "policiers": ("policier",),
    "poliomyélitique": ("poliomyélitique",),
    "poliomyélitiques": ("poliomyélitique",),
    "poliorcétique": ("poliorcétique",),
    "poliorcétiques": ("poliorcétique",),
    "polissable": ("polissable",),
    "polissables": ("polissable",),
    "polisseur": ("polisseur",),
    "polisseurs": ("polisseur",),
    "polisseuse": ("polisseur",),
    "polisseuses": ("polisseur",),
    "polisson": ("polisson",),
    "polissonne": ("polisson",),
    "polissonnes": ("polisson",),
    "polissons": ("polisson",),
    "politicien": ("politicien",),
    "politicienne": ("politicien",),
    "politiciennes": ("politicien",),
    "politiciens": ("politicien",),
    "politico-religieuse": ("politico-religieux",),
    "politico-religieuses": ("politico-religieux",),
    "politico-religieux": ("politico-religieux",),
    "politique": ("politique",),
    "politiques": ("politique",),
    "pollicidigitale": ("pollicidigital",),
    "pollicidigitales": ("pollicidigital",),
    "pollicidigital": ("pollicidigital",),
    "pollicidigitaux": ("pollicidigital",),
    "pollinique": ("pollinique",),
    "polliniques": ("pollinique",),
    "pollinisateur": ("pollinisateur",),
    "pollinisateurs": ("pollinisateur",),
    "pollinisatrice": ("pollinisateur",),
    "pollinisatrices": ("pollinisateur",),
    "polluable": ("polluable",),
    "polluables": ("polluable",),
    "pollueur": ("pollueur",),
    "pollueurs": ("pollueur",),
    "pollueuse": ("pollueur",),
    "pollueuses": ("pollueur",),
    "poloïdale": ("poloïdal",),
    "poloïdales": ("poloïdal",),
    "poloïdal": ("poloïdal",),
    "poloïdaux": ("poloïdal",),
    "polonaise": ("polonais",),
    "polonaises": ("polonais",),
    "polonais": ("polonais",),
    "polonophone": ("polonophone",),
    "polonophones": ("polonophone",),
    "poltron": ("poltron",),
    "poltronne": ("poltron",),
    "poltronnes": ("poltron",),
    "poltrons": ("poltron",),
    "polyacide": ("polyacide",),
    "polyacides": ("polyacide",),
    "polyacrylique": ("polyacrylique",),
    "polyacryliques": ("polyacrylique",),
    "polyadénopathique": ("polyadénopathique",),
    "polyadénopathiques": ("polyadénopathique",),
    "polyadique": ("polyadique",),
    "polyadiques": ("polyadique",),
    "polyagglutinable": ("polyagglutinable",),
    "polyagglutinables": ("polyagglutinable",),
    "polyakène": ("polyakène",),
    "polyakènes": ("polyakène",),
    "polyalgique": ("polyalgique",),
    "polyalgiques": ("polyalgique",),
    "polyallylique": ("polyallylique",),
    "polyallyliques": ("polyallylique",),
    "polyandre": ("polyandre",),
    "polyandres": ("polyandre",),
    "polyandrique": ("polyandrique",),
    "polyandriques": ("polyandrique",),
    "polyanodique": ("polyanodique",),
    "polyanodiques": ("polyanodique",),
    "polyarchique": ("polyarchique",),
    "polyarchiques": ("polyarchique",),
    "polyartérielle": ("polyartériel",),
    "polyartérielles": ("polyartériel",),
    "polyartériel": ("polyartériel",),
    "polyartériels": ("polyartériel",),
    "polyarthropathique": ("polyarthropathique",),
    "polyarthropathiques": ("polyarthropathique",),
    "polyarticulaire": ("polyarticulaire",),
    "polyarticulaires": ("polyarticulaire",),
    "polyatomique": ("polyatomique",),
    "polyatomiques": ("polyatomique",),
    "polybasique": ("polybasique",),
    "polybasiques": ("polybasique",),
    "polycalique": ("polycalique",),
    "polycaliques": ("polycalique",),
    "polycamératique": ("polycamératique",),
    "polycamératiques": ("polycamératique",),
    "polycarentielle": ("polycarentiel",),
    "polycarentielles": ("polycarentiel",),
    "polycarentiel": ("polycarentiel",),
    "polycarentiels": ("polycarentiel",),
    "polycarpique": ("polycarpique",),
    "polycarpiques": ("polycarpique",),
    "polycathodique": ("polycathodique",),
    "polycathodiques": ("polycathodique",),
    "polycellulaire": ("polycellulaire",),
    "polycellulaires": ("polycellulaire",),
    "polycentrique": ("polycentrique",),
    "polycentriques": ("polycentrique",),
    "polycéphale": ("polycéphale",),
    "polycéphales": ("polycéphale",),
    "polychroïque": ("polychroïque",),
    "polychroïques": ("polychroïque",),
    "polychromatique": ("polychromatique",),
    "polychromatiques": ("polychromatique",),
    "polychrome": ("polychrome",),
    "polychromes": ("polychrome",),
    "polycinétique": ("polycinétique",),
    "polycinétiques": ("polycinétique",),
    "polyclonale": ("polyclonal",),
    "polyclonales": ("polyclonal",),
    "polyclonal": ("polyclonal",),
    "polyclonaux": ("polyclonal",),
    "polycorique": ("polycorique",),
    "polycoriques": ("polycorique",),
    "polycourant": ("polycourant",),
    "polycyclique": ("polycyclique",),
    "polycycliques": ("polycyclique",),
    "polydactyle": ("polydactyle",),
    "polydactyles": ("polydactyle",),
    "polydentate": ("polydentate",),
    "polydentates": ("polydentate",),
    "polydisperse": ("polydisperse",),
    "polydisperses": ("polydisperse",),
    "polydrome": ("polydrome",),
    "polydromes": ("polydrome",),
    "polydystrophique": ("polydystrophique",),
    "polydystrophiques": ("polydystrophique",),
    "polyèdre": ("polyèdre",),
    "polyèdres": ("polyèdre",),
    "polyédrique": ("polyédrique",),
    "polyédriques": ("polyédrique",),
    "polyembryonnaire": ("polyembryonnaire",),
    "polyembryonnaires": ("polyembryonnaire",),
    "polyendocrinien": ("polyendocrinien",),
    "polyendocrinienne": ("polyendocrinien",),
    "polyendocriniennes": ("polyendocrinien",),
    "polyendocriniens": ("polyendocrinien",),
    "polyénique": ("polyénique",),
    "polyéniques": ("polyénique",),
    "polyépiphysaire": ("polyépiphysaire",),
    "polyépiphysaires": ("polyépiphysaire",),
    "polyéthylénique": ("polyéthylénique",),
    "polyéthyléniques": ("polyéthylénique",),
    "polyfactorielle": ("polyfactoriel",),
    "polyfactorielles": ("polyfactoriel",),
    "polyfactoriel": ("polyfactoriel",),
    "polyfactoriels": ("polyfactoriel",),
    "polyfonctionnelle": ("polyfonctionnel",),
    "polyfonctionnelles": ("polyfonctionnel",),
    "polyfonctionnel": ("polyfonctionnel",),
    "polyfonctionnels": ("polyfonctionnel",),
    "polygame": ("polygame",),
    "polygames": ("polygame",),
    "polygamique": ("polygamique",),
    "polygamiques": ("polygamique",),
    "polygénétique": ("polygénétique",),
    "polygénétiques": ("polygénétique",),
    "polygénique": ("polygénique",),
    "polygéniques": ("polygénique",),
    "polygéniste": ("polygéniste",),
    "polygénistes": ("polygéniste",),
    "polyglotte": ("polyglotte",),
    "polyglottes": ("polyglotte",),
    "polygonale": ("polygonal",),
    "polygonales": ("polygonal",),
    "polygonal": ("polygonal",),
    "polygonaux": ("polygonal",),
    "polygonosomique": ("polygonosomique",),
    "polygonosomiques": ("polygonosomique",),
    "polygraphique": ("polygraphique",),
    "polygraphiques": ("polygraphique",),
    "polygyne": ("polygyne",),
    "polygynes": ("polygyne",),
    "polygynique": ("polygynique",),
    "polygyniques": ("polygynique",),
    "polykinétique": ("polykinétique",),
    "polykinétiques": ("polykinétique",),
    "polykystique": ("polykystique",),
    "polykystiques": ("polykystique",),
    "polymèle": ("polymèle",),
    "polymèles": ("polymèle",),
    "polymère": ("polymère",),
    "polymères": ("polymère",),
    "polymérique": ("polymérique",),
    "polymériques": ("polymérique",),
    "polymérisable": ("polymérisable",),
    "polymérisables": ("polymérisable",),
    "polymétallique": ("polymétallique",),
    "polymétalliques": ("polymétallique",),
    "polymictique": ("polymictique",),
    "polymictiques": ("polymictique",),
    "polyminérale": ("polyminéral",),
    "polyminérales": ("polyminéral",),
    "polyminéral": ("polyminéral",),
    "polyminéraux": ("polyminéral",),
    "polymodale": ("polymodal",),
    "polymodales": ("polymodal",),
    "polymodal": ("polymodal",),
    "polymodaux": ("polymodal",),
    "polymoléculaire": ("polymoléculaire",),
    "polymoléculaires": ("polymoléculaire",),
    "polymorphe": ("polymorphe",),
    "polymorphes": ("polymorphe",),
    "polymorphique": ("polymorphique",),
    "polymorphiques": ("polymorphique",),
    "polynésien": ("polynésien",),
    "polynésienne": ("polynésien",),
    "polynésiennes": ("polynésien",),
    "polynésiens": ("polynésien",),
    "polynévritogène": ("polynévritogène",),
    "polynévritogènes": ("polynévritogène",),
    "polynomiale": ("polynomial",),
    "polynomiales": ("polynomial",),
    "polynomial": ("polynomial",),
    "polynomiaux": ("polynomial",),
    "polynosique": ("polynosique",),
    "polynosiques": ("polynosique",),
    "polynucléaire": ("polynucléaire",),
    "polynucléaires": ("polynucléaire",),
    "polynucléotidique": ("polynucléotidique",),
    "polynucléotidiques": ("polynucléotidique",),
    "polyoptre": ("polyoptre",),
    "polyoptres": ("polyoptre",),
    "polyosidique": ("polyosidique",),
    "polyosidiques": ("polyosidique",),
    "polypage": ("polypage",),
    "polypages": ("polypage",),
    "polypeptidique": ("polypeptidique",),
    "polypeptidiques": ("polypeptidique",),
    "polypeptidopexique": ("polypeptidopexique",),
    "polypeptidopexiques": ("polypeptidopexique",),
    "polypétale": ("polypétale",),
    "polypétales": ("polypétale",),
    "polypeuse": ("polypeux",),
    "polypeuses": ("polypeux",),
    "polypeux": ("polypeux",),
    "polyphage": ("polyphage",),
    "polyphages": ("polyphage",),
    "polyphagique": ("polyphagique",),
    "polyphagiques": ("polyphagique",),
    "polyphasique": ("polyphasique",),
    "polyphasiques": ("polyphasique",),
    "polyphénolique": ("polyphénolique",),
    "polyphénoliques": ("polyphénolique",),
    "polyphone": ("polyphone",),
    "polyphones": ("polyphone",),
    "polyphonique": ("polyphonique",),
    "polyphoniques": ("polyphonique",),
    "polyphylétique": ("polyphylétique",),
    "polyphylétiques": ("polyphylétique",),
    "polypien": ("polypien",),
    "polypienne": ("polypien",),
    "polypiennes": ("polypien",),
    "polypiens": ("polypien",),
    "polyploïde": ("polyploïde",),
    "polyploïdes": ("polyploïde",),
    "polypnéique": ("polypnéique",),
    "polypnéiques": ("polypnéique",),
    "polypoïde": ("polypoïde",),
    "polypoïdes": ("polypoïde",),
    "polypolistique": ("polypolistique",),
    "polypolistiques": ("polypolistique",),
    "polyrème": ("polyrème",),
    "polyrèmes": ("polyrème",),
    "polysaccharidique": ("polysaccharidique",),
    "polysaccharidiques": ("polysaccharidique",),
    "polysémique": ("polysémique",),
    "polysémiques": ("polysémique",),
    "polysoc": ("polysoc",),
    "polysperme": ("polysperme",),
    "polyspermes": ("polysperme",),
    "polysphérique": ("polysphérique",),
    "polysphériques": ("polysphérique",),
    "polystélique": ("polystélique",),
    "polystéliques": ("polystélique",),
    "polystémone": ("polystémone",),
    "polystémones": ("polystémone",),
    "polystéroïdique": ("polystéroïdique",),
    "polystéroïdiques": ("polystéroïdique",),
    "polystome": ("polystome",),
    "polystomes": ("polystome",),
    "polystyle": ("polystyle",),
    "polystyles": ("polystyle",),
    "polysyllabe": ("polysyllabe",),
    "polysyllabes": ("polysyllabe",),
    "polysyllabique": ("polysyllabique",),
    "polysyllabiques": ("polysyllabique",),
    "polysyllogistique": ("polysyllogistique",),
    "polysyllogistiques": ("polysyllogistique",),
    "polysynaptique": ("polysynaptique",),
    "polysynaptiques": ("polysynaptique",),
    "polysynthétique": ("polysynthétique",),
    "polysynthétiques": ("polysynthétique",),
    "polytaxique": ("polytaxique",),
    "polytaxiques": ("polytaxique",),
    "polytechnicien": ("polytechnicien",),
    "polytechnicienne": ("polytechnicien",),
    "polytechniciennes": ("polytechnicien",),
    "polytechniciens": ("polytechnicien",),
    "polytechnique": ("polytechnique",),
    "polytechniques": ("polytechnique",),
    "polyterpénique": ("polyterpénique",),
    "polyterpéniques": ("polyterpénique",),
    "polythéiste": ("polythéiste",),
    "polythéistes": ("polythéiste",),
    "polytherme": ("polytherme",),
    "polythermes": ("polytherme",),
    "polytissulaire": ("polytissulaire",),
    "polytissulaires": ("polytissulaire",),
    "polytonale": ("polytonal",),
    "polytonales": ("polytonal",),
    "polytonal": ("polytonal",),
    "polytonaux": ("polytonal",),
    "polytoxicomane": ("polytoxicomane",),
    "polytoxicomanes": ("polytoxicomane",),
    "polytypique": ("polytypique",),
    "polytypiques": ("polytypique",),
    "polyuridipsique": ("polyuridipsique",),
    "polyuridipsiques": ("polyuridipsique",),
    "polyurique": ("polyurique",),
    "polyuriques": ("polyurique",),
    "polyurodipsique": ("polyurodipsique",),
    "polyurodipsiques": ("polyurodipsique",),
    "polyuro-polydipsique": ("polyuro-polydipsique",),
    "polyuropolydipsique": ("polyuropolydipsique",),
    "polyuropolydipsiques": ("polyuropolydipsique",),
    "polyvalvulaire": ("polyvalvulaire",),
    "polyvalvulaires": ("polyvalvulaire",),
    "polyvinylidénique": ("polyvinylidénique",),
    "polyvinylidéniques": ("polyvinylidénique",),
    "polyvinylique": ("polyvinylique",),
    "polyvinyliques": ("polyvinylique",),
    "polyviscérale": ("polyviscéral",),
    "polyviscérales": ("polyviscéral",),
    "polyviscéral": ("polyviscéral",),
    "polyviscéraux": ("polyviscéral",),
    "pomarin": ("pomarin",),
    "pomarins": ("pomarin",),
    "pommée": ("pommé",),
    "pommées": ("pommé",),
    "pommé": ("pommé",),
    "pomme": ("pomme",),
    "pommés": ("pommé",),
    "pommifère": ("pommifère",),
    "pommifères": ("pommifère",),
    "pomologique": ("pomologique",),
    "pomologiques": ("pomologique",),
    "pomonale": ("pomonal",),
    "pomonales": ("pomonal",),
    "pomonal": ("pomonal",),
    "pomonaux": ("pomonal",),
    "pompéien": ("pompéien",),
    "pompéienne": ("pompéien",),
    "pompéiennes": ("pompéien",),
    "pompéiens": ("pompéien",),
    "pompette": ("pompette",),
    "pompettes": ("pompette",),
    "pompeur": ("pompeur",),
    "pompeurs": ("pompeur",),
    "pompeuse": ("pompeux",),
    "pompeuses": ("pompeux",),
    "pompeux": ("pompeux",),
    "pompière": ("pompier",),
    "pompières": ("pompier",),
    "pompier": ("pompier",),
    "pompiers": ("pompier",),
    "pompon": ("pompon",),
    "ponantaise": ("ponantais",),
    "ponantaises": ("ponantais",),
    "ponantais": ("ponantais",),
    "poncée": ("poncé",),
    "poncées": ("poncé",),
    "poncé": ("poncé",),
    "ponce": ("ponce",),
    "poncés": ("poncé",),
    "ponceau": ("ponceau",),
    "ponceuse": ("ponceux",),
    "ponceuses": ("ponceux",),
    "ponceux": ("ponceux",),
    "ponctuelle": ("ponctuel",),
    "ponctuelles": ("ponctuel",),
    "ponctuel": ("ponctuel",),
    "ponctuels": ("ponctuel",),
    "pondérable": ("pondérable",),
    "pondérables": ("pondérable",),
    "pondérale": ("pondéral",),
    "pondérales": ("pondéral",),
    "pondéral": ("pondéral",),
    "pondéraux": ("pondéral",),
    "pondérateur": ("pondérateur",),
    "pondérateurs": ("pondérateur",),
    "pondératrice": ("pondérateur",),
    "pondératrices": ("pondérateur",),
    "pondéreuse": ("pondéreux",),
    "pondéreuses": ("pondéreux",),
    "pondéreux": ("pondéreux",),
    "pondérostaturale": ("pondérostatural",),
    "pondérostaturales": ("pondérostatural",),
    "pondérostatural": ("pondérostatural",),
    "pondérostaturaux": ("pondérostatural",),
    "pondeur": ("pondeur",),
    "pondeurs": ("pondeur",),
    "pondeuse": ("pondeur",),
    "pondeuses": ("pondeur",),
    "pongitif": ("pongitif",),
    "pongitifs": ("pongitif",),
    "pongitive": ("pongitif",),
    "pongitives": ("pongitif",),
    "pontificale": ("pontifical",),
    "pontificales": ("pontifical",),
    "pontifical": ("pontifical",),
    "pontificaux": ("pontifical",),
    "pontique": ("pontique",),
    "pontiques": ("pontique",),
    "pop": ("pop",),
    "popote": ("popote",),
    "populacière": ("populacier",),
    "populacières": ("populacier",),
    "populacier": ("populacier",),
    "populaciers": ("populacier",),
    "populaire": ("populaire",),
    "populaires": ("populaire",),
    "populationniste": ("populationniste",),
    "populationnistes": ("populationniste",),
    "populeuse": ("populeux",),
    "populeuses": ("populeux",),
    "populeux": ("populeux",),
    "populiste": ("populiste",),
    "populistes": ("populiste",),
    "poradénique": ("poradénique",),
    "poradéniques": ("poradénique",),
    "porcelainière": ("porcelainier",),
    "porcelainières": ("porcelainier",),
    "porcelainier": ("porcelainier",),
    "porcelainiers": ("porcelainier",),
    "porcelanique": ("porcelanique",),
    "porcelaniques": ("porcelanique",),
    "poreuse": ("poreux",),
    "poreuses": ("poreux",),
    "poreux": ("poreux",),
    "porno": ("porno",),
    "pornos": ("porno",),
    "pornographique": ("pornographique",),
    "pornographiques": ("pornographique",),
    "porphyrinique": ("porphyrinique",),
    "porphyriniques": ("porphyrinique",),
    "porphyrique": ("porphyrique",),
    "porphyriques": ("porphyrique",),
    "porphyrogénète": ("porphyrogénète",),
    "porphyrogénètes": ("porphyrogénète",),
    "porphyroïde": ("porphyroïde",),
    "porphyroïdes": ("porphyroïde",),
    "portable": ("portable",),
    "portables": ("portable",),
    "portale": ("portal",),
    "portales": ("portal",),
    "portal": ("portal",),
    "portaux": ("portal",),
    "portatif": ("portatif",),
    "portatifs": ("portatif",),
    "portative": ("portatif",),
    "portatives": ("portatif",),
    "portée": ("porté",),
    "portées": ("porté",),
    "porté": ("porté",),
    "porte": ("porte",),
    "portés": ("porté",),
    "portes": ("porte",),
    "porteur": ("porteur",),
    "porteurs": ("porteur",),
    "porteuse": ("porteur",),
    "porteuses": ("porteur",),
    "portière": ("portière",),
    "portières": ("portière",),
    "portionnable": ("portionnable",),
    "portionnables": ("portionnable",),
    "portionnaire": ("portionnaire",),
    "portionnaires": ("portionnaire",),
    "portuaire": ("portuaire",),
    "portuaires": ("portuaire",),
    "portugaise": ("portugais",),
    "portugaises": ("portugais",),
    "portugais": ("portugais",),
    "poruleuse": ("poruleux",),
    "poruleuses": ("poruleux",),
    "poruleux": ("poruleux",),
    "poseur": ("poseur",),
    "poseurs": ("poseur",),
    "poseuse": ("poseur",),
    "poseuses": ("poseur",),
    "positif": ("positif",),
    "positifs": ("positif",),
    "positive": ("positif",),
    "positives": ("positif",),
    "positionnelle": ("positionnel",),
    "positionnelles": ("positionnel",),
    "positionnel": ("positionnel",),
    "positionnels": ("positionnel",),
    "positiviste": ("positiviste",),
    "positivistes": ("positiviste",),
    "posologique": ("posologique",),
    "posologiques": ("posologique",),
    "possédable": ("possédable",),
    "possédables": ("possédable",),
    "possesseur": ("possesseur",),
    "possesseurs": ("possesseur",),
    "possessif": ("possessif",),
    "possessifs": ("possessif",),
    "possessive": ("possessif",),
    "possessives": ("possessif",),
    "possessionné": ("possessionné",),
    "possessionnés": ("possessionné",),
    "possessionnelle": ("possessionnel",),
    "possessionnelles": ("possessionnel",),
    "possessionnel": ("possessionnel",),
    "possessionnels": ("possessionnel",),
    "possessoire": ("possessoire",),
    "possessoires": ("possessoire",),
    "possibiliste": ("possibiliste",),
    "possibilistes": ("possibiliste",),
    "possible": ("possible",),
    "possibles": ("possible",),
    "postabortif": ("postabortif",),
    "postabortifs": ("postabortif",),
    "postabortive": ("postabortif",),
    "postabortives": ("postabortif",),
    "post-agrarienne": ("post-agrarien",),
    "postale": ("postal",),
    "postales": ("postal",),
    "postal": ("postal",),
    "postaux": ("postal",),
    "postalvéolaire": ("postalvéolaire",),
    "postalvéolaires": ("postalvéolaire",),
    "postchirurgicale": ("postchirurgical",),
    "postchirurgicales": ("postchirurgical",),
    "postchirurgical": ("postchirurgical",),
    "postchirurgicaux": ("postchirurgical",),
    "postclassique": ("postclassique",),
    "postclassiques": ("postclassique",),
    "postcoïtale": ("postcoïtal",),
    "post-coïtales": ("post-coïtal",),
    "postcoïtales": ("postcoïtal",),
    "postcoïtal": ("postcoïtal",),
    "postcoïtaux": ("postcoïtal",),
    "postcoloniale": ("postcolonial",),
    "postcoloniales": ("postcolonial",),
    "postcolonial": ("postcolonial",),
    "postcoloniaux": ("postcolonial",),
    "postcommuniste": ("postcommuniste",),
    "postcommunistes": ("postcommuniste",),
    "postconciliaire": ("postconciliaire",),
    "postconciliaires": ("postconciliaire",),
    "postconsonantique": ("postconsonantique",),
    "postconsonantiques": ("postconsonantique",),
    "postdentale": ("postdental",),
    "postdentales": ("postdental",),
    "postdental": ("postdental",),
    "postdentaux": ("postdental",),
    "postdorsale": ("postdorsal",),
    "postdorsales": ("postdorsal",),
    "postdorsal": ("postdorsal",),
    "postdorsaux": ("postdorsal",),
    "postembryonaire": ("postembryonaire",),
    "postembryonaires": ("postembryonaire",),
    "postérosif": ("postérosif",),
    "postérosifs": ("postérosif",),
    "postérosive": ("postérosif",),
    "postérosives": ("postérosif",),
    "postexilique": ("postexilique",),
    "postexiliques": ("postexilique",),
    "postfermentaire": ("postfermentaire",),
    "postfermentaires": ("postfermentaire",),
    "postganglionnaire": ("postganglionnaire",),
    "postganglionnaires": ("postganglionnaire",),
    "postglaciaire": ("postglaciaire",),
    "postglaciaires": ("postglaciaire",),
    "posthume": ("posthume",),
    "posthumes": ("posthume",),
    "postiche": ("postiche",),
    "postiches": ("postiche",),
    "post-impressionniste": ("postimpressionniste",),
    "postimpressionniste": ("postimpressionniste",),
    "postimpressionnistes": ("postimpressionniste",),
    "post-industrielle": ("postindustriel",),
    "postindustrielle": ("postindustriel",),
    "postindustrielles": ("postindustriel",),
    "post-industriel": ("postindustriel",),
    "postindustriel": ("postindustriel",),
    "post-industriels": ("postindustriel",),
    "postindustriels": ("postindustriel",),
    "postjonctionnelle": ("postjonctionnel",),
    "postjonctionnelles": ("postjonctionnel",),
    "postjonctionnel": ("postjonctionnel",),
    "postjonctionnels": ("postjonctionnel",),
    "postlarvaire": ("postlarvaire",),
    "postlarvaires": ("postlarvaire",),
    "postmature": ("postmature",),
    "postmatures": ("postmature",),
    "post-menstruelles": ("post-menstruel",),
    "postmictionnelle": ("postmictionnel",),
    "postmictionnelles": ("postmictionnel",),
    "postmictionnel": ("postmictionnel",),
    "postmictionnels": ("postmictionnel",),
    "post-moderne": ("post-moderne",),
    "postmoderne": ("postmoderne",),
    "post-modernes": ("post-moderne",),
    "postmodernes": ("postmoderne",),
    "postnéoclassique": ("postnéoclassique",),
    "postnéoclassiques": ("postnéoclassique",),
    "postnucléaire": ("postnucléaire",),
    "postnucléaires": ("postnucléaire",),
    "postoculaire": ("postoculaire",),
    "postoculaires": ("postoculaire",),
    "post-opératoire": ("post-opératoire",),
    "postopératoire": ("postopératoire",),
    "postopératoires": ("postopératoire",),
    "postorale": ("postoral",),
    "postorales": ("postoral",),
    "postoral": ("postoral",),
    "postoraux": ("postoral",),
    "postpalatale": ("postpalatal",),
    "postpalatales": ("postpalatal",),
    "postpalatal": ("postpalatal",),
    "postpalataux": ("postpalatal",),
    "postpénale": ("postpénal",),
    "postpénales": ("postpénal",),
    "postpénal": ("postpénal",),
    "postpénaux": ("postpénal",),
    "postposable": ("postposable",),
    "postposables": ("postposable",),
    "postpositif": ("postpositif",),
    "postpositifs": ("postpositif",),
    "postpositive": ("postpositif",),
    "postpositives": ("postpositif",),
    "postprandiale": ("postprandial",),
    "postprandiales": ("postprandial",),
    "post-prandial": ("post-prandial",),
    "postprandial": ("postprandial",),
    "postprandiaux": ("postprandial",),
    "postrévolutionnaire": ("postrévolutionnaire",),
    "postrévolutionnaires": ("postrévolutionnaire",),
    "postromantique": ("postromantique",),
    "postromantiques": ("postromantique",),
    "post-scolaire": ("post-scolaire",),
    "postscolaire": ("postscolaire",),
    "postscolaires": ("postscolaire",),
    "postsecondaire": ("postsecondaire",),
    "postsecondaires": ("postsecondaire",),
    "postsynaptique": ("postsynaptique",),
    "post-synaptiques": ("post-synaptique",),
    "postsynaptiques": ("postsynaptique",),
    "post-tétaniques": ("post-tétanique",),
    "postthérapeutique": ("postthérapeutique",),
    "postthérapeutiques": ("postthérapeutique",),
    "post-transfusionnelle": ("post-transfusionnel",),
    "post-transfusionnel": ("post-transfusionnel",),
    "post-transfusionnels": ("post-transfusionnel",),
    "post-trématique": ("post-trématique",),
    "postulable": ("postulable",),
    "postulables": ("postulable",),
    "postuniversitaire": ("postuniversitaire",),
    "postuniversitaires": ("postuniversitaire",),
    "posturale": ("postural",),
    "posturales": ("postural",),
    "postural": ("postural",),
    "posturaux": ("postural",),
    "post-urbaines": ("post-urbain",),
    "postvélaire": ("postvélaire",),
    "postvélaires": ("postvélaire",),
    "postvocalique": ("postvocalique",),
    "postvocaliques": ("postvocalique",),
    "postzygotique": ("postzygotique",),
    "postzygotiques": ("postzygotique",),
    "potabilisable": ("potabilisable",),
    "potabilisables": ("potabilisable",),
    "potable": ("potable",),
    "potables": ("potable",),
    "potagère": ("potager",),
    "potagères": ("potager",),
    "potager": ("potager",),
    "potagers": ("potager",),
    "potassique": ("potassique",),
    "potassiques": ("potassique",),
    "potentielle": ("potentiel",),
    "potentielles": ("potentiel",),
    "potentiel": ("potentiel",),
    "potentiels": ("potentiel",),
    "potentiométrique": ("potentiométrique",),
    "potentiométriques": ("potentiométrique",),
    "potestatif": ("potestatif",),
    "potestatifs": ("potestatif",),
    "potestative": ("potestatif",),
    "potestatives": ("potestatif",),
    "potiche": ("potiche",),
    "potiches": ("potiche",),
    "potinière": ("potinier",),
    "potinières": ("potinier",),
    "potinier": ("potinier",),
    "potiniers": ("potinier",),
    "potologique": ("potologique",),
    "potologiques": ("potologique",),
    "potomane": ("potomane",),
    "potomanes": ("potomane",),
    "pottique": ("pottique",),
    "pottiques": ("pottique",),
    "pouacre": ("pouacre",),
    "pouacres": ("pouacre",),
    "poudreuse": ("poudreux",),
    "poudreuses": ("poudreux",),
    "poudreux": ("poudreux",),
    "pouf": ("pouf",),
    "poufs": ("pouf",),
    "pouilleuse": ("pouilleux",),
    "pouilleuses": ("pouilleux",),
    "pouilleux": ("pouilleux",),
    "poujadiste": ("poujadiste",),
    "poujadistes": ("poujadiste",),
    "poulinière": ("poulinière",),
    "poulinières": ("poulinière",),
    "pourchasseur": ("pourchasseur",),
    "pourchasseurs": ("pourchasseur",),
    "pourchasseuse": ("pourchasseur",),
    "pourchasseuses": ("pourchasseur",),
    "pourfendeur": ("pourfendeur",),
    "pourfendeurs": ("pourfendeur",),
    "pourfendeuse": ("pourfendeur",),
    "pourfendeuses": ("pourfendeur",),
    "pourprée": ("pourpré",),
    "pourprées": ("pourpré",),
    "pourpré": ("pourpré",),
    "pourpre": ("pourpre",),
    "pourprés": ("pourpré",),
    "pourpres": ("pourpre",),
    "pourrissable": ("pourrissable",),
    "pourrissables": ("pourrissable",),
    "pourrisseur": ("pourrisseur",),
    "pourrisseurs": ("pourrisseur",),
    "pourrisseuse": ("pourrisseur",),
    "pourrisseuses": ("pourrisseur",),
    "pourvoyeur": ("pourvoyeur",),
    "pourvoyeurs": ("pourvoyeur",),
    "pourvoyeuse": ("pourvoyeur",),
    "pourvoyeuses": ("pourvoyeur",),
    "poussiéreuse": ("poussiéreux",),
    "poussiéreuses": ("poussiéreux",),
    "poussiéreux": ("poussiéreux",),
    "poussif": ("poussif",),
    "poussifs": ("poussif",),
    "poussive": ("poussif",),
    "poussives": ("poussif",),
    "pouzzolanique": ("pouzzolanique",),
    "pouzzolaniques": ("pouzzolanique",),
    "pouzzolanométallurgique": ("pouzzolanométallurgique",),
    "pouzzolanométallurgiques": ("pouzzolanométallurgique",),
    "pradosien": ("pradosien",),
    "pradosienne": ("pradosien",),
    "pradosiennes": ("pradosien",),
    "pradosiens": ("pradosien",),
    "pragmatique": ("pragmatique",),
    "pragmatiques": ("pragmatique",),
    "pragmatiste": ("pragmatiste",),
    "pragmatistes": ("pragmatiste",),
    "pragoise": ("pragois",),
    "pragoises": ("pragois",),
    "pragois": ("pragois",),
    "praguoise": ("praguois",),
    "praguoises": ("praguois",),
    "praguois": ("praguois",),
    "prairiale": ("prairial",),
    "prairiales": ("prairial",),
    "prairial": ("prairial",),
    "prairiaux": ("prairial",),
    "prandiale": ("prandial",),
    "prandiales": ("prandial",),
    "prandial": ("prandial",),
    "prandiaux": ("prandial",),
    "praticable": ("praticable",),
    "praticables": ("praticable",),
    "praticien": ("praticien",),
    "praticienne": ("praticien",),
    "praticiennes": ("praticien",),
    "praticiens": ("praticien",),
    "pratique": ("pratique",),
    "pratiques": ("pratique",),
    "praxéologique": ("praxéologique",),
    "praxéologiques": ("praxéologique",),
    "praxique": ("praxique",),
    "praxiques": ("praxique",),
    "préadamite": ("préadamite",),
    "préadamites": ("préadamite",),
    "pré-agrarien": ("pré-agrarien",),
    "pré-agrariens": ("pré-agrarien",),
    "préalable": ("préalable",),
    "préalables": ("préalable",),
    "prébendiaire": ("prébendiaire",),
    "prébendiaires": ("prébendiaire",),
    "prébétique": ("prébétique",),
    "prébétiques": ("prébétique",),
    "prébiotique": ("prébiotique",),
    "prébiotiques": ("prébiotique",),
    "précaire": ("précaire",),
    "précaires": ("précaire",),
    "précalicielle": ("précaliciel",),
    "précalicielles": ("précaliciel",),
    "précaliciel": ("précaliciel",),
    "précaliciels": ("précaliciel",),
    "précambrien": ("précambrien",),
    "précambrienne": ("précambrien",),
    "précambriennes": ("précambrien",),
    "précambriens": ("précambrien",),
    "précancéreuse": ("précancéreux",),
    "précancéreuses": ("précancéreux",),
    "précancéreux": ("précancéreux",),
    "précapitaliste": ("précapitaliste",),
    "précapitalistes": ("précapitaliste",),
    "précatif": ("précatif",),
    "précatifs": ("précatif",),
    "précative": ("précatif",),
    "précatives": ("précatif",),
    "précausale": ("précausal",),
    "précausales": ("précausal",),
    "précausal": ("précausal",),
    "précausaux": ("précausal",),
    "précautionneuse": ("précautionneux",),
    "précautionneuses": ("précautionneux",),
    "précautionneux": ("précautionneux",),
    "préceltique": ("préceltique",),
    "préceltiques": ("préceltique",),
    "précentrale": ("précentral",),
    "précentrales": ("précentral",),
    "précentral": ("précentral",),
    "précentraux": ("précentral",),
    "préceptorale": ("préceptoral",),
    "préceptorales": ("préceptoral",),
    "préceptoral": ("préceptoral",),
    "préceptoraux": ("préceptoral",),
    "précéramique": ("précéramique",),
    "précéramiques": ("précéramique",),
    "préchelléen": ("préchelléen",),
    "préchelléenne": ("préchelléen",),
    "préchelléennes": ("préchelléen",),
    "préchelléens": ("préchelléen",),
    "prêcheur": ("prêcheur",),
    "prêcheurs": ("prêcheur",),
    "prêcheuse": ("prêcheur",),
    "prêcheuses": ("prêcheur",),
    "précieuse": ("précieux",),
    "précieuses": ("précieux",),
    "précieux": ("précieux",),
    "précipitable": ("précipitable",),
    "précipitables": ("précipitable",),
    "préciputaire": ("préciputaire",),
    "préciputaires": ("préciputaire",),
    "précirrhotique": ("précirrhotique",),
    "précirrhotiques": ("précirrhotique",),
    "précise": ("précis",),
    "précises": ("précis",),
    "précis": ("précis",),
    "précisionniste": ("précisionniste",),
    "précisionnistes": ("précisionniste",),
    "préclassique": ("préclassique",),
    "préclassiques": ("préclassique",),
    "préclinique": ("préclinique",),
    "précliniques": ("préclinique",),
    "précoce": ("précoce",),
    "précoces": ("précoce",),
    "précognitif": ("précognitif",),
    "précognitifs": ("précognitif",),
    "précognitive": ("précognitif",),
    "précognitives": ("précognitif",),
    "précolique": ("précolique",),
    "précoliques": ("précolique",),
    "précolombien": ("précolombien",),
    "précolombienne": ("précolombien",),
    "précolombiennes": ("précolombien",),
    "précolombiens": ("précolombien",),
    "précoloniale": ("précolonial",),
    "précoloniales": ("précolonial",),
    "précolonial": ("précolonial",),
    "précoloniaux": ("précolonial",),
    "précompétitif": ("précompétitif",),
    "précompétitifs": ("précompétitif",),
    "précompétitive": ("précompétitif",),
    "précompétitives": ("précompétitif",),
    "préconceptif": ("préconceptif",),
    "préconceptifs": ("préconceptif",),
    "préconceptive": ("préconceptif",),
    "préconceptives": ("préconceptif",),
    "préconceptuelle": ("préconceptuel",),
    "préconceptuelles": ("préconceptuel",),
    "préconceptuel": ("préconceptuel",),
    "préconceptuels": ("préconceptuel",),
    "préconciliaire": ("préconciliaire",),
    "préconciliaires": ("préconciliaire",),
    "préconjugale": ("préconjugal",),
    "préconjugales": ("préconjugal",),
    "préconjugal": ("préconjugal",),
    "préconjugaux": ("préconjugal",),
    "préconsonantique": ("préconsonantique",),
    "préconsonantiques": ("préconsonantique",),
    "précontentieuse": ("précontentieux",),
    "précontentieuses": ("précontentieux",),
    "précontentieux": ("précontentieux",),
    "précontractuelle": ("précontractuel",),
    "précontractuelles": ("précontractuel",),
    "précontractuel": ("précontractuel",),
    "précontractuels": ("précontractuel",),
    "précopulatoire": ("précopulatoire",),
    "précopulatoires": ("précopulatoire",),
    "précordiale": ("précordial",),
    "précordiales": ("précordial",),
    "précordial": ("précordial",),
    "précordiaux": ("précordial",),
    "précordialgique": ("précordialgique",),
    "précordialgiques": ("précordialgique",),
    "précornéen": ("précornéen",),
    "précornéenne": ("précornéen",),
    "précornéennes": ("précornéen",),
    "précornéens": ("précornéen",),
    "précurseur": ("précurseur",),
    "précurseurs": ("précurseur",),
    "prédateur": ("prédateur",),
    "prédateurs": ("prédateur",),
    "prédatrice": ("prédateur",),
    "prédatrices": ("prédateur",),
    "prédeltaïque": ("prédeltaïque",),
    "prédeltaïques": ("prédeltaïque",),
    "prédémentielle": ("prédémentiel",),
    "prédémentielles": ("prédémentiel",),
    "prédémentiel": ("prédémentiel",),
    "prédémentiels": ("prédémentiel",),
    "prédésinentielle": ("prédésinentiel",),
    "prédésinentielles": ("prédésinentiel",),
    "prédésinentiel": ("prédésinentiel",),
    "prédésinentiels": ("prédésinentiel",),
    "prédiabétique": ("prédiabétique",),
    "prédiabétiques": ("prédiabétique",),
    "prédiale": ("prédial",),
    "prédiales": ("prédial",),
    "prédial": ("prédial",),
    "prédiaux": ("prédial",),
    "prédiastolique": ("prédiastolique",),
    "prédiastoliques": ("prédiastolique",),
    "prédicable": ("prédicable",),
    "prédicables": ("prédicable",),
    "prédicamentale": ("prédicamental",),
    "prédicamentales": ("prédicamental",),
    "prédicamental": ("prédicamental",),
    "prédicamentaux": ("prédicamental",),
    "prédicatif": ("prédicatif",),
    "prédicatifs": ("prédicatif",),
    "prédicative": ("prédicatif",),
    "prédicatives": ("prédicatif",),
    "prédictible": ("prédictible",),
    "prédictibles": ("prédictible",),
    "prédictif": ("prédictif",),
    "prédictifs": ("prédictif",),
    "prédictive": ("prédictif",),
    "prédictives": ("prédictif",),
    "prédorsale": ("prédorsal",),
    "prédorsales": ("prédorsal",),
    "prédorsal": ("prédorsal",),
    "prédorsaux": ("prédorsal",),
    "prédynastique": ("prédynastique",),
    "prédynastiques": ("prédynastique",),
    "préélectorale": ("préélectoral",),
    "pré-électorales": ("pré-électoral",),
    "préélectorales": ("préélectoral",),
    "pré-électoral": ("pré-électoral",),
    "préélectoral": ("préélectoral",),
    "préélectoraux": ("préélectoral",),
    "préélémentaire": ("préélémentaire",),
    "préélémentaires": ("préélémentaire",),
    "préemptif": ("préemptif",),
    "préemptifs": ("préemptif",),
    "préemptive": ("préemptif",),
    "préemptives": ("préemptif",),
    "préétatique": ("préétatique",),
    "préétatiques": ("préétatique",),
    "préfectorale": ("préfectoral",),
    "préfectorales": ("préfectoral",),
    "préfectoral": ("préfectoral",),
    "préfectoraux": ("préfectoral",),
    "préférable": ("préférable",),
    "préférables": ("préférable",),
    "préférentielle": ("préférentiel",),
    "préférentielles": ("préférentiel",),
    "préférentiel": ("préférentiel",),
    "préférentiels": ("préférentiel",),
    "préfermentaire": ("préfermentaire",),
    "préfermentaires": ("préfermentaire",),
    "préfinançable": ("préfinançable",),
    "préfinançables": ("préfinançable",),
    "préfixable": ("préfixable",),
    "préfixables": ("préfixable",),
    "préfixale": ("préfixal",),
    "préfixales": ("préfixal",),
    "préfixal": ("préfixal",),
    "préfixaux": ("préfixal",),
    "préfixe": ("préfix",),
    "préfixes": ("préfix",),
    "préfix": ("préfix",),
    "préformatif": ("préformatif",),
    "préformatifs": ("préformatif",),
    "préformative": ("préformatif",),
    "préformatives": ("préformatif",),
    "préfrontale": ("préfrontal",),
    "préfrontales": ("préfrontal",),
    "préfrontal": ("préfrontal",),
    "préfrontaux": ("préfrontal",),
    "préganglionnaire": ("préganglionnaire",),
    "préganglionnaires": ("préganglionnaire",),
    "prégénitale": ("prégénital",),
    "prégénitales": ("prégénital",),
    "prégénital": ("prégénital",),
    "prégénitaux": ("prégénital",),
    "préglaciaire": ("préglaciaire",),
    "préglaciaires": ("préglaciaire",),
    "préhellénique": ("préhellénique",),
    "préhelléniques": ("préhellénique",),
    "préhenseur": ("préhenseur",),
    "préhenseurs": ("préhenseur",),
    "préhensible": ("préhensible",),
    "préhensibles": ("préhensible",),
    "préhensile": ("préhensile",),
    "préhensiles": ("préhensile",),
    "préhilbertien": ("préhilbertien",),
    "préhilbertienne": ("préhilbertien",),
    "préhilbertiennes": ("préhilbertien",),
    "préhilbertiens": ("préhilbertien",),
    "préhispanique": ("préhispanique",),
    "préhispaniques": ("préhispanique",),
    "préhistorique": ("préhistorique",),
    "préhistoriques": ("préhistorique",),
    "prehnitique": ("prehnitique",),
    "prehnitiques": ("prehnitique",),
    "préictérique": ("préictérique",),
    "préictériques": ("préictérique",),
    "préimpressionniste": ("préimpressionniste",),
    "préimpressionnistes": ("préimpressionniste",),
    "préindustrielle": ("préindustriel",),
    "préindustrielles": ("préindustriel",),
    "préindustriel": ("préindustriel",),
    "préindustriels": ("préindustriel",),
    "préinfundibulaire": ("préinfundibulaire",),
    "préinfundibulaires": ("préinfundibulaire",),
    "préislamique": ("préislamique",),
    "préislamiques": ("préislamique",),
    "préjudiciable": ("préjudiciable",),
    "préjudiciables": ("préjudiciable",),
    "préjudiciaux": ("préjudiciel",),
    "préjudicielle": ("préjudiciel",),
    "préjudicielles": ("préjudiciel",),
    "préjudiciel": ("préjudiciel",),
    "préjudiciels": ("préjudiciel",),
    "préjugeable": ("préjugeable",),
    "préjugeables": ("préjugeable",),
    "préleucémique": ("préleucémique",),
    "préleucémiques": ("préleucémique",),
    "préliminaire": ("préliminaire",),
    "préliminaires": ("préliminaire",),
    "prélittorale": ("prélittoral",),
    "prélittorales": ("prélittoral",),
    "prélittoral": ("prélittoral",),
    "prélittoraux": ("prélittoral",),
    "pré-logique": ("pré-logique",),
    "prélogique": ("prélogique",),
    "pré-logiques": ("pré-logique",),
    "prélogiques": ("prélogique",),
    "prémenstruelle": ("prémenstruel",),
    "prémenstruelles": ("prémenstruel",),
    "prémenstruel": ("prémenstruel",),
    "prémenstruels": ("prémenstruel",),
    "première": ("premier",),
    "premières": ("premier",),
    "premier": ("premier",),
    "premiers": ("premier",),
    "prémilitaire": ("prémilitaire",),
    "prémilitaires": ("prémilitaire",),
    "prémoderne": ("prémoderne",),
    "prémodernes": ("prémoderne",),
    "prémonitoire": ("prémonitoire",),
    "prémonitoires": ("prémonitoire",),
    "prémorbide": ("prémorbide",),
    "prémorbides": ("prémorbide",),
    "prémosaïque": ("prémosaïque",),
    "prémosaïques": ("prémosaïque",),
    "prémoteur": ("prémoteur",),
    "prémoteurs": ("prémoteur",),
    "prémotrice": ("prémoteur",),
    "prémotrices": ("prémoteur",),
    "prémycosique": ("prémycosique",),
    "prémycosiques": ("prémycosique",),
    "prenable": ("prenable",),
    "prenables": ("prenable",),
    "preneur": ("preneur",),
    "preneurs": ("preneur",),
    "preneuse": ("preneur",),
    "preneuses": ("preneur",),
    "prénexe": ("prénexe",),
    "prénexes": ("prénexe",),
    "prénuptiale": ("prénuptial",),
    "prénuptiales": ("prénuptial",),
    "prénuptial": ("prénuptial",),
    "prénuptiaux": ("prénuptial",),
    "préobjectale": ("préobjectal",),
    "préobjectales": ("préobjectal",),
    "préobjectal": ("préobjectal",),
    "préobjectaux": ("préobjectal",),
    "préoedipien": ("préoedipien",),
    "préoedipienne": ("préoedipien",),
    "préoedipiennes": ("préoedipien",),
    "préoedipiens": ("préoedipien",),
    "préolympique": ("préolympique",),
    "préolympiques": ("préolympique",),
    "préopératoire": ("préopératoire",),
    "préopératoires": ("préopératoire",),
    "préoptique": ("préoptique",),
    "préoptiques": ("préoptique",),
    "préorale": ("préoral",),
    "préorales": ("préoral",),
    "préoral": ("préoral",),
    "préoraux": ("préoral",),
    "préorbitaire": ("préorbitaire",),
    "préorbitaires": ("préorbitaire",),
    "préovulatoire": ("préovulatoire",),
    "préovulatoires": ("préovulatoire",),
    "prépalatale": ("prépalatal",),
    "prépalatales": ("prépalatal",),
    "prépalatal": ("prépalatal",),
    "prépalataux": ("prépalatal",),
    "préparatoire": ("préparatoire",),
    "préparatoires": ("préparatoire",),
    "préparlementaire": ("préparlementaire",),
    "préparlementaires": ("préparlementaire",),
    "préperceptif": ("préperceptif",),
    "préperceptifs": ("préperceptif",),
    "préperceptive": ("préperceptif",),
    "préperceptives": ("préperceptif",),
    "prépiriforme": ("prépiriforme",),
    "prépiriformes": ("prépiriforme",),
    "préplanétaire": ("préplanétaire",),
    "préplanétaires": ("préplanétaire",),
    "préposable": ("préposable",),
    "préposables": ("préposable",),
    "prépositif": ("prépositif",),
    "prépositifs": ("prépositif",),
    "prépositive": ("prépositif",),
    "prépositives": ("prépositif",),
    "prépositionnelle": ("prépositionnel",),
    "prépositionnelles": ("prépositionnel",),
    "prépositionnel": ("prépositionnel",),
    "prépositionnels": ("prépositionnel",),
    "préprandiale": ("préprandial",),
    "préprandiales": ("préprandial",),
    "préprandial": ("préprandial",),
    "préprandiaux": ("préprandial",),
    "préprofessionnelle": ("préprofessionnel",),
    "préprofessionnelles": ("préprofessionnel",),
    "préprofessionnel": ("préprofessionnel",),
    "préprofessionnels": ("préprofessionnel",),
    "préprothétique": ("préprothétique",),
    "préprothétiques": ("préprothétique",),
    "prépsychotique": ("prépsychotique",),
    "prépsychotiques": ("prépsychotique",),
    "prépubère": ("prépubère",),
    "prépubères": ("prépubère",),
    "prépubertaire": ("prépubertaire",),
    "prépubertaires": ("prépubertaire",),
    "préputiale": ("préputial",),
    "préputiales": ("préputial",),
    "préputial": ("préputial",),
    "préputiaux": ("préputial",),
    "préraphaélite": ("préraphaélite",),
    "préraphaélites": ("préraphaélite",),
    "préréflexif": ("préréflexif",),
    "préréflexifs": ("préréflexif",),
    "préréflexive": ("préréflexif",),
    "préréflexives": ("préréflexif",),
    "préréglable": ("préréglable",),
    "préréglables": ("préréglable",),
    "prérévolutionnaire": ("prérévolutionnaire",),
    "prérévolutionnaires": ("prérévolutionnaire",),
    "préromantique": ("préromantique",),
    "préromantiques": ("préromantique",),
    "prérotulien": ("prérotulien",),
    "prérotulienne": ("prérotulien",),
    "prérotuliennes": ("prérotulien",),
    "prérotuliens": ("prérotulien",),
    "présaharien": ("présaharien",),
    "présaharienne": ("présaharien",),
    "présahariennes": ("présaharien",),
    "présahariens": ("présaharien",),
    "presbyte": ("presbyte",),
    "presbytes": ("presbyte",),
    "presbytérale": ("presbytéral",),
    "presbytérales": ("presbytéral",),
    "presbytéral": ("presbytéral",),
    "presbytéraux": ("presbytéral",),
    "presbytérien": ("presbytérien",),
    "presbytérienne": ("presbytérien",),
    "presbytériennes": ("presbytérien",),
    "presbytériens": ("presbytérien",),
    "préscalénique": ("préscalénique",),
    "préscaléniques": ("préscalénique",),
    "préscientifique": ("préscientifique",),
    "préscientifiques": ("préscientifique",),
    "préscolaire": ("préscolaire",),
    "préscolaires": ("préscolaire",),
    "prescriptible": ("prescriptible",),
    "prescriptibles": ("prescriptible",),
    "présélectif": ("présélectif",),
    "présélectifs": ("présélectif",),
    "présélective": ("présélectif",),
    "présélectives": ("présélectif",),
    "présélectionneur": ("présélectionneur",),
    "présélectionneurs": ("présélectionneur",),
    "présélectionneuse": ("présélectionneur",),
    "présélectionneuses": ("présélectionneur",),
    "présellaire": ("présellaire",),
    "présellaires": ("présellaire",),
    "présénile": ("présénile",),
    "préséniles": ("présénile",),
    "présentable": ("présentable",),
    "présentables": ("présentable",),
    "présérologique": ("présérologique",),
    "présérologiques": ("présérologique",),
    "préservateur": ("préservateur",),
    "préservateurs": ("préservateur",),
    "préservatrice": ("préservateur",),
    "préservatrices": ("préservateur",),
    "préservatif": ("préservatif",),
    "préservatifs": ("préservatif",),
    "préservative": ("préservatif",),
    "préservatives": ("préservatif",),
    "présidentiable": ("présidentiable",),
    "présidentiables": ("présidentiable",),
    "présidentielle": ("présidentiel",),
    "présidentielles": ("présidentiel",),
    "présidentiel": ("présidentiel",),
    "présidentiels": ("présidentiel",),
    "présidiale": ("présidial",),
    "présidiales": ("présidial",),
    "présidial": ("présidial",),
    "présidiaux": ("présidial",),
    "présocratique": ("présocratique",),
    "présocratiques": ("présocratique",),
    "présomptif": ("présomptif",),
    "présomptifs": ("présomptif",),
    "présomptive": ("présomptif",),
    "présomptives": ("présomptif",),
    "présomptueuse": ("présomptueux",),
    "présomptueuses": ("présomptueux",),
    "présomptueux": ("présomptueux",),
    "présphygmique": ("présphygmique",),
    "présphygmiques": ("présphygmique",),
    "presseur": ("presseur",),
    "presseurs": ("presseur",),
    "presseuse": ("presseur",),
    "presseuses": ("presseur",),
    "prestataire": ("prestataire",),
    "prestataires": ("prestataire",),
    "préstatistique": ("préstatistique",),
    "préstatistiques": ("préstatistique",),
    "preste": ("preste",),
    "prestes": ("preste",),
    "prestigieuse": ("prestigieux",),
    "prestigieuses": ("prestigieux",),
    "prestigieux": ("prestigieux",),
    "préstratégique": ("préstratégique",),
    "préstratégiques": ("préstratégique",),
    "présumable": ("présumable",),
    "présumables": ("présumable",),
    "présuppositionnelle": ("présuppositionnel",),
    "présuppositionnelles": ("présuppositionnel",),
    "présuppositionnel": ("présuppositionnel",),
    "présuppositionnels": ("présuppositionnel",),
    "présynaptique": ("présynaptique",),
    "présynaptiques": ("présynaptique",),
    "présystolique": ("présystolique",),
    "présystoliques": ("présystolique",),
    "prêtable": ("prêtable",),
    "prêtables": ("prêtable",),
    "prétectale": ("prétectal",),
    "prétectales": ("prétectal",),
    "prétectal": ("prétectal",),
    "prétectaux": ("prétectal",),
    "prétentieuse": ("prétentieux",),
    "prétentieuses": ("prétentieux",),
    "prétentieux": ("prétentieux",),
    "préterme": ("préterme",),
    "prétermes": ("préterme",),
    "préterminale": ("préterminal",),
    "préterminales": ("préterminal",),
    "préterminal": ("préterminal",),
    "préterminaux": ("préterminal",),
    "préternaturelle": ("préternaturel",),
    "préternaturelles": ("préternaturel",),
    "préternaturel": ("préternaturel",),
    "préternaturels": ("préternaturel",),
    "prêteur": ("prêteur",),
    "prêteurs": ("prêteur",),
    "prêteuse": ("prêteur",),
    "prêteuses": ("prêteur",),
    "prétexte": ("prétexte",),
    "prétextes": ("prétexte",),
    "préthérapeutique": ("préthérapeutique",),
    "préthérapeutiques": ("préthérapeutique",),
    "prétibiale": ("prétibial",),
    "prétibiales": ("prétibial",),
    "prétibial": ("prétibial",),
    "prétibiaux": ("prétibial",),
    "prétonique": ("prétonique",),
    "prétoniques": ("prétonique",),
    "prétoriale": ("prétorial",),
    "prétoriales": ("prétorial",),
    "prétorial": ("prétorial",),
    "prétoriaux": ("prétorial",),
    "prétorien": ("prétorien",),
    "prétorienne": ("prétorien",),
    "prétoriennes": ("prétorien",),
    "prétoriens": ("prétorien",),
    "prétransfusionnelle": ("prétransfusionnel",),
    "prétransfusionnelles": ("prétransfusionnel",),
    "prétransfusionnel": ("prétransfusionnel",),
    "prétransfusionnels": ("prétransfusionnel",),
    "prétrématique": ("prétrématique",),
    "prétrématiques": ("prétrématique",),
    "prétrigéminale": ("prétrigéminal",),
    "prétrigéminales": ("prétrigéminal",),
    "prétrigéminal": ("prétrigéminal",),
    "prétrigéminaux": ("prétrigéminal",),
    "pré-urbain": ("pré-urbain",),
    "pré-urbains": ("pré-urbain",),
    "preux": ("preux",),
    "prévaricateur": ("prévaricateur",),
    "prévaricateurs": ("prévaricateur",),
    "prévaricatrice": ("prévaricateur",),
    "prévaricatrices": ("prévaricateur",),
    "prévélaire": ("prévélaire",),
    "prévélaires": ("prévélaire",),
    "préventif": ("préventif",),
    "préventifs": ("préventif",),
    "préventive": ("préventif",),
    "préventives": ("préventif",),
    "préventriculaire": ("préventriculaire",),
    "préventriculaires": ("préventriculaire",),
    "préverbale": ("préverbal",),
    "préverbales": ("préverbal",),
    "préverbal": ("préverbal",),
    "préverbaux": ("préverbal",),
    "prévertébrale": ("prévertébral",),
    "prévertébrales": ("prévertébral",),
    "prévertébral": ("prévertébral",),
    "prévertébraux": ("prévertébral",),
    "prévisible": ("prévisible",),
    "prévisibles": ("prévisible",),
    "prévisionnelle": ("prévisionnel",),
    "prévisionnelles": ("prévisionnel",),
    "prévisionnel": ("prévisionnel",),
    "prévisionnels": ("prévisionnel",),
    "prévisionniste": ("prévisionniste",),
    "prévisionnistes": ("prévisionniste",),
    "prévocalique": ("prévocalique",),
    "prévocaliques": ("prévocalique",),
    "prévôtale": ("prévôtal",),
    "prévôtales": ("prévôtal",),
    "prévôtal": ("prévôtal",),
    "prévôtaux": ("prévôtal",),
    "priapique": ("priapique",),
    "priapiques": ("priapique",),
    "prieurale": ("prieural",),
    "prieurales": ("prieural",),
    "prieural": ("prieural",),
    "prieuraux": ("prieural",),
    "prima": ("prima",),
    "prime": ("prime",),
    "primaire": ("primaire",),
    "primaires": ("primaire",),
    "primatiale": ("primatial",),
    "primatiales": ("primatial",),
    "primatial": ("primatial",),
    "primatiaux": ("primatial",),
    "primée": ("primé",),
    "primées": ("primé",),
    "primé": ("primé",),
    "primés": ("primé",),
    "primes": ("prime",),
    "primesautière": ("primesautier",),
    "primesautières": ("primesautier",),
    "primesautier": ("primesautier",),
    "primesautiers": ("primesautier",),
    "primigeste": ("primigeste",),
    "primigestes": ("primigeste",),
    "primipare": ("primipare",),
    "primipares": ("primipare",),
    "primitif": ("primitif",),
    "primitifs": ("primitif",),
    "primitive": ("primitif",),
    "primitives": ("primitif",),
    "primitiviste": ("primitiviste",),
    "primitivistes": ("primitiviste",),
    "primordiale": ("primordial",),
    "primordiales": ("primordial",),
    "primordial": ("primordial",),
    "primordiaux": ("primordial",),
    "primulaire": ("primulaire",),
    "primulaires": ("primulaire",),
    "princeps": ("princeps",),
    "princesse": ("princesse",),
    "princière": ("princier",),
    "princières": ("princier",),
    "princier": ("princier",),
    "princiers": ("princier",),
    "principale": ("principal",),
    "principales": ("principal",),
    "principal": ("principal",),
    "principaux": ("principal",),
    "principielle": ("principiel",),
    "principielles": ("principiel",),
    "principiel": ("principiel",),
    "principiels": ("principiel",),
    "printanière": ("printanier",),
    "printanières": ("printanier",),
    "printanier": ("printanier",),
    "printaniers": ("printanier",),
    "priorale": ("prioral",),
    "priorales": ("prioral",),
    "prioral": ("prioral",),
    "prioraux": ("prioral",),
    "prioritaire": ("prioritaire",),
    "prioritaires": ("prioritaire",),
    "prisable": ("prisable",),
    "prisables": ("prisable",),
    "prise": ("pris",),
    "prises": ("pris",),
    "pris": ("pris",),
    "priscillianiste": ("priscillianiste",),
    "priscillianistes": ("priscillianiste",),
    "prismatique": ("prismatique",),
    "prismatiques": ("prismatique",),
    "prisonnière": ("prisonnier",),
    "prisonnières": ("prisonnier",),
    "prisonnier": ("prisonnier",),
    "prisonniers": ("prisonnier",),
    "privatif": ("privatif",),
    "privatifs": ("privatif",),
    "privative": ("privatif",),
    "privatives": ("privatif",),
    "privatisable": ("privatisable",),
    "privatisables": ("privatisable",),
    "privée": ("privé",),
    "privées": ("privé",),
    "privé": ("privé",),
    "prive": ("prive",),
    "privés": ("privé",),
    "prives": ("prive",),
    "proactif": ("proactif",),
    "proactifs": ("proactif",),
    "proactive": ("proactif",),
    "proactives": ("proactif",),
    "pro-américain": ("pro-américain",),
    "pro": ("pro",),
    "pros": ("pro",),
    "probabilioriste": ("probabilioriste",),
    "probabilioristes": ("probabilioriste",),
    "probabilisable": ("probabilisable",),
    "probabilisables": ("probabilisable",),
    "probabiliste": ("probabiliste",),
    "probabilistes": ("probabiliste",),
    "probable": ("probable",),
    "probables": ("probable",),
    "probatique": ("probatique",),
    "probatiques": ("probatique",),
    "probatoire": ("probatoire",),
    "probatoires": ("probatoire",),
    "probe": ("probe",),
    "probes": ("probe",),
    "problématique": ("problématique",),
    "problématiques": ("problématique",),
    "procaryote": ("procaryote",),
    "procaryotes": ("procaryote",),
    "procédurale": ("procédural",),
    "procédurales": ("procédural",),
    "procédural": ("procédural",),
    "procéduraux": ("procédural",),
    "procédurière": ("procédurier",),
    "procédurières": ("procédurier",),
    "procédurier": ("procédurier",),
    "procéduriers": ("procédurier",),
    "procéphalique": ("procéphalique",),
    "procéphaliques": ("procéphalique",),
    "processif": ("processif",),
    "processifs": ("processif",),
    "processive": ("processif",),
    "processives": ("processif",),
    "processionnaire": ("processionnaire",),
    "processionnaires": ("processionnaire",),
    "processionnelle": ("processionnel",),
    "processionnelles": ("processionnel",),
    "processionnel": ("processionnel",),
    "processionnels": ("processionnel",),
    "proche": ("proche",),
    "proches": ("proche",),
    "proche-orientales": ("proche-oriental",),
    "proche-oriental": ("proche-oriental",),
    "prochinoise": ("prochinois",),
    "prochinoises": ("prochinois",),
    "prochinois": ("prochinois",),
    "proclitique": ("proclitique",),
    "proclitiques": ("proclitique",),
    "proclive": ("proclive",),
    "proclives": ("proclive",),
    "pro-communiste": ("pro-communiste",),
    "proconsulaire": ("proconsulaire",),
    "proconsulaires": ("proconsulaire",),
    "procréateur": ("procréateur",),
    "procréateurs": ("procréateur",),
    "procréatrice": ("procréateur",),
    "procréatrices": ("procréateur",),
    "procritique": ("procritique",),
    "procritiques": ("procritique",),
    "procroate": ("procroate",),
    "procroates": ("procroate",),
    "proctodéale": ("proctodéal",),
    "proctodéales": ("proctodéal",),
    "proctodéal": ("proctodéal",),
    "proctodéaux": ("proctodéal",),
    "procuratoire": ("procuratoire",),
    "procuratoires": ("procuratoire",),
    "procursif": ("procursif",),
    "procursifs": ("procursif",),
    "procursive": ("procursif",),
    "procursives": ("procursif",),
    "prodige": ("prodige",),
    "prodiges": ("prodige",),
    "prodigieuse": ("prodigieux",),
    "prodigieuses": ("prodigieux",),
    "prodigieux": ("prodigieux",),
    "prodigue": ("prodigue",),
    "prodigues": ("prodigue",),
    "prodromique": ("prodromique",),
    "prodromiques": ("prodromique",),
    "producteur": ("producteur",),
    "producteurs": ("producteur",),
    "productrice": ("producteur",),
    "productrices": ("producteur",),
    "productible": ("productible",),
    "productibles": ("productible",),
    "productif": ("productif",),
    "productifs": ("productif",),
    "productive": ("productif",),
    "productives": ("productif",),
    "productique": ("productique",),
    "productiques": ("productique",),
    "productiviste": ("productiviste",),
    "productivistes": ("productiviste",),
    "proeutectique": ("proeutectique",),
    "proeutectiques": ("proeutectique",),
    "proeutectoïde": ("proeutectoïde",),
    "proeutectoïdes": ("proeutectoïde",),
    "profanateur": ("profanateur",),
    "profanateurs": ("profanateur",),
    "profanatrice": ("profanateur",),
    "profanatrices": ("profanateur",),
    "profane": ("profane",),
    "profanes": ("profane",),
    "profasciste": ("profasciste",),
    "profascistes": ("profasciste",),
    "profectif": ("profectif",),
    "profectifs": ("profectif",),
    "profective": ("profectif",),
    "profectives": ("profectif",),
    "profès": ("profès",),
    "professe": ("profès",),
    "professes": ("profès",),
    "professionnelle": ("professionnel",),
    "professionnelles": ("professionnel",),
    "professionnel": ("professionnel",),
    "professionnels": ("professionnel",),
    "professorale": ("professoral",),
    "professorales": ("professoral",),
    "professoral": ("professoral",),
    "professoraux": ("professoral",),
    "profitable": ("profitable",),
    "profitables": ("profitable",),
    "profuse": ("profus",),
    "profuses": ("profus",),
    "profus": ("profus",),
    "progamique": ("progamique",),
    "progamiques": ("progamique",),
    "progénésique": ("progénésique",),
    "progénésiques": ("progénésique",),
    "progénétique": ("progénétique",),
    "progénétiques": ("progénétique",),
    "progéroïde": ("progéroïde",),
    "progéroïdes": ("progéroïde",),
    "progestagène": ("progestagène",),
    "progestagènes": ("progestagène",),
    "progestatif": ("progestatif",),
    "progestatifs": ("progestatif",),
    "progestative": ("progestatif",),
    "progestatives": ("progestatif",),
    "progestéronique": ("progestéronique",),
    "progestéroniques": ("progestéronique",),
    "progestinogène": ("progestinogène",),
    "progestinogènes": ("progestinogène",),
    "progestogène": ("progestogène",),
    "progestogènes": ("progestogène",),
    "progestomimétique": ("progestomimétique",),
    "progestomimétiques": ("progestomimétique",),
    "proglaciaire": ("proglaciaire",),
    "proglaciaires": ("proglaciaire",),
    "prognathe": ("prognathe",),
    "prognathes": ("prognathe",),
    "pro-gouvernementale": ("pro-gouvernemental",),
    "progouvernementale": ("progouvernemental",),
    "progouvernementales": ("progouvernemental",),
    "pro-gouvernemental": ("pro-gouvernemental",),
    "progouvernemental": ("progouvernemental",),
    "pro-gouvernementaux": ("pro-gouvernemental",),
    "progouvernementaux": ("progouvernemental",),
    "prograde": ("prograde",),
    "progrades": ("prograde",),
    "programmable": ("programmable",),
    "programmables": ("programmable",),
    "programmateur": ("programmateur",),
    "programmateurs": ("programmateur",),
    "programmatrice": ("programmateur",),
    "programmatrices": ("programmateur",),
    "programmatique": ("programmatique",),
    "programmatiques": ("programmatique",),
    "progressif": ("progressif",),
    "progressifs": ("progressif",),
    "progressive": ("progressif",),
    "progressives": ("progressif",),
    "progressiste": ("progressiste",),
    "progressistes": ("progressiste",),
    "prohibitif": ("prohibitif",),
    "prohibitifs": ("prohibitif",),
    "prohibitive": ("prohibitif",),
    "prohibitives": ("prohibitif",),
    "prohibitionniste": ("prohibitionniste",),
    "prohibitionnistes": ("prohibitionniste",),
    "prohibitoire": ("prohibitoire",),
    "prohibitoires": ("prohibitoire",),
    "projectif": ("projectif",),
    "projectifs": ("projectif",),
    "projective": ("projectif",),
    "projectives": ("projectif",),
    "projetable": ("projetable",),
    "projetables": ("projetable",),
    "proleptique": ("proleptique",),
    "proleptiques": ("proleptique",),
    "prolétaire": ("prolétaire",),
    "prolétaires": ("prolétaire",),
    "prolétarien": ("prolétarien",),
    "prolétarienne": ("prolétarien",),
    "prolétariennes": ("prolétarien",),
    "prolétariens": ("prolétarien",),
    "prolifératif": ("prolifératif",),
    "prolifératifs": ("prolifératif",),
    "proliférative": ("prolifératif",),
    "prolifératives": ("prolifératif",),
    "prolifère": ("prolifère",),
    "prolifères": ("prolifère",),
    "prolifique": ("prolifique",),
    "prolifiques": ("prolifique",),
    "proligère": ("proligère",),
    "proligères": ("proligère",),
    "prolixe": ("prolixe",),
    "prolixes": ("prolixe",),
    "prolo": ("prolo",),
    "prolos": ("prolo",),
    "prolongateur": ("prolongateur",),
    "prolongateurs": ("prolongateur",),
    "prolongatrice": ("prolongateur",),
    "prolongatrices": ("prolongateur",),
    "prolongeable": ("prolongeable",),
    "prolongeables": ("prolongeable",),
    "prométhéen": ("prométhéen",),
    "prométhéenne": ("prométhéen",),
    "prométhéennes": ("prométhéen",),
    "prométhéens": ("prométhéen",),
    "prometteur": ("prometteur",),
    "prometteurs": ("prometteur",),
    "prometteuse": ("prometteur",),
    "prometteuses": ("prometteur",),
    "promise": ("promis",),
    "promises": ("promis",),
    "promis": ("promis",),
    "promiscue": ("promiscue",),
    "promiscues": ("promiscue",),
    "promissoire": ("promissoire",),
    "promissoires": ("promissoire",),
    "promoteur": ("promoteur",),
    "promoteurs": ("promoteur",),
    "promotrice": ("promoteur",),
    "promotrices": ("promoteur",),
    "promotionnelle": ("promotionnel",),
    "promotionnelles": ("promotionnel",),
    "promotionnel": ("promotionnel",),
    "promotionnels": ("promotionnel",),
    "promouvable": ("promouvable",),
    "promouvables": ("promouvable",),
    "promulgateur": ("promulgateur",),
    "promulgateurs": ("promulgateur",),
    "promulgatrice": ("promulgateur",),
    "promulgatrices": ("promulgateur",),
    "promyélocytaire": ("promyélocytaire",),
    "promyélocytaires": ("promyélocytaire",),
    "pronateur": ("pronateur",),
    "pronateurs": ("pronateur",),
    "pronatrice": ("pronateur",),
    "pronatrices": ("pronateur",),
    "pronéphrétique": ("pronéphrétique",),
    "pronéphrétiques": ("pronéphrétique",),
    "pronominale": ("pronominal",),
    "pronominales": ("pronominal",),
    "pronominal": ("pronominal",),
    "pronominaux": ("pronominal",),
    "pronominalisable": ("pronominalisable",),
    "pronominalisables": ("pronominalisable",),
    "prononçable": ("prononçable",),
    "prononçables": ("prononçable",),
    "pronostique": ("pronostique",),
    "pronostiques": ("pronostique",),
    "pro-occidentale": ("pro-occidental",),
    "pro-occidentales": ("pro-occidental",),
    "pro-occidental": ("pro-occidental",),
    "propagandiste": ("propagandiste",),
    "propagandistes": ("propagandiste",),
    "propagateur": ("propagateur",),
    "propagateurs": ("propagateur",),
    "propagatrice": ("propagateur",),
    "propagatrices": ("propagateur",),
    "propanique": ("propanique",),
    "propaniques": ("propanique",),
    "propanoïque": ("propanoïque",),
    "propanoïques": ("propanoïque",),
    "propargylique": ("propargylique",),
    "propargyliques": ("propargylique",),
    "proparoxyton": ("proparoxyton",),
    "proparoxytons": ("proparoxyton",),
    "proparoxytonique": ("proparoxytonique",),
    "proparoxytoniques": ("proparoxytonique",),
    "propédeute": ("propédeute",),
    "propédeutes": ("propédeute",),
    "propédeutique": ("propédeutique",),
    "propédeutiques": ("propédeutique",),
    "propénoïque": ("propénoïque",),
    "propénoïques": ("propénoïque",),
    "propénylique": ("propénylique",),
    "propényliques": ("propénylique",),
    "prophasique": ("prophasique",),
    "prophasiques": ("prophasique",),
    "prophétique": ("prophétique",),
    "prophétiques": ("prophétique",),
    "prophylactique": ("prophylactique",),
    "prophylactiques": ("prophylactique",),
    "propice": ("propice",),
    "propices": ("propice",),
    "propiolique": ("propiolique",),
    "propioliques": ("propiolique",),
    "propionique": ("propionique",),
    "propioniques": ("propionique",),
    "propitiateur": ("propitiateur",),
    "propitiateurs": ("propitiateur",),
    "propitiatrice": ("propitiateur",),
    "propitiatrices": ("propitiateur",),
    "propitiatoire": ("propitiatoire",),
    "propitiatoires": ("propitiatoire",),
    "proportionnelle": ("proportionnel",),
    "proportionnelles": ("proportionnel",),
    "proportionnel": ("proportionnel",),
    "proportionnels": ("proportionnel",),
    "proposable": ("proposable",),
    "proposables": ("proposable",),
    "propositionnelle": ("propositionnel",),
    "propositionnelles": ("propositionnel",),
    "propositionnel": ("propositionnel",),
    "propositionnels": ("propositionnel",),
    "propre": ("propre",),
    "propres": ("propre",),
    "propret": ("propret",),
    "proprets": ("propret",),
    "proprette": ("propret",),
    "proprettes": ("propret",),
    "proprioceptif": ("proprioceptif",),
    "proprioceptifs": ("proprioceptif",),
    "proprioceptive": ("proprioceptif",),
    "proprioceptives": ("proprioceptif",),
    "propulseur": ("propulseur",),
    "propulseurs": ("propulseur",),
    "propulsif": ("propulsif",),
    "propulsifs": ("propulsif",),
    "propulsive": ("propulsif",),
    "propulsives": ("propulsif",),
    "propylique": ("propylique",),
    "propyliques": ("propylique",),
    "propynoïque": ("propynoïque",),
    "propynoïques": ("propynoïque",),
    "prorogatif": ("prorogatif",),
    "prorogatifs": ("prorogatif",),
    "prorogative": ("prorogatif",),
    "prorogatives": ("prorogatif",),
    "prorogeable": ("prorogeable",),
    "prorogeables": ("prorogeable",),
    "prosaïque": ("prosaïque",),
    "prosaïques": ("prosaïque",),
    "proscripteur": ("proscripteur",),
    "proscripteurs": ("proscripteur",),
    "proscriptrice": ("proscripteur",),
    "proscriptrices": ("proscripteur",),
    "prosélytique": ("prosélytique",),
    "prosélytiques": ("prosélytique",),
    "prosencéphalique": ("prosencéphalique",),
    "prosencéphaliques": ("prosencéphalique",),
    "prosociale": ("prosocial",),
    "prosociales": ("prosocial",),
    "prosocial": ("prosocial",),
    "prosociaux": ("prosocial",),
    "prosodématique": ("prosodématique",),
    "prosodématiques": ("prosodématique",),
    "prosodiaque": ("prosodiaque",),
    "prosodiaques": ("prosodiaque",),
    "prosodique": ("prosodique",),
    "prosodiques": ("prosodique",),
    "prosoviétique": ("prosoviétique",),
    "prosoviétiques": ("prosoviétique",),
    "prospecteur": ("prospecteur",),
    "prospecteurs": ("prospecteur",),
    "prospectrice": ("prospecteur",),
    "prospectrices": ("prospecteur",),
    "prospectif": ("prospectif",),
    "prospectifs": ("prospectif",),
    "prospective": ("prospectif",),
    "prospectives": ("prospectif",),
    "prospère": ("prospère",),
    "prospères": ("prospère",),
    "prostanoïque": ("prostanoïque",),
    "prostanoïques": ("prostanoïque",),
    "prostatique": ("prostatique",),
    "prostatiques": ("prostatique",),
    "prosthétique": ("prosthétique",),
    "prosthétiques": ("prosthétique",),
    "prostyle": ("prostyle",),
    "prostyles": ("prostyle",),
    "prosyllogistique": ("prosyllogistique",),
    "prosyllogistiques": ("prosyllogistique",),
    "protandre": ("protandre",),
    "protandres": ("protandre",),
    "protanope": ("protanope",),
    "protanopes": ("protanope",),
    "protéagineuse": ("protéagineux",),
    "protéagineuses": ("protéagineux",),
    "protéagineux": ("protéagineux",),
    "protecteur": ("protecteur",),
    "protecteurs": ("protecteur",),
    "protectrice": ("protecteur",),
    "protectrices": ("protecteur",),
    "protectionniste": ("protectionniste",),
    "protectionnistes": ("protectionniste",),
    "protégeable": ("protégeable",),
    "protégeables": ("protégeable",),
    "protéiforme": ("protéiforme",),
    "protéiformes": ("protéiforme",),
    "protéinique": ("protéinique",),
    "protéiniques": ("protéinique",),
    "protéinocalorique": ("protéinocalorique",),
    "protéinocaloriques": ("protéinocalorique",),
    "protéinoglucidique": ("protéinoglucidique",),
    "protéinoglucidiques": ("protéinoglucidique",),
    "protéiprive": ("protéiprive",),
    "protéiprives": ("protéiprive",),
    "protéique": ("protéique",),
    "protéiques": ("protéique",),
    "protélien": ("protélien",),
    "protélienne": ("protélien",),
    "protéliennes": ("protélien",),
    "protéliens": ("protélien",),
    "protéolipidique": ("protéolipidique",),
    "protéolipidiques": ("protéolipidique",),
    "protéolytique": ("protéolytique",),
    "protéolytiques": ("protéolytique",),
    "protéotannnique": ("protéotannnique",),
    "protéotannniques": ("protéotannnique",),
    "protérandre": ("protérandre",),
    "protérandres": ("protérandre",),
    "protérandrique": ("protérandrique",),
    "protérandriques": ("protérandrique",),
    "protérogynique": ("protérogynique",),
    "protérogyniques": ("protérogynique",),
    "protérozoïque": ("protérozoïque",),
    "protérozoïques": ("protérozoïque",),
    "protestable": ("protestable",),
    "protestables": ("protestable",),
    "protestataire": ("protestataire",),
    "protestataires": ("protestataire",),
    "protestatif": ("protestatif",),
    "protestatifs": ("protestatif",),
    "protestative": ("protestatif",),
    "protestatives": ("protestatif",),
    "prothétique": ("prothétique",),
    "prothétiques": ("prothétique",),
    "prothoracique": ("prothoracique",),
    "prothoraciques": ("prothoracique",),
    "prothrombinique": ("prothrombinique",),
    "prothrombiniques": ("prothrombinique",),
    "prothrombique": ("prothrombique",),
    "prothrombiques": ("prothrombique",),
    "protidique": ("protidique",),
    "protidiques": ("protidique",),
    "protidoglucidique": ("protidoglucidique",),
    "protidoglucidiques": ("protidoglucidique",),
    "protidolipidique": ("protidolipidique",),
    "protidolipidiques": ("protidolipidique",),
    "protocanonique": ("protocanonique",),
    "protocanoniques": ("protocanonique",),
    "protocatéchique": ("protocatéchique",),
    "protocatéchiques": ("protocatéchique",),
    "protocérébrale": ("protocérébral",),
    "protocérébrales": ("protocérébral",),
    "protocérébral": ("protocérébral",),
    "protocérébraux": ("protocérébral",),
    "protocolaire": ("protocolaire",),
    "protocolaires": ("protocolaire",),
    "protodiastolique": ("protodiastolique",),
    "protodiastoliques": ("protodiastolique",),
    "protodorique": ("protodorique",),
    "protodoriques": ("protodorique",),
    "protogalactique": ("protogalactique",),
    "protogalactiques": ("protogalactique",),
    "protogyne": ("protogyne",),
    "protogynes": ("protogyne",),
    "protohistorique": ("protohistorique",),
    "protohistoriques": ("protohistorique",),
    "proto-industrielle": ("proto-industriel",),
    "protolytique": ("protolytique",),
    "protolytiques": ("protolytique",),
    "protomastigote": ("protomastigote",),
    "protomastigotes": ("protomastigote",),
    "protométrique": ("protométrique",),
    "protométriques": ("protométrique",),
    "protonique": ("protonique",),
    "protoniques": ("protonique",),
    "protopathique": ("protopathique",),
    "protopathiques": ("protopathique",),
    "protoplanétaire": ("protoplanétaire",),
    "protoplanétaires": ("protoplanétaire",),
    "protoplasmique": ("protoplasmique",),
    "protoplasmiques": ("protoplasmique",),
    "protosinaïtique": ("protosinaïtique",),
    "protosinaïtiques": ("protosinaïtique",),
    "protosolaire": ("protosolaire",),
    "protosolaires": ("protosolaire",),
    "protostellaire": ("protostellaire",),
    "protostellaires": ("protostellaire",),
    "protostomien": ("protostomien",),
    "protostomienne": ("protostomien",),
    "protostomiennes": ("protostomien",),
    "protostomiens": ("protostomien",),
    "protosystolique": ("protosystolique",),
    "protosystoliques": ("protosystolique",),
    "prototropique": ("prototropique",),
    "prototropiques": ("prototropique",),
    "protractile": ("protractile",),
    "protractiles": ("protractile",),
    "protruse": ("protrus",),
    "protruses": ("protrus",),
    "protrus": ("protrus",),
    "protubérantielle": ("protubérantiel",),
    "protubérantielles": ("protubérantiel",),
    "protubérantiel": ("protubérantiel",),
    "protubérantiels": ("protubérantiel",),
    "protypographique": ("protypographique",),
    "protypographiques": ("protypographique",),
    "proudhonien": ("proudhonien",),
    "proudhonienne": ("proudhonien",),
    "proudhoniennes": ("proudhonien",),
    "proudhoniens": ("proudhonien",),
    "proustien": ("proustien",),
    "proustienne": ("proustien",),
    "proustiennes": ("proustien",),
    "proustiens": ("proustien",),
    "prouvable": ("prouvable",),
    "prouvables": ("prouvable",),
    "provençale": ("provençal",),
    "provençales": ("provençal",),
    "provençal": ("provençal",),
    "provençaux": ("provençal",),
    "proverbiale": ("proverbial",),
    "proverbiales": ("proverbial",),
    "proverbial": ("proverbial",),
    "proverbiaux": ("proverbial",),
    "providentialiste": ("providentialiste",),
    "providentialistes": ("providentialiste",),
    "providentielle": ("providentiel",),
    "providentielles": ("providentiel",),
    "providentiel": ("providentiel",),
    "providentiels": ("providentiel",),
    "provignable": ("provignable",),
    "provignables": ("provignable",),
    "provinciale": ("provincial",),
    "provinciales": ("provincial",),
    "provincial": ("provincial",),
    "provinciaux": ("provincial",),
    "provirale": ("proviral",),
    "provirales": ("proviral",),
    "proviral": ("proviral",),
    "proviraux": ("proviral",),
    "provisionnelle": ("provisionnel",),
    "provisionnelles": ("provisionnel",),
    "provisionnel": ("provisionnel",),
    "provisionnels": ("provisionnel",),
    "provisoire": ("provisoire",),
    "provisoires": ("provisoire",),
    "provo": ("provo",),
    "provos": ("provo",),
    "provocateur": ("provocateur",),
    "provocateurs": ("provocateur",),
    "provocatrice": ("provocateur",),
    "provocatrices": ("provocateur",),
    "proximale": ("proximal",),
    "proximales": ("proximal",),
    "proximal": ("proximal",),
    "proximaux": ("proximal",),
    "prude": ("prude",),
    "prudes": ("prude",),
    "prudentielle": ("prudentiel",),
    "prudentielles": ("prudentiel",),
    "prudentiel": ("prudentiel",),
    "prudentiels": ("prudentiel",),
    "prud'homales": ("prud'homal",),
    "prud'homal": ("prud'homal",),
    "prud'homaux": ("prud'homal",),
    "prudhommesque": ("prudhommesque",),
    "prudhommesques": ("prudhommesque",),
    "pruineuse": ("pruineux",),
    "pruineuses": ("pruineux",),
    "pruineux": ("pruineux",),
    "prune": ("prune",),
    "prurigène": ("prurigène",),
    "prurigènes": ("prurigène",),
    "prurigineuse": ("prurigineux",),
    "prurigineuses": ("prurigineux",),
    "prurigineux": ("prurigineux",),
    "prussien": ("prussien",),
    "prussienne": ("prussien",),
    "prussiennes": ("prussien",),
    "prussiens": ("prussien",),
    "prussique": ("prussique",),
    "prussiques": ("prussique",),
    "psalmique": ("psalmique",),
    "psalmiques": ("psalmique",),
    "psalmodique": ("psalmodique",),
    "psalmodiques": ("psalmodique",),
    "pseudoadiabatique": ("pseudoadiabatique",),
    "pseudoadiabatiques": ("pseudoadiabatique",),
    "pseudoaléatoire": ("pseudoaléatoire",),
    "pseudoaléatoires": ("pseudoaléatoire",),
    "pseudo-bulbaire": ("pseudobulbaire",),
    "pseudobulbaire": ("pseudobulbaire",),
    "pseudobulbaires": ("pseudobulbaire",),
    "pseudocomitiale": ("pseudocomitial",),
    "pseudocomitiales": ("pseudocomitial",),
    "pseudocomitial": ("pseudocomitial",),
    "pseudocomitiaux": ("pseudocomitial",),
    "pseudodébile": ("pseudodébile",),
    "pseudodébiles": ("pseudodébile",),
    "pseudodéficitaire": ("pseudodéficitaire",),
    "pseudodéficitaires": ("pseudodéficitaire",),
    "pseudo-endocrinienne": ("pseudo-endocrinien",),
    "pseudoexfoliatif": ("pseudoexfoliatif",),
    "pseudoexfoliatifs": ("pseudoexfoliatif",),
    "pseudoexfoliative": ("pseudoexfoliatif",),
    "pseudoexfoliatives": ("pseudoexfoliatif",),
    "pseudogrippale": ("pseudogrippal",),
    "pseudogrippales": ("pseudogrippal",),
    "pseudogrippal": ("pseudogrippal",),
    "pseudogrippaux": ("pseudogrippal",),
    "pseudo-inflammatoires": ("pseudo-inflammatoire",),
    "pseudo-intransitif": ("pseudo-intransitif",),
    "pseudo-intransitives": ("pseudo-intransitif",),
    "pseudo-membraneuse": ("pseudomembraneux",),
    "pseudomembraneuse": ("pseudomembraneux",),
    "pseudomembraneuses": ("pseudomembraneux",),
    "pseudomembraneux": ("pseudomembraneux",),
    "pseudomorphique": ("pseudomorphique",),
    "pseudomorphiques": ("pseudomorphique",),
    "pseudomyopathique": ("pseudomyopathique",),
    "pseudomyopathiques": ("pseudomyopathique",),
    "pseudonyme": ("pseudonyme",),
    "pseudonymes": ("pseudonyme",),
    "pseudopalustre": ("pseudopalustre",),
    "pseudopalustres": ("pseudopalustre",),
    "pseudopeladique": ("pseudopeladique",),
    "pseudopeladiques": ("pseudopeladique",),
    "pseudoploïde": ("pseudoploïde",),
    "pseudoploïdes": ("pseudoploïde",),
    "pseudorectangle": ("pseudorectangle",),
    "pseudorectangles": ("pseudorectangle",),
    "pseudo-sphérique": ("pseudosphérique",),
    "pseudotumorale": ("pseudotumoral",),
    "pseudotumorales": ("pseudotumoral",),
    "pseudo-tumoral": ("pseudotumoral",),
    "pseudotumoral": ("pseudotumoral",),
    "pseudotumoraux": ("pseudotumoral",),
    "psophométrique": ("psophométrique",),
    "psophométriques": ("psophométrique",),
    "psoralénique": ("psoralénique",),
    "psoraléniques": ("psoralénique",),
    "psoriasique": ("psoriasique",),
    "psoriasiques": ("psoriasique",),
    "psorique": ("psorique",),
    "psoriques": ("psorique",),
    "psoroptique": ("psoroptique",),
    "psoroptiques": ("psoroptique",),
    "psychagogique": ("psychagogique",),
    "psychagogiques": ("psychagogique",),
    "psychanalytique": ("psychanalytique",),
    "psychanalytiques": ("psychanalytique",),
    "psychasthénique": ("psychasthénique",),
    "psychasthéniques": ("psychasthénique",),
    "psychédélique": ("psychédélique",),
    "psychédéliques": ("psychédélique",),
    "psychiatrique": ("psychiatrique",),
    "psychiatriques": ("psychiatrique",),
    "psychique": ("psychique",),
    "psychiques": ("psychique",),
    "psycho-affectif": ("psychoaffectif",),
    "psychoaffectif": ("psychoaffectif",),
    "psychoaffectifs": ("psychoaffectif",),
    "psycho-affective": ("psychoaffectif",),
    "psychoaffective": ("psychoaffectif",),
    "psycho-affectives": ("psychoaffectif",),
    "psychoaffectives": ("psychoaffectif",),
    "psychoanaleptique": ("psychoanaleptique",),
    "psychoanaleptiques": ("psychoanaleptique",),
    "psychobiologique": ("psychobiologique",),
    "psychobiologiques": ("psychobiologique",),
    "psychochimique": ("psychochimique",),
    "psychochimiques": ("psychochimique",),
    "psychocritique": ("psychocritique",),
    "psychocritiques": ("psychocritique",),
    "psychodépresseur": ("psychodépresseur",),
    "psychodépresseurs": ("psychodépresseur",),
    "psychodépressive": ("psychodépressive",),
    "psychodépressives": ("psychodépressive",),
    "psychodramatique": ("psychodramatique",),
    "psychodramatiques": ("psychodramatique",),
    "psychodynamique": ("psychodynamique",),
    "psychodynamiques": ("psychodynamique",),
    "psychodysleptique": ("psychodysleptique",),
    "psychodysleptiques": ("psychodysleptique",),
    "psychogalvanique": ("psychogalvanique",),
    "psychogalvaniques": ("psychogalvanique",),
    "psychogène": ("psychogène",),
    "psychogènes": ("psychogène",),
    "psychogénétique": ("psychogénétique",),
    "psychogénétiques": ("psychogénétique",),
    "psychographique": ("psychographique",),
    "psychographiques": ("psychographique",),
    "psychokinésique": ("psychokinésique",),
    "psychokinésiques": ("psychokinésique",),
    "psycholeptique": ("psycholeptique",),
    "psycholeptiques": ("psycholeptique",),
    "psycholinguistique": ("psycholinguistique",),
    "psycholinguistiques": ("psycholinguistique",),
    "psychologique": ("psychologique",),
    "psychologiques": ("psychologique",),
    "psychologiste": ("psychologiste",),
    "psychologistes": ("psychologiste",),
    "psychologue": ("psychologue",),
    "psychologues": ("psychologue",),
    "psychométrique": ("psychométrique",),
    "psychométriques": ("psychométrique",),
    "psychomoteur": ("psychomoteur",),
    "psychomoteurs": ("psychomoteur",),
    "psychomotrice": ("psychomoteur",),
    "psychomotrices": ("psychomoteur",),
    "psychoneurasthénique": ("psychoneurasthénique",),
    "psychoneurasthéniques": ("psychoneurasthénique",),
    "psychopathique": ("psychopathique",),
    "psychopathiques": ("psychopathique",),
    "psychopathogène": ("psychopathogène",),
    "psychopathogènes": ("psychopathogène",),
    "psychopathologique": ("psychopathologique",),
    "psychopathologiques": ("psychopathologique",),
    "psychopédagogique": ("psychopédagogique",),
    "psychopédagogiques": ("psychopédagogique",),
    "psychopharmacologique": ("psychopharmacologique",),
    "psychopharmacologiques": ("psychopharmacologique",),
    "psycho-physiologique": ("psychophysiologique",),
    "psychophysiologique": ("psychophysiologique",),
    "psychophysiologiques": ("psychophysiologique",),
    "psychophysique": ("psychophysique",),
    "psychophysiques": ("psychophysique",),
    "psychoplégique": ("psychoplégique",),
    "psychoplégiques": ("psychoplégique",),
    "psychopompe": ("psychopompe",),
    "psychopompes": ("psychopompe",),
    "psychoprophylactique": ("psychoprophylactique",),
    "psychoprophylactiques": ("psychoprophylactique",),
    "psychorégulateur": ("psychorégulateur",),
    "psychorégulateurs": ("psychorégulateur",),
    "psychorégulatrice": ("psychorégulateur",),
    "psychorégulatrices": ("psychorégulateur",),
    "psychorigide": ("psychorigide",),
    "psychorigides": ("psychorigide",),
    "psychosédatif": ("psychosédatif",),
    "psychosédatifs": ("psychosédatif",),
    "psychosédative": ("psychosédatif",),
    "psychosédatives": ("psychosédatif",),
    "psychosensorielle": ("psychosensoriel",),
    "psychosensorielles": ("psychosensoriel",),
    "psychosensoriel": ("psychosensoriel",),
    "psychosensoriels": ("psychosensoriel",),
    "psychosexuelle": ("psychosexuel",),
    "psychosexuelles": ("psychosexuel",),
    "psychosexuel": ("psychosexuel",),
    "psychosexuels": ("psychosexuel",),
    "psychosique": ("psychosique",),
    "psychosiques": ("psychosique",),
    "psychosociale": ("psychosocial",),
    "psychosociales": ("psychosocial",),
    "psychosocial": ("psychosocial",),
    "psychosociaux": ("psychosocial",),
    "psychosociologique": ("psychosociologique",),
    "psychosociologiques": ("psychosociologique",),
    "psychosomatique": ("psychosomatique",),
    "psychosomatiques": ("psychosomatique",),
    "psychotechnique": ("psychotechnique",),
    "psychotechniques": ("psychotechnique",),
    "psychothérapeutique": ("psychothérapeutique",),
    "psychothérapeutiques": ("psychothérapeutique",),
    "psychothérapique": ("psychothérapique",),
    "psychothérapiques": ("psychothérapique",),
    "psychotique": ("psychotique",),
    "psychotiques": ("psychotique",),
    "psychotonique": ("psychotonique",),
    "psychotoniques": ("psychotonique",),
    "psychotronique": ("psychotronique",),
    "psychotroniques": ("psychotronique",),
    "psychotrope": ("psychotrope",),
    "psychotropes": ("psychotrope",),
    "psychrométrique": ("psychrométrique",),
    "psychrométriques": ("psychrométrique",),
    "psychrophile": ("psychrophile",),
    "psychrophiles": ("psychrophile",),
    "ptérodactyle": ("ptérodactyle",),
    "ptérodactyles": ("ptérodactyle",),
    "ptéroyglutaminique": ("ptéroyglutaminique",),
    "ptéroyglutaminiques": ("ptéroyglutaminique",),
    "ptéroylglutamique": ("ptéroylglutamique",),
    "ptéroylglutamiques": ("ptéroylglutamique",),
    "ptérygoïde": ("ptérygoïde",),
    "ptérygoïdes": ("ptérygoïde",),
    "ptérygoïdien": ("ptérygoïdien",),
    "ptérygoïdienne": ("ptérygoïdien",),
    "ptérygoïdiennes": ("ptérygoïdien",),
    "ptérygoïdiens": ("ptérygoïdien",),
    "ptolémaïque": ("ptolémaïque",),
    "ptolémaïques": ("ptolémaïque",),
    "ptoléméen": ("ptoléméen",),
    "ptoléméenne": ("ptoléméen",),
    "ptoléméennes": ("ptoléméen",),
    "ptoléméens": ("ptoléméen",),
    "ptoloméen": ("ptoloméen",),
    "ptoloméenne": ("ptoloméen",),
    "ptoloméennes": ("ptoloméen",),
    "ptoloméens": ("ptoloméen",),
    "ptosique": ("ptosique",),
    "ptosiques": ("ptosique",),
    "pubère": ("pubère",),
    "pubères": ("pubère",),
    "pubertaire": ("pubertaire",),
    "pubertaires": ("pubertaire",),
    "pubien": ("pubien",),
    "pubienne": ("pubien",),
    "pubiennes": ("pubien",),
    "pubiens": ("pubien",),
    "publiable": ("publiable",),
    "publiables": ("publiable",),
    "public": ("public",),
    "publics": ("public",),
    "publique": ("public",),
    "publiques": ("public",),
    "publicitaire": ("publicitaire",),
    "publicitaires": ("publicitaire",),
    "puce": ("puce",),
    "puceau": ("puceau",),
    "puceaux": ("puceau",),
    "pucelle": ("puceau",),
    "pucelles": ("puceau",),
    "pudique": ("pudique",),
    "pudiques": ("pudique",),
    "pueblo": ("pueblo",),
    "pueblos": ("pueblo",),
    "puerpérale": ("puerpéral",),
    "puerpérales": ("puerpéral",),
    "puerpéral": ("puerpéral",),
    "puerpéraux": ("puerpéral",),
    "pugilistique": ("pugilistique",),
    "pugilistiques": ("pugilistique",),
    "pugnace": ("pugnace",),
    "pugnaces": ("pugnace",),
    "puisatière": ("puisatier",),
    "puisatières": ("puisatier",),
    "puisatier": ("puisatier",),
    "puisatiers": ("puisatier",),
    "pulmonaire": ("pulmonaire",),
    "pulmonaires": ("pulmonaire",),
    "pulmonique": ("pulmonique",),
    "pulmoniques": ("pulmonique",),
    "pulpaire": ("pulpaire",),
    "pulpaires": ("pulpaire",),
    "pulpeuse": ("pulpeux",),
    "pulpeuses": ("pulpeux",),
    "pulpeux": ("pulpeux",),
    "pulsatif": ("pulsatif",),
    "pulsatifs": ("pulsatif",),
    "pulsative": ("pulsatif",),
    "pulsatives": ("pulsatif",),
    "pulsatile": ("pulsatile",),
    "pulsatiles": ("pulsatile",),
    "pulsatoire": ("pulsatoire",),
    "pulsatoires": ("pulsatoire",),
    "pulsionnelle": ("pulsionnel",),
    "pulsionnelles": ("pulsionnel",),
    "pulsionnel": ("pulsionnel",),
    "pulsionnels": ("pulsionnel",),
    "pulvérateur": ("pulvérateur",),
    "pulvérateurs": ("pulvérateur",),
    "pulvératrice": ("pulvérateur",),
    "pulvératrices": ("pulvérateur",),
    "pulvérisable": ("pulvérisable",),
    "pulvérisables": ("pulvérisable",),
    "pumicif": ("pumicif",),
    "pumicifs": ("pumicif",),
    "pumicive": ("pumicif",),
    "pumicives": ("pumicif",),
    "punaise": ("punais",),
    "punaises": ("punais",),
    "punais": ("punais",),
    "punctiforme": ("punctiforme",),
    "punctiformes": ("punctiforme",),
    "punique": ("punique",),
    "puniques": ("punique",),
    "punissable": ("punissable",),
    "punissables": ("punissable",),
    "punisseur": ("punisseur",),
    "punisseurs": ("punisseur",),
    "punisseuse": ("punisseur",),
    "punisseuses": ("punisseur",),
    "punitif": ("punitif",),
    "punitifs": ("punitif",),
    "punitive": ("punitif",),
    "punitives": ("punitif",),
    "punjabi": ("punjabi",),
    "punjabis": ("punjabi",),
    "punk": ("punk",),
    "pupillaire": ("pupillaire",),
    "pupillaires": ("pupillaire",),
    "pupipare": ("pupipare",),
    "pupipares": ("pupipare",),
    "pupivore": ("pupivore",),
    "pupivores": ("pupivore",),
    "puranique": ("puranique",),
    "puraniques": ("puranique",),
    "purgatif": ("purgatif",),
    "purgatifs": ("purgatif",),
    "purgative": ("purgatif",),
    "purgatives": ("purgatif",),
    "purificateur": ("purificateur",),
    "purificateurs": ("purificateur",),
    "purificatrice": ("purificateur",),
    "purificatrices": ("purificateur",),
    "purificatoire": ("purificatoire",),
    "purificatoires": ("purificatoire",),
    "puriforme": ("puriforme",),
    "puriformes": ("puriforme",),
    "purinogène": ("purinogène",),
    "purinogènes": ("purinogène",),
    "purinophore": ("purinophore",),
    "purinophores": ("purinophore",),
    "purique": ("purique",),
    "puriques": ("purique",),
    "puriste": ("puriste",),
    "puristes": ("puriste",),
    "purpurique": ("purpurique",),
    "purpuriques": ("purpurique",),
    "puseyiste": ("puseyiste",),
    "puseyistes": ("puseyiste",),
    "pusillanime": ("pusillanime",),
    "pusillanimes": ("pusillanime",),
    "pustuleuse": ("pustuleux",),
    "pustuleuses": ("pustuleux",),
    "pustuleux": ("pustuleux",),
    "putain": ("putain",),
    "putains": ("putain",),
    "putassière": ("putassier",),
    "putassières": ("putassier",),
    "putassier": ("putassier",),
    "putassiers": ("putassier",),
    "putatif": ("putatif",),
    "putatifs": ("putatif",),
    "putative": ("putatif",),
    "putatives": ("putatif",),
    "pute": ("pute",),
    "putes": ("pute",),
    "putréfiable": ("putréfiable",),
    "putréfiables": ("putréfiable",),
    "putrescible": ("putrescible",),
    "putrescibles": ("putrescible",),
    "putride": ("putride",),
    "putrides": ("putride",),
    "putschiste": ("putschiste",),
    "putschistes": ("putschiste",),
    "pycnique": ("pycnique",),
    "pycniques": ("pycnique",),
    "pycnoïde": ("pycnoïde",),
    "pycnoïdes": ("pycnoïde",),
    "pycnoleptique": ("pycnoleptique",),
    "pycnoleptiques": ("pycnoleptique",),
    "pycnomorphe": ("pycnomorphe",),
    "pycnomorphes": ("pycnomorphe",),
    "pyélique": ("pyélique",),
    "pyéliques": ("pyélique",),
    "pyélocalicielle": ("pyélocaliciel",),
    "pyélocalicielles": ("pyélocaliciel",),
    "pyélocaliciel": ("pyélocaliciel",),
    "pyélocaliciels": ("pyélocaliciel",),
    "pyélogénique": ("pyélogénique",),
    "pyélogéniques": ("pyélogénique",),
    "pyélo-urétérale": ("pyélo-urétéral",),
    "pyélovésicale": ("pyélovésical",),
    "pyélovésicales": ("pyélovésical",),
    "pyélovésical": ("pyélovésical",),
    "pyélovésicaux": ("pyélovésical",),
    "pygmée": ("pygmée",),
    "pygmées": ("pygmée",),
    "pylorique": ("pylorique",),
    "pyloriques": ("pylorique",),
    "pyocyanique": ("pyocyanique",),
    "pyocyaniques": ("pyocyanique",),
    "pyogène": ("pyogène",),
    "pyogènes": ("pyogène",),
    "pyogénique": ("pyogénique",),
    "pyogéniques": ("pyogénique",),
    "pyohémique": ("pyohémique",),
    "pyohémiques": ("pyohémique",),
    "pyorrhéique": ("pyorrhéique",),
    "pyorrhéiques": ("pyorrhéique",),
    "pyostercorale": ("pyostercoral",),
    "pyostercorales": ("pyostercoral",),
    "pyostercoral": ("pyostercoral",),
    "pyostercoraux": ("pyostercoral",),
    "pyramidale": ("pyramidal",),
    "pyramidales": ("pyramidal",),
    "pyramidal": ("pyramidal",),
    "pyramidaux": ("pyramidal",),
    "pyrannique": ("pyrannique",),
    "pyranniques": ("pyrannique",),
    "pyrazinoïque": ("pyrazinoïque",),
    "pyrazinoïques": ("pyrazinoïque",),
    "pyrazolique": ("pyrazolique",),
    "pyrazoliques": ("pyrazolique",),
    "pyrazolonique": ("pyrazolonique",),
    "pyrazoloniques": ("pyrazolonique",),
    "pyrénaïque": ("pyrénaïque",),
    "pyrénaïques": ("pyrénaïque",),
    "pyrénéen": ("pyrénéen",),
    "pyrénéenne": ("pyrénéen",),
    "pyrénéennes": ("pyrénéen",),
    "pyrénéens": ("pyrénéen",),
    "pyrétique": ("pyrétique",),
    "pyrétiques": ("pyrétique",),
    "pyrétogène": ("pyrétogène",),
    "pyrétogènes": ("pyrétogène",),
    "pyridinecarboxylique": ("pyridinecarboxylique",),
    "pyridinecarboxyliques": ("pyridinecarboxylique",),
    "pyridinique": ("pyridinique",),
    "pyridiniques": ("pyridinique",),
    "pyridique": ("pyridique",),
    "pyridiques": ("pyridique",),
    "pyridoxique": ("pyridoxique",),
    "pyridoxiques": ("pyridoxique",),
    "pyrimidique": ("pyrimidique",),
    "pyrimidiques": ("pyrimidique",),
    "pyriteuse": ("pyriteux",),
    "pyriteuses": ("pyriteux",),
    "pyriteux": ("pyriteux",),
    "pyritifère": ("pyritifère",),
    "pyritifères": ("pyritifère",),
    "pyroarsénieuse": ("pyroarsénieux",),
    "pyroarsénieuses": ("pyroarsénieux",),
    "pyroarsénieux": ("pyroarsénieux",),
    "pyroborique": ("pyroborique",),
    "pyroboriques": ("pyroborique",),
    "pyroclastique": ("pyroclastique",),
    "pyroclastiques": ("pyroclastique",),
    "pyrodynamique": ("pyrodynamique",),
    "pyrodynamiques": ("pyrodynamique",),
    "pyroélectrique": ("pyroélectrique",),
    "pyroélectriques": ("pyroélectrique",),
    "pyrofuge": ("pyrofuge",),
    "pyrofuges": ("pyrofuge",),
    "pyrogallique": ("pyrogallique",),
    "pyrogalliques": ("pyrogallique",),
    "pyrogénée": ("pyrogéné",),
    "pyrogénées": ("pyrogéné",),
    "pyrogéné": ("pyrogéné",),
    "pyrogène": ("pyrogène",),
    "pyrogénés": ("pyrogéné",),
    "pyrogènes": ("pyrogène",),
    "pyrognostique": ("pyrognostique",),
    "pyrognostiques": ("pyrognostique",),
    "pyroligneuse": ("pyroligneux",),
    "pyroligneuses": ("pyroligneux",),
    "pyroligneux": ("pyroligneux",),
    "pyromagnétique": ("pyromagnétique",),
    "pyromagnétiques": ("pyromagnétique",),
    "pyromane": ("pyromane",),
    "pyromanes": ("pyromane",),
    "pyromécanique": ("pyromécanique",),
    "pyromécaniques": ("pyromécanique",),
    "pyromellique": ("pyromellique",),
    "pyromelliques": ("pyromellique",),
    "pyromellitique": ("pyromellitique",),
    "pyromellitiques": ("pyromellitique",),
    "pyrométallurgique": ("pyrométallurgique",),
    "pyrométallurgiques": ("pyrométallurgique",),
    "pyrométasomatique": ("pyrométasomatique",),
    "pyrométasomatiques": ("pyrométasomatique",),
    "pyrométrique": ("pyrométrique",),
    "pyrométriques": ("pyrométrique",),
    "pyromucique": ("pyromucique",),
    "pyromuciques": ("pyromucique",),
    "pyrophane": ("pyrophane",),
    "pyrophanes": ("pyrophane",),
    "pyrophorique": ("pyrophorique",),
    "pyrophoriques": ("pyrophorique",),
    "pyrophosphamique": ("pyrophosphamique",),
    "pyrophosphamiques": ("pyrophosphamique",),
    "pyrophosphoreuse": ("pyrophosphoreux",),
    "pyrophosphoreuses": ("pyrophosphoreux",),
    "pyrophosphoreux": ("pyrophosphoreux",),
    "pyrophosphorique": ("pyrophosphorique",),
    "pyrophosphoriques": ("pyrophosphorique",),
    "pyrostatique": ("pyrostatique",),
    "pyrostatiques": ("pyrostatique",),
    "pyrosulfureuse": ("pyrosulfureux",),
    "pyrosulfureuses": ("pyrosulfureux",),
    "pyrosulfureux": ("pyrosulfureux",),
    "pyrosulfurique": ("pyrosulfurique",),
    "pyrosulfuriques": ("pyrosulfurique",),
    "pyrotechnique": ("pyrotechnique",),
    "pyrotechniques": ("pyrotechnique",),
    "pyroxénique": ("pyroxénique",),
    "pyroxéniques": ("pyroxénique",),
    "pyrrhonien": ("pyrrhonien",),
    "pyrrhonienne": ("pyrrhonien",),
    "pyrrhoniennes": ("pyrrhonien",),
    "pyrrhoniens": ("pyrrhonien",),
    "pyrrolidinique": ("pyrrolidinique",),
    "pyrrolidiniques": ("pyrrolidinique",),
    "pyrrolique": ("pyrrolique",),
    "pyrroliques": ("pyrrolique",),
    "pyruvique": ("pyruvique",),
    "pyruviques": ("pyruvique",),
    "pythagoricien": ("pythagoricien",),
    "pythagoricienne": ("pythagoricien",),
    "pythagoriciennes": ("pythagoricien",),
    "pythagoriciens": ("pythagoricien",),
    "pythagorique": ("pythagorique",),
    "pythagoriques": ("pythagorique",),
    "pythien": ("pythien",),
    "pythienne": ("pythien",),
    "pythiennes": ("pythien",),
    "pythiens": ("pythien",),
    "pythique": ("pythique",),
    "pythiques": ("pythique",),
    "quadragénaire": ("quadragénaire",),
    "quadragénaires": ("quadragénaire",),
    "quadragésimale": ("quadragésimal",),
    "quadragésimales": ("quadragésimal",),
    "quadragésimal": ("quadragésimal",),
    "quadragésimaux": ("quadragésimal",),
    "quadrangulaire": ("quadrangulaire",),
    "quadrangulaires": ("quadrangulaire",),
    "quadranoptique": ("quadranoptique",),
    "quadranoptiques": ("quadranoptique",),
    "quadratique": ("quadratique",),
    "quadratiques": ("quadratique",),
    "quadri": ("quadri",),
    "quadricâble": ("quadricâble",),
    "quadriceps": ("quadriceps",),
    "quadricolore": ("quadricolore",),
    "quadricolores": ("quadricolore",),
    "quadridimensionnelle": ("quadridimensionnel",),
    "quadridimensionnelles": ("quadridimensionnel",),
    "quadridimensionnel": ("quadridimensionnel",),
    "quadridimensionnels": ("quadridimensionnel",),
    "quadriennale": ("quadriennal",),
    "quadriennales": ("quadriennal",),
    "quadriennal": ("quadriennal",),
    "quadriennaux": ("quadriennal",),
    "quadrifide": ("quadrifide",),
    "quadrifides": ("quadrifide",),
    "quadriflèche": ("quadriflèche",),
    "quadriflèches": ("quadriflèche",),
    "quadrigémellaire": ("quadrigémellaire",),
    "quadrigémellaires": ("quadrigémellaire",),
    "quadrijumeau": ("quadrijumeau",),
    "quadrijumeaux": ("quadrijumeau",),
    "quadrijumelle": ("quadrijumeau",),
    "quadrijumelles": ("quadrijumeau",),
    "quadrilatérale": ("quadrilatéral",),
    "quadrilatérales": ("quadrilatéral",),
    "quadrilatéral": ("quadrilatéral",),
    "quadrilatéraux": ("quadrilatéral",),
    "quadrimestrielle": ("quadrimestriel",),
    "quadrimestrielles": ("quadrimestriel",),
    "quadrimestriel": ("quadrimestriel",),
    "quadrimestriels": ("quadrimestriel",),
    "quadrimoteur": ("quadrimoteur",),
    "quadrimoteurs": ("quadrimoteur",),
    "quadripartite": ("quadripartite",),
    "quadripartites": ("quadripartite",),
    "quadriphonique": ("quadriphonique",),
    "quadriphoniques": ("quadriphonique",),
    "quadriplace": ("quadriplace",),
    "quadriplaces": ("quadriplace",),
    "quadriplégique": ("quadriplégique",),
    "quadriplégiques": ("quadriplégique",),
    "quadripode": ("quadripode",),
    "quadripodes": ("quadripode",),
    "quadripolaire": ("quadripolaire",),
    "quadripolaires": ("quadripolaire",),
    "quadrique": ("quadrique",),
    "quadriques": ("quadrique",),
    "quadriréacteur": ("quadriréacteur",),
    "quadriréacteurs": ("quadriréacteur",),
    "quadrisyllabique": ("quadrisyllabique",),
    "quadrisyllabiques": ("quadrisyllabique",),
    "quadrumane": ("quadrumane",),
    "quadrumanes": ("quadrumane",),
    "quadrupède": ("quadrupède",),
    "quadrupèdes": ("quadrupède",),
    "quadruple": ("quadruple",),
    "quadruples": ("quadruple",),
    "quadrupolaire": ("quadrupolaire",),
    "quadrupolaires": ("quadrupolaire",),
    "qualifiable": ("qualifiable",),
    "qualifiables": ("qualifiable",),
    "qualificatif": ("qualificatif",),
    "qualificatifs": ("qualificatif",),
    "qualificative": ("qualificatif",),
    "qualificatives": ("qualificatif",),
    "qualitatif": ("qualitatif",),
    "qualitatifs": ("qualitatif",),
    "qualitative": ("qualitatif",),
    "qualitatives": ("qualitatif",),
    "quantifiable": ("quantifiable",),
    "quantifiables": ("quantifiable",),
    "quantique": ("quantique",),
    "quantiques": ("quantique",),
    "quantitatif": ("quantitatif",),
    "quantitatifs": ("quantitatif",),
    "quantitative": ("quantitatif",),
    "quantitatives": ("quantitatif",),
    "quantitativiste": ("quantitativiste",),
    "quantitativistes": ("quantitativiste",),
    "quarante-huitardes": ("quarante-huitard",),
    "quarantenaire": ("quarantenaire",),
    "quarantenaires": ("quarantenaire",),
    "quarantième": ("quarantième",),
    "quarantièmes": ("quarantième",),
    "quarrable": ("quarrable",),
    "quarrables": ("quarrable",),
    "quartane": ("quartane",),
    "quartanes": ("quartane",),
    "quartique": ("quartique",),
    "quartiques": ("quartique",),
    "quartzeuse": ("quartzeux",),
    "quartzeuses": ("quartzeux",),
    "quartzeux": ("quartzeux",),
    "quartzifère": ("quartzifère",),
    "quartzifères": ("quartzifère",),
    "quartziforme": ("quartziforme",),
    "quartziformes": ("quartziforme",),
    "quartzique": ("quartzique",),
    "quartziques": ("quartzique",),
    "quartzitique": ("quartzitique",),
    "quartzitiques": ("quartzitique",),
    "quasi-délictuel": ("quasi-délictuel",),
    "quasi-délictuels": ("quasi-délictuel",),
    "quasi-homonyme": ("quasi-homonyme",),
    "quasiidentique": ("quasiidentique",),
    "quasiidentiques": ("quasiidentique",),
    "quasi-linéaire": ("quasi-linéaire",),
    "quasi-statiques": ("quasi-statique",),
    "quasistellaire": ("quasistellaire",),
    "quasistellaires": ("quasistellaire",),
    "quasi-voulue": ("quasi-voulu",),
    "quaternaire": ("quaternaire",),
    "quaternaires": ("quaternaire",),
    "quatorzième": ("quatorzième",),
    "quatorzièmes": ("quatorzième",),
    "quatrième": ("quatrième",),
    "quatrièmes": ("quatrième",),
    "quattrocentiste": ("quattrocentiste",),
    "quattrocentistes": ("quattrocentiste",),
    "québécoise": ("québécois",),
    "québécoises": ("québécois",),
    "québécois": ("québécois",),
    "quechua": ("quechua",),
    "quechuas": ("quechua",),
    "quelconque": ("quelconque",),
    "quelconques": ("quelconque",),
    "quérable": ("quérable",),
    "quérables": ("quérable",),
    "quercinoise": ("quercinois",),
    "quercinoises": ("quercinois",),
    "quercinois": ("quercinois",),
    "querelleur": ("querelleur",),
    "querelleurs": ("querelleur",),
    "querelleuse": ("querelleux",),
    "querelleuses": ("querelleux",),
    "querelleux": ("querelleux",),
    "questionneur": ("questionneur",),
    "questionneurs": ("questionneur",),
    "questionneuse": ("questionneur",),
    "questionneuses": ("questionneur",),
    "questorien": ("questorien",),
    "questorienne": ("questorien",),
    "questoriennes": ("questorien",),
    "questoriens": ("questorien",),
    "quêteur": ("quêteur",),
    "quêteurs": ("quêteur",),
    "quêteuse": ("quêteur",),
    "quêteuses": ("quêteur",),
    "quichua": ("quichua",),
    "quichuas": ("quichua",),
    "quiète": ("quiet",),
    "quiètes": ("quiet",),
    "quiet": ("quiet",),
    "quiets": ("quiet",),
    "quiétiste": ("quiétiste",),
    "quiétistes": ("quiétiste",),
    "quinaire": ("quinaire",),
    "quinaires": ("quinaire",),
    "quincaillière": ("quincaillier",),
    "quincaillières": ("quincaillier",),
    "quincaillier": ("quincaillier",),
    "quincailliers": ("quincaillier",),
    "quinconciale": ("quinconcial",),
    "quinconciales": ("quinconcial",),
    "quinconcial": ("quinconcial",),
    "quinconciaux": ("quinconcial",),
    "quinique": ("quinique",),
    "quiniques": ("quinique",),
    "quinoléinique": ("quinoléinique",),
    "quinoléiniques": ("quinoléinique",),
    "quinoléique": ("quinoléique",),
    "quinoléiques": ("quinoléique",),
    "quinquagénaire": ("quinquagénaire",),
    "quinquagénaires": ("quinquagénaire",),
    "quinquennale": ("quinquennal",),
    "quinquennales": ("quinquennal",),
    "quinquennal": ("quinquennal",),
    "quinquennaux": ("quinquennal",),
    "quintane": ("quintane",),
    "quintanes": ("quintane",),
    "quinte": ("quinte",),
    "quintes": ("quinte",),
    "quinteuse": ("quinteux",),
    "quinteuses": ("quinteux",),
    "quinteux": ("quinteux",),
    "quintuple": ("quintuple",),
    "quintuples": ("quintuple",),
    "quinzième": ("quinzième",),
    "quinzièmes": ("quinzième",),
    "quirinale": ("quirinal",),
    "quirinales": ("quirinal",),
    "quirinal": ("quirinal",),
    "quirinaux": ("quirinal",),
    "quitte": ("quitte",),
    "quittes": ("quitte",),
    "quote": ("quote",),
    "quotes": ("quote",),
    "quotidien": ("quotidien",),
    "quotidienne": ("quotidien",),
    "quotidiennes": ("quotidien",),
    "quotidiens": ("quotidien",),
    "rabâcheur": ("rabâcheur",),
    "rabâcheurs": ("rabâcheur",),
    "rabâcheuse": ("rabâcheur",),
    "rabâcheuses": ("rabâcheur",),
    "rabbinique": ("rabbinique",),
    "rabbiniques": ("rabbinique",),
    "rabelaisien": ("rabelaisien",),
    "rabelaisienne": ("rabelaisien",),
    "rabelaisiennes": ("rabelaisien",),
    "rabelaisiens": ("rabelaisien",),
    "rabique": ("rabique",),
    "rabiques": ("rabique",),
    "raboteuse": ("raboteux",),
    "raboteuses": ("raboteux",),
    "raboteux": ("raboteux",),
    "raccommodable": ("raccommodable",),
    "raccommodables": ("raccommodable",),
    "raccordable": ("raccordable",),
    "raccordables": ("raccordable",),
    "raccrocheur": ("raccrocheur",),
    "raccrocheurs": ("raccrocheur",),
    "raccrocheuse": ("raccrocheur",),
    "raccrocheuses": ("raccrocheur",),
    "racémeuse": ("racémeux",),
    "racémeuses": ("racémeux",),
    "racémeux": ("racémeux",),
    "racémique": ("racémique",),
    "racémiques": ("racémique",),
    "rachetable": ("rachetable",),
    "rachetables": ("rachetable",),
    "racheteur": ("racheteur",),
    "racheteurs": ("racheteur",),
    "racheteuse": ("racheteur",),
    "racheteuses": ("racheteur",),
    "rachialgique": ("rachialgique",),
    "rachialgiques": ("rachialgique",),
    "rachidien": ("rachidien",),
    "rachidienne": ("rachidien",),
    "rachidiennes": ("rachidien",),
    "rachidiens": ("rachidien",),
    "rachitigène": ("rachitigène",),
    "rachitigènes": ("rachitigène",),
    "rachitique": ("rachitique",),
    "rachitiques": ("rachitique",),
    "raciale": ("racial",),
    "raciales": ("racial",),
    "racial": ("racial",),
    "raciaux": ("racial",),
    "racinaire": ("racinaire",),
    "racinaires": ("racinaire",),
    "racinien": ("racinien",),
    "racinienne": ("racinien",),
    "raciniennes": ("racinien",),
    "raciniens": ("racinien",),
    "raciste": ("raciste",),
    "racistes": ("raciste",),
    "rackable": ("rackable",),
    "rackables": ("rackable",),
    "racoleur": ("racoleur",),
    "racoleurs": ("racoleur",),
    "racoleuse": ("racoleur",),
    "racoleuses": ("racoleur",),
    "racontable": ("racontable",),
    "racontables": ("racontable",),
    "radariste": ("radariste",),
    "radaristes": ("radariste",),
    "radiable": ("radiable",),
    "radiables": ("radiable",),
    "radiaire": ("radiaire",),
    "radiaires": ("radiaire",),
    "radiale": ("radial",),
    "radiales": ("radial",),
    "radial": ("radial",),
    "radiaux": ("radial",),
    "radiatif": ("radiatif",),
    "radiatifs": ("radiatif",),
    "radiative": ("radiatif",),
    "radiatives": ("radiatif",),
    "radicalaire": ("radicalaire",),
    "radicalaires": ("radicalaire",),
    "radicale": ("radical",),
    "radicales": ("radical",),
    "radical": ("radical",),
    "radicaux": ("radical",),
    "radicaliste": ("radicaliste",),
    "radicalistes": ("radicaliste",),
    "radiculaire": ("radiculaire",),
    "radiculaires": ("radiculaire",),
    "radiculo-cordonales": ("radiculo-cordonal",),
    "radiesthésique": ("radiesthésique",),
    "radiesthésiques": ("radiesthésique",),
    "radieuse": ("radieux",),
    "radieuses": ("radieux",),
    "radieux": ("radieux",),
    "radioactif": ("radioactif",),
    "radioactifs": ("radioactif",),
    "radioactive": ("radioactif",),
    "radioactives": ("radioactif",),
    "radio": ("radio",),
    "radioastronomique": ("radioastronomique",),
    "radioastronomiques": ("radioastronomique",),
    "radiobiologique": ("radiobiologique",),
    "radiobiologiques": ("radiobiologique",),
    "radiobiotique": ("radiobiotique",),
    "radiobiotiques": ("radiobiotique",),
    "radiochimique": ("radiochimique",),
    "radiochimiques": ("radiochimique",),
    "radio-commandées": ("radio-commandé",),
    "radiocompétitif": ("radiocompétitif",),
    "radiocompétitifs": ("radiocompétitif",),
    "radiocompétitive": ("radiocompétitif",),
    "radiocompétitives": ("radiocompétitif",),
    "radioconcentrique": ("radioconcentrique",),
    "radioconcentriques": ("radioconcentrique",),
    "radiocristallographique": ("radiocristallographique",),
    "radiocristallographiques": ("radiocristallographique",),
    "radio-durcissables": ("radio-durcissable",),
    "radioélectrique": ("radioélectrique",),
    "radioélectriques": ("radioélectrique",),
    "radioélectronique": ("radioélectronique",),
    "radioélectroniques": ("radioélectronique",),
    "radiogène": ("radiogène",),
    "radiogènes": ("radiogène",),
    "radiogénique": ("radiogénique",),
    "radiogéniques": ("radiogénique",),
    "radiogoniométrique": ("radiogoniométrique",),
    "radiogoniométriques": ("radiogoniométrique",),
    "radiographique": ("radiographique",),
    "radiographiques": ("radiographique",),
    "radio-humérale": ("radio-huméral",),
    "radioimmunologique": ("radioimmunologique",),
    "radio-immunologiques": ("radio-immunologique",),
    "radioimmunologiques": ("radioimmunologique",),
    "radio-induit": ("radio-induit",),
    "radio-induits": ("radio-induit",),
    "radiolabile": ("radiolabile",),
    "radiolabiles": ("radiolabile",),
    "radiologique": ("radiologique",),
    "radiologiques": ("radiologique",),
    "radiométrique": ("radiométrique",),
    "radiométriques": ("radiométrique",),
    "radiomimétique": ("radiomimétique",),
    "radiomimétiques": ("radiomimétique",),
    "radionucléidique": ("radionucléidique",),
    "radionucléidiques": ("radionucléidique",),
    "radio-palmaire": ("radio-palmaire",),
    "radiopharmaceutique": ("radiopharmaceutique",),
    "radiopharmaceutiques": ("radiopharmaceutique",),
    "radiophonique": ("radiophonique",),
    "radiophoniques": ("radiophonique",),
    "radiophysique": ("radiophysique",),
    "radiophysiques": ("radiophysique",),
    "radioprotecteur": ("radioprotecteur",),
    "radioprotecteurs": ("radioprotecteur",),
    "radioprotectrice": ("radioprotecteur",),
    "radioprotectrices": ("radioprotecteur",),
    "radioscientifique": ("radioscientifique",),
    "radioscientifiques": ("radioscientifique",),
    "radioscopique": ("radioscopique",),
    "radioscopiques": ("radioscopique",),
    "radiosensible": ("radiosensible",),
    "radiosensibles": ("radiosensible",),
    "radiotechnique": ("radiotechnique",),
    "radiotechniques": ("radiotechnique",),
    "radiotélégraphique": ("radiotélégraphique",),
    "radiotélégraphiques": ("radiotélégraphique",),
    "radiotéléphonique": ("radiotéléphonique",),
    "radiotéléphoniques": ("radiotéléphonique",),
    "radiothérapique": ("radiothérapique",),
    "radiothérapiques": ("radiothérapique",),
    "radiovisiographique": ("radiovisiographique",),
    "radiovisiographiques": ("radiovisiographique",),
    "radique": ("radique",),
    "radiques": ("radique",),
    "radjasthani": ("radjasthani",),
    "radjasthanis": ("radjasthani",),
    "radoteur": ("radoteur",),
    "radoteurs": ("radoteur",),
    "radoteuse": ("radoteur",),
    "radoteuses": ("radoteur",),
    "raffineur": ("raffineur",),
    "raffineurs": ("raffineur",),
    "raffineuse": ("raffineur",),
    "raffineuses": ("raffineur",),
    "rafraîchisseur": ("rafraîchisseur",),
    "rafraîchisseurs": ("rafraîchisseur",),
    "rafraîchisseuse": ("rafraîchisseur",),
    "rafraîchisseuses": ("rafraîchisseur",),
    "rageur": ("rageur",),
    "rageurs": ("rageur",),
    "rageuse": ("rageur",),
    "rageuses": ("rageur",),
    "raglan": ("raglan",),
    "raide": ("raide",),
    "raides": ("raide",),
    "railleur": ("railleur",),
    "railleurs": ("railleur",),
    "railleuse": ("railleur",),
    "railleuses": ("railleur",),
    "railroute": ("railroute",),
    "raisonnable": ("raisonnable",),
    "raisonnables": ("raisonnable",),
    "raisonneur": ("raisonneur",),
    "raisonneurs": ("raisonneur",),
    "raisonneuse": ("raisonneur",),
    "raisonneuses": ("raisonneur",),
    "ralentisseur": ("ralentisseur",),
    "ralentisseurs": ("ralentisseur",),
    "ralentisseuse": ("ralentisseur",),
    "ralentisseuses": ("ralentisseur",),
    "râleur": ("râleur",),
    "râleurs": ("râleur",),
    "râleuse": ("râleur",),
    "râleuses": ("râleur",),
    "ramasseur": ("ramasseur",),
    "ramasseurs": ("ramasseur",),
    "ramasseuse": ("ramasseur",),
    "ramasseuses": ("ramasseur",),
    "raméale": ("raméal",),
    "raméales": ("raméal",),
    "raméal": ("raméal",),
    "raméaux": ("raméal",),
    "ramenable": ("ramenable",),
    "ramenables": ("ramenable",),
    "rameuse": ("rameux",),
    "rameuses": ("rameux",),
    "rameux": ("rameux",),
    "ramingue": ("ramingue",),
    "ramingues": ("ramingue",),
    "ramiste": ("ramiste",),
    "ramistes": ("ramiste",),
    "ramollissable": ("ramollissable",),
    "ramollissables": ("ramollissable",),
    "ramollo": ("ramollo",),
    "ramollos": ("ramollo",),
    "ramonable": ("ramonable",),
    "ramonables": ("ramonable",),
    "rampin": ("rampin",),
    "rampins": ("rampin",),
    "rance": ("rance",),
    "rances": ("rance",),
    "rancescible": ("rancescible",),
    "rancescibles": ("rancescible",),
    "rançonneur": ("rançonneur",),
    "rançonneurs": ("rançonneur",),
    "rançonneuse": ("rançonneur",),
    "rançonneuses": ("rançonneur",),
    "rancuneuse": ("rancuneux",),
    "rancuneuses": ("rancuneux",),
    "rancuneux": ("rancuneux",),
    "rancunière": ("rancunier",),
    "rancunières": ("rancunier",),
    "rancunier": ("rancunier",),
    "rancuniers": ("rancunier",),
    "random": ("random",),
    "ranimable": ("ranimable",),
    "ranimables": ("ranimable",),
    "ranine": ("ranine",),
    "ranines": ("ranine",),
    "rapace": ("rapace",),
    "rapaces": ("rapace",),
    "rapakivique": ("rapakivique",),
    "rapakiviques": ("rapakivique",),
    "rapakiwique": ("rapakiwique",),
    "rapakiwiques": ("rapakiwique",),
    "râpeuse": ("râpeux",),
    "râpeuses": ("râpeux",),
    "râpeux": ("râpeux",),
    "raphaélesque": ("raphaélesque",),
    "raphaélesques": ("raphaélesque",),
    "raphaélique": ("raphaélique",),
    "raphaéliques": ("raphaélique",),
    "rapide": ("rapide",),
    "rapides": ("rapide",),
    "rapineur": ("rapineur",),
    "rapineurs": ("rapineur",),
    "rapineuse": ("rapineur",),
    "rapineuses": ("rapineur",),
    "raplapla": ("raplapla",),
    "rappelable": ("rappelable",),
    "rappelables": ("rappelable",),
    "rapplique": ("rapplique",),
    "rappliques": ("rapplique",),
    "rapportable": ("rapportable",),
    "rapportables": ("rapportable",),
    "rapporteur": ("rapporteur",),
    "rapporteurs": ("rapporteur",),
    "rapporteuse": ("rapporteur",),
    "rapporteuses": ("rapporteur",),
    "rapprocheur": ("rapprocheur",),
    "rapprocheurs": ("rapprocheur",),
    "rapprocheuse": ("rapprocheur",),
    "rapprocheuses": ("rapprocheur",),
    "rapsodique": ("rapsodique",),
    "rapsodiques": ("rapsodique",),
    "rare": ("rare",),
    "rares": ("rare",),
    "raréfiable": ("raréfiable",),
    "raréfiables": ("raréfiable",),
    "rarissime": ("rarissime",),
    "rarissimes": ("rarissime",),
    "rase": ("ras",),
    "rases": ("ras",),
    "ras": ("ras",),
    "raseur": ("raseur",),
    "raseurs": ("raseur",),
    "raseuse": ("raseur",),
    "raseuses": ("raseur",),
    "rasoir": ("rasoir",),
    "rassise": ("rassis",),
    "rassises": ("rassis",),
    "rassis": ("rassis",),
    "rasta": ("rasta",),
    "rastas": ("rasta",),
    "rastafari": ("rastafari",),
    "rastafaris": ("rastafari",),
    "rat": ("rat",),
    "rats": ("rat",),
    "râteleur": ("râteleur",),
    "râteleurs": ("râteleur",),
    "râteleuse": ("râteleur",),
    "râteleuses": ("râteleur",),
    "raticide": ("raticide",),
    "raticides": ("raticide",),
    "ratière": ("ratier",),
    "ratières": ("ratier",),
    "ratier": ("ratier",),
    "ratiers": ("ratier",),
    "rationalisable": ("rationalisable",),
    "rationalisables": ("rationalisable",),
    "rationaliste": ("rationaliste",),
    "rationalistes": ("rationaliste",),
    "rationnaire": ("rationnaire",),
    "rationnaires": ("rationnaire",),
    "rationnelle": ("rationnel",),
    "rationnelles": ("rationnel",),
    "rationnel": ("rationnel",),
    "rationnels": ("rationnel",),
    "rattrapable": ("rattrapable",),
    "rattrapables": ("rattrapable",),
    "rauque": ("rauque",),
    "rauques": ("rauque",),
    "ravageur": ("ravageur",),
    "ravageurs": ("ravageur",),
    "ravageuse": ("ravageur",),
    "ravageuses": ("ravageur",),
    "ravaleur": ("ravaleur",),
    "ravaleurs": ("ravaleur",),
    "ravaleuse": ("ravaleur",),
    "ravaleuses": ("ravaleur",),
    "ravanceur": ("ravanceur",),
    "ravanceurs": ("ravanceur",),
    "ravanceuse": ("ravanceur",),
    "ravanceuses": ("ravanceur",),
    "ravineuse": ("ravineux",),
    "ravineuses": ("ravineux",),
    "ravineux": ("ravineux",),
    "ravisseur": ("ravisseur",),
    "ravisseurs": ("ravisseur",),
    "ravisseuse": ("ravisseur",),
    "ravisseuses": ("ravisseur",),
    "ravitailleur": ("ravitailleur",),
    "ravitailleurs": ("ravitailleur",),
    "ravitailleuse": ("ravitailleur",),
    "ravitailleuses": ("ravitailleur",),
    "rayonneur": ("rayonneur",),
    "rayonneurs": ("rayonneur",),
    "rayonneuse": ("rayonneur",),
    "rayonneuses": ("rayonneur",),
    "réac": ("réac",),
    "réacs": ("réac",),
    "réactif": ("réactif",),
    "réactifs": ("réactif",),
    "réactive": ("réactif",),
    "réactives": ("réactif",),
    "réactionnaire": ("réactionnaire",),
    "réactionnaires": ("réactionnaire",),
    "réactionnelle": ("réactionnel",),
    "réactionnelles": ("réactionnel",),
    "réactionnel": ("réactionnel",),
    "réactionnels": ("réactionnel",),
    "réactivable": ("réactivable",),
    "réactivables": ("réactivable",),
    "réactogène": ("réactogène",),
    "réactogènes": ("réactogène",),
    "réactualisable": ("réactualisable",),
    "réactualisables": ("réactualisable",),
    "réadaptable": ("réadaptable",),
    "réadaptables": ("réadaptable",),
    "réaginique": ("réaginique",),
    "réaginiques": ("réaginique",),
    "réale": ("réal",),
    "réales": ("réal",),
    "réal": ("réal",),
    "réaux": ("réal",),
    "réalisable": ("réalisable",),
    "réalisables": ("réalisable",),
    "réaliste": ("réaliste",),
    "réalistes": ("réaliste",),
    "réanimable": ("réanimable",),
    "réanimables": ("réanimable",),
    "rébarbatif": ("rébarbatif",),
    "rébarbatifs": ("rébarbatif",),
    "rébarbative": ("rébarbatif",),
    "rébarbatives": ("rébarbatif",),
    "rebelle": ("rebelle",),
    "rebelles": ("rebelle",),
    "récapitulatif": ("récapitulatif",),
    "récapitulatifs": ("récapitulatif",),
    "récapitulative": ("récapitulatif",),
    "récapitulatives": ("récapitulatif",),
    "recenseur": ("recenseur",),
    "recenseurs": ("recenseur",),
    "recenseuse": ("recenseur",),
    "recenseuses": ("recenseur",),
    "récepteur": ("récepteur",),
    "récepteurs": ("récepteur",),
    "réceptrice": ("récepteur",),
    "réceptrices": ("récepteur",),
    "réceptice": ("réceptice",),
    "réceptices": ("réceptice",),
    "réceptif": ("réceptif",),
    "réceptifs": ("réceptif",),
    "réceptive": ("réceptif",),
    "réceptives": ("réceptif",),
    "réceptionnaire": ("réceptionnaire",),
    "réceptionnaires": ("réceptionnaire",),
    "réceptionniste": ("réceptionniste",),
    "réceptionnistes": ("réceptionniste",),
    "récessif": ("récessif",),
    "récessifs": ("récessif",),
    "récessive": ("récessif",),
    "récessives": ("récessif",),
    "récessionniste": ("récessionniste",),
    "récessionnistes": ("récessionniste",),
    "recevable": ("recevable",),
    "recevables": ("recevable",),
    "rechampie": ("rechampi",),
    "réchampie": ("réchampi",),
    "rechampies": ("rechampi",),
    "réchampies": ("réchampi",),
    "rechampi": ("rechampi",),
    "réchampi": ("réchampi",),
    "rechampis": ("rechampi",),
    "réchampis": ("réchampi",),
    "rechargeable": ("rechargeable",),
    "rechargeables": ("rechargeable",),
    "rêche": ("rêche",),
    "rêches": ("rêche",),
    "récidiviste": ("récidiviste",),
    "récidivistes": ("récidiviste",),
    "récifale": ("récifal",),
    "récifales": ("récifal",),
    "récifal": ("récifal",),
    "récifaux": ("récifal",),
    "réciproque": ("réciproque",),
    "réciproques": ("réciproque",),
    "recluse": ("reclus",),
    "recluses": ("reclus",),
    "reclus": ("reclus",),
    "récognitif": ("récognitif",),
    "récognitifs": ("récognitif",),
    "récognitive": ("récognitif",),
    "récognitives": ("récognitif",),
    "récoltable": ("récoltable",),
    "récoltables": ("récoltable",),
    "recommandable": ("recommandable",),
    "recommandables": ("recommandable",),
    "recomposable": ("recomposable",),
    "recomposables": ("recomposable",),
    "réconciliable": ("réconciliable",),
    "réconciliables": ("réconciliable",),
    "reconductible": ("reconductible",),
    "reconductibles": ("reconductible",),
    "reconfigurable": ("reconfigurable",),
    "reconfigurables": ("reconfigurable",),
    "reconnaissable": ("reconnaissable",),
    "reconnaissables": ("reconnaissable",),
    "reconstituable": ("reconstituable",),
    "reconstituables": ("reconstituable",),
    "reconstitutif": ("reconstitutif",),
    "reconstitutifs": ("reconstitutif",),
    "reconstitutive": ("reconstitutif",),
    "reconstitutives": ("reconstitutif",),
    "reconstructeur": ("reconstructeur",),
    "reconstructeurs": ("reconstructeur",),
    "reconstructrice": ("reconstructeur",),
    "reconstructrices": ("reconstructeur",),
    "reconstructible": ("reconstructible",),
    "reconstructibles": ("reconstructible",),
    "reconventionnelle": ("reconventionnel",),
    "reconventionnelles": ("reconventionnel",),
    "reconventionnel": ("reconventionnel",),
    "reconventionnels": ("reconventionnel",),
    "record": ("record",),
    "recouvrable": ("recouvrable",),
    "recouvrables": ("recouvrable",),
    "recréateur": ("recréateur",),
    "recréateurs": ("recréateur",),
    "recréatrice": ("recréateur",),
    "recréatrices": ("recréateur",),
    "récréatif": ("récréatif",),
    "récréatifs": ("récréatif",),
    "récréative": ("récréatif",),
    "récréatives": ("récréatif",),
    "récriminateur": ("récriminateur",),
    "récriminateurs": ("récriminateur",),
    "récriminatrice": ("récriminateur",),
    "récriminatrices": ("récriminateur",),
    "récriminatoire": ("récriminatoire",),
    "récriminatoires": ("récriminatoire",),
    "recruteur": ("recruteur",),
    "recruteurs": ("recruteur",),
    "recruteuse": ("recruteur",),
    "recruteuses": ("recruteur",),
    "rectale": ("rectal",),
    "rectales": ("rectal",),
    "rectal": ("rectal",),
    "rectaux": ("rectal",),
    "rectangle": ("rectangle",),
    "rectangles": ("rectangle",),
    "rectangulaire": ("rectangulaire",),
    "rectangulaires": ("rectangulaire",),
    "recteur": ("recteur",),
    "recteurs": ("recteur",),
    "rectrice": ("recteur",),
    "rectrices": ("recteur",),
    "rectifiable": ("rectifiable",),
    "rectifiables": ("rectifiable",),
    "rectificateur": ("rectificateur",),
    "rectificateurs": ("rectificateur",),
    "rectificatrice": ("rectificateur",),
    "rectificatrices": ("rectificateur",),
    "rectificatif": ("rectificatif",),
    "rectificatifs": ("rectificatif",),
    "rectificative": ("rectificatif",),
    "rectificatives": ("rectificatif",),
    "rectiligne": ("rectiligne",),
    "rectilignes": ("rectiligne",),
    "rectilinéaire": ("rectilinéaire",),
    "rectilinéaires": ("rectilinéaire",),
    "rectorale": ("rectoral",),
    "rectorales": ("rectoral",),
    "rectoral": ("rectoral",),
    "rectoraux": ("rectoral",),
    "recto-urétral": ("recto-urétral",),
    "recto-urétraux": ("recto-urétral",),
    "recto-vaginales": ("rectovaginal",),
    "recto-vésicale": ("rectovésical",),
    "récupérable": ("récupérable",),
    "récupérables": ("récupérable",),
    "récupérateur": ("récupérateur",),
    "récupérateurs": ("récupérateur",),
    "récupératrice": ("récupérateur",),
    "récupératrices": ("récupérateur",),
    "récursif": ("récursif",),
    "récursifs": ("récursif",),
    "récursive": ("récursif",),
    "récursives": ("récursif",),
    "récursoire": ("récursoire",),
    "récursoires": ("récursoire",),
    "récusable": ("récusable",),
    "récusables": ("récusable",),
    "recyclable": ("recyclable",),
    "recyclables": ("recyclable",),
    "rédactionnelle": ("rédactionnel",),
    "rédactionnelles": ("rédactionnel",),
    "rédactionnel": ("rédactionnel",),
    "rédactionnels": ("rédactionnel",),
    "rédempteur": ("rédempteur",),
    "rédempteurs": ("rédempteur",),
    "rédemptrice": ("rédempteur",),
    "rédemptrices": ("rédempteur",),
    "redevable": ("redevable",),
    "redevables": ("redevable",),
    "rédhibitoire": ("rédhibitoire",),
    "rédhibitoires": ("rédhibitoire",),
    "redistributeur": ("redistributeur",),
    "redistributeurs": ("redistributeur",),
    "redistributrice": ("redistributeur",),
    "redistributrices": ("redistributeur",),
    "redistributif": ("redistributif",),
    "redistributifs": ("redistributif",),
    "redistributive": ("redistributif",),
    "redistributives": ("redistributif",),
    "redoutable": ("redoutable",),
    "redoutables": ("redoutable",),
    "redox": ("redox",),
    "redresseur": ("redresseur",),
    "redresseurs": ("redresseur",),
    "redresseuse": ("redresseur",),
    "redresseuses": ("redresseur",),
    "réducteur": ("réducteur",),
    "réducteurs": ("réducteur",),
    "réductrice": ("réducteur",),
    "réductrices": ("réducteur",),
    "réductible": ("réductible",),
    "réductibles": ("réductible",),
    "réductionnelle": ("réductionnel",),
    "réductionnelles": ("réductionnel",),
    "réductionnel": ("réductionnel",),
    "réductionnels": ("réductionnel",),
    "réductionniste": ("réductionniste",),
    "réductionnistes": ("réductionniste",),
    "réduplicatif": ("réduplicatif",),
    "réduplicatifs": ("réduplicatif",),
    "réduplicative": ("réduplicatif",),
    "réduplicatives": ("réduplicatif",),
    "redux": ("redux",),
    "rééducateur": ("rééducateur",),
    "rééducateurs": ("rééducateur",),
    "rééducatrice": ("rééducateur",),
    "rééducatrices": ("rééducateur",),
    "réelle": ("réel",),
    "réelles": ("réel",),
    "réel": ("réel",),
    "réels": ("réel",),
    "rééligible": ("rééligible",),
    "rééligibles": ("rééligible",),
    "réemployable": ("réemployable",),
    "réemployables": ("réemployable",),
    "réexaminable": ("réexaminable",),
    "réexaminables": ("réexaminable",),
    "référendaire": ("référendaire",),
    "référendaires": ("référendaire",),
    "référentielle": ("référentiel",),
    "référentielles": ("référentiel",),
    "référentiel": ("référentiel",),
    "référentiels": ("référentiel",),
    "réflecteur": ("réflecteur",),
    "réflecteurs": ("réflecteur",),
    "réflectrice": ("réflecteur",),
    "réflectrices": ("réflecteur",),
    "réflectif": ("réflectif",),
    "réflectifs": ("réflectif",),
    "réflective": ("réflectif",),
    "réflectives": ("réflectif",),
    "reflex": ("reflex",),
    "réflexe": ("réflexe",),
    "réflexes": ("réflexe",),
    "réflexible": ("réflexible",),
    "réflexibles": ("réflexible",),
    "réflexif": ("réflexif",),
    "réflexifs": ("réflexif",),
    "réflexive": ("réflexif",),
    "réflexives": ("réflexif",),
    "réflexogène": ("réflexogène",),
    "réflexogènes": ("réflexogène",),
    "refondateur": ("refondateur",),
    "refondateurs": ("refondateur",),
    "refondatrice": ("refondateur",),
    "refondatrices": ("refondateur",),
    "réformable": ("réformable",),
    "réformables": ("réformable",),
    "réformateur": ("réformateur",),
    "réformateurs": ("réformateur",),
    "réformatrice": ("réformateur",),
    "réformatrices": ("réformateur",),
    "réformiste": ("réformiste",),
    "réformistes": ("réformiste",),
    "réfractaire": ("réfractaire",),
    "réfractaires": ("réfractaire",),
    "réfracteur": ("réfracteur",),
    "réfracteurs": ("réfracteur",),
    "réfractrice": ("réfracteur",),
    "réfractrices": ("réfracteur",),
    "réfractif": ("réfractif",),
    "réfractifs": ("réfractif",),
    "réfractive": ("réfractif",),
    "réfractives": ("réfractif",),
    "réfractométrique": ("réfractométrique",),
    "réfractométriques": ("réfractométrique",),
    "réfrangible": ("réfrangible",),
    "réfrangibles": ("réfrangible",),
    "refroidisseur": ("refroidisseur",),
    "refroidisseurs": ("refroidisseur",),
    "refroidisseuse": ("refroidisseur",),
    "refroidisseuses": ("refroidisseur",),
    "refusable": ("refusable",),
    "refusables": ("refusable",),
    "réfutable": ("réfutable",),
    "réfutables": ("réfutable",),
    "régale": ("régale",),
    "régales": ("régale",),
    "régalien": ("régalien",),
    "régalienne": ("régalien",),
    "régaliennes": ("régalien",),
    "régaliens": ("régalien",),
    "regardable": ("regardable",),
    "regardables": ("regardable",),
    "régence": ("régence",),
    "regency": ("regency",),
    "régénérateur": ("régénérateur",),
    "régénérateurs": ("régénérateur",),
    "régénératrice": ("régénérateur",),
    "régénératrices": ("régénérateur",),
    "régénératif": ("régénératif",),
    "régénératifs": ("régénératif",),
    "régénérative": ("régénératif",),
    "régénératives": ("régénératif",),
    "régicide": ("régicide",),
    "régicides": ("régicide",),
    "regimbeur": ("regimbeur",),
    "regimbeurs": ("regimbeur",),
    "regimbeuse": ("regimbeur",),
    "regimbeuses": ("regimbeur",),
    "régimentaire": ("régimentaire",),
    "régimentaires": ("régimentaire",),
    "régionale": ("régional",),
    "régionales": ("régional",),
    "régional": ("régional",),
    "régionaux": ("régional",),
    "régionaliste": ("régionaliste",),
    "régionalistes": ("régionaliste",),
    "régiosélectif": ("régiosélectif",),
    "régiosélectifs": ("régiosélectif",),
    "régiosélective": ("régiosélectif",),
    "régiosélectives": ("régiosélectif",),
    "régiospécifique": ("régiospécifique",),
    "régiospécifiques": ("régiospécifique",),
    "réglable": ("réglable",),
    "réglables": ("réglable",),
    "réglementaire": ("réglementaire",),
    "réglementaires": ("réglementaire",),
    "réglementariste": ("réglementariste",),
    "réglementaristes": ("réglementariste",),
    "réglo": ("réglo",),
    "regrattière": ("regrattier",),
    "regrattières": ("regrattier",),
    "regrattier": ("regrattier",),
    "regrattiers": ("regrattier",),
    "régressif": ("régressif",),
    "régressifs": ("régressif",),
    "régressive": ("régressif",),
    "régressives": ("régressif",),
    "regrettable": ("regrettable",),
    "regrettables": ("regrettable",),
    "régulable": ("régulable",),
    "régulables": ("régulable",),
    "régularisable": ("régularisable",),
    "régularisables": ("régularisable",),
    "régulateur": ("régulateur",),
    "régulateurs": ("régulateur",),
    "régulatrice": ("régulateur",),
    "régulatrices": ("régulateur",),
    "régulationniste": ("régulationniste",),
    "régulationnistes": ("régulationniste",),
    "régulière": ("régulier",),
    "régulières": ("régulier",),
    "régulier": ("régulier",),
    "réguliers": ("régulier",),
    "réhabilitable": ("réhabilitable",),
    "réhabilitables": ("réhabilitable",),
    "réhabilitatoire": ("réhabilitatoire",),
    "réhabilitatoires": ("réhabilitatoire",),
    "rehausseur": ("rehausseur",),
    "rehausseurs": ("rehausseur",),
    "rehausseuse": ("rehausseur",),
    "rehausseuses": ("rehausseur",),
    "réinscriptible": ("réinscriptible",),
    "réinscriptibles": ("réinscriptible",),
    "réinsérable": ("réinsérable",),
    "réinsérables": ("réinsérable",),
    "réintégrable": ("réintégrable",),
    "réintégrables": ("réintégrable",),
    "réitérable": ("réitérable",),
    "réitérables": ("réitérable",),
    "réitérateur": ("réitérateur",),
    "réitérateurs": ("réitérateur",),
    "réitératrice": ("réitérateur",),
    "réitératrices": ("réitérateur",),
    "réitératif": ("réitératif",),
    "réitératifs": ("réitératif",),
    "réitérative": ("réitératif",),
    "réitératives": ("réitératif",),
    "rejetable": ("rejetable",),
    "rejetables": ("rejetable",),
    "relapse": ("relaps",),
    "relapses": ("relaps",),
    "relaps": ("relaps",),
    "relatif": ("relatif",),
    "relatifs": ("relatif",),
    "relative": ("relatif",),
    "relatives": ("relatif",),
    "relationnelle": ("relationnel",),
    "relationnelles": ("relationnel",),
    "relationnel": ("relationnel",),
    "relationnels": ("relationnel",),
    "relativiste": ("relativiste",),
    "relativistes": ("relativiste",),
    "relax": ("relax",),
    "relaxe": ("relaxe",),
    "relaxes": ("relaxe",),
    "relégable": ("relégable",),
    "relégables": ("relégable",),
    "relégendable": ("relégendable",),
    "relégendables": ("relégendable",),
    "relevable": ("relevable",),
    "relevables": ("relevable",),
    "releveur": ("releveur",),
    "releveurs": ("releveur",),
    "releveuse": ("releveur",),
    "releveuses": ("releveur",),
    "reliable": ("reliable",),
    "reliables": ("reliable",),
    "relieur": ("relieur",),
    "relieurs": ("relieur",),
    "relieuse": ("relieur",),
    "relieuses": ("relieur",),
    "religieuse": ("religieux",),
    "religieuses": ("religieux",),
    "religieux": ("religieux",),
    "relisible": ("relisible",),
    "relisibles": ("relisible",),
    "remaniable": ("remaniable",),
    "remaniables": ("remaniable",),
    "remarquable": ("remarquable",),
    "remarquables": ("remarquable",),
    "remboursable": ("remboursable",),
    "remboursables": ("remboursable",),
    "rembranesque": ("rembranesque",),
    "rembranesques": ("rembranesque",),
    "remédiable": ("remédiable",),
    "remédiables": ("remédiable",),
    "remise": ("remis",),
    "remises": ("remis",),
    "remis": ("remis",),
    "rémissible": ("rémissible",),
    "rémissibles": ("rémissible",),
    "rémoise": ("rémois",),
    "rémoises": ("rémois",),
    "rémois": ("rémois",),
    "remontable": ("remontable",),
    "remontables": ("remontable",),
    "remorquable": ("remorquable",),
    "remorquables": ("remorquable",),
    "remorqueur": ("remorqueur",),
    "remorqueurs": ("remorqueur",),
    "remorqueuse": ("remorqueur",),
    "remorqueuses": ("remorqueur",),
    "remplaçable": ("remplaçable",),
    "remplaçables": ("remplaçable",),
    "remplisseur": ("remplisseur",),
    "remplisseurs": ("remplisseur",),
    "remplisseuse": ("remplisseur",),
    "remplisseuses": ("remplisseur",),
    "remployable": ("remployable",),
    "remployables": ("remployable",),
    "remuable": ("remuable",),
    "remuables": ("remuable",),
    "rémunérable": ("rémunérable",),
    "rémunérables": ("rémunérable",),
    "rémunérateur": ("rémunérateur",),
    "rémunérateurs": ("rémunérateur",),
    "rémunératrice": ("rémunérateur",),
    "rémunératrices": ("rémunérateur",),
    "rémunératoire": ("rémunératoire",),
    "rémunératoires": ("rémunératoire",),
    "renâcleur": ("renâcleur",),
    "renâcleurs": ("renâcleur",),
    "renâcleuse": ("renâcleur",),
    "renâcleuses": ("renâcleur",),
    "renaissance": ("renaissance",),
    "rénale": ("rénal",),
    "rénales": ("rénal",),
    "rénal": ("rénal",),
    "rénaux": ("rénal",),
    "renforçateur": ("renforçateur",),
    "renforçateurs": ("renforçateur",),
    "renforçatrice": ("renforçateur",),
    "renforçatrices": ("renforçateur",),
    "renforçatif": ("renforçatif",),
    "renforçatifs": ("renforçatif",),
    "renforçative": ("renforçatif",),
    "renforçatives": ("renforçatif",),
    "reniable": ("reniable",),
    "reniables": ("reniable",),
    "renifleur": ("renifleur",),
    "renifleurs": ("renifleur",),
    "renifleuse": ("renifleur",),
    "renifleuses": ("renifleur",),
    "réniforme": ("réniforme",),
    "réniformes": ("réniforme",),
    "rennaise": ("rennais",),
    "rennaises": ("rennais",),
    "rennais": ("rennais",),
    "renonciatif": ("renonciatif",),
    "renonciatifs": ("renonciatif",),
    "renonciative": ("renonciatif",),
    "renonciatives": ("renonciatif",),
    "rénoprive": ("rénoprive",),
    "rénoprives": ("rénoprive",),
    "rénorénale": ("rénorénal",),
    "rénorénales": ("rénorénal",),
    "rénorénal": ("rénorénal",),
    "rénorénaux": ("rénorénal",),
    "rénotrope": ("rénotrope",),
    "rénotropes": ("rénotrope",),
    "renouvelable": ("renouvelable",),
    "renouvelables": ("renouvelable",),
    "rénovasculaire": ("rénovasculaire",),
    "rénovasculaires": ("rénovasculaire",),
    "rénovateur": ("rénovateur",),
    "rénovateurs": ("rénovateur",),
    "rénovatrice": ("rénovateur",),
    "rénovatrices": ("rénovateur",),
    "rentable": ("rentable",),
    "rentables": ("rentable",),
    "renversable": ("renversable",),
    "renversables": ("renversable",),
    "renvideur": ("renvideur",),
    "renvideurs": ("renvideur",),
    "renvideuse": ("renvideur",),
    "renvideuses": ("renvideur",),
    "réopérable": ("réopérable",),
    "réopérables": ("réopérable",),
    "réorganisateur": ("réorganisateur",),
    "réorganisateurs": ("réorganisateur",),
    "réorganisatrice": ("réorganisateur",),
    "réorganisatrices": ("réorganisateur",),
    "réparable": ("réparable",),
    "réparables": ("réparable",),
    "réparateur": ("réparateur",),
    "réparateurs": ("réparateur",),
    "réparatrice": ("réparateur",),
    "réparatrices": ("réparateur",),
    "répartiteur": ("répartiteur",),
    "répartiteurs": ("répartiteur",),
    "répartitrice": ("répartiteur",),
    "répartitrices": ("répartiteur",),
    "repérable": ("repérable",),
    "repérables": ("repérable",),
    "répétable": ("répétable",),
    "répétables": ("répétable",),
    "répétible": ("répétible",),
    "répétibles": ("répétible",),
    "répétiteur": ("répétiteur",),
    "répétiteurs": ("répétiteur",),
    "répétitrice": ("répétiteur",),
    "répétitrices": ("répétiteur",),
    "répétitif": ("répétitif",),
    "répétitifs": ("répétitif",),
    "répétitive": ("répétitif",),
    "répétitives": ("répétitif",),
    "replantable": ("replantable",),
    "replantables": ("replantable",),
    "replète": ("replet",),
    "replètes": ("replet",),
    "replet": ("replet",),
    "replets": ("replet",),
    "réplétif": ("réplétif",),
    "réplétifs": ("réplétif",),
    "réplétive": ("réplétif",),
    "réplétives": ("réplétif",),
    "repliable": ("repliable",),
    "repliables": ("repliable",),
    "réplicatif": ("réplicatif",),
    "réplicatifs": ("réplicatif",),
    "réplicative": ("réplicatif",),
    "réplicatives": ("réplicatif",),
    "répondeur": ("répondeur",),
    "répondeurs": ("répondeur",),
    "répondeuse": ("répondeur",),
    "répondeuses": ("répondeur",),
    "reportable": ("reportable",),
    "reportables": ("reportable",),
    "répréhensible": ("répréhensible",),
    "répréhensibles": ("répréhensible",),
    "repreneur": ("repreneur",),
    "repreneurs": ("repreneur",),
    "repreneuse": ("repreneur",),
    "repreneuses": ("repreneur",),
    "représentable": ("représentable",),
    "représentables": ("représentable",),
    "représentatif": ("représentatif",),
    "représentatifs": ("représentatif",),
    "représentative": ("représentatif",),
    "représentatives": ("représentatif",),
    "répressible": ("répressible",),
    "répressibles": ("répressible",),
    "répressif": ("répressif",),
    "répressifs": ("répressif",),
    "répressive": ("répressif",),
    "répressives": ("répressif",),
    "réprimable": ("réprimable",),
    "réprimables": ("réprimable",),
    "réprimandable": ("réprimandable",),
    "réprimandables": ("réprimandable",),
    "réprobateur": ("réprobateur",),
    "réprobateurs": ("réprobateur",),
    "réprobatrice": ("réprobateur",),
    "réprobatrices": ("réprobateur",),
    "reprochable": ("reprochable",),
    "reprochables": ("reprochable",),
    "reproducteur": ("reproducteur",),
    "reproducteurs": ("reproducteur",),
    "reproductrice": ("reproducteur",),
    "reproductrices": ("reproducteur",),
    "reproductible": ("reproductible",),
    "reproductibles": ("reproductible",),
    "reproductif": ("reproductif",),
    "reproductifs": ("reproductif",),
    "reproductive": ("reproductif",),
    "reproductives": ("reproductif",),
    "reprogrammable": ("reprogrammable",),
    "reprogrammables": ("reprogrammable",),
    "reptilien": ("reptilien",),
    "reptilienne": ("reptilien",),
    "reptiliennes": ("reptilien",),
    "reptiliens": ("reptilien",),
    "répugnatoire": ("répugnatoire",),
    "répugnatoires": ("répugnatoire",),
    "répulsif": ("répulsif",),
    "répulsifs": ("répulsif",),
    "répulsive": ("répulsif",),
    "répulsives": ("répulsif",),
    "requérable": ("requérable",),
    "requérables": ("requérable",),
    "requise": ("requis",),
    "requises": ("requis",),
    "requis": ("requis",),
    "réquisitionnable": ("réquisitionnable",),
    "réquisitionnables": ("réquisitionnable",),
    "réquisitoriale": ("réquisitorial",),
    "réquisitoriales": ("réquisitorial",),
    "réquisitorial": ("réquisitorial",),
    "réquisitoriaux": ("réquisitorial",),
    "rescindable": ("rescindable",),
    "rescindables": ("rescindable",),
    "rescisible": ("rescisible",),
    "rescisibles": ("rescisible",),
    "rescisoire": ("rescisoire",),
    "rescisoires": ("rescisoire",),
    "résécable": ("résécable",),
    "résécables": ("résécable",),
    "réséda": ("réséda",),
    "réservataire": ("réservataire",),
    "réservataires": ("réservataire",),
    "réservatif": ("réservatif",),
    "réservatifs": ("réservatif",),
    "réservative": ("réservatif",),
    "réservatives": ("réservatif",),
    "réserviste": ("réserviste",),
    "réservistes": ("réserviste",),
    "résidentielle": ("résidentiel",),
    "résidentielles": ("résidentiel",),
    "résidentiel": ("résidentiel",),
    "résidentiels": ("résidentiel",),
    "résiduaire": ("résiduaire",),
    "résiduaires": ("résiduaire",),
    "résiduelle": ("résiduel",),
    "résiduelles": ("résiduel",),
    "résiduel": ("résiduel",),
    "résiduels": ("résiduel",),
    "résignable": ("résignable",),
    "résignables": ("résignable",),
    "résiliable": ("résiliable",),
    "résiliables": ("résiliable",),
    "résineuse": ("résineux",),
    "résineuses": ("résineux",),
    "résineux": ("résineux",),
    "résinière": ("résinier",),
    "résinières": ("résinier",),
    "résinier": ("résinier",),
    "résiniers": ("résinier",),
    "résinifère": ("résinifère",),
    "résinifères": ("résinifère",),
    "résinifiable": ("résinifiable",),
    "résinifiables": ("résinifiable",),
    "résinique": ("résinique",),
    "résiniques": ("résinique",),
    "résinoïde": ("résinoïde",),
    "résinoïdes": ("résinoïde",),
    "résistible": ("résistible",),
    "résistibles": ("résistible",),
    "résistif": ("résistif",),
    "résistifs": ("résistif",),
    "résistive": ("résistif",),
    "résistives": ("résistif",),
    "résoluble": ("résoluble",),
    "résolubles": ("résoluble",),
    "résolutif": ("résolutif",),
    "résolutifs": ("résolutif",),
    "résolutive": ("résolutif",),
    "résolutives": ("résolutif",),
    "résolutoire": ("résolutoire",),
    "résolutoires": ("résolutoire",),
    "résonateur": ("résonateur",),
    "résonateurs": ("résonateur",),
    "résonatrice": ("résonateur",),
    "résonatrices": ("résonateur",),
    "résorbable": ("résorbable",),
    "résorbables": ("résorbable",),
    "respectable": ("respectable",),
    "respectables": ("respectable",),
    "respectif": ("respectif",),
    "respectifs": ("respectif",),
    "respective": ("respectif",),
    "respectives": ("respectif",),
    "respectueuse": ("respectueux",),
    "respectueuses": ("respectueux",),
    "respectueux": ("respectueux",),
    "respirable": ("respirable",),
    "respirables": ("respirable",),
    "respirateur": ("respirateur",),
    "respirateurs": ("respirateur",),
    "respiratoire": ("respiratoire",),
    "respiratoires": ("respiratoire",),
    "responsable": ("responsable",),
    "responsables": ("responsable",),
    "responsoriale": ("responsorial",),
    "responsoriales": ("responsorial",),
    "responsorial": ("responsorial",),
    "responsoriaux": ("responsorial",),
    "resquilleur": ("resquilleur",),
    "resquilleurs": ("resquilleur",),
    "resquilleuse": ("resquilleur",),
    "resquilleuses": ("resquilleur",),
    "ressasseur": ("ressasseur",),
    "ressasseurs": ("ressasseur",),
    "ressasseuse": ("ressasseur",),
    "ressasseuses": ("ressasseur",),
    "restaurateur": ("restaurateur",),
    "restaurateurs": ("restaurateur",),
    "restauratrice": ("restaurateur",),
    "restauratrices": ("restaurateur",),
    "restituable": ("restituable",),
    "restituables": ("restituable",),
    "restituteur": ("restituteur",),
    "restituteurs": ("restituteur",),
    "restitutrice": ("restituteur",),
    "restitutrices": ("restituteur",),
    "restitutif": ("restitutif",),
    "restitutifs": ("restitutif",),
    "restitutive": ("restitutif",),
    "restitutives": ("restitutif",),
    "restitutoire": ("restitutoire",),
    "restitutoires": ("restitutoire",),
    "restrictif": ("restrictif",),
    "restrictifs": ("restrictif",),
    "restrictive": ("restrictif",),
    "restrictives": ("restrictif",),
    "résultatif": ("résultatif",),
    "résultatifs": ("résultatif",),
    "résultative": ("résultatif",),
    "résultatives": ("résultatif",),
    "résurrectionnelle": ("résurrectionnel",),
    "résurrectionnelles": ("résurrectionnel",),
    "résurrectionnel": ("résurrectionnel",),
    "résurrectionnels": ("résurrectionnel",),
    "retard": ("retard",),
    "retardataire": ("retardataire",),
    "retardataires": ("retardataire",),
    "retardateur": ("retardateur",),
    "retardateurs": ("retardateur",),
    "retardatrice": ("retardateur",),
    "retardatrices": ("retardateur",),
    "rétenteur": ("rétenteur",),
    "rétenteurs": ("rétenteur",),
    "rétentrice": ("rétenteur",),
    "rétentrices": ("rétenteur",),
    "réticulaire": ("réticulaire",),
    "réticulaires": ("réticulaire",),
    "réticulinique": ("réticulinique",),
    "réticuliniques": ("réticulinique",),
    "réticulo-endothéliale": ("réticulo-endothélial",),
    "réticulo-endothélial": ("réticulo-endothélial",),
    "réticulo-endothéliaux": ("réticulo-endothélial",),
    "réticulo-filamenteux": ("réticulo-filamenteux",),
    "réticulotrope": ("réticulotrope",),
    "réticulotropes": ("réticulotrope",),
    "rétif": ("rétif",),
    "rétifs": ("rétif",),
    "rétive": ("rétif",),
    "rétives": ("rétif",),
    "rétinien": ("rétinien",),
    "rétinienne": ("rétinien",),
    "rétiniennes": ("rétinien",),
    "rétiniens": ("rétinien",),
    "rétinoïque": ("rétinoïque",),
    "rétinoïques": ("rétinoïque",),
    "rétinotopique": ("rétinotopique",),
    "rétinotopiques": ("rétinotopique",),
    "rétique": ("rétique",),
    "rétiques": ("rétique",),
    "retirable": ("retirable",),
    "retirables": ("retirable",),
    "rétorquable": ("rétorquable",),
    "rétorquables": ("rétorquable",),
    "retorse": ("retors",),
    "retorses": ("retors",),
    "retors": ("retors",),
    "rétothéliale": ("rétothélial",),
    "rétothéliales": ("rétothélial",),
    "rétothélial": ("rétothélial",),
    "rétothéliaux": ("rétothélial",),
    "retouchable": ("retouchable",),
    "retouchables": ("retouchable",),
    "retournable": ("retournable",),
    "retournables": ("retournable",),
    "rétractable": ("rétractable",),
    "rétractables": ("rétractable",),
    "rétracteur": ("rétracteur",),
    "rétracteurs": ("rétracteur",),
    "rétractrice": ("rétracteur",),
    "rétractrices": ("rétracteur",),
    "rétractible": ("rétractible",),
    "rétractibles": ("rétractible",),
    "rétractif": ("rétractif",),
    "rétractifs": ("rétractif",),
    "rétractive": ("rétractif",),
    "rétractives": ("rétractif",),
    "rétractile": ("rétractile",),
    "rétractiles": ("rétractile",),
    "rétroactif": ("rétroactif",),
    "rétroactifs": ("rétroactif",),
    "rétroactive": ("rétroactif",),
    "rétroactives": ("rétroactif",),
    "rétro": ("rétro",),
    "rétrobulbaire": ("rétrobulbaire",),
    "rétrobulbaires": ("rétrobulbaire",),
    "rétrocaecale": ("rétrocaecal",),
    "rétrocaecales": ("rétrocaecal",),
    "rétrocaecal": ("rétrocaecal",),
    "rétrocaecaux": ("rétrocaecal",),
    "rétrochiasmatique": ("rétrochiasmatique",),
    "rétrochiasmatiques": ("rétrochiasmatique",),
    "rétrocrurale": ("rétrocrural",),
    "rétrocrurales": ("rétrocrural",),
    "rétrocrural": ("rétrocrural",),
    "rétrocruraux": ("rétrocrural",),
    "rétroflexe": ("rétroflexe",),
    "rétroflexes": ("rétroflexe",),
    "rétrogradée": ("rétrogradé",),
    "rétrogradées": ("rétrogradé",),
    "rétrogradé": ("rétrogradé",),
    "rétrograde": ("rétrograde",),
    "rétrogradés": ("rétrogradé",),
    "rétrogrades": ("rétrograde",),
    "rétrolentale": ("rétrolental",),
    "rétrolentales": ("rétrolental",),
    "rétrolental": ("rétrolental",),
    "rétrolentaux": ("rétrolental",),
    "rétrolunaire": ("rétrolunaire",),
    "rétrolunaires": ("rétrolunaire",),
    "rétromammaire": ("rétromammaire",),
    "rétromammaires": ("rétromammaire",),
    "rétronasale": ("rétronasal",),
    "rétronasales": ("rétronasal",),
    "rétronasal": ("rétronasal",),
    "rétronasaux": ("rétronasal",),
    "rétropéritonéale": ("rétropéritonéal",),
    "rétropéritonéales": ("rétropéritonéal",),
    "rétropéritonéal": ("rétropéritonéal",),
    "rétropéritonéaux": ("rétropéritonéal",),
    "rétropharyngien": ("rétropharyngien",),
    "rétropharyngienne": ("rétropharyngien",),
    "rétropharyngiennes": ("rétropharyngien",),
    "rétropharyngiens": ("rétropharyngien",),
    "rétroplacentaire": ("rétroplacentaire",),
    "rétroplacentaires": ("rétroplacentaire",),
    "rétropubien": ("rétropubien",),
    "rétropubienne": ("rétropubien",),
    "rétropubiennes": ("rétropubien",),
    "rétropubiens": ("rétropubien",),
    "rétrorolandique": ("rétrorolandique",),
    "rétrorolandiques": ("rétrorolandique",),
    "rétroscalénique": ("rétroscalénique",),
    "rétroscaléniques": ("rétroscalénique",),
    "rétrosellaire": ("rétrosellaire",),
    "rétrosellaires": ("rétrosellaire",),
    "rétrospectif": ("rétrospectif",),
    "rétrospectifs": ("rétrospectif",),
    "rétrospective": ("rétrospectif",),
    "rétrospectives": ("rétrospectif",),
    "rétrosternale": ("rétrosternal",),
    "rétrosternales": ("rétrosternal",),
    "rétrosternal": ("rétrosternal",),
    "rétrosternaux": ("rétrosternal",),
    "retrouvable": ("retrouvable",),
    "retrouvables": ("retrouvable",),
    "rétrovirale": ("rétroviral",),
    "rétrovirales": ("rétroviral",),
    "rétroviral": ("rétroviral",),
    "rétroviraux": ("rétroviral",),
    "réunionaise": ("réunionais",),
    "réunionaises": ("réunionais",),
    "réunionais": ("réunionais",),
    "réunionnaise": ("réunionnais",),
    "réunionnaises": ("réunionnais",),
    "réunionnais": ("réunionnais",),
    "réutilisable": ("réutilisable",),
    "réutilisables": ("réutilisable",),
    "revanchiste": ("revanchiste",),
    "revanchistes": ("revanchiste",),
    "rêvasseur": ("rêvasseur",),
    "rêvasseurs": ("rêvasseur",),
    "rêvasseuse": ("rêvasseur",),
    "rêvasseuses": ("rêvasseur",),
    "revêche": ("revêche",),
    "revêches": ("revêche",),
    "réveilleur": ("réveilleur",),
    "réveilleurs": ("réveilleur",),
    "réveilleuse": ("réveilleur",),
    "réveilleuses": ("réveilleur",),
    "révélable": ("révélable",),
    "révélables": ("révélable",),
    "révélateur": ("révélateur",),
    "révélateurs": ("révélateur",),
    "révélatrice": ("révélateur",),
    "révélatrices": ("révélateur",),
    "revendicateur": ("revendicateur",),
    "revendicateurs": ("revendicateur",),
    "revendicatrice": ("revendicateur",),
    "revendicatrices": ("revendicateur",),
    "revendicatif": ("revendicatif",),
    "revendicatifs": ("revendicatif",),
    "revendicative": ("revendicatif",),
    "revendicatives": ("revendicatif",),
    "révérencielle": ("révérenciel",),
    "révérencielles": ("révérenciel",),
    "révérenciel": ("révérenciel",),
    "révérenciels": ("révérenciel",),
    "révérencieuse": ("révérencieux",),
    "révérencieuses": ("révérencieux",),
    "révérencieux": ("révérencieux",),
    "révérendissime": ("révérendissime",),
    "révérendissimes": ("révérendissime",),
    "réversale": ("réversal",),
    "réversales": ("réversal",),
    "réversal": ("réversal",),
    "réversaux": ("réversal",),
    "réversible": ("réversible",),
    "réversibles": ("réversible",),
    "réversif": ("réversif",),
    "réversifs": ("réversif",),
    "réversive": ("réversif",),
    "réversives": ("réversif",),
    "rêveur": ("rêveur",),
    "rêveurs": ("rêveur",),
    "rêveuse": ("rêveur",),
    "rêveuses": ("rêveur",),
    "révisable": ("révisable",),
    "révisables": ("révisable",),
    "révisible": ("révisible",),
    "révisibles": ("révisible",),
    "révisionnelle": ("révisionnel",),
    "révisionnelles": ("révisionnel",),
    "révisionnel": ("révisionnel",),
    "révisionnels": ("révisionnel",),
    "révisionniste": ("révisionniste",),
    "révisionnistes": ("révisionniste",),
    "révocable": ("révocable",),
    "révocables": ("révocable",),
    "révocatoire": ("révocatoire",),
    "révocatoires": ("révocatoire",),
    "révolutif": ("révolutif",),
    "révolutifs": ("révolutif",),
    "révolutive": ("révolutif",),
    "révolutives": ("révolutif",),
    "révolutionnaire": ("révolutionnaire",),
    "révolutionnaires": ("révolutionnaire",),
    "révolutionnariste": ("révolutionnariste",),
    "révolutionnaristes": ("révolutionnariste",),
    "revolving": ("revolving",),
    "révulsif": ("révulsif",),
    "révulsifs": ("révulsif",),
    "révulsive": ("révulsif",),
    "révulsives": ("révulsif",),
    "rexiste": ("rexiste",),
    "rexistes": ("rexiste",),
    "rhapsodique": ("rhapsodique",),
    "rhapsodiques": ("rhapsodique",),
    "rhaznévide": ("rhaznévide",),
    "rhaznévides": ("rhaznévide",),
    "rhegmatogène": ("rhegmatogène",),
    "rhegmatogènes": ("rhegmatogène",),
    "rhénique": ("rhénique",),
    "rhéniques": ("rhénique",),
    "rhéobasique": ("rhéobasique",),
    "rhéobasiques": ("rhéobasique",),
    "rhéoencéphalographique": ("rhéoencéphalographique",),
    "rhéoencéphalographiques": ("rhéoencéphalographique",),
    "rhéographique": ("rhéographique",),
    "rhéographiques": ("rhéographique",),
    "rhéologique": ("rhéologique",),
    "rhéologiques": ("rhéologique",),
    "rhéophile": ("rhéophile",),
    "rhéophiles": ("rhéophile",),
    "rhéostatique": ("rhéostatique",),
    "rhéostatiques": ("rhéostatique",),
    "rhétien": ("rhétien",),
    "rhétienne": ("rhétien",),
    "rhétiennes": ("rhétien",),
    "rhétiens": ("rhétien",),
    "rhétique": ("rhétique",),
    "rhétiques": ("rhétique",),
    "rhétoricien": ("rhétoricien",),
    "rhétoricienne": ("rhétoricien",),
    "rhétoriciennes": ("rhétoricien",),
    "rhétoriciens": ("rhétoricien",),
    "rhétorique": ("rhétorique",),
    "rhétoriques": ("rhétorique",),
    "rhéto-romans": ("rhéto-roman",),
    "rhexistasique": ("rhexistasique",),
    "rhexistasiques": ("rhexistasique",),
    "rhinale": ("rhinal",),
    "rhinales": ("rhinal",),
    "rhinal": ("rhinal",),
    "rhinaux": ("rhinal",),
    "rhinencéphalique": ("rhinencéphalique",),
    "rhinencéphaliques": ("rhinencéphalique",),
    "rhinogène": ("rhinogène",),
    "rhinogènes": ("rhinogène",),
    "rhinopharyngien": ("rhinopharyngien",),
    "rhinopharyngienne": ("rhinopharyngien",),
    "rhinopharyngiennes": ("rhinopharyngien",),
    "rhinopharyngiens": ("rhinopharyngien",),
    "rhinoplastique": ("rhinoplastique",),
    "rhinoplastiques": ("rhinoplastique",),
    "rhizocarpique": ("rhizocarpique",),
    "rhizocarpiques": ("rhizocarpique",),
    "rhizogène": ("rhizogène",),
    "rhizogènes": ("rhizogène",),
    "rhizomateuse": ("rhizomateux",),
    "rhizomateuses": ("rhizomateux",),
    "rhizomateux": ("rhizomateux",),
    "rhizomélique": ("rhizomélique",),
    "rhizoméliques": ("rhizomélique",),
    "rhizophage": ("rhizophage",),
    "rhizophages": ("rhizophage",),
    "rhizopodien": ("rhizopodien",),
    "rhizopodienne": ("rhizopodien",),
    "rhizopodiennes": ("rhizopodien",),
    "rhizopodiens": ("rhizopodien",),
    "rhodanien": ("rhodanien",),
    "rhodanienne": ("rhodanien",),
    "rhodaniennes": ("rhodanien",),
    "rhodaniens": ("rhodanien",),
    "rhodaninique": ("rhodaninique",),
    "rhodaniniques": ("rhodaninique",),
    "rhodanique": ("rhodanique",),
    "rhodaniques": ("rhodanique",),
    "rhodésien": ("rhodésien",),
    "rhodésienne": ("rhodésien",),
    "rhodésiennes": ("rhodésien",),
    "rhodésiens": ("rhodésien",),
    "rhodien": ("rhodien",),
    "rhodienne": ("rhodien",),
    "rhodiennes": ("rhodien",),
    "rhodiens": ("rhodien",),
    "rhodique": ("rhodique",),
    "rhodiques": ("rhodique",),
    "rhombencéphalique": ("rhombencéphalique",),
    "rhombencéphaliques": ("rhombencéphalique",),
    "rhombique": ("rhombique",),
    "rhombiques": ("rhombique",),
    "rhomboédrique": ("rhomboédrique",),
    "rhomboédriques": ("rhomboédrique",),
    "rhomboïdale": ("rhomboïdal",),
    "rhomboïdales": ("rhomboïdal",),
    "rhomboïdal": ("rhomboïdal",),
    "rhomboïdaux": ("rhomboïdal",),
    "rhomboïde": ("rhomboïde",),
    "rhomboïdes": ("rhomboïde",),
    "rhumatismale": ("rhumatismal",),
    "rhumatismales": ("rhumatismal",),
    "rhumatismal": ("rhumatismal",),
    "rhumatismaux": ("rhumatismal",),
    "rhumatogène": ("rhumatogène",),
    "rhumatogènes": ("rhumatogène",),
    "rhumatoïde": ("rhumatoïde",),
    "rhumatoïdes": ("rhumatoïde",),
    "rhumatologique": ("rhumatologique",),
    "rhumatologiques": ("rhumatologique",),
    "rhuride": ("rhuride",),
    "rhurides": ("rhuride",),
    "rhyolitique": ("rhyolitique",),
    "rhyolitiques": ("rhyolitique",),
    "ribonique": ("ribonique",),
    "riboniques": ("ribonique",),
    "ribonucléique": ("ribonucléique",),
    "ribonucléiques": ("ribonucléique",),
    "ribosomale": ("ribosomal",),
    "ribosomales": ("ribosomal",),
    "ribosomal": ("ribosomal",),
    "ribosomaux": ("ribosomal",),
    "ribosomique": ("ribosomique",),
    "ribosomiques": ("ribosomique",),
    "ricaneur": ("ricaneur",),
    "ricaneurs": ("ricaneur",),
    "ricaneuse": ("ricaneur",),
    "ricaneuses": ("ricaneur",),
    "riche": ("riche",),
    "riches": ("riche",),
    "richissime": ("richissime",),
    "richissimes": ("richissime",),
    "ricinoléique": ("ricinoléique",),
    "ricinoléiques": ("ricinoléique",),
    "ridicule": ("ridicule",),
    "ridicules": ("ridicule",),
    "riedériforme": ("riedériforme",),
    "riedériformes": ("riedériforme",),
    "riemannien": ("riemannien",),
    "riemannienne": ("riemannien",),
    "riemanniennes": ("riemannien",),
    "riemanniens": ("riemannien",),
    "rieur": ("rieur",),
    "rieurs": ("rieur",),
    "rieuse": ("rieur",),
    "rieuses": ("rieur",),
    "rigide": ("rigide",),
    "rigides": ("rigide",),
    "rigoleur": ("rigoleur",),
    "rigoleurs": ("rigoleur",),
    "rigoleuse": ("rigoleur",),
    "rigoleuses": ("rigoleur",),
    "rigolo": ("rigolo",),
    "rigolos": ("rigolo",),
    "rigolote": ("rigolo",),
    "rigolotes": ("rigolo",),
    "rigoriste": ("rigoriste",),
    "rigoristes": ("rigoriste",),
    "rigoureuse": ("rigoureux",),
    "rigoureuses": ("rigoureux",),
    "rigoureux": ("rigoureux",),
    "rikiki": ("rikiki",),
    "rimbaldien": ("rimbaldien",),
    "rimbaldienne": ("rimbaldien",),
    "rimbaldiennes": ("rimbaldien",),
    "rimbaldiens": ("rimbaldien",),
    "ripuaire": ("ripuaire",),
    "ripuaires": ("ripuaire",),
    "riquiqui": ("riquiqui",),
    "risible": ("risible",),
    "risibles": ("risible",),
    "risquable": ("risquable",),
    "risquables": ("risquable",),
    "rissien": ("rissien",),
    "rissienne": ("rissien",),
    "rissiennes": ("rissien",),
    "rissiens": ("rissien",),
    "ritologique": ("ritologique",),
    "ritologiques": ("ritologique",),
    "ritualiste": ("ritualiste",),
    "ritualistes": ("ritualiste",),
    "rituelle": ("rituel",),
    "rituelles": ("rituel",),
    "rituel": ("rituel",),
    "rituels": ("rituel",),
    "rivale": ("rival",),
    "rivales": ("rival",),
    "rival": ("rival",),
    "rivaux": ("rival",),
    "rivereuse": ("rivereux",),
    "rivereuses": ("rivereux",),
    "rivereux": ("rivereux",),
    "riviéreuse": ("riviéreux",),
    "riviéreuses": ("riviéreux",),
    "riviéreux": ("riviéreux",),
    "rivulaire": ("rivulaire",),
    "rivulaires": ("rivulaire",),
    "rizicole": ("rizicole",),
    "rizicoles": ("rizicole",),
    "rizicultivable": ("rizicultivable",),
    "rizicultivables": ("rizicultivable",),
    "rizière": ("rizier",),
    "rizières": ("rizier",),
    "rizier": ("rizier",),
    "riziers": ("rizier",),
    "riziforme": ("riziforme",),
    "riziformes": ("riziforme",),
    "riziphage": ("riziphage",),
    "riziphages": ("riziphage",),
    "robertsonien": ("robertsonien",),
    "robertsonienne": ("robertsonien",),
    "robertsoniennes": ("robertsonien",),
    "robertsoniens": ("robertsonien",),
    "robertsonnien": ("robertsonnien",),
    "robertsonnienne": ("robertsonnien",),
    "robertsonniennes": ("robertsonnien",),
    "robertsonniens": ("robertsonnien",),
    "roboratif": ("roboratif",),
    "roboratifs": ("roboratif",),
    "roborative": ("roboratif",),
    "roboratives": ("roboratif",),
    "robotique": ("robotique",),
    "robotiques": ("robotique",),
    "robusta": ("robusta",),
    "robuste": ("robuste",),
    "robustes": ("robuste",),
    "rocaille": ("rocaille",),
    "rocailleuse": ("rocailleux",),
    "rocailleuses": ("rocailleux",),
    "rocailleux": ("rocailleux",),
    "rocambolesque": ("rocambolesque",),
    "rocambolesques": ("rocambolesque",),
    "roccellique": ("roccellique",),
    "roccelliques": ("roccellique",),
    "rocheuse": ("rocheux",),
    "rocheuses": ("rocheux",),
    "rocheux": ("rocheux",),
    "rock": ("rock",),
    "rococo": ("rococo",),
    "rôdeur": ("rôdeur",),
    "rôdeurs": ("rôdeur",),
    "rôdeuse": ("rôdeur",),
    "rôdeuses": ("rôdeur",),
    "rodomont": ("rodomont",),
    "rodomonts": ("rodomont",),
    "rogatoire": ("rogatoire",),
    "rogatoires": ("rogatoire",),
    "rogneur": ("rogneur",),
    "rogneurs": ("rogneur",),
    "rogneuse": ("rogneur",),
    "rogneuses": ("rogneur",),
    "rogommeuse": ("rogommeux",),
    "rogommeuses": ("rogommeux",),
    "rogommeux": ("rogommeux",),
    "roguée": ("rogué",),
    "roguées": ("rogué",),
    "rogué": ("rogué",),
    "rogue": ("rogue",),
    "rogués": ("rogué",),
    "rogues": ("rogue",),
    "roide": ("roide",),
    "roides": ("roide",),
    "rolandique": ("rolandique",),
    "rolandiques": ("rolandique",),
    "romaïque": ("romaïque",),
    "romaïques": ("romaïque",),
    "romanesque": ("romanesque",),
    "romanesques": ("romanesque",),
    "romaniste": ("romaniste",),
    "romanistes": ("romaniste",),
    "romanistique": ("romanistique",),
    "romanistiques": ("romanistique",),
    "romantique": ("romantique",),
    "romantiques": ("romantique",),
    "roméique": ("roméique",),
    "roméiques": ("roméique",),
    "ronceuse": ("ronceux",),
    "ronceuses": ("ronceux",),
    "ronceux": ("ronceux",),
    "ronchon": ("ronchon",),
    "ronchons": ("ronchon",),
    "ronchonneur": ("ronchonneur",),
    "ronchonneurs": ("ronchonneur",),
    "ronchonneuse": ("ronchonneur",),
    "ronchonneuses": ("ronchonneur",),
    "rondelet": ("rondelet",),
    "rondelets": ("rondelet",),
    "rondelette": ("rondelet",),
    "rondelettes": ("rondelet",),
    "rongeable": ("rongeable",),
    "rongeables": ("rongeable",),
    "rongeur": ("rongeur",),
    "rongeurs": ("rongeur",),
    "rongeuse": ("rongeur",),
    "rongeuses": ("rongeur",),
    "rosat": ("rosat",),
    "rosâtre": ("rosâtre",),
    "rosâtres": ("rosâtre",),
    "rosée": ("rosé",),
    "rosées": ("rosé",),
    "rosé": ("rosé",),
    "rose": ("rose",),
    "rosés": ("rosé",),
    "roses": ("rose",),
    "roselière": ("roselier",),
    "roselières": ("roselier",),
    "roselier": ("roselier",),
    "roseliers": ("roselier",),
    "rosicrucien": ("rosicrucien",),
    "rosicrucienne": ("rosicrucien",),
    "rosicruciennes": ("rosicrucien",),
    "rosicruciens": ("rosicrucien",),
    "rosse": ("rosse",),
    "rosses": ("rosse",),
    "rossinien": ("rossinien",),
    "rossinienne": ("rossinien",),
    "rossiniennes": ("rossinien",),
    "rossiniens": ("rossinien",),
    "rostrale": ("rostral",),
    "rostrales": ("rostral",),
    "rostral": ("rostral",),
    "rostraux": ("rostral",),
    "rotarien": ("rotarien",),
    "rotarienne": ("rotarien",),
    "rotariennes": ("rotarien",),
    "rotariens": ("rotarien",),
    "rotateur": ("rotateur",),
    "rotateurs": ("rotateur",),
    "rotatrice": ("rotateur",),
    "rotatrices": ("rotateur",),
    "rotatif": ("rotatif",),
    "rotatifs": ("rotatif",),
    "rotative": ("rotatif",),
    "rotatives": ("rotatif",),
    "rotationnelle": ("rotationnel",),
    "rotationnelles": ("rotationnel",),
    "rotationnel": ("rotationnel",),
    "rotationnels": ("rotationnel",),
    "rotatoire": ("rotatoire",),
    "rotatoires": ("rotatoire",),
    "rotorique": ("rotorique",),
    "rotoriques": ("rotorique",),
    "rotulien": ("rotulien",),
    "rotulienne": ("rotulien",),
    "rotuliennes": ("rotulien",),
    "rotuliens": ("rotulien",),
    "roturière": ("roturier",),
    "roturières": ("roturier",),
    "roturier": ("roturier",),
    "roturiers": ("roturier",),
    "rouan": ("rouan",),
    "rouanne": ("rouan",),
    "rouannes": ("rouan",),
    "rouans": ("rouan",),
    "roubaisien": ("roubaisien",),
    "roubaisienne": ("roubaisien",),
    "roubaisiennes": ("roubaisien",),
    "roubaisiens": ("roubaisien",),
    "rouennaise": ("rouennais",),
    "rouennaises": ("rouennais",),
    "rouennais": ("rouennais",),
    "rouge": ("rouge",),
    "rouges": ("rouge",),
    "rougeâtre": ("rougeâtre",),
    "rougeâtres": ("rougeâtre",),
    "rougeoleuse": ("rougeoleux",),
    "rougeoleuses": ("rougeoleux",),
    "rougeoleux": ("rougeoleux",),
    "rouillée": ("rouillé",),
    "rouillées": ("rouillé",),
    "rouillé": ("rouillé",),
    "rouille": ("rouille",),
    "rouillés": ("rouillé",),
    "rouletabillesque": ("rouletabillesque",),
    "rouletabillesques": ("rouletabillesque",),
    "rouleur": ("rouleur",),
    "rouleurs": ("rouleur",),
    "rouleuse": ("rouleur",),
    "rouleuses": ("rouleur",),
    "roumanophone": ("roumanophone",),
    "roumanophones": ("roumanophone",),
    "rouspéteur": ("rouspéteur",),
    "rouspéteurs": ("rouspéteur",),
    "rouspéteuse": ("rouspéteur",),
    "rouspéteuses": ("rouspéteur",),
    "roussâtre": ("roussâtre",),
    "roussâtres": ("roussâtre",),
    "rousseauiste": ("rousseauiste",),
    "rousseauistes": ("rousseauiste",),
    "roussillonnaise": ("roussillonnais",),
    "roussillonnaises": ("roussillonnais",),
    "roussillonnais": ("roussillonnais",),
    "routable": ("routable",),
    "routables": ("routable",),
    "routière": ("routier",),
    "routières": ("routier",),
    "routier": ("routier",),
    "routiers": ("routier",),
    "routinière": ("routinier",),
    "routinières": ("routinier",),
    "routinier": ("routinier",),
    "routiniers": ("routinier",),
    "rouverain": ("rouverain",),
    "rouverains": ("rouverain",),
    "rouverin": ("rouverin",),
    "rouverins": ("rouverin",),
    "rouvieuse": ("rouvieux",),
    "rouvieuses": ("rouvieux",),
    "rouvieux": ("rouvieux",),
    "rouvre": ("rouvre",),
    "rouvres": ("rouvre",),
    "rousse": ("roux",),
    "rousses": ("roux",),
    "roux": ("roux",),
    "royale": ("royal",),
    "royales": ("royal",),
    "royal": ("royal",),
    "royaux": ("royal",),
    "royaliste": ("royaliste",),
    "royalistes": ("royaliste",),
    "ruandaise": ("ruandais",),
    "ruandaises": ("ruandais",),
    "ruandais": ("ruandais",),
    "rubaneur": ("rubaneur",),
    "rubaneurs": ("rubaneur",),
    "rubaneuse": ("rubaneur",),
    "rubaneuses": ("rubaneur",),
    "rubanière": ("rubanier",),
    "rubanières": ("rubanier",),
    "rubanier": ("rubanier",),
    "rubaniers": ("rubanier",),
    "rubénien": ("rubénien",),
    "rubénienne": ("rubénien",),
    "rubéniennes": ("rubénien",),
    "rubéniens": ("rubénien",),
    "rubéoleuse": ("rubéoleux",),
    "rubéoleuses": ("rubéoleux",),
    "rubéoleux": ("rubéoleux",),
    "rubéoliforme": ("rubéoliforme",),
    "rubéoliformes": ("rubéoliforme",),
    "rubéolique": ("rubéolique",),
    "rubéoliques": ("rubéolique",),
    "rubérythrique": ("rubérythrique",),
    "rubérythriques": ("rubérythrique",),
    "rubican": ("rubican",),
    "rubicans": ("rubican",),
    "rubigineuse": ("rubigineux",),
    "rubigineuses": ("rubigineux",),
    "rubigineux": ("rubigineux",),
    "rubis": ("rubis",),
    "rubrothalamique": ("rubrothalamique",),
    "rubrothalamiques": ("rubrothalamique",),
    "rucheuse": ("rucheux",),
    "rucheuses": ("rucheux",),
    "rucheux": ("rucheux",),
    "rude": ("rude",),
    "rudes": ("rude",),
    "rudérale": ("rudéral",),
    "rudérales": ("rudéral",),
    "rudéral": ("rudéral",),
    "rudéraux": ("rudéral",),
    "rudimentaire": ("rudimentaire",),
    "rudimentaires": ("rudimentaire",),
    "rudolphine": ("rudolphine",),
    "rudolphines": ("rudolphine",),
    "rufigallique": ("rufigallique",),
    "rufigalliques": ("rufigallique",),
    "rugbystique": ("rugbystique",),
    "rugbystiques": ("rugbystique",),
    "rugueuse": ("rugueux",),
    "rugueuses": ("rugueux",),
    "rugueux": ("rugueux",),
    "ruineuse": ("ruineux",),
    "ruineuses": ("ruineux",),
    "ruineux": ("ruineux",),
    "ruiniforme": ("ruiniforme",),
    "ruiniformes": ("ruiniforme",),
    "ruminale": ("ruminal",),
    "ruminales": ("ruminal",),
    "ruminal": ("ruminal",),
    "ruminaux": ("ruminal",),
    "runique": ("runique",),
    "runiques": ("runique",),
    "rupestre": ("rupestre",),
    "rupestres": ("rupestre",),
    "rupicole": ("rupicole",),
    "rupicoles": ("rupicole",),
    "rupioïde": ("rupioïde",),
    "rupioïdes": ("rupioïde",),
    "rurale": ("rural",),
    "rurales": ("rural",),
    "rural": ("rural",),
    "ruraux": ("rural",),
    "russe": ("russe",),
    "russes": ("russe",),
    "russien": ("russien",),
    "russienne": ("russien",),
    "russiennes": ("russien",),
    "russiens": ("russien",),
    "russo-japonaise": ("russo-japonais",),
    "russo-japonais": ("russo-japonais",),
    "russophile": ("russophile",),
    "russophiles": ("russophile",),
    "russophone": ("russophone",),
    "russophones": ("russophone",),
    "rustique": ("rustique",),
    "rustiques": ("rustique",),
    "rustre": ("rustre",),
    "rustres": ("rustre",),
    "ruthène": ("ruthène",),
    "ruthènes": ("ruthène",),
    "ruthénique": ("ruthénique",),
    "ruthéniques": ("ruthénique",),
    "rwandaise": ("rwandais",),
    "rwandaises": ("rwandais",),
    "rwandais": ("rwandais",),
    "rythmique": ("rythmique",),
    "rythmiques": ("rythmique",),
    "sabbathien": ("sabbathien",),
    "sabbathienne": ("sabbathien",),
    "sabbathiennes": ("sabbathien",),
    "sabbathiens": ("sabbathien",),
    "sabbatique": ("sabbatique",),
    "sabbatiques": ("sabbatique",),
    "sabéen": ("sabéen",),
    "sabéenne": ("sabéen",),
    "sabéennes": ("sabéen",),
    "sabéens": ("sabéen",),
    "sabellique": ("sabellique",),
    "sabelliques": ("sabellique",),
    "sablée": ("sablé",),
    "sablées": ("sablé",),
    "sablé": ("sablé",),
    "sable": ("sable",),
    "sablés": ("sablé",),
    "sableuse": ("sableux",),
    "sableuses": ("sableux",),
    "sableux": ("sableux",),
    "sablonneuse": ("sablonneux",),
    "sablonneuses": ("sablonneux",),
    "sablonneux": ("sablonneux",),
    "sabra": ("sabra",),
    "sabras": ("sabra",),
    "saburrale": ("saburral",),
    "saburrales": ("saburral",),
    "saburral": ("saburral",),
    "saburraux": ("saburral",),
    "saccageur": ("saccageur",),
    "saccageurs": ("saccageur",),
    "saccageuse": ("saccageur",),
    "saccageuses": ("saccageur",),
    "sacchareuse": ("sacchareux",),
    "sacchareuses": ("sacchareux",),
    "sacchareux": ("sacchareux",),
    "saccharifère": ("saccharifère",),
    "saccharifères": ("saccharifère",),
    "saccharifiable": ("saccharifiable",),
    "saccharifiables": ("saccharifiable",),
    "saccharimétrique": ("saccharimétrique",),
    "saccharimétriques": ("saccharimétrique",),
    "saccharinique": ("saccharinique",),
    "sacchariniques": ("saccharinique",),
    "saccharique": ("saccharique",),
    "sacchariques": ("saccharique",),
    "saccharoïde": ("saccharoïde",),
    "saccharoïdes": ("saccharoïde",),
    "sacciforme": ("sacciforme",),
    "sacciformes": ("sacciforme",),
    "sacculaire": ("sacculaire",),
    "sacculaires": ("sacculaire",),
    "sacculiforme": ("sacculiforme",),
    "sacculiformes": ("sacculiforme",),
    "sacerdotale": ("sacerdotal",),
    "sacerdotales": ("sacerdotal",),
    "sacerdotal": ("sacerdotal",),
    "sacerdotaux": ("sacerdotal",),
    "sacrale": ("sacral",),
    "sacrales": ("sacral",),
    "sacral": ("sacral",),
    "sacraux": ("sacral",),
    "sacramentaire": ("sacramentaire",),
    "sacramentaires": ("sacramentaire",),
    "sacramentale": ("sacramental",),
    "sacramentales": ("sacramental",),
    "sacramental": ("sacramental",),
    "sacramentaux": ("sacramental",),
    "sacramentelle": ("sacramentel",),
    "sacramentelles": ("sacramentel",),
    "sacramentel": ("sacramentel",),
    "sacramentels": ("sacramentel",),
    "sacrificatoire": ("sacrificatoire",),
    "sacrificatoires": ("sacrificatoire",),
    "sacrificielle": ("sacrificiel",),
    "sacrificielles": ("sacrificiel",),
    "sacrificiel": ("sacrificiel",),
    "sacrificiels": ("sacrificiel",),
    "sacrilège": ("sacrilège",),
    "sacrilèges": ("sacrilège",),
    "sacro-coccygien": ("sacro-coccygien",),
    "sacrococcygien": ("sacrococcygien",),
    "sacrococcygienne": ("sacrococcygien",),
    "sacrococcygiennes": ("sacrococcygien",),
    "sacro-coccygiens": ("sacro-coccygien",),
    "sacrococcygiens": ("sacrococcygien",),
    "sacro-lombaire": ("sacro-lombaire",),
    "sacro-sainte": ("sacro-saint",),
    "sacro-saintes": ("sacro-saint",),
    "sacro-saint": ("sacro-saint",),
    "sacro-saints": ("sacro-saint",),
    "sacro-sciatiques": ("sacro-sciatique",),
    "sadducéen": ("sadducéen",),
    "sadducéenne": ("sadducéen",),
    "sadducéennes": ("sadducéen",),
    "sadducéens": ("sadducéen",),
    "sadique": ("sadique",),
    "sadiques": ("sadique",),
    "sado": ("sado",),
    "sados": ("sado",),
    "sadomasochiste": ("sadomasochiste",),
    "sadomasochistes": ("sadomasochiste",),
    "saducéen": ("saducéen",),
    "saducéenne": ("saducéen",),
    "saducéennes": ("saducéen",),
    "saducéens": ("saducéen",),
    "safran": ("safran",),
    "sagace": ("sagace",),
    "sagaces": ("sagace",),
    "sage": ("sage",),
    "sages": ("sage",),
    "sagittale": ("sagittal",),
    "sagittales": ("sagittal",),
    "sagittal": ("sagittal",),
    "sagittaux": ("sagittal",),
    "saharien": ("saharien",),
    "saharienne": ("saharien",),
    "sahariennes": ("saharien",),
    "sahariens": ("saharien",),
    "sahélien": ("sahélien",),
    "sahélienne": ("sahélien",),
    "sahéliennes": ("sahélien",),
    "sahéliens": ("sahélien",),
    "saigneuse": ("saigneux",),
    "saigneuses": ("saigneux",),
    "saigneux": ("saigneux",),
    "saisissable": ("saisissable",),
    "saisissables": ("saisissable",),
    "saisonnière": ("saisonnier",),
    "saisonnières": ("saisonnier",),
    "saisonnier": ("saisonnier",),
    "saisonniers": ("saisonnier",),
    "saïte": ("saïte",),
    "saïtes": ("saïte",),
    "salace": ("salace",),
    "salaces": ("salace",),
    "salariale": ("salarial",),
    "salariales": ("salarial",),
    "salarial": ("salarial",),
    "salariaux": ("salarial",),
    "salaud": ("salaud",),
    "salauds": ("salaud",),
    "salazariste": ("salazariste",),
    "salazaristes": ("salazariste",),
    "salée": ("salé",),
    "salées": ("salé",),
    "salé": ("salé",),
    "sale": ("sale",),
    "salés": ("salé",),
    "sales": ("sale",),
    "salésien": ("salésien",),
    "salésienne": ("salésien",),
    "salésiennes": ("salésien",),
    "salésiens": ("salésien",),
    "salicole": ("salicole",),
    "salicoles": ("salicole",),
    "salicylique": ("salicylique",),
    "salicyliques": ("salicylique",),
    "salidiurétique": ("salidiurétique",),
    "salidiurétiques": ("salidiurétique",),
    "salien": ("salien",),
    "salienne": ("salien",),
    "saliennes": ("salien",),
    "saliens": ("salien",),
    "salifère": ("salifère",),
    "salifères": ("salifère",),
    "salifiable": ("salifiable",),
    "salifiables": ("salifiable",),
    "salingue": ("salingue",),
    "salingues": ("salingue",),
    "salinière": ("salinier",),
    "salinières": ("salinier",),
    "salinier": ("salinier",),
    "saliniers": ("salinier",),
    "salique": ("salique",),
    "saliques": ("salique",),
    "salissable": ("salissable",),
    "salissables": ("salissable",),
    "salivaire": ("salivaire",),
    "salivaires": ("salivaire",),
    "salonnière": ("salonnier",),
    "salonnières": ("salonnier",),
    "salonnier": ("salonnier",),
    "salonniers": ("salonnier",),
    "salope": ("salope",),
    "salopes": ("salope",),
    "salpêtreuse": ("salpêtreux",),
    "salpêtreuses": ("salpêtreux",),
    "salpêtreux": ("salpêtreux",),
    "salpingien": ("salpingien",),
    "salpingienne": ("salpingien",),
    "salpingiennes": ("salpingien",),
    "salpingiens": ("salpingien",),
    "salsodique": ("salsodique",),
    "salsodiques": ("salsodique",),
    "saltatoire": ("saltatoire",),
    "saltatoires": ("saltatoire",),
    "salubre": ("salubre",),
    "salubres": ("salubre",),
    "salurétique": ("salurétique",),
    "salurétiques": ("salurétique",),
    "salutaire": ("salutaire",),
    "salutaires": ("salutaire",),
    "salutiste": ("salutiste",),
    "salutistes": ("salutiste",),
    "salvadorien": ("salvadorien",),
    "salvadorienne": ("salvadorien",),
    "salvadoriennes": ("salvadorien",),
    "salvadoriens": ("salvadorien",),
    "salvateur": ("salvateur",),
    "salvateurs": ("salvateur",),
    "salvatrice": ("sauveur",),
    "salvatrices": ("sauveur",),
    "salzbourgeoise": ("salzbourgeois",),
    "salzbourgeoises": ("salzbourgeois",),
    "salzbourgeois": ("salzbourgeois",),
    "samartien": ("samartien",),
    "samartienne": ("samartien",),
    "samartiennes": ("samartien",),
    "samartiens": ("samartien",),
    "samnite": ("samnite",),
    "samnites": ("samnite",),
    "samoyède": ("samoyède",),
    "samoyèdes": ("samoyède",),
    "sanatoriale": ("sanatorial",),
    "sanatoriales": ("sanatorial",),
    "sanatorial": ("sanatorial",),
    "sanatoriaux": ("sanatorial",),
    "sanctificateur": ("sanctificateur",),
    "sanctificateurs": ("sanctificateur",),
    "sanctificatrice": ("sanctificateur",),
    "sanctificatrices": ("sanctificateur",),
    "sanctionnable": ("sanctionnable",),
    "sanctionnables": ("sanctionnable",),
    "sanctionnateur": ("sanctionnateur",),
    "sanctionnateurs": ("sanctionnateur",),
    "sanctionnatrice": ("sanctionnateur",),
    "sanctionnatrices": ("sanctionnateur",),
    "sandaracopimarique": ("sandaracopimarique",),
    "sandaracopimariques": ("sandaracopimarique",),
    "sandiniste": ("sandiniste",),
    "sandinistes": ("sandiniste",),
    "sanfédiste": ("sanfédiste",),
    "sanfédistes": ("sanfédiste",),
    "sanguicole": ("sanguicole",),
    "sanguicoles": ("sanguicole",),
    "sanguinaire": ("sanguinaire",),
    "sanguinaires": ("sanguinaire",),
    "sanidinite": ("sanidinite",),
    "sanidinites": ("sanidinite",),
    "sanieuse": ("sanieux",),
    "sanieuses": ("sanieux",),
    "sanieux": ("sanieux",),
    "sanitaire": ("sanitaire",),
    "sanitaires": ("sanitaire",),
    "sanscritique": ("sanscritique",),
    "sanscritiques": ("sanscritique",),
    "sanskritique": ("sanskritique",),
    "sanskritiques": ("sanskritique",),
    "santaféen": ("santaféen",),
    "santaféenne": ("santaféen",),
    "santaféennes": ("santaféen",),
    "santaféens": ("santaféen",),
    "santoninique": ("santoninique",),
    "santoniniques": ("santoninique",),
    "saoudien": ("saoudien",),
    "saoudienne": ("saoudien",),
    "saoudiennes": ("saoudien",),
    "saoudiens": ("saoudien",),
    "saoudite": ("saoudite",),
    "saoudites": ("saoudite",),
    "saphène": ("saphène",),
    "saphènes": ("saphène",),
    "saphique": ("saphique",),
    "saphiques": ("saphique",),
    "sapide": ("sapide",),
    "sapides": ("sapide",),
    "sapiens": ("sapiens",),
    "sapientiale": ("sapiential",),
    "sapientiales": ("sapiential",),
    "sapiential": ("sapiential",),
    "sapientiaux": ("sapientiel",),
    "sapientielle": ("sapientiel",),
    "sapientielles": ("sapientiel",),
    "sapientiel": ("sapientiel",),
    "saponifiable": ("saponifiable",),
    "saponifiables": ("saponifiable",),
    "saprogène": ("saprogène",),
    "saprogènes": ("saprogène",),
    "sapropélique": ("sapropélique",),
    "sapropéliques": ("sapropélique",),
    "saprophage": ("saprophage",),
    "saprophages": ("saprophage",),
    "saprophyte": ("saprophyte",),
    "saprophytes": ("saprophyte",),
    "saprophytique": ("saprophytique",),
    "saprophytiques": ("saprophytique",),
    "saproxylique": ("saproxylique",),
    "saproxyliques": ("saproxylique",),
    "sarcastique": ("sarcastique",),
    "sarcastiques": ("sarcastique",),
    "sarcoïde": ("sarcoïde",),
    "sarcoïdes": ("sarcoïde",),
    "sarcoïdosique": ("sarcoïdosique",),
    "sarcoïdosiques": ("sarcoïdosique",),
    "sarcomateuse": ("sarcomateux",),
    "sarcomateuses": ("sarcomateux",),
    "sarcomateux": ("sarcomateux",),
    "sarcomatogène": ("sarcomatogène",),
    "sarcomatogènes": ("sarcomatogène",),
    "sarcoplasmique": ("sarcoplasmique",),
    "sarcoplasmiques": ("sarcoplasmique",),
    "sarcoplastique": ("sarcoplastique",),
    "sarcoplastiques": ("sarcoplastique",),
    "sarcoptique": ("sarcoptique",),
    "sarcoptiques": ("sarcoptique",),
    "sardanapalesque": ("sardanapalesque",),
    "sardanapalesques": ("sardanapalesque",),
    "sarde": ("sarde",),
    "sardes": ("sarde",),
    "sardinière": ("sardinier",),
    "sardinières": ("sardinier",),
    "sardinier": ("sardinier",),
    "sardiniers": ("sardinier",),
    "sardonique": ("sardonique",),
    "sardoniques": ("sardonique",),
    "sarmate": ("sarmate",),
    "sarmates": ("sarmate",),
    "sarmatique": ("sarmatique",),
    "sarmatiques": ("sarmatique",),
    "sarmenteuse": ("sarmenteux",),
    "sarmenteuses": ("sarmenteux",),
    "sarmenteux": ("sarmenteux",),
    "sarracénique": ("sarracénique",),
    "sarracéniques": ("sarracénique",),
    "sarroise": ("sarrois",),
    "sarroises": ("sarrois",),
    "sarrois": ("sarrois",),
    "sarthoise": ("sarthois",),
    "sarthoises": ("sarthois",),
    "sarthois": ("sarthois",),
    "sartrien": ("sartrien",),
    "sartrienne": ("sartrien",),
    "sartriennes": ("sartrien",),
    "sartriens": ("sartrien",),
    "sassable": ("sassable",),
    "sassables": ("sassable",),
    "sassanide": ("sassanide",),
    "sassanides": ("sassanide",),
    "satanique": ("satanique",),
    "sataniques": ("satanique",),
    "sataniste": ("sataniste",),
    "satanistes": ("sataniste",),
    "satellisable": ("satellisable",),
    "satellisables": ("satellisable",),
    "satellitaire": ("satellitaire",),
    "satellitaires": ("satellitaire",),
    "satineur": ("satineur",),
    "satineurs": ("satineur",),
    "satineuse": ("satineur",),
    "satineuses": ("satineur",),
    "satirique": ("satirique",),
    "satiriques": ("satirique",),
    "satisfactoire": ("satisfactoire",),
    "satisfactoires": ("satisfactoire",),
    "satisfiable": ("satisfiable",),
    "satisfiables": ("satisfiable",),
    "satrapique": ("satrapique",),
    "satrapiques": ("satrapique",),
    "saturable": ("saturable",),
    "saturables": ("saturable",),
    "saturnien": ("saturnien",),
    "saturnienne": ("saturnien",),
    "saturniennes": ("saturnien",),
    "saturniens": ("saturnien",),
    "satyrique": ("satyrique",),
    "satyriques": ("satyrique",),
    "sauf": ("sauf",),
    "saufs": ("sauf",),
    "sauve": ("sauf",),
    "sauves": ("sauf",),
    "saumâtre": ("saumâtre",),
    "saumâtres": ("saumâtre",),
    "saumon": ("saumon",),
    "saupoudreur": ("saupoudreur",),
    "saupoudreurs": ("saupoudreur",),
    "saupoudreuse": ("saupoudreur",),
    "saupoudreuses": ("saupoudreur",),
    "saur": ("saur",),
    "saurs": ("saur",),
    "sauret": ("sauret",),
    "saurets": ("sauret",),
    "saurien": ("saurien",),
    "sauriens": ("saurien",),
    "saurisseur": ("saurisseur",),
    "saurisseurs": ("saurisseur",),
    "saurisseuse": ("saurisseur",),
    "saurisseuses": ("saurisseur",),
    "sauteur": ("sauteur",),
    "sauteurs": ("sauteur",),
    "sauteuse": ("sauteur",),
    "sauteuses": ("sauteur",),
    "sauvable": ("sauvable",),
    "sauvables": ("sauvable",),
    "sauvage": ("sauvage",),
    "sauvages": ("sauvage",),
    "sauvageon": ("sauvageon",),
    "sauvageonne": ("sauvageon",),
    "sauvageonnes": ("sauvageon",),
    "sauvageons": ("sauvageon",),
    "sauveterrien": ("sauveterrien",),
    "sauveterrienne": ("sauveterrien",),
    "sauveterriennes": ("sauveterrien",),
    "sauveterriens": ("sauveterrien",),
    "sauveteur": ("sauveteur",),
    "sauveteurs": ("sauveteur",),
    "sauveteuse": ("sauveteur",),
    "sauveteuses": ("sauveteur",),
    "sauveur": ("sauveur",),
    "sauveurs": ("sauveur",),
    "savoisien": ("savoisien",),
    "savoisienne": ("savoisien",),
    "savoisiennes": ("savoisien",),
    "savoisiens": ("savoisien",),
    "savonneuse": ("savonneux",),
    "savonneuses": ("savonneux",),
    "savonneux": ("savonneux",),
    "savonnière": ("savonnier",),
    "savonnières": ("savonnier",),
    "savonnier": ("savonnier",),
    "savonniers": ("savonnier",),
    "savoureuse": ("savoureux",),
    "savoureuses": ("savoureux",),
    "savoureux": ("savoureux",),
    "saxatile": ("saxatile",),
    "saxatiles": ("saxatile",),
    "saxicole": ("saxicole",),
    "saxicoles": ("saxicole",),
    "saxon": ("saxon",),
    "saxonne": ("saxon",),
    "saxonnes": ("saxon",),
    "saxons": ("saxon",),
    "scabieuse": ("scabieux",),
    "scabieuses": ("scabieux",),
    "scabieux": ("scabieux",),
    "scabre": ("scabre",),
    "scabres": ("scabre",),
    "scabreuse": ("scabreux",),
    "scabreuses": ("scabreux",),
    "scabreux": ("scabreux",),
    "scalaire": ("scalaire",),
    "scalaires": ("scalaire",),
    "scaldien": ("scaldien",),
    "scaldienne": ("scaldien",),
    "scaldiennes": ("scaldien",),
    "scaldiens": ("scaldien",),
    "scalène": ("scalène",),
    "scalènes": ("scalène",),
    "scandaleuse": ("scandaleux",),
    "scandaleuses": ("scandaleux",),
    "scandaleux": ("scandaleux",),
    "scandinave": ("scandinave",),
    "scandinaves": ("scandinave",),
    "scandinaviste": ("scandinaviste",),
    "scandinavistes": ("scandinaviste",),
    "scannographique": ("scannographique",),
    "scannographiques": ("scannographique",),
    "scanographique": ("scanographique",),
    "scanographiques": ("scanographique",),
    "scaphoïde": ("scaphoïde",),
    "scaphoïdes": ("scaphoïde",),
    "scapulaire": ("scapulaire",),
    "scapulaires": ("scapulaire",),
    "scapulo-humoral": ("scapulo-humoral",),
    "scapulo-humoraux": ("scapulo-humoral",),
    "scapulo-thoraciques": ("scapulo-thoracique",),
    "scarieuse": ("scarieux",),
    "scarieuses": ("scarieux",),
    "scarieux": ("scarieux",),
    "scarlatineuse": ("scarlatineux",),
    "scarlatineuses": ("scarlatineux",),
    "scarlatineux": ("scarlatineux",),
    "scarlatiniforme": ("scarlatiniforme",),
    "scarlatiniformes": ("scarlatiniforme",),
    "scarlatinoïde": ("scarlatinoïde",),
    "scarlatinoïdes": ("scarlatinoïde",),
    "scatologique": ("scatologique",),
    "scatologiques": ("scatologique",),
    "scatophage": ("scatophage",),
    "scatophages": ("scatophage",),
    "scatophile": ("scatophile",),
    "scatophiles": ("scatophile",),
    "scénique": ("scénique",),
    "scéniques": ("scénique",),
    "scénographique": ("scénographique",),
    "scénographiques": ("scénographique",),
    "sceptique": ("sceptique",),
    "sceptiques": ("sceptique",),
    "schelem": ("schelem",),
    "schématique": ("schématique",),
    "schématiques": ("schématique",),
    "schipperke": ("schipperke",),
    "schipperkes": ("schipperke",),
    "schismatique": ("schismatique",),
    "schismatiques": ("schismatique",),
    "schisteuse": ("schisteux",),
    "schisteuses": ("schisteux",),
    "schisteux": ("schisteux",),
    "schistoïde": ("schistoïde",),
    "schistoïdes": ("schistoïde",),
    "schizo": ("schizo",),
    "schizos": ("schizo",),
    "schizogonique": ("schizogonique",),
    "schizogoniques": ("schizogonique",),
    "schizoïde": ("schizoïde",),
    "schizoïdes": ("schizoïde",),
    "schizomaniaque": ("schizomaniaque",),
    "schizomaniaques": ("schizomaniaque",),
    "schizonticide": ("schizonticide",),
    "schizonticides": ("schizonticide",),
    "schizontocide": ("schizontocide",),
    "schizontocides": ("schizontocide",),
    "schizophasique": ("schizophasique",),
    "schizophasiques": ("schizophasique",),
    "schizophrène": ("schizophrène",),
    "schizophrènes": ("schizophrène",),
    "schizophrénique": ("schizophrénique",),
    "schizophréniques": ("schizophrénique",),
    "schizothyme": ("schizothyme",),
    "schizothymes": ("schizothyme",),
    "schizothymique": ("schizothymique",),
    "schizothymiques": ("schizothymique",),
    "schlagueur": ("schlagueur",),
    "schlagueurs": ("schlagueur",),
    "schlammeuse": ("schlammeux",),
    "schlammeuses": ("schlammeux",),
    "schlammeux": ("schlammeux",),
    "schlass": ("schlass",),
    "schwannien": ("schwannien",),
    "schwannienne": ("schwannien",),
    "schwanniennes": ("schwannien",),
    "schwanniens": ("schwannien",),
    "sciable": ("sciable",),
    "sciables": ("sciable",),
    "sciagraphique": ("sciagraphique",),
    "sciagraphiques": ("sciagraphique",),
    "scialytique": ("scialytique",),
    "scialytiques": ("scialytique",),
    "sciaphile": ("sciaphile",),
    "sciaphiles": ("sciaphile",),
    "sciasphérique": ("sciasphérique",),
    "sciasphériques": ("sciasphérique",),
    "sciatalgique": ("sciatalgique",),
    "sciatalgiques": ("sciatalgique",),
    "sciatique": ("sciatique",),
    "sciatiques": ("sciatique",),
    "scientifique": ("scientifique",),
    "scientifiques": ("scientifique",),
    "scientiste": ("scientiste",),
    "scientistes": ("scientiste",),
    "scientologique": ("scientologique",),
    "scientologiques": ("scientologique",),
    "scillitique": ("scillitique",),
    "scillitiques": ("scillitique",),
    "scindable": ("scindable",),
    "scindables": ("scindable",),
    "sciographique": ("sciographique",),
    "sciographiques": ("sciographique",),
    "scissile": ("scissile",),
    "scissiles": ("scissile",),
    "scissionnaire": ("scissionnaire",),
    "scissionnaires": ("scissionnaire",),
    "scissionniste": ("scissionniste",),
    "scissionnistes": ("scissionniste",),
    "scissipare": ("scissipare",),
    "scissipares": ("scissipare",),
    "sclérale": ("scléral",),
    "sclérales": ("scléral",),
    "scléral": ("scléral",),
    "scléraux": ("scléral",),
    "sclérenchymateuse": ("sclérenchymateux",),
    "sclérenchymateuses": ("sclérenchymateux",),
    "sclérenchymateux": ("sclérenchymateux",),
    "scléreuse": ("scléreux",),
    "scléreuses": ("scléreux",),
    "scléreux": ("scléreux",),
    "sclérodermiforme": ("sclérodermiforme",),
    "sclérodermiformes": ("sclérodermiforme",),
    "sclérogène": ("sclérogène",),
    "sclérogènes": ("sclérogène",),
    "sclérophylle": ("sclérophylle",),
    "sclérophylles": ("sclérophylle",),
    "sclérotomiale": ("sclérotomial",),
    "sclérotomiales": ("sclérotomial",),
    "sclérotomial": ("sclérotomial",),
    "sclérotomiaux": ("sclérotomial",),
    "scolaire": ("scolaire",),
    "scolaires": ("scolaire",),
    "scolarisable": ("scolarisable",),
    "scolarisables": ("scolarisable",),
    "scolastique": ("scolastique",),
    "scolastiques": ("scolastique",),
    "scoliotique": ("scoliotique",),
    "scoliotiques": ("scoliotique",),
    "scolopidien": ("scolopidien",),
    "scolopidienne": ("scolopidien",),
    "scolopidiennes": ("scolopidien",),
    "scolopidiens": ("scolopidien",),
    "scoptophilique": ("scoptophilique",),
    "scoptophiliques": ("scoptophilique",),
    "scorbutique": ("scorbutique",),
    "scorbutiques": ("scorbutique",),
    "scorpioïde": ("scorpioïde",),
    "scorpioïdes": ("scorpioïde",),
    "scotiste": ("scotiste",),
    "scotistes": ("scotiste",),
    "scotopique": ("scotopique",),
    "scotopiques": ("scotopique",),
    "scratch": ("scratch",),
    "scripophilique": ("scripophilique",),
    "scripophiliques": ("scripophilique",),
    "scripturaire": ("scripturaire",),
    "scripturaires": ("scripturaire",),
    "scripturale": ("scriptural",),
    "scripturales": ("scriptural",),
    "scriptural": ("scriptural",),
    "scripturaux": ("scriptural",),
    "scrofuleuse": ("scrofuleux",),
    "scrofuleuses": ("scrofuleux",),
    "scrofuleux": ("scrofuleux",),
    "scrotale": ("scrotal",),
    "scrotales": ("scrotal",),
    "scrotal": ("scrotal",),
    "scrotaux": ("scrotal",),
    "scrupuleuse": ("scrupuleux",),
    "scrupuleuses": ("scrupuleux",),
    "scrupuleux": ("scrupuleux",),
    "scrutateur": ("scrutateur",),
    "scrutateurs": ("scrutateur",),
    "scrutatrice": ("scrutateur",),
    "scrutatrices": ("scrutateur",),
    "sculpturale": ("sculptural",),
    "sculpturales": ("sculptural",),
    "sculptural": ("sculptural",),
    "sculpturaux": ("sculptural",),
    "scutellaire": ("scutellaire",),
    "scutellaires": ("scutellaire",),
    "scutiforme": ("scutiforme",),
    "scutiformes": ("scutiforme",),
    "scutulaire": ("scutulaire",),
    "scutulaires": ("scutulaire",),
    "scythe": ("scythe",),
    "scythes": ("scythe",),
    "scythique": ("scythique",),
    "scythiques": ("scythique",),
    "sébacique": ("sébacique",),
    "sébaciques": ("sébacique",),
    "séborrhéique": ("séborrhéique",),
    "séborrhéiques": ("séborrhéique",),
    "sécable": ("sécable",),
    "sécables": ("sécable",),
    "sèche": ("sec",),
    "sèches": ("sec",),
    "sec": ("sec",),
    "secs": ("sec",),
    "sécessionniste": ("sécessionniste",),
    "sécessionnistes": ("sécessionniste",),
    "sécheur": ("sécheur",),
    "sécheurs": ("sécheur",),
    "sécheuse": ("sécheur",),
    "sécheuses": ("sécheur",),
    "secondaire": ("secondaire",),
    "secondaires": ("secondaire",),
    "secondigeste": ("secondigeste",),
    "secondigestes": ("secondigeste",),
    "secondipare": ("secondipare",),
    "secondipares": ("secondipare",),
    "secourable": ("secourable",),
    "secourables": ("secourable",),
    "secoureur": ("secoureur",),
    "secoureurs": ("secoureur",),
    "secoureuse": ("secoureur",),
    "secoureuses": ("secoureur",),
    "sécrétagogue": ("sécrétagogue",),
    "sécrétagogues": ("sécrétagogue",),
    "secrète": ("secret",),
    "secrètes": ("secret",),
    "secret": ("secret",),
    "secrets": ("secret",),
    "sécréteur": ("sécréteur",),
    "sécréteurs": ("sécréteur",),
    "sécréteuse": ("sécréteur",),
    "sécréteuses": ("sécréteur",),
    "sécrétrice": ("sécréteur",),
    "sécrétrices": ("sécréteur",),
    "sécrétoire": ("sécrétoire",),
    "sécrétoires": ("sécrétoire",),
    "sectaire": ("sectaire",),
    "sectaires": ("sectaire",),
    "sectile": ("sectile",),
    "sectiles": ("sectile",),
    "sectorale": ("sectoral",),
    "sectorales": ("sectoral",),
    "sectoral": ("sectoral",),
    "sectoraux": ("sectoral",),
    "sectoriale": ("sectorial",),
    "sectoriales": ("sectorial",),
    "sectorial": ("sectorial",),
    "sectoriaux": ("sectorial",),
    "sectorielle": ("sectoriel",),
    "sectorielles": ("sectoriel",),
    "sectoriel": ("sectoriel",),
    "sectoriels": ("sectoriel",),
    "séculaire": ("séculaire",),
    "séculaires": ("séculaire",),
    "séculière": ("séculier",),
    "séculières": ("séculier",),
    "séculier": ("séculier",),
    "séculiers": ("séculier",),
    "sécure": ("sécure",),
    "sécures": ("sécure",),
    "sécuritaire": ("sécuritaire",),
    "sécuritaires": ("sécuritaire",),
    "sédalonique": ("sédalonique",),
    "sédaloniques": ("sédalonique",),
    "sédatif": ("sédatif",),
    "sédatifs": ("sédatif",),
    "sédative": ("sédatif",),
    "sédatives": ("sédatif",),
    "sédélocien": ("sédélocien",),
    "sédélocienne": ("sédélocien",),
    "sédélociennes": ("sédélocien",),
    "sédélociens": ("sédélocien",),
    "sédentaire": ("sédentaire",),
    "sédentaires": ("sédentaire",),
    "sédimentaire": ("sédimentaire",),
    "sédimentaires": ("sédimentaire",),
    "sédimenteuse": ("sédimenteux",),
    "sédimenteuses": ("sédimenteux",),
    "sédimenteux": ("sédimenteux",),
    "sédimentologique": ("sédimentologique",),
    "sédimentologiques": ("sédimentologique",),
    "séditieuse": ("séditieux",),
    "séditieuses": ("séditieux",),
    "séditieux": ("séditieux",),
    "séducteur": ("séducteur",),
    "séducteurs": ("séducteur",),
    "séductrice": ("séducteur",),
    "séductrices": ("séducteur",),
    "séductible": ("séductible",),
    "séductibles": ("séductible",),
    "sefaraddim": ("sefaraddi",),
    "sefaraddi": ("sefaraddi",),
    "séfarade": ("séfarade",),
    "séfarades": ("séfarade",),
    "sefardim": ("sefardi",),
    "sefardi": ("sefardi",),
    "séfardite": ("séfardite",),
    "séfardites": ("séfardite",),
    "segmentaire": ("segmentaire",),
    "segmentaires": ("segmentaire",),
    "segmentale": ("segmental",),
    "segmentales": ("segmental",),
    "segmental": ("segmental",),
    "segmentaux": ("segmental",),
    "ségrégable": ("ségrégable",),
    "ségrégables": ("ségrégable",),
    "ségrégatif": ("ségrégatif",),
    "ségrégatifs": ("ségrégatif",),
    "ségrégative": ("ségrégatif",),
    "ségrégatives": ("ségrégatif",),
    "ségrégationniste": ("ségrégationniste",),
    "ségrégationnistes": ("ségrégationniste",),
    "seigneuriale": ("seigneurial",),
    "seigneuriales": ("seigneurial",),
    "seigneurial": ("seigneurial",),
    "seigneuriaux": ("seigneurial",),
    "seineur": ("seineur",),
    "seineurs": ("seineur",),
    "seineuse": ("seineur",),
    "seineuses": ("seineur",),
    "séismale": ("séismal",),
    "séismales": ("séismal",),
    "séismal": ("séismal",),
    "séismaux": ("séismal",),
    "séismique": ("séismique",),
    "séismiques": ("séismique",),
    "séismogénique": ("séismogénique",),
    "séismogéniques": ("séismogénique",),
    "séismographique": ("séismographique",),
    "séismographiques": ("séismographique",),
    "séismologique": ("séismologique",),
    "séismologiques": ("séismologique",),
    "seizième": ("seizième",),
    "seizièmes": ("seizième",),
    "seiziémiste": ("seiziémiste",),
    "seiziémistes": ("seiziémiste",),
    "sélacien": ("sélacien",),
    "sélacienne": ("sélacien",),
    "sélaciennes": ("sélacien",),
    "sélaciens": ("sélacien",),
    "sélectable": ("sélectable",),
    "sélectables": ("sélectable",),
    "sélecte": ("sélect",),
    "sélectes": ("sélect",),
    "sélect": ("sélect",),
    "select": ("select",),
    "sélects": ("sélect",),
    "sélecteur": ("sélecteur",),
    "sélecteurs": ("sélecteur",),
    "sélectrice": ("sélecteur",),
    "sélectrices": ("sélecteur",),
    "sélectif": ("sélectif",),
    "sélectifs": ("sélectif",),
    "sélective": ("sélectif",),
    "sélectives": ("sélectif",),
    "sélectionnable": ("sélectionnable",),
    "sélectionnables": ("sélectionnable",),
    "sélectionnelle": ("sélectionnel",),
    "sélectionnelles": ("sélectionnel",),
    "sélectionnel": ("sélectionnel",),
    "sélectionnels": ("sélectionnel",),
    "sélectionneur": ("sélectionneur",),
    "sélectionneurs": ("sélectionneur",),
    "sélectionneuse": ("sélectionneur",),
    "sélectionneuses": ("sélectionneur",),
    "sélectionniste": ("sélectionniste",),
    "sélectionnistes": ("sélectionniste",),
    "sélénhydrique": ("sélénhydrique",),
    "sélénhydriques": ("sélénhydrique",),
    "sélénien": ("sélénien",),
    "sélénienne": ("sélénien",),
    "séléniennes": ("sélénien",),
    "séléniens": ("sélénien",),
    "sélénieuse": ("sélénieux",),
    "sélénieuses": ("sélénieux",),
    "sélénieux": ("sélénieux",),
    "sélénique": ("sélénique",),
    "séléniques": ("sélénique",),
    "séléniteuse": ("séléniteux",),
    "séléniteuses": ("séléniteux",),
    "séléniteux": ("séléniteux",),
    "sélénocentrique": ("sélénocentrique",),
    "sélénocentriques": ("sélénocentrique",),
    "sélénocyanique": ("sélénocyanique",),
    "sélénocyaniques": ("sélénocyanique",),
    "sélénodonte": ("sélénodonte",),
    "sélénodontes": ("sélénodonte",),
    "sélénographique": ("sélénographique",),
    "sélénographiques": ("sélénographique",),
    "séleucide": ("séleucide",),
    "séleucides": ("séleucide",),
    "selfique": ("selfique",),
    "selfiques": ("selfique",),
    "sellaire": ("sellaire",),
    "sellaires": ("sellaire",),
    "sémantique": ("sémantique",),
    "sémantiques": ("sémantique",),
    "sémaphorique": ("sémaphorique",),
    "sémaphoriques": ("sémaphorique",),
    "sémasiologique": ("sémasiologique",),
    "sémasiologiques": ("sémasiologique",),
    "semblable": ("semblable",),
    "semblables": ("semblable",),
    "séméiographique": ("séméiographique",),
    "séméiographiques": ("séméiographique",),
    "séméiologique": ("séméiologique",),
    "séméiologiques": ("séméiologique",),
    "séméiotique": ("séméiotique",),
    "séméiotiques": ("séméiotique",),
    "sémelfactif": ("sémelfactif",),
    "sémelfactifs": ("sémelfactif",),
    "sémelfactive": ("sémelfactif",),
    "sémelfactives": ("sémelfactif",),
    "semencière": ("semencier",),
    "semencières": ("semencier",),
    "semencier": ("semencier",),
    "semenciers": ("semencier",),
    "semestrielle": ("semestriel",),
    "semestrielles": ("semestriel",),
    "semestriel": ("semestriel",),
    "semestriels": ("semestriel",),
    "semi-annuelle": ("semi-annuel",),
    "semi-annuel": ("semi-annuel",),
    "semi-annuels": ("semi-annuel",),
    "semi-argentée": ("semi-argenté",),
    "semi-argentées": ("semi-argenté",),
    "semi-aride": ("semi-aride",),
    "semi-arides": ("semi-aride",),
    "semi-ariennes": ("semi-arien",),
    "semi-automatique": ("semi-automatique",),
    "semi-automatiques": ("semi-automatique",),
    "semi-autopropulsée": ("semi-autopropulsé",),
    "semi-autopropulsées": ("semi-autopropulsé",),
    "semi-auxiliaire": ("semi-auxiliaire",),
    "semi-balistiques": ("semi-balistique",),
    "semi-chenillée": ("semi-chenillé",),
    "semi-chenillés": ("semi-chenillé",),
    "semi-circulaire": ("semi-circulaire",),
    "semi-circulaires": ("semi-circulaire",),
    "semi-conducteur": ("semi-conducteur",),
    "semiconducteur": ("semiconducteur",),
    "semi-conducteurs": ("semi-conducteur",),
    "semiconducteurs": ("semiconducteur",),
    "semi-conductrice": ("semi-conducteur",),
    "semiconductrice": ("semiconducteur",),
    "semiconductrices": ("semiconducteur",),
    "semi-continue": ("semi-continu",),
    "semi-continues": ("semi-continu",),
    "semi-continu": ("semi-continu",),
    "semi-continus": ("semi-continu",),
    "semi-convergentes": ("semi-convergent",),
    "semi-convergent": ("semi-convergent",),
    "semi-convergents": ("semi-convergent",),
    "semi-cubique": ("semi-cubique",),
    "semidinique": ("semidinique",),
    "semidiniques": ("semidinique",),
    "semi-direct": ("semi-direct",),
    "semi-directs": ("semi-direct",),
    "semi-distillées": ("semi-distillé",),
    "semi-distillé": ("semi-distillé",),
    "semi-distillés": ("semi-distillé",),
    "semi-double": ("semi-double",),
    "semi-doubles": ("semi-double",),
    "semi-durables": ("semi-durable",),
    "semi-dures": ("semi-dur",),
    "semi-dur": ("semi-dur",),
    "semi-figé": ("semi-figé",),
    "semi-figés": ("semi-figé",),
    "semi-globales": ("semi-global",),
    "semi-gothique": ("semi-gothique",),
    "semi-harmonique": ("semi-harmonique",),
    "semi-harmoniques": ("semi-harmonique",),
    "semi-hebdomadaire": ("semi-hebdomadaire",),
    "semi-létale": ("semi-létal",),
    "semi-létal": ("semi-létal",),
    "semi-létaux": ("semi-létal",),
    "semi-léthale": ("semi-léthal",),
    "semi-logarithmique": ("semi-logarithmique",),
    "semi-lunaire": ("semi-lunaire",),
    "semi-mensuel": ("semi-mensuel",),
    "semi-mensuels": ("semi-mensuel",),
    "séminale": ("séminal",),
    "séminales": ("séminal",),
    "séminal": ("séminal",),
    "séminaux": ("séminal",),
    "séminariale": ("séminarial",),
    "séminariales": ("séminarial",),
    "séminarial": ("séminarial",),
    "séminariaux": ("séminarial",),
    "semi-nasale": ("semi-nasal",),
    "semi-nasal": ("semi-nasal",),
    "semi-nasaux": ("semi-nasal",),
    "séminifère": ("séminifère",),
    "séminifères": ("séminifère",),
    "semi-nomades": ("semi-nomade",),
    "semi-officielle": ("semi-officiel",),
    "semi-officiel": ("semi-officiel",),
    "sémiographique": ("sémiographique",),
    "sémiographiques": ("sémiographique",),
    "sémiologique": ("sémiologique",),
    "sémiologiques": ("sémiologique",),
    "semi-onciale": ("semi-oncial",),
    "sémiotique": ("sémiotique",),
    "sémiotiques": ("sémiotique",),
    "semi-ouvert": ("semi-ouvert",),
    "semi-ouverts": ("semi-ouvert",),
    "semi-ouvrées": ("semi-ouvré",),
    "semi-peignés": ("semi-peigné",),
    "semi-pélagiennes": ("semi-pélagien",),
    "semi-pélagiques": ("semi-pélagique",),
    "semi-permanente": ("semi-permanent",),
    "semi-permanent": ("semi-permanent",),
    "semi-permanents": ("semi-permanent",),
    "semi-perméable": ("semi-perméable",),
    "semiperméable": ("semiperméable",),
    "semiperméables": ("semiperméable",),
    "semi-polaire": ("semi-polaire",),
    "semi-portées": ("semi-porté",),
    "semi-précieux": ("semi-précieux",),
    "semi-présidentielles": ("semi-présidentiel",),
    "semi-public": ("semi-public",),
    "semi-publics": ("semi-public",),
    "semi-publique": ("semi-public",),
    "sémique": ("sémique",),
    "sémiques": ("sémique",),
    "semi-représentatifs": ("semi-représentatif",),
    "semi-rigide": ("semi-rigide",),
    "semi-rigides": ("semi-rigide",),
    "semi-submersible": ("semi-submersible",),
    "sémite": ("sémite",),
    "sémites": ("sémite",),
    "sémitique": ("sémitique",),
    "sémitiques": ("sémitique",),
    "semi-torique": ("semi-torique",),
    "semi-tubulaires": ("semi-tubulaire",),
    "sempiternelle": ("sempiternel",),
    "sempiternelles": ("sempiternel",),
    "sempiternel": ("sempiternel",),
    "sempiternels": ("sempiternel",),
    "sempronien": ("sempronien",),
    "sempronienne": ("sempronien",),
    "semproniennes": ("sempronien",),
    "semproniens": ("sempronien",),
    "sénatoriale": ("sénatorial",),
    "sénatoriales": ("sénatorial",),
    "sénatorial": ("sénatorial",),
    "sénatoriaux": ("sénatorial",),
    "sénatorien": ("sénatorien",),
    "sénatorienne": ("sénatorien",),
    "sénatoriennes": ("sénatorien",),
    "sénatoriens": ("sénatorien",),
    "sendériste": ("sendériste",),
    "sendéristes": ("sendériste",),
    "sénécioïque": ("sénécioïque",),
    "sénécioïques": ("sénécioïque",),
    "sénégalaise": ("sénégalais",),
    "sénégalaises": ("sénégalais",),
    "sénégalais": ("sénégalais",),
    "sénégambien": ("sénégambien",),
    "sénégambienne": ("sénégambien",),
    "sénégambiennes": ("sénégambien",),
    "sénégambiens": ("sénégambien",),
    "sénestrée": ("sénestré",),
    "sénestrées": ("sénestré",),
    "sénestré": ("sénestré",),
    "senestre": ("senestre",),
    "sénestre": ("sénestre",),
    "sénestrés": ("sénestré",),
    "senestres": ("senestre",),
    "sénestres": ("sénestre",),
    "sénestrogyre": ("sénestrogyre",),
    "sénestrogyres": ("sénestrogyre",),
    "senestrorsum": ("senestrorsum",),
    "sénile": ("sénile",),
    "séniles": ("sénile",),
    "senior": ("senior",),
    "seniors": ("senior",),
    "senneur": ("senneur",),
    "senneurs": ("senneur",),
    "senneuse": ("senneur",),
    "senneuses": ("senneur",),
    "sénonaise": ("sénonais",),
    "sénonaises": ("sénonais",),
    "sénonais": ("sénonais",),
    "sénousiste": ("sénousiste",),
    "sénousistes": ("sénousiste",),
    "sensas": ("sensas",),
    "sensass": ("sensass",),
    "sensationnaliste": ("sensationnaliste",),
    "sensationnalistes": ("sensationnaliste",),
    "sensationnelle": ("sensationnel",),
    "sensationnelles": ("sensationnel",),
    "sensationnel": ("sensationnel",),
    "sensationnels": ("sensationnel",),
    "sensationniste": ("sensationniste",),
    "sensationnistes": ("sensationniste",),
    "sensibilisable": ("sensibilisable",),
    "sensibilisables": ("sensibilisable",),
    "sensibilisateur": ("sensibilisateur",),
    "sensibilisateurs": ("sensibilisateur",),
    "sensibilisatrice": ("sensibilisateur",),
    "sensibilisatrices": ("sensibilisateur",),
    "sensible": ("sensible",),
    "sensibles": ("sensible",),
    "sensiste": ("sensiste",),
    "sensistes": ("sensiste",),
    "sensitif": ("sensitif",),
    "sensitifs": ("sensitif",),
    "sensitive": ("sensitif",),
    "sensitives": ("sensitif",),
    "sensitivo-moteur": ("sensitivo-moteur",),
    "sensitivomoteur": ("sensitivomoteur",),
    "sensitivomoteurs": ("sensitivomoteur",),
    "sensitivomotrice": ("sensitivomoteur",),
    "sensitivo-motrices": ("sensitivo-moteur",),
    "sensitivomotrices": ("sensitivomoteur",),
    "sensitivo-sensitive": ("sensitivo-sensitif",),
    "sensitivo-sensorielle": ("sensitivo-sensoriel",),
    "sensitométrique": ("sensitométrique",),
    "sensitométriques": ("sensitométrique",),
    "sensorielle": ("sensoriel",),
    "sensorielles": ("sensoriel",),
    "sensoriel": ("sensoriel",),
    "sensoriels": ("sensoriel",),
    "sensorimétrique": ("sensorimétrique",),
    "sensorimétriques": ("sensorimétrique",),
    "sensori-moteur": ("sensori-moteur",),
    "sensorimoteur": ("sensorimoteur",),
    "sensori-moteurs": ("sensori-moteur",),
    "sensorimoteurs": ("sensorimoteur",),
    "sensorimotrice": ("sensorimoteur",),
    "sensori-motrices": ("sensori-moteur",),
    "sensorimotrices": ("sensorimoteur",),
    "sensori-toniques": ("sensori-tonique",),
    "sensualiste": ("sensualiste",),
    "sensualistes": ("sensualiste",),
    "sensuelle": ("sensuel",),
    "sensuelles": ("sensuel",),
    "sensuel": ("sensuel",),
    "sensuels": ("sensuel",),
    "sentencieuse": ("sentencieux",),
    "sentencieuses": ("sentencieux",),
    "sentencieux": ("sentencieux",),
    "sentimentale": ("sentimental",),
    "sentimentales": ("sentimental",),
    "sentimental": ("sentimental",),
    "sentimentaux": ("sentimental",),
    "sentimentaliste": ("sentimentaliste",),
    "sentimentalistes": ("sentimentaliste",),
    "séoudien": ("séoudien",),
    "séoudienne": ("séoudien",),
    "séoudiennes": ("séoudien",),
    "séoudiens": ("séoudien",),
    "séoudite": ("séoudite",),
    "séoudites": ("séoudite",),
    "sépalaire": ("sépalaire",),
    "sépalaires": ("sépalaire",),
    "sépaloïde": ("sépaloïde",),
    "sépaloïdes": ("sépaloïde",),
    "séparable": ("séparable",),
    "séparables": ("séparable",),
    "séparateur": ("séparateur",),
    "séparateurs": ("séparateur",),
    "séparatrice": ("séparateur",),
    "séparatrices": ("séparateur",),
    "séparatif": ("séparatif",),
    "séparatifs": ("séparatif",),
    "séparative": ("séparatif",),
    "séparatives": ("séparatif",),
    "séparatiste": ("séparatiste",),
    "séparatistes": ("séparatiste",),
    "sépharade": ("sépharade",),
    "sépharades": ("sépharade",),
    "sépia": ("sépia",),
    "septale": ("septal",),
    "septales": ("septal",),
    "septal": ("septal",),
    "septaux": ("septal",),
    "septane": ("septane",),
    "septanes": ("septane",),
    "septantième": ("septantième",),
    "septantièmes": ("septantième",),
    "septembrale": ("septembral",),
    "septembrales": ("septembral",),
    "septembral": ("septembral",),
    "septembraux": ("septembral",),
    "septénaire": ("septénaire",),
    "septénaires": ("septénaire",),
    "septennale": ("septennal",),
    "septennales": ("septennal",),
    "septennal": ("septennal",),
    "septennaux": ("septennal",),
    "septentrionale": ("septentrional",),
    "septentrionales": ("septentrional",),
    "septentrional": ("septentrional",),
    "septentrionaux": ("septentrional",),
    "septicémique": ("septicémique",),
    "septicémiques": ("septicémique",),
    "septidien": ("septidien",),
    "septidienne": ("septidien",),
    "septidiennes": ("septidien",),
    "septidiens": ("septidien",),
    "septième": ("septième",),
    "septièmes": ("septième",),
    "septimontiale": ("septimontial",),
    "septimontiales": ("septimontial",),
    "septimontial": ("septimontial",),
    "septimontiaux": ("septimontial",),
    "septique": ("septique",),
    "septiques": ("septique",),
    "septuagénaire": ("septuagénaire",),
    "septuagénaires": ("septuagénaire",),
    "septuple": ("septuple",),
    "septuples": ("septuple",),
    "sépulcrale": ("sépulcral",),
    "sépulcrales": ("sépulcral",),
    "sépulcral": ("sépulcral",),
    "sépulcraux": ("sépulcral",),
    "séquellaire": ("séquellaire",),
    "séquellaires": ("séquellaire",),
    "séquentielle": ("séquentiel",),
    "séquentielles": ("séquentiel",),
    "séquentiel": ("séquentiel",),
    "séquentiels": ("séquentiel",),
    "séraphique": ("séraphique",),
    "séraphiques": ("séraphique",),
    "serbe": ("serbe",),
    "serbes": ("serbe",),
    "serbo-croate": ("serbo-croate",),
    "serbo-croates": ("serbo-croate",),
    "sérénissime": ("sérénissime",),
    "sérénissimes": ("sérénissime",),
    "séreuse": ("séreux",),
    "séreuses": ("séreux",),
    "séreux": ("séreux",),
    "serf": ("serf",),
    "serfs": ("serf",),
    "serve": ("serf",),
    "serves": ("serf",),
    "séricicole": ("séricicole",),
    "séricicoles": ("séricicole",),
    "séricigène": ("séricigène",),
    "séricigènes": ("séricigène",),
    "sériciteuse": ("sériciteux",),
    "sériciteuses": ("sériciteux",),
    "sériciteux": ("sériciteux",),
    "sérielle": ("sériel",),
    "sérielles": ("sériel",),
    "sériel": ("sériel",),
    "sériels": ("sériel",),
    "sérieuse": ("sérieux",),
    "sérieuses": ("sérieux",),
    "sérieux": ("sérieux",),
    "sérigraphique": ("sérigraphique",),
    "sérigraphiques": ("sérigraphique",),
    "serin": ("serin",),
    "sérique": ("sérique",),
    "sériques": ("sérique",),
    "sermonneur": ("sermonneur",),
    "sermonneurs": ("sermonneur",),
    "sermonneuse": ("sermonneur",),
    "sermonneuses": ("sermonneur",),
    "sérofibrineuse": ("sérofibrineux",),
    "sérofibrineuses": ("sérofibrineux",),
    "sérofibrineux": ("sérofibrineux",),
    "séro-immunologique": ("séro-immunologique",),
    "sérologique": ("sérologique",),
    "sérologiques": ("sérologique",),
    "séronégatif": ("séronégatif",),
    "séronégatifs": ("séronégatif",),
    "séronégative": ("séronégatif",),
    "séronégatives": ("séronégatif",),
    "séropositif": ("séropositif",),
    "séropositifs": ("séropositif",),
    "séropositive": ("séropositif",),
    "séropositives": ("séropositif",),
    "sérothérapique": ("sérothérapique",),
    "sérothérapiques": ("sérothérapique",),
    "sérotine": ("sérotine",),
    "sérotines": ("sérotine",),
    "sérotoninergique": ("sérotoninergique",),
    "sérotoninergiques": ("sérotoninergique",),
    "serpentiforme": ("serpentiforme",),
    "serpentiformes": ("serpentiforme",),
    "serpentineuse": ("serpentineux",),
    "serpentineuses": ("serpentineux",),
    "serpentineux": ("serpentineux",),
    "serpigineuse": ("serpigineux",),
    "serpigineuses": ("serpigineux",),
    "serpigineux": ("serpigineux",),
    "serrate": ("serrate",),
    "serrates": ("serrate",),
    "serratique": ("serratique",),
    "serratiques": ("serratique",),
    "sertisseur": ("sertisseur",),
    "sertisseurs": ("sertisseur",),
    "sertisseuse": ("sertisseur",),
    "sertisseuses": ("sertisseur",),
    "sertoreuse": ("sertoreux",),
    "sertoreuses": ("sertoreux",),
    "sertoreux": ("sertoreux",),
    "serveur": ("serveur",),
    "serveurs": ("serveur",),
    "serveuse": ("serveur",),
    "serveuses": ("serveur",),
    "serviable": ("serviable",),
    "serviables": ("serviable",),
    "servile": ("servile",),
    "serviles": ("servile",),
    "sésamoïde": ("sésamoïde",),
    "sésamoïdes": ("sésamoïde",),
    "sésamoïdien": ("sésamoïdien",),
    "sésamoïdienne": ("sésamoïdien",),
    "sésamoïdiennes": ("sésamoïdien",),
    "sésamoïdiens": ("sésamoïdien",),
    "sesquialtère": ("sesquialtère",),
    "sesquialtères": ("sesquialtère",),
    "sesquilinéaire": ("sesquilinéaire",),
    "sesquilinéaires": ("sesquilinéaire",),
    "sesquiterpénique": ("sesquiterpénique",),
    "sesquiterpéniques": ("sesquiterpénique",),
    "sessile": ("sessile",),
    "sessiles": ("sessile",),
    "sétigère": ("sétigère",),
    "sétigères": ("sétigère",),
    "sétoise": ("sétois",),
    "sétoises": ("sétois",),
    "sétois": ("sétois",),
    "seulet": ("seulet",),
    "seulets": ("seulet",),
    "seulette": ("seulet",),
    "seulettes": ("seulet",),
    "sévère": ("sévère",),
    "sévères": ("sévère",),
    "sexagénaire": ("sexagénaire",),
    "sexagénaires": ("sexagénaire",),
    "sexagésimale": ("sexagésimal",),
    "sexagésimales": ("sexagésimal",),
    "sexagésimal": ("sexagésimal",),
    "sexagésimaux": ("sexagésimal",),
    "sexangulaire": ("sexangulaire",),
    "sexangulaires": ("sexangulaire",),
    "sexdigitaire": ("sexdigitaire",),
    "sexdigitaires": ("sexdigitaire",),
    "sexdigitale": ("sexdigital",),
    "sexdigitales": ("sexdigital",),
    "sexdigital": ("sexdigital",),
    "sexdigitaux": ("sexdigital",),
    "sexennale": ("sexennal",),
    "sexennales": ("sexennal",),
    "sexennal": ("sexennal",),
    "sexennaux": ("sexennal",),
    "sexiste": ("sexiste",),
    "sexistes": ("sexiste",),
    "sexologique": ("sexologique",),
    "sexologiques": ("sexologique",),
    "sexothérapeutique": ("sexothérapeutique",),
    "sexothérapeutiques": ("sexothérapeutique",),
    "sexothérapique": ("sexothérapique",),
    "sexothérapiques": ("sexothérapique",),
    "sexpartite": ("sexpartite",),
    "sexpartites": ("sexpartite",),
    "sextane": ("sextane",),
    "sextanes": ("sextane",),
    "sexuelle": ("sexuel",),
    "sexuelles": ("sexuel",),
    "sexuel": ("sexuel",),
    "sexuels": ("sexuel",),
    "sexy": ("sexy",),
    "seychelloise": ("seychellois",),
    "seychelloises": ("seychellois",),
    "seychellois": ("seychellois",),
    "shakespearien": ("shakespearien",),
    "shakespearienne": ("shakespearien",),
    "shakespeariennes": ("shakespearien",),
    "shakespeariens": ("shakespearien",),
    "shellolique": ("shellolique",),
    "shelloliques": ("shellolique",),
    "shintoïque": ("shintoïque",),
    "shintoïques": ("shintoïque",),
    "shintoïste": ("shintoïste",),
    "shintoïstes": ("shintoïste",),
    "shocking": ("shocking",),
    "shogounale": ("shogounal",),
    "shogounales": ("shogounal",),
    "shogounal": ("shogounal",),
    "shogounaux": ("shogounal",),
    "shogunale": ("shogunal",),
    "shogunales": ("shogunal",),
    "shogunal": ("shogunal",),
    "shogunaux": ("shogunal",),
    "shorthorn": ("shorthorn",),
    "sialagogue": ("sialagogue",),
    "sialagogues": ("sialagogue",),
    "sialique": ("sialique",),
    "sialiques": ("sialique",),
    "siallitique": ("siallitique",),
    "siallitiques": ("siallitique",),
    "sialogène": ("sialogène",),
    "sialogènes": ("sialogène",),
    "siamoise": ("siamois",),
    "siamoises": ("siamois",),
    "siamois": ("siamois",),
    "sibérien": ("sibérien",),
    "sibérienne": ("sibérien",),
    "sibériennes": ("sibérien",),
    "sibériens": ("sibérien",),
    "sibyllique": ("sibyllique",),
    "sibylliques": ("sibyllique",),
    "siccatif": ("siccatif",),
    "siccatifs": ("siccatif",),
    "siccative": ("siccatif",),
    "siccatives": ("siccatif",),
    "sicilien": ("sicilien",),
    "sicilienne": ("sicilien",),
    "siciliennes": ("sicilien",),
    "siciliens": ("sicilien",),
    "sidatique": ("sidatique",),
    "sidatiques": ("sidatique",),
    "sidéen": ("sidéen",),
    "sidéenne": ("sidéen",),
    "sidéennes": ("sidéen",),
    "sidéens": ("sidéen",),
    "sidérale": ("sidéral",),
    "sidérales": ("sidéral",),
    "sidéral": ("sidéral",),
    "sidéraux": ("sidéral",),
    "sidérique": ("sidérique",),
    "sidériques": ("sidérique",),
    "sidéroblastique": ("sidéroblastique",),
    "sidéroblastiques": ("sidéroblastique",),
    "sidérolithique": ("sidérolithique",),
    "sidérolithiques": ("sidérolithique",),
    "sidérolitique": ("sidérolitique",),
    "sidérolitiques": ("sidérolitique",),
    "sidéropénique": ("sidéropénique",),
    "sidéropéniques": ("sidéropénique",),
    "sidérophore": ("sidérophore",),
    "sidérophores": ("sidérophore",),
    "sidéroprive": ("sidéroprive",),
    "sidéroprives": ("sidéroprive",),
    "sidérurgique": ("sidérurgique",),
    "sidérurgiques": ("sidérurgique",),
    "sien": ("sien",),
    "sienne": ("sien",),
    "siennes": ("sien",),
    "siens": ("sien",),
    "siennoise": ("siennois",),
    "siennoises": ("siennois",),
    "siennois": ("siennois",),
    "siffleur": ("siffleur",),
    "siffleurs": ("siffleur",),
    "siffleuse": ("siffleur",),
    "siffleuses": ("siffleur",),
    "sigillaire": ("sigillaire",),
    "sigillaires": ("sigillaire",),
    "sigillographique": ("sigillographique",),
    "sigillographiques": ("sigillographique",),
    "siglique": ("siglique",),
    "sigliques": ("siglique",),
    "sigmatique": ("sigmatique",),
    "sigmatiques": ("sigmatique",),
    "sigmoïde": ("sigmoïde",),
    "sigmoïdes": ("sigmoïde",),
    "sigmoïdien": ("sigmoïdien",),
    "sigmoïdienne": ("sigmoïdien",),
    "sigmoïdiennes": ("sigmoïdien",),
    "sigmoïdiens": ("sigmoïdien",),
    "signalétique": ("signalétique",),
    "signalétiques": ("signalétique",),
    "signaleur": ("signaleur",),
    "signaleurs": ("signaleur",),
    "signaleuse": ("signaleur",),
    "signaleuses": ("signaleur",),
    "signalisateur": ("signalisateur",),
    "signalisateurs": ("signalisateur",),
    "signalisatrice": ("signalisateur",),
    "signalisatrices": ("signalisateur",),
    "significatif": ("significatif",),
    "significatifs": ("significatif",),
    "significative": ("significatif",),
    "significatives": ("significatif",),
    "sikh": ("sikh",),
    "sikhs": ("sikh",),
    "silencieuse": ("silencieux",),
    "silencieuses": ("silencieux",),
    "silencieux": ("silencieux",),
    "silésien": ("silésien",),
    "silésienne": ("silésien",),
    "silésiennes": ("silésien",),
    "silésiens": ("silésien",),
    "siliceuse": ("siliceux",),
    "siliceuses": ("siliceux",),
    "siliceux": ("siliceux",),
    "silicicole": ("silicicole",),
    "silicicoles": ("silicicole",),
    "silicique": ("silicique",),
    "siliciques": ("silicique",),
    "silico-alumineuses": ("silico-alumineux",),
    "silicocyanhydrique": ("silicocyanhydrique",),
    "silicocyanhydriques": ("silicocyanhydrique",),
    "silicofluorhydrique": ("silicofluorhydrique",),
    "silicofluorhydriques": ("silicofluorhydrique",),
    "silicomanganeuse": ("silicomanganeux",),
    "silicomanganeuses": ("silicomanganeux",),
    "silicomanganeux": ("silicomanganeux",),
    "siliconique": ("siliconique",),
    "siliconiques": ("siliconique",),
    "silicosodocalcique": ("silicosodocalcique",),
    "silicosodocalciques": ("silicosodocalcique",),
    "silicotique": ("silicotique",),
    "silicotiques": ("silicotique",),
    "silteuse": ("silteux",),
    "silteuses": ("silteux",),
    "silteux": ("silteux",),
    "silurien": ("silurien",),
    "silurienne": ("silurien",),
    "siluriennes": ("silurien",),
    "siluriens": ("silurien",),
    "simien": ("simien",),
    "simienne": ("simien",),
    "simiennes": ("simien",),
    "simiens": ("simien",),
    "simiesque": ("simiesque",),
    "simiesques": ("simiesque",),
    "similaire": ("similaire",),
    "similaires": ("similaire",),
    "simique": ("simique",),
    "simiques": ("simique",),
    "simoniaque": ("simoniaque",),
    "simoniaques": ("simoniaque",),
    "simonien": ("simonien",),
    "simonienne": ("simonien",),
    "simoniennes": ("simonien",),
    "simoniens": ("simonien",),
    "simple": ("simple",),
    "simples": ("simple",),
    "simplet": ("simplet",),
    "simplets": ("simplet",),
    "simplette": ("simplet",),
    "simplettes": ("simplet",),
    "simplex": ("simplex",),
    "simplifiable": ("simplifiable",),
    "simplifiables": ("simplifiable",),
    "simplificateur": ("simplificateur",),
    "simplificateurs": ("simplificateur",),
    "simplificatrice": ("simplificateur",),
    "simplificatrices": ("simplificateur",),
    "simplissime": ("simplissime",),
    "simplissimes": ("simplissime",),
    "simpliste": ("simpliste",),
    "simplistes": ("simpliste",),
    "simulable": ("simulable",),
    "simulables": ("simulable",),
    "simultanéiste": ("simultanéiste",),
    "simultanéistes": ("simultanéiste",),
    "sinanthropien": ("sinanthropien",),
    "sinanthropienne": ("sinanthropien",),
    "sinanthropiennes": ("sinanthropien",),
    "sinanthropiens": ("sinanthropien",),
    "sinapique": ("sinapique",),
    "sinapiques": ("sinapique",),
    "sincère": ("sincère",),
    "sincères": ("sincère",),
    "sincipitale": ("sincipital",),
    "sincipitales": ("sincipital",),
    "sincipital": ("sincipital",),
    "sincipitaux": ("sincipital",),
    "singapourien": ("singapourien",),
    "singapourienne": ("singapourien",),
    "singapouriennes": ("singapourien",),
    "singapouriens": ("singapourien",),
    "single": ("single",),
    "singulaire": ("singulaire",),
    "singulaires": ("singulaire",),
    "singulière": ("singulier",),
    "singulières": ("singulier",),
    "singulier": ("singulier",),
    "singuliers": ("singulier",),
    "sinistrée": ("sinistré",),
    "sinistrées": ("sinistré",),
    "sinistré": ("sinistré",),
    "sinistre": ("sinistre",),
    "sinistrés": ("sinistré",),
    "sinistres": ("sinistre",),
    "sinistrogyre": ("sinistrogyre",),
    "sinistrogyres": ("sinistrogyre",),
    "sinoc": ("sinoc",),
    "sinocs": ("sinoc",),
    "sino-coréen": ("sino-coréen",),
    "sino-coréenne": ("sino-coréen",),
    "sino-coréens": ("sino-coréen",),
    "sinophile": ("sinophile",),
    "sinophiles": ("sinophile",),
    "sinophobe": ("sinophobe",),
    "sinophobes": ("sinophobe",),
    "sinoque": ("sinoque",),
    "sinoques": ("sinoque",),
    "sino-vietnamien": ("sino-vietnamien",),
    "sino-vietnamiennes": ("sino-vietnamien",),
    "sinucarotidien": ("sinucarotidien",),
    "sinucarotidienne": ("sinucarotidien",),
    "sinucarotidiennes": ("sinucarotidien",),
    "sinucarotidiens": ("sinucarotidien",),
    "sinueuse": ("sinueux",),
    "sinueuses": ("sinueux",),
    "sinueux": ("sinueux",),
    "sinusaire": ("sinusaire",),
    "sinusaires": ("sinusaire",),
    "sinusale": ("sinusal",),
    "sinusales": ("sinusal",),
    "sinusal": ("sinusal",),
    "sinusaux": ("sinusal",),
    "sinusien": ("sinusien",),
    "sinusienne": ("sinusien",),
    "sinusiennes": ("sinusien",),
    "sinusiens": ("sinusien",),
    "sinusoïdale": ("sinusoïdal",),
    "sinusoïdales": ("sinusoïdal",),
    "sinusoïdal": ("sinusoïdal",),
    "sinusoïdaux": ("sinusoïdal",),
    "sioniste": ("sioniste",),
    "sionistes": ("sioniste",),
    "sioux": ("sioux",),
    "siphoïde": ("siphoïde",),
    "siphoïdes": ("siphoïde",),
    "siphonale": ("siphonal",),
    "siphonales": ("siphonal",),
    "siphonal": ("siphonal",),
    "siphonaux": ("siphonal",),
    "siroteur": ("siroteur",),
    "siroteurs": ("siroteur",),
    "siroteuse": ("siroteur",),
    "siroteuses": ("siroteur",),
    "sirupeuse": ("sirupeux",),
    "sirupeuses": ("sirupeux",),
    "sirupeux": ("sirupeux",),
    "sise": ("sis",),
    "sises": ("sis",),
    "sis": ("sis",),
    "sismale": ("sismal",),
    "sismales": ("sismal",),
    "sismal": ("sismal",),
    "sismaux": ("sismal",),
    "sismique": ("sismique",),
    "sismiques": ("sismique",),
    "sismogénique": ("sismogénique",),
    "sismogéniques": ("sismogénique",),
    "sismographique": ("sismographique",),
    "sismographiques": ("sismographique",),
    "sismologique": ("sismologique",),
    "sismologiques": ("sismologique",),
    "sismotectonique": ("sismotectonique",),
    "sismotectoniques": ("sismotectonique",),
    "sitifienne": ("sitifienne",),
    "sitifiennes": ("sitifienne",),
    "situable": ("situable",),
    "situables": ("situable",),
    "situationnelle": ("situationnel",),
    "situationnelles": ("situationnel",),
    "situationnel": ("situationnel",),
    "situationnels": ("situationnel",),
    "situationniste": ("situationniste",),
    "situationnistes": ("situationniste",),
    "sivaïte": ("sivaïte",),
    "sivaïtes": ("sivaïte",),
    "sixième": ("sixième",),
    "sixièmes": ("sixième",),
    "sixtine": ("sixtine",),
    "sixtines": ("sixtine",),
    "skiable": ("skiable",),
    "skiables": ("skiable",),
    "skinnerien": ("skinnerien",),
    "skinnerienne": ("skinnerien",),
    "skinneriennes": ("skinnerien",),
    "skinneriens": ("skinnerien",),
    "skioptique": ("skioptique",),
    "skioptiques": ("skioptique",),
    "skodique": ("skodique",),
    "skodiques": ("skodique",),
    "slave": ("slave",),
    "slaves": ("slave",),
    "slaviste": ("slaviste",),
    "slavistes": ("slaviste",),
    "slavistique": ("slavistique",),
    "slavistiques": ("slavistique",),
    "slavon": ("slavon",),
    "slavonne": ("slavon",),
    "slavonnes": ("slavon",),
    "slavons": ("slavon",),
    "slavophile": ("slavophile",),
    "slavophiles": ("slavophile",),
    "slovaque": ("slovaque",),
    "slovaques": ("slovaque",),
    "slovène": ("slovène",),
    "slovènes": ("slovène",),
    "smart": ("smart",),
    "smectique": ("smectique",),
    "smectiques": ("smectique",),
    "snob": ("snob",),
    "snobs": ("snob",),
    "sobre": ("sobre",),
    "sobres": ("sobre",),
    "sociable": ("sociable",),
    "sociables": ("sociable",),
    "sociale": ("social",),
    "sociales": ("social",),
    "social": ("social",),
    "sociaux": ("social",),
    "social-démocrate": ("social-démocrate",),
    "social-démocrates": ("social-démocrate",),
    "socialiste": ("socialiste",),
    "socialistes": ("socialiste",),
    "socialo": ("socialo",),
    "socialos": ("socialo",),
    "sociétaire": ("sociétaire",),
    "sociétaires": ("sociétaire",),
    "sociétale": ("sociétal",),
    "sociétales": ("sociétal",),
    "sociétal": ("sociétal",),
    "sociétaux": ("sociétal",),
    "socioaffectif": ("socioaffectif",),
    "socioaffectifs": ("socioaffectif",),
    "socioaffective": ("socioaffectif",),
    "socioaffectives": ("socioaffectif",),
    "sociobiologique": ("sociobiologique",),
    "sociobiologiques": ("sociobiologique",),
    "sociocritique": ("sociocritique",),
    "sociocritiques": ("sociocritique",),
    "socioculturelle": ("socioculturel",),
    "socio-culturelles": ("socio-culturel",),
    "socioculturelles": ("socioculturel",),
    "socio-culturel": ("socio-culturel",),
    "socioculturel": ("socioculturel",),
    "socio-culturels": ("socio-culturel",),
    "socioculturels": ("socioculturel",),
    "sociodramatique": ("sociodramatique",),
    "sociodramatiques": ("sociodramatique",),
    "socio-économique": ("socio-économique",),
    "socioéconomique": ("socioéconomique",),
    "socio-économiques": ("socio-économique",),
    "socioéconomiques": ("socioéconomique",),
    "socio-éducatif": ("socio-éducatif",),
    "socio-éducatifs": ("socio-éducatif",),
    "socio-éducative": ("socio-éducatif",),
    "socio-éducatives": ("socio-éducatif",),
    "socio-familiales": ("socio-familial",),
    "sociogénétique": ("sociogénétique",),
    "sociogénétiques": ("sociogénétique",),
    "sociographique": ("sociographique",),
    "sociographiques": ("sociographique",),
    "sociohistorique": ("sociohistorique",),
    "sociohistoriques": ("sociohistorique",),
    "sociolinguistique": ("sociolinguistique",),
    "sociolinguistiques": ("sociolinguistique",),
    "sociologique": ("sociologique",),
    "sociologiques": ("sociologique",),
    "sociologiste": ("sociologiste",),
    "sociologistes": ("sociologiste",),
    "sociométrique": ("sociométrique",),
    "sociométriques": ("sociométrique",),
    "sociopathe": ("sociopathe",),
    "sociopathes": ("sociopathe",),
    "sociopathique": ("sociopathique",),
    "sociopathiques": ("sociopathique",),
    "socio-politique": ("socio-politique",),
    "sociopolitique": ("sociopolitique",),
    "sociopolitiques": ("sociopolitique",),
    "socioprofessionnelle": ("socioprofessionnel",),
    "socioprofessionnelles": ("socioprofessionnel",),
    "socioprofessionnel": ("socioprofessionnel",),
    "socioprofessionnels": ("socioprofessionnel",),
    "socioreligieuse": ("socioreligieux",),
    "socioreligieuses": ("socioreligieux",),
    "socio-religieux": ("socio-religieux",),
    "socioreligieux": ("socioreligieux",),
    "sociosportif": ("sociosportif",),
    "sociosportifs": ("sociosportif",),
    "sociosportive": ("sociosportif",),
    "sociosportives": ("sociosportif",),
    "sociotechnique": ("sociotechnique",),
    "sociotechniques": ("sociotechnique",),
    "sociothérapique": ("sociothérapique",),
    "sociothérapiques": ("sociothérapique",),
    "socratique": ("socratique",),
    "socratiques": ("socratique",),
    "sodique": ("sodique",),
    "sodiques": ("sodique",),
    "sodomique": ("sodomique",),
    "sodomiques": ("sodomique",),
    "soft": ("soft",),
    "soignable": ("soignable",),
    "soignables": ("soignable",),
    "soigneuse": ("soigneux",),
    "soigneuses": ("soigneux",),
    "soigneux": ("soigneux",),
    "soixantième": ("soixantième",),
    "soixantièmes": ("soixantième",),
    "solaire": ("solaire",),
    "solaires": ("solaire",),
    "soldatesque": ("soldatesque",),
    "soldatesques": ("soldatesque",),
    "soléaire": ("soléaire",),
    "soléaires": ("soléaire",),
    "solennelle": ("solennel",),
    "solennelles": ("solennel",),
    "solennel": ("solennel",),
    "solennels": ("solennel",),
    "solénoïdale": ("solénoïdal",),
    "solénoïdales": ("solénoïdal",),
    "solénoïdal": ("solénoïdal",),
    "solénoïdaux": ("solénoïdal",),
    "solfatarien": ("solfatarien",),
    "solfatarienne": ("solfatarien",),
    "solfatariennes": ("solfatarien",),
    "solfatariens": ("solfatarien",),
    "solidaire": ("solidaire",),
    "solidaires": ("solidaire",),
    "solidariste": ("solidariste",),
    "solidaristes": ("solidariste",),
    "solide": ("solide",),
    "solides": ("solide",),
    "solifluidale": ("solifluidal",),
    "solifluidales": ("solifluidal",),
    "solifluidal": ("solifluidal",),
    "solifluidaux": ("solifluidal",),
    "solipède": ("solipède",),
    "solipèdes": ("solipède",),
    "solipsiste": ("solipsiste",),
    "solipsistes": ("solipsiste",),
    "soliste": ("soliste",),
    "solistes": ("soliste",),
    "solitaire": ("solitaire",),
    "solitaires": ("solitaire",),
    "solo": ("solo",),
    "solsticiale": ("solsticial",),
    "solsticiales": ("solsticial",),
    "solsticial": ("solsticial",),
    "solsticiaux": ("solsticial",),
    "soluble": ("soluble",),
    "solubles": ("soluble",),
    "solunaire": ("solunaire",),
    "solunaires": ("solunaire",),
    "solutréen": ("solutréen",),
    "solutréenne": ("solutréen",),
    "solutréennes": ("solutréen",),
    "solutréens": ("solutréen",),
    "solvable": ("solvable",),
    "solvables": ("solvable",),
    "somalien": ("somalien",),
    "somalienne": ("somalien",),
    "somaliennes": ("somalien",),
    "somaliens": ("somalien",),
    "somatique": ("somatique",),
    "somatiques": ("somatique",),
    "somatométrique": ("somatométrique",),
    "somatométriques": ("somatométrique",),
    "somato-moteur": ("somato-moteur",),
    "somatomoteur": ("somatomoteur",),
    "somatomoteurs": ("somatomoteur",),
    "somatomotrice": ("somatomoteur",),
    "somatomotrices": ("somatomoteur",),
    "somato-sensible": ("somato-sensible",),
    "somato-sensitif": ("somato-sensitif",),
    "somato-sensitive": ("somato-sensitif",),
    "somatosensorielle": ("somatosensoriel",),
    "somatosensorielles": ("somatosensoriel",),
    "somatosensoriel": ("somatosensoriel",),
    "somatosensoriels": ("somatosensoriel",),
    "somatotopique": ("somatotopique",),
    "somatotopiques": ("somatotopique",),
    "somatotrope": ("somatotrope",),
    "somatotropes": ("somatotrope",),
    "sombre": ("sombre",),
    "sombres": ("sombre",),
    "somesthésique": ("somesthésique",),
    "somesthésiques": ("somesthésique",),
    "sommable": ("sommable",),
    "sommables": ("sommable",),
    "sommaire": ("sommaire",),
    "sommaires": ("sommaire",),
    "sommatoire": ("sommatoire",),
    "sommatoires": ("sommatoire",),
    "sommeilleuse": ("sommeilleux",),
    "sommeilleuses": ("sommeilleux",),
    "sommeilleux": ("sommeilleux",),
    "sommitale": ("sommital",),
    "sommitales": ("sommital",),
    "sommital": ("sommital",),
    "sommitaux": ("sommital",),
    "somnambule": ("somnambule",),
    "somnambules": ("somnambule",),
    "somnambulesque": ("somnambulesque",),
    "somnambulesques": ("somnambulesque",),
    "somnambulique": ("somnambulique",),
    "somnambuliques": ("somnambulique",),
    "somnifère": ("somnifère",),
    "somnifères": ("somnifère",),
    "somptuaire": ("somptuaire",),
    "somptuaires": ("somptuaire",),
    "somptueuse": ("somptueux",),
    "somptueuses": ("somptueux",),
    "somptueux": ("somptueux",),
    "sondeur": ("sondeur",),
    "sondeurs": ("sondeur",),
    "sondeuse": ("sondeur",),
    "sondeuses": ("sondeur",),
    "song": ("song",),
    "songs": ("song",),
    "songeur": ("songeur",),
    "songeurs": ("songeur",),
    "songeuse": ("songeur",),
    "songeuses": ("songeur",),
    "songhaï": ("songhaï",),
    "songhaïs": ("songhaï",),
    "sonique": ("sonique",),
    "soniques": ("sonique",),
    "sonométrique": ("sonométrique",),
    "sonométriques": ("sonométrique",),
    "sonore": ("sonore",),
    "sonores": ("sonore",),
    "sophianique": ("sophianique",),
    "sophianiques": ("sophianique",),
    "sophiologique": ("sophiologique",),
    "sophiologiques": ("sophiologique",),
    "sophistiquée": ("sophistiqué",),
    "sophistiquées": ("sophistiqué",),
    "sophistiqué": ("sophistiqué",),
    "sophistique": ("sophistique",),
    "sophistiqués": ("sophistiqué",),
    "sophistiques": ("sophistique",),
    "sophrologique": ("sophrologique",),
    "sophrologiques": ("sophrologique",),
    "sophronique": ("sophronique",),
    "sophroniques": ("sophronique",),
    "sopo": ("sopo",),
    "soporatif": ("soporatif",),
    "soporatifs": ("soporatif",),
    "soporative": ("soporatif",),
    "soporatives": ("soporatif",),
    "soporeuse": ("soporeux",),
    "soporeuses": ("soporeux",),
    "soporeux": ("soporeux",),
    "soporifique": ("soporifique",),
    "soporifiques": ("soporifique",),
    "sorbique": ("sorbique",),
    "sorbiques": ("sorbique",),
    "sorbonnique": ("sorbonnique",),
    "sorbonniques": ("sorbonnique",),
    "sorcier": ("sorcier",),
    "sorciers": ("sorcier",),
    "sordide": ("sordide",),
    "sordides": ("sordide",),
    "sororale": ("sororal",),
    "sororales": ("sororal",),
    "sororal": ("sororal",),
    "sororaux": ("sororal",),
    "sortable": ("sortable",),
    "sortables": ("sortable",),
    "sot": ("sot",),
    "sots": ("sot",),
    "sotte": ("sot",),
    "sottes": ("sot",),
    "sotho": ("sotho",),
    "sothos": ("sotho",),
    "soucieuse": ("soucieux",),
    "soucieuses": ("soucieux",),
    "soucieux": ("soucieux",),
    "soudable": ("soudable",),
    "soudables": ("soudable",),
    "soudanaise": ("soudanais",),
    "soudanaises": ("soudanais",),
    "soudanais": ("soudanais",),
    "soudanien": ("soudanien",),
    "soudanienne": ("soudanien",),
    "soudaniennes": ("soudanien",),
    "soudaniens": ("soudanien",),
    "soudeur": ("soudeur",),
    "soudeurs": ("soudeur",),
    "soudière": ("soudier",),
    "soudières": ("soudier",),
    "soudier": ("soudier",),
    "soudiers": ("soudier",),
    "souffleur": ("souffleur",),
    "souffleurs": ("souffleur",),
    "souffleuse": ("souffleur",),
    "souffleuses": ("souffleur",),
    "souffreteuse": ("souffreteux",),
    "souffreteuses": ("souffreteux",),
    "souffreteux": ("souffreteux",),
    "soufite": ("soufite",),
    "soufites": ("soufite",),
    "soufrée": ("soufré",),
    "soufrées": ("soufré",),
    "soufré": ("soufré",),
    "soufre": ("soufre",),
    "soufrés": ("soufré",),
    "souhaitable": ("souhaitable",),
    "souhaitables": ("souhaitable",),
    "soûle": ("soûl",),
    "soûles": ("soûl",),
    "soûl": ("soûl",),
    "soul": ("soul",),
    "soûls": ("soûl",),
    "soumise": ("soumis",),
    "soumises": ("soumis",),
    "soumis": ("soumis",),
    "soupçonnable": ("soupçonnable",),
    "soupçonnables": ("soupçonnable",),
    "soupçonneuse": ("soupçonneux",),
    "soupçonneuses": ("soupçonneux",),
    "soupçonneux": ("soupçonneux",),
    "souple": ("souple",),
    "souples": ("souple",),
    "sourcilière": ("sourcilier",),
    "sourcilières": ("sourcilier",),
    "sourcilier": ("sourcilier",),
    "sourciliers": ("sourcilier",),
    "sourcilleuse": ("sourcilleux",),
    "sourcilleuses": ("sourcilleux",),
    "sourcilleux": ("sourcilleux",),
    "sourdingue": ("sourdingue",),
    "sourdingues": ("sourdingue",),
    "sourde-muette": ("sourd-muet",),
    "sourd-muet": ("sourd-muet",),
    "sourds-muets": ("sourd-muet",),
    "souricière": ("souricier",),
    "souricières": ("souricier",),
    "souricier": ("souricier",),
    "souriciers": ("souricier",),
    "souris": ("souris",),
    "sournoise": ("sournois",),
    "sournoises": ("sournois",),
    "sournois": ("sournois",),
    "sous-adapté": ("sous-adapté",),
    "sous-adaptés": ("sous-adapté",),
    "sous-administrées": ("sous-administré",),
    "sous-aponévrotique": ("sous-aponévrotique",),
    "sous-arachnoïdien": ("sous-arachnoïdien",),
    "sous-arachnoïdienne": ("sous-arachnoïdien",),
    "sous-astragalien": ("sous-astragalien",),
    "sous-astragaliens": ("sous-astragalien",),
    "sous-calibré": ("sous-calibré",),
    "sous-calibrés": ("sous-calibré",),
    "sous-capitalisées": ("sous-capitalisé",),
    "sous-capitalisé": ("sous-capitalisé",),
    "sous-chargée": ("sous-chargé",),
    "sous-claviculaire": ("sous-claviculaire",),
    "sous-clavière": ("sous-clavier",),
    "sousclavière": ("sousclavier",),
    "sous-clavières": ("sous-clavier",),
    "sousclavières": ("sousclavier",),
    "sousclavier": ("sousclavier",),
    "sous-claviers": ("sous-clavier",),
    "sousclaviers": ("sousclavier",),
    "sous-commissurale": ("sous-commissural",),
    "sous-conjonctivale": ("sous-conjonctival",),
    "sous-coracoïdien": ("sous-coracoïdien",),
    "sous-coracoïdiens": ("sous-coracoïdien",),
    "sous-cortical": ("sous-cortical",),
    "sous-costales": ("sous-costal",),
    "sous-crépitantes": ("sous-crépitant",),
    "sous-culturelles": ("sous-culturel",),
    "sous-cutané": ("sous-cutané",),
    "sous-cutanés": ("sous-cutané",),
    "sous-développée": ("sous-développé",),
    "sous-développées": ("sous-développé",),
    "sous-développé": ("sous-développé",),
    "sous-développés": ("sous-développé",),
    "sous-dirigée": ("sous-dirigé",),
    "sous-durale": ("sous-dural",),
    "sous-élytral": ("sous-élytral",),
    "sous-élytraux": ("sous-élytral",),
    "sous-entendue": ("sous-entendu",),
    "sous-entendues": ("sous-entendu",),
    "sous-entendu": ("sous-entendu",),
    "sous-entendus": ("sous-entendu",),
    "sous-épineuse": ("sous-épineux",),
    "sous-filé": ("sous-filé",),
    "sous-filés": ("sous-filé",),
    "sous-fréquenté": ("sous-fréquenté",),
    "sous-fréquentés": ("sous-fréquenté",),
    "sous-glaciaires": ("sous-glaciaire",),
    "sous-industrialisée": ("sous-industrialisé",),
    "sous-lacustre": ("sous-lacustre",),
    "sous-ligneuse": ("sous-ligneux",),
    "sous-liminaire": ("sous-liminaire",),
    "sous-marine": ("sous-marin",),
    "sous-marines": ("sous-marin",),
    "sous-marin": ("sous-marin",),
    "sous-marins": ("sous-marin",),
    "sous-médicalisées": ("sous-médicalisé",),
    "sous-mésocoliques": ("sous-mésocolique",),
    "sous-muqueuses": ("sous-muqueux",),
    "sous-nasal": ("sous-nasal",),
    "sous-nasaux": ("sous-nasal",),
    "sous-neural": ("sous-neural",),
    "sous-neuraux": ("sous-neural",),
    "sous-occipitales": ("sous-occipital",),
    "sous-ombilicale": ("sous-ombilical",),
    "sous-optique": ("sous-optique",),
    "sous-orbitaire": ("sous-orbitaire",),
    "sous-orbitale": ("sous-orbital",),
    "sous-périostées": ("sous-périosté",),
    "sous-peuplée": ("sous-peuplé",),
    "sous-peuplées": ("sous-peuplé",),
    "sous-peuplé": ("sous-peuplé",),
    "sous-productifs": ("sous-productif",),
    "sous-productive": ("sous-productif",),
    "sous-pubienne": ("sous-pubien",),
    "sous-réparti": ("sous-réparti",),
    "sous-répartis": ("sous-réparti",),
    "sous-représentées": ("sous-représenté",),
    "sous-représenté": ("sous-représenté",),
    "sous-saturé": ("sous-saturé",),
    "sous-saturés": ("sous-saturé",),
    "sous-séreuse": ("sous-séreux",),
    "sous-tentorielle": ("sous-tentoriel",),
    "soustractif": ("soustractif",),
    "soustractifs": ("soustractif",),
    "soustractive": ("soustractif",),
    "soustractives": ("soustractif",),
    "sous-trochantérienne": ("sous-trochantérien",),
    "sous-unguéal": ("sous-unguéal",),
    "sous-unguéaux": ("sous-unguéal",),
    "sous-venté": ("sous-venté",),
    "sous-ventés": ("sous-venté",),
    "sous-vireurs": ("sous-vireur",),
    "sous-voltée": ("sous-volté",),
    "soutenable": ("soutenable",),
    "soutenables": ("soutenable",),
    "souverainiste": ("souverainiste",),
    "souverainistes": ("souverainiste",),
    "soviétique": ("soviétique",),
    "soviétiques": ("soviétique",),
    "soyeuse": ("soyeux",),
    "soyeuses": ("soyeux",),
    "soyeux": ("soyeux",),
    "spacieuse": ("spacieux",),
    "spacieuses": ("spacieux",),
    "spacieux": ("spacieux",),
    "spaciophile": ("spaciophile",),
    "spaciophiles": ("spaciophile",),
    "spaciophobe": ("spaciophobe",),
    "spaciophobes": ("spaciophobe",),
    "spagirique": ("spagirique",),
    "spagiriques": ("spagirique",),
    "spagyrique": ("spagyrique",),
    "spagyriques": ("spagyrique",),
    "spartakiste": ("spartakiste",),
    "spartakistes": ("spartakiste",),
    "spartiate": ("spartiate",),
    "spartiates": ("spartiate",),
    "spasmique": ("spasmique",),
    "spasmiques": ("spasmique",),
    "spasmodique": ("spasmodique",),
    "spasmodiques": ("spasmodique",),
    "spasmogène": ("spasmogène",),
    "spasmogènes": ("spasmogène",),
    "spasmolytique": ("spasmolytique",),
    "spasmolytiques": ("spasmolytique",),
    "spasmophile": ("spasmophile",),
    "spasmophiles": ("spasmophile",),
    "spasmophilique": ("spasmophilique",),
    "spasmophiliques": ("spasmophilique",),
    "spastique": ("spastique",),
    "spastiques": ("spastique",),
    "spathique": ("spathique",),
    "spathiques": ("spathique",),
    "spatiale": ("spatial",),
    "spatiales": ("spatial",),
    "spatial": ("spatial",),
    "spatiaux": ("spatial",),
    "spatiodynamique": ("spatiodynamique",),
    "spatiodynamiques": ("spatiodynamique",),
    "spatio-temporelles": ("spatio-temporel",),
    "spéciale": ("spécial",),
    "spéciales": ("spécial",),
    "spécial": ("spécial",),
    "spéciaux": ("spécial",),
    "spécialiste": ("spécialiste",),
    "spécialistes": ("spécialiste",),
    "spécieuse": ("spécieux",),
    "spécieuses": ("spécieux",),
    "spécieux": ("spécieux",),
    "spécifiable": ("spécifiable",),
    "spécifiables": ("spécifiable",),
    "spécificatif": ("spécificatif",),
    "spécificatifs": ("spécificatif",),
    "spécificative": ("spécificatif",),
    "spécificatives": ("spécificatif",),
    "spécifique": ("spécifique",),
    "spécifiques": ("spécifique",),
    "spectaculaire": ("spectaculaire",),
    "spectaculaires": ("spectaculaire",),
    "spectrale": ("spectral",),
    "spectrales": ("spectral",),
    "spectral": ("spectral",),
    "spectraux": ("spectral",),
    "spectrique": ("spectrique",),
    "spectriques": ("spectrique",),
    "spectrochimique": ("spectrochimique",),
    "spectrochimiques": ("spectrochimique",),
    "spectrographique": ("spectrographique",),
    "spectrographiques": ("spectrographique",),
    "spectrométrique": ("spectrométrique",),
    "spectrométriques": ("spectrométrique",),
    "spectrophotométrique": ("spectrophotométrique",),
    "spectrophotométriques": ("spectrophotométrique",),
    "spectroscopique": ("spectroscopique",),
    "spectroscopiques": ("spectroscopique",),
    "spéculaire": ("spéculaire",),
    "spéculaires": ("spéculaire",),
    "spéculatif": ("spéculatif",),
    "spéculatifs": ("spéculatif",),
    "spéculative": ("spéculatif",),
    "spéculatives": ("spéculatif",),
    "spéléologique": ("spéléologique",),
    "spéléologiques": ("spéléologique",),
    "spermaticide": ("spermaticide",),
    "spermaticides": ("spermaticide",),
    "spermatique": ("spermatique",),
    "spermatiques": ("spermatique",),
    "spermatiste": ("spermatiste",),
    "spermatistes": ("spermatiste",),
    "spermatophage": ("spermatophage",),
    "spermatophages": ("spermatophage",),
    "spermatozoïdien": ("spermatozoïdien",),
    "spermatozoïdienne": ("spermatozoïdien",),
    "spermatozoïdiennes": ("spermatozoïdien",),
    "spermatozoïdiens": ("spermatozoïdien",),
    "spermicide": ("spermicide",),
    "spermicides": ("spermicide",),
    "spermotoxique": ("spermotoxique",),
    "spermotoxiques": ("spermotoxique",),
    "sphénocaverneuse": ("sphénocaverneux",),
    "sphénocaverneuses": ("sphénocaverneux",),
    "sphénocaverneux": ("sphénocaverneux",),
    "sphénoïdale": ("sphénoïdal",),
    "sphénoïdales": ("sphénoïdal",),
    "sphénoïdal": ("sphénoïdal",),
    "sphénoïdaux": ("sphénoïdal",),
    "sphénoïde": ("sphénoïde",),
    "sphénoïdes": ("sphénoïde",),
    "sphénomaxillaire": ("sphénomaxillaire",),
    "sphénomaxillaires": ("sphénomaxillaire",),
    "sphérique": ("sphérique",),
    "sphériques": ("sphérique",),
    "sphéroconique": ("sphéroconique",),
    "sphéroconiques": ("sphéroconique",),
    "sphéroïdale": ("sphéroïdal",),
    "sphéroïdales": ("sphéroïdal",),
    "sphéroïdal": ("sphéroïdal",),
    "sphéroïdaux": ("sphéroïdal",),
    "sphéroïdique": ("sphéroïdique",),
    "sphéroïdiques": ("sphéroïdique",),
    "sphérolitique": ("sphérolitique",),
    "sphérolitiques": ("sphérolitique",),
    "sphinctérien": ("sphinctérien",),
    "sphinctérienne": ("sphinctérien",),
    "sphinctériennes": ("sphinctérien",),
    "sphinctériens": ("sphinctérien",),
    "sphrygmique": ("sphrygmique",),
    "sphrygmiques": ("sphrygmique",),
    "sphygmique": ("sphygmique",),
    "sphygmiques": ("sphygmique",),
    "sphygmographique": ("sphygmographique",),
    "sphygmographiques": ("sphygmographique",),
    "spiciforme": ("spiciforme",),
    "spiciformes": ("spiciforme",),
    "spinale": ("spinal",),
    "spinales": ("spinal",),
    "spinal": ("spinal",),
    "spinaux": ("spinal",),
    "spinalien": ("spinalien",),
    "spinalienne": ("spinalien",),
    "spinaliennes": ("spinalien",),
    "spinaliens": ("spinalien",),
    "spinocellulaire": ("spinocellulaire",),
    "spino-cellulaires": ("spino-cellulaire",),
    "spinocellulaires": ("spinocellulaire",),
    "spino-cérébelleux": ("spino-cérébelleux",),
    "spinorielle": ("spinoriel",),
    "spinorielles": ("spinoriel",),
    "spinoriel": ("spinoriel",),
    "spinoriels": ("spinoriel",),
    "spinosiste": ("spinosiste",),
    "spinosistes": ("spinosiste",),
    "spino-thalamique": ("spino-thalamique",),
    "spinoziste": ("spinoziste",),
    "spinozistes": ("spinoziste",),
    "spinuleuse": ("spinuleux",),
    "spinuleuses": ("spinuleux",),
    "spinuleux": ("spinuleux",),
    "spiraculaire": ("spiraculaire",),
    "spiraculaires": ("spiraculaire",),
    "spirale": ("spiral",),
    "spirales": ("spiral",),
    "spiral": ("spiral",),
    "spiraux": ("spiral",),
    "spirannique": ("spirannique",),
    "spiranniques": ("spirannique",),
    "spirillaire": ("spirillaire",),
    "spirillaires": ("spirillaire",),
    "spirite": ("spirite",),
    "spirites": ("spirite",),
    "spiritualiste": ("spiritualiste",),
    "spiritualistes": ("spiritualiste",),
    "spirituelle": ("spirituel",),
    "spirituelles": ("spirituel",),
    "spirituel": ("spirituel",),
    "spirituels": ("spirituel",),
    "spiritueuse": ("spiritueux",),
    "spiritueuses": ("spiritueux",),
    "spiritueux": ("spiritueux",),
    "spirochétique": ("spirochétique",),
    "spirochétiques": ("spirochétique",),
    "spirochétogène": ("spirochétogène",),
    "spirochétogènes": ("spirochétogène",),
    "spiroïdale": ("spiroïdal",),
    "spiroïdales": ("spiroïdal",),
    "spiroïdal": ("spiroïdal",),
    "spiroïdaux": ("spiroïdal",),
    "spiroïde": ("spiroïde",),
    "spiroïdes": ("spiroïde",),
    "spirométrique": ("spirométrique",),
    "spirométriques": ("spirométrique",),
    "splanchnique": ("splanchnique",),
    "splanchniques": ("splanchnique",),
    "splanchnokystique": ("splanchnokystique",),
    "splanchnokystiques": ("splanchnokystique",),
    "splanchnopleurale": ("splanchnopleural",),
    "splanchnopleurales": ("splanchnopleural",),
    "splanchnopleural": ("splanchnopleural",),
    "splanchnopleuraux": ("splanchnopleural",),
    "splanchnotrope": ("splanchnotrope",),
    "splanchnotropes": ("splanchnotrope",),
    "spleenétique": ("spleenétique",),
    "spleenétiques": ("spleenétique",),
    "splendide": ("splendide",),
    "splendides": ("splendide",),
    "splénétique": ("splénétique",),
    "splénétiques": ("splénétique",),
    "splénique": ("splénique",),
    "spléniques": ("splénique",),
    "splénocardiaque": ("splénocardiaque",),
    "splénocardiaques": ("splénocardiaque",),
    "splénoganglionnaire": ("splénoganglionnaire",),
    "splénoganglionnaires": ("splénoganglionnaire",),
    "splénogène": ("splénogène",),
    "splénogènes": ("splénogène",),
    "splénomégalique": ("splénomégalique",),
    "splénomégaliques": ("splénomégalique",),
    "splénométrique": ("splénométrique",),
    "splénométriques": ("splénométrique",),
    "spoliateur": ("spoliateur",),
    "spoliateurs": ("spoliateur",),
    "spoliatrice": ("spoliateur",),
    "spoliatrices": ("spoliateur",),
    "spondaïque": ("spondaïque",),
    "spondaïques": ("spondaïque",),
    "spondyloépiphysaire": ("spondyloépiphysaire",),
    "spondyloépiphysaires": ("spondyloépiphysaire",),
    "spongieuse": ("spongieux",),
    "spongieuses": ("spongieux",),
    "spongieux": ("spongieux",),
    "spongiforme": ("spongiforme",),
    "spongiformes": ("spongiforme",),
    "spongiostique": ("spongiostique",),
    "spongiostiques": ("spongiostique",),
    "spongoïde": ("spongoïde",),
    "spongoïdes": ("spongoïde",),
    "spontanéiste": ("spontanéiste",),
    "spontanéistes": ("spontanéiste",),
    "sporadique": ("sporadique",),
    "sporadiques": ("sporadique",),
    "sporifère": ("sporifère",),
    "sporifères": ("sporifère",),
    "sporogonique": ("sporogonique",),
    "sporogoniques": ("sporogonique",),
    "sporophytique": ("sporophytique",),
    "sporophytiques": ("sporophytique",),
    "sporotrichosique": ("sporotrichosique",),
    "sporotrichosiques": ("sporotrichosique",),
    "sporozoïtique": ("sporozoïtique",),
    "sporozoïtiques": ("sporozoïtique",),
    "sport": ("sport",),
    "sportif": ("sportif",),
    "sportifs": ("sportif",),
    "sportive": ("sportif",),
    "sportives": ("sportif",),
    "spot": ("spot",),
    "spumeuse": ("spumeux",),
    "spumeuses": ("spumeux",),
    "spumeux": ("spumeux",),
    "squameuse": ("squameux",),
    "squameuses": ("squameux",),
    "squameux": ("squameux",),
    "squamifère": ("squamifère",),
    "squamifères": ("squamifère",),
    "squarreuse": ("squarreux",),
    "squarreuses": ("squarreux",),
    "squarreux": ("squarreux",),
    "squelettique": ("squelettique",),
    "squelettiques": ("squelettique",),
    "squirreuse": ("squirreux",),
    "squirreuses": ("squirreux",),
    "squirreux": ("squirreux",),
    "squirrheuse": ("squirrheux",),
    "squirrheuses": ("squirrheux",),
    "squirrheux": ("squirrheux",),
    "ss": ("ss",),
    "stabile": ("stabile",),
    "stabiles": ("stabile",),
    "stabilisateur": ("stabilisateur",),
    "stabilisateurs": ("stabilisateur",),
    "stabilisatrice": ("stabilisateur",),
    "stabilisatrices": ("stabilisateur",),
    "stable": ("stable",),
    "stables": ("stable",),
    "stadimétrique": ("stadimétrique",),
    "stadimétriques": ("stadimétrique",),
    "stagflationniste": ("stagflationniste",),
    "stagflationnistes": ("stagflationniste",),
    "stagiaire": ("stagiaire",),
    "stagiaires": ("stagiaire",),
    "stagnatile": ("stagnatile",),
    "stagnatiles": ("stagnatile",),
    "stagnationniste": ("stagnationniste",),
    "stagnationnistes": ("stagnationniste",),
    "stakhanoviste": ("stakhanoviste",),
    "stakhanovistes": ("stakhanoviste",),
    "stalactifère": ("stalactifère",),
    "stalactifères": ("stalactifère",),
    "stalagmométrique": ("stalagmométrique",),
    "stalagmométriques": ("stalagmométrique",),
    "stalinien": ("stalinien",),
    "stalinienne": ("stalinien",),
    "staliniennes": ("stalinien",),
    "staliniens": ("stalinien",),
    "staminale": ("staminal",),
    "staminales": ("staminal",),
    "staminal": ("staminal",),
    "staminaux": ("staminal",),
    "staminifère": ("staminifère",),
    "staminifères": ("staminifère",),
    "standard": ("standard",),
    "stanneuse": ("stanneux",),
    "stanneuses": ("stanneux",),
    "stanneux": ("stanneux",),
    "stannifère": ("stannifère",),
    "stannifères": ("stannifère",),
    "stannique": ("stannique",),
    "stanniques": ("stannique",),
    "stapédien": ("stapédien",),
    "stapédienne": ("stapédien",),
    "stapédiennes": ("stapédien",),
    "stapédiens": ("stapédien",),
    "staphylococcique": ("staphylococcique",),
    "staphylococciques": ("staphylococcique",),
    "staphylomateuse": ("staphylomateux",),
    "staphylomateuses": ("staphylomateux",),
    "staphylomateux": ("staphylomateux",),
    "statif": ("statif",),
    "statifs": ("statif",),
    "stative": ("statif",),
    "statives": ("statif",),
    "stationnaire": ("stationnaire",),
    "stationnaires": ("stationnaire",),
    "stationnale": ("stationnale",),
    "stationnales": ("stationnale",),
    "stationnelle": ("stationnel",),
    "stationnelles": ("stationnel",),
    "stationnel": ("stationnel",),
    "stationnels": ("stationnel",),
    "statique": ("statique",),
    "statiques": ("statique",),
    "statistique": ("statistique",),
    "statistiques": ("statistique",),
    "statocratique": ("statocratique",),
    "statocratiques": ("statocratique",),
    "statorique": ("statorique",),
    "statoriques": ("statorique",),
    "statuaire": ("statuaire",),
    "statuaires": ("statuaire",),
    "staturale": ("statural",),
    "staturales": ("statural",),
    "statural": ("statural",),
    "staturaux": ("statural",),
    "staturopondérale": ("staturopondéral",),
    "staturopondérales": ("staturopondéral",),
    "staturopondéral": ("staturopondéral",),
    "staturopondéraux": ("staturopondéral",),
    "statutaire": ("statutaire",),
    "statutaires": ("statutaire",),
    "stéarique": ("stéarique",),
    "stéariques": ("stéarique",),
    "stéatolytique": ("stéatolytique",),
    "stéatolytiques": ("stéatolytique",),
    "stéatopyge": ("stéatopyge",),
    "stéatopyges": ("stéatopyge",),
    "stellaire": ("stellaire",),
    "stellaires": ("stellaire",),
    "stellionataire": ("stellionataire",),
    "stellionataires": ("stellionataire",),
    "stendhalien": ("stendhalien",),
    "stendhalienne": ("stendhalien",),
    "stendhaliennes": ("stendhalien",),
    "stendhaliens": ("stendhalien",),
    "sténocardique": ("sténocardique",),
    "sténocardiques": ("sténocardique",),
    "sténographique": ("sténographique",),
    "sténographiques": ("sténographique",),
    "sténo-ioniques": ("sténo-ionique",),
    "sténopéique": ("sténopéique",),
    "sténopéiques": ("sténopéique",),
    "sténotherme": ("sténotherme",),
    "sténothermes": ("sténotherme",),
    "sténotypique": ("sténotypique",),
    "sténotypiques": ("sténotypique",),
    "stéphanéphore": ("stéphanéphore",),
    "stéphanéphores": ("stéphanéphore",),
    "stéphanite": ("stéphanite",),
    "stéphanites": ("stéphanite",),
    "stéphanoise": ("stéphanois",),
    "stéphanoises": ("stéphanois",),
    "stéphanois": ("stéphanois",),
    "steppique": ("steppique",),
    "steppiques": ("steppique",),
    "stercoraire": ("stercoraire",),
    "stercoraires": ("stercoraire",),
    "stercorale": ("stercoral",),
    "stercorales": ("stercoral",),
    "stercoral": ("stercoral",),
    "stercoraux": ("stercoral",),
    "stéréo": ("stéréo",),
    "stéréochimique": ("stéréochimique",),
    "stéréochimiques": ("stéréochimique",),
    "stéréoélectif": ("stéréoélectif",),
    "stéréoélectifs": ("stéréoélectif",),
    "stéréoélective": ("stéréoélectif",),
    "stéréoélectives": ("stéréoélectif",),
    "stéréoencéphalographique": ("stéréoencéphalographique",),
    "stéréoencéphalographiques": ("stéréoencéphalographique",),
    "stéréognostique": ("stéréognostique",),
    "stéréognostiques": ("stéréognostique",),
    "stéréographique": ("stéréographique",),
    "stéréographiques": ("stéréographique",),
    "stéréométrique": ("stéréométrique",),
    "stéréométriques": ("stéréométrique",),
    "stéréophonique": ("stéréophonique",),
    "stéréophoniques": ("stéréophonique",),
    "stéréorégulière": ("stéréorégulier",),
    "stéréorégulières": ("stéréorégulier",),
    "stéréorégulier": ("stéréorégulier",),
    "stéréoréguliers": ("stéréorégulier",),
    "stéréoscopique": ("stéréoscopique",),
    "stéréoscopiques": ("stéréoscopique",),
    "stéréosélectif": ("stéréosélectif",),
    "stéréosélectifs": ("stéréosélectif",),
    "stéréosélective": ("stéréosélectif",),
    "stéréosélectives": ("stéréosélectif",),
    "stéréospécifique": ("stéréospécifique",),
    "stéréospécifiques": ("stéréospécifique",),
    "stéréotaxique": ("stéréotaxique",),
    "stéréotaxiques": ("stéréotaxique",),
    "stéréotomique": ("stéréotomique",),
    "stéréotomiques": ("stéréotomique",),
    "stérile": ("stérile",),
    "stériles": ("stérile",),
    "stériliste": ("stériliste",),
    "stérilistes": ("stériliste",),
    "stérique": ("stérique",),
    "stériques": ("stérique",),
    "sterling": ("sterling",),
    "sternale": ("sternal",),
    "sternales": ("sternal",),
    "sternal": ("sternal",),
    "sternaux": ("sternal",),
    "sternocleidomastoïdien": ("sternocleidomastoïdien",),
    "sternocleidomastoïdiens": ("sternocleidomastoïdien",),
    "sternodorsale": ("sternodorsal",),
    "sternodorsales": ("sternodorsal",),
    "sternodorsal": ("sternodorsal",),
    "sternodorsaux": ("sternodorsal",),
    "sternopage": ("sternopage",),
    "sternopages": ("sternopage",),
    "sternutatoire": ("sternutatoire",),
    "sternutatoires": ("sternutatoire",),
    "stéroïde": ("stéroïde",),
    "stéroïdes": ("stéroïde",),
    "stéroïdien": ("stéroïdien",),
    "stéroïdienne": ("stéroïdien",),
    "stéroïdiennes": ("stéroïdien",),
    "stéroïdiens": ("stéroïdien",),
    "stéroïdique": ("stéroïdique",),
    "stéroïdiques": ("stéroïdique",),
    "stérolique": ("stérolique",),
    "stéroliques": ("stérolique",),
    "stertoreuse": ("stertoreux",),
    "stertoreuses": ("stertoreux",),
    "stertoreux": ("stertoreux",),
    "stéthacoustique": ("stéthacoustique",),
    "stéthacoustiques": ("stéthacoustique",),
    "stéthoscopique": ("stéthoscopique",),
    "stéthoscopiques": ("stéthoscopique",),
    "sthénique": ("sthénique",),
    "sthéniques": ("sthénique",),
    "stigmatique": ("stigmatique",),
    "stigmatiques": ("stigmatique",),
    "stigmergique": ("stigmergique",),
    "stigmergiques": ("stigmergique",),
    "stilbénique": ("stilbénique",),
    "stilbéniques": ("stilbénique",),
    "stillatoire": ("stillatoire",),
    "stillatoires": ("stillatoire",),
    "stimugène": ("stimugène",),
    "stimugènes": ("stimugène",),
    "stimulateur": ("stimulateur",),
    "stimulateurs": ("stimulateur",),
    "stimulatrice": ("stimulateur",),
    "stimulatrices": ("stimulateur",),
    "stipulaire": ("stipulaire",),
    "stipulaires": ("stipulaire",),
    "stipulatif": ("stipulatif",),
    "stipulatifs": ("stipulatif",),
    "stipulative": ("stipulatif",),
    "stipulatives": ("stipulatif",),
    "stochastique": ("stochastique",),
    "stochastiques": ("stochastique",),
    "stockable": ("stockable",),
    "stockables": ("stockable",),
    "stockeur": ("stockeur",),
    "stockeurs": ("stockeur",),
    "stockeuse": ("stockeur",),
    "stockeuses": ("stockeur",),
    "stoechiométrique": ("stoechiométrique",),
    "stoechiométriques": ("stoechiométrique",),
    "stoïcien": ("stoïcien",),
    "stoïcienne": ("stoïcien",),
    "stoïciennes": ("stoïcien",),
    "stoïciens": ("stoïcien",),
    "stoïque": ("stoïque",),
    "stoïques": ("stoïque",),
    "stoloniale": ("stolonial",),
    "stoloniales": ("stolonial",),
    "stolonial": ("stolonial",),
    "stoloniaux": ("stolonial",),
    "stolonifère": ("stolonifère",),
    "stolonifères": ("stolonifère",),
    "stomacale": ("stomacal",),
    "stomacales": ("stomacal",),
    "stomacal": ("stomacal",),
    "stomacaux": ("stomacal",),
    "stomachique": ("stomachique",),
    "stomachiques": ("stomachique",),
    "stomatique": ("stomatique",),
    "stomatiques": ("stomatique",),
    "stomatogastrique": ("stomatogastrique",),
    "stomatogastriques": ("stomatogastrique",),
    "stomatologique": ("stomatologique",),
    "stomatologiques": ("stomatologique",),
    "stomatorragique": ("stomatorragique",),
    "stomatorragiques": ("stomatorragique",),
    "strabique": ("strabique",),
    "strabiques": ("strabique",),
    "strasbourgeoise": ("strasbourgeois",),
    "strasbourgeoises": ("strasbourgeois",),
    "strasbourgeois": ("strasbourgeois",),
    "stratégique": ("stratégique",),
    "stratégiques": ("stratégique",),
    "stratiforme": ("stratiforme",),
    "stratiformes": ("stratiforme",),
    "stratigraphique": ("stratigraphique",),
    "stratigraphiques": ("stratigraphique",),
    "stratosphérique": ("stratosphérique",),
    "stratosphériques": ("stratosphérique",),
    "strech": ("strech",),
    "streptococcique": ("streptococcique",),
    "streptococciques": ("streptococcique",),
    "stretch": ("stretch",),
    "striatale": ("striatal",),
    "striatales": ("striatal",),
    "striatal": ("striatal",),
    "striataux": ("striatal",),
    "stridoreuse": ("stridoreux",),
    "stridoreuses": ("stridoreux",),
    "stridoreux": ("stridoreux",),
    "stridulatoire": ("stridulatoire",),
    "stridulatoires": ("stridulatoire",),
    "striduleuse": ("striduleux",),
    "striduleuses": ("striduleux",),
    "striduleux": ("striduleux",),
    "striopallidale": ("striopallidal",),
    "striopallidales": ("striopallidal",),
    "striopallidal": ("striopallidal",),
    "striopallidaux": ("striopallidal",),
    "strioscopique": ("strioscopique",),
    "strioscopiques": ("strioscopique",),
    "stripeur": ("stripeur",),
    "stripeurs": ("stripeur",),
    "strippable": ("strippable",),
    "strippables": ("strippable",),
    "stroboscopique": ("stroboscopique",),
    "stroboscopiques": ("stroboscopique",),
    "strombolien": ("strombolien",),
    "strombolienne": ("strombolien",),
    "stromboliennes": ("strombolien",),
    "stromboliens": ("strombolien",),
    "strophique": ("strophique",),
    "strophiques": ("strophique",),
    "structurable": ("structurable",),
    "structurables": ("structurable",),
    "structurale": ("structural",),
    "structurales": ("structural",),
    "structural": ("structural",),
    "structuraux": ("structural",),
    "structuraliste": ("structuraliste",),
    "structuralistes": ("structuraliste",),
    "structurelle": ("structurel",),
    "structurelles": ("structurel",),
    "structurel": ("structurel",),
    "structurels": ("structurel",),
    "strumeuse": ("strumeux",),
    "strumeuses": ("strumeux",),
    "strumeux": ("strumeux",),
    "studieuse": ("studieux",),
    "studieuses": ("studieux",),
    "studieux": ("studieux",),
    "stupide": ("stupide",),
    "stupides": ("stupide",),
    "stuporeuse": ("stuporeux",),
    "stuporeuses": ("stuporeux",),
    "stuporeux": ("stuporeux",),
    "stylique": ("stylique",),
    "styliques": ("stylique",),
    "stylistique": ("stylistique",),
    "stylistiques": ("stylistique",),
    "stylocarotidien": ("stylocarotidien",),
    "stylocarotidienne": ("stylocarotidien",),
    "stylocarotidiennes": ("stylocarotidien",),
    "stylocarotidiens": ("stylocarotidien",),
    "stylographique": ("stylographique",),
    "stylographiques": ("stylographique",),
    "stylo-hyoïdiennes": ("stylo-hyoïdien",),
    "styloïde": ("styloïde",),
    "styloïdes": ("styloïde",),
    "stylolithique": ("stylolithique",),
    "stylolithiques": ("stylolithique",),
    "stylolitique": ("stylolitique",),
    "stylolitiques": ("stylolitique",),
    "stylo-mastoïdienne": ("stylo-mastoïdien",),
    "stylo-pharyngien": ("stylo-pharyngien",),
    "stylo-pharyngiens": ("stylo-pharyngien",),
    "styloradiale": ("styloradial",),
    "styloradiales": ("styloradial",),
    "styloradial": ("styloradial",),
    "styloradiaux": ("styloradial",),
    "stylotypique": ("stylotypique",),
    "stylotypiques": ("stylotypique",),
    "styphnique": ("styphnique",),
    "styphniques": ("styphnique",),
    "styptique": ("styptique",),
    "styptiques": ("styptique",),
    "suave": ("suave",),
    "suaves": ("suave",),
    "subaérien": ("subaérien",),
    "subaérienne": ("subaérien",),
    "subaériennes": ("subaérien",),
    "subaériens": ("subaérien",),
    "subaiguë": ("subaigu",),
    "subaiguës": ("subaigu",),
    "subaigu": ("subaigu",),
    "subaigus": ("subaigu",),
    "subalaire": ("subalaire",),
    "subalaires": ("subalaire",),
    "subalterne": ("subalterne",),
    "subalternes": ("subalterne",),
    "subantarctique": ("subantarctique",),
    "subantarctiques": ("subantarctique",),
    "sub-aquatique": ("sub-aquatique",),
    "subaquatique": ("subaquatique",),
    "subaquatiques": ("subaquatique",),
    "subarachnoïdien": ("subarachnoïdien",),
    "subarachnoïdienne": ("subarachnoïdien",),
    "subarachnoïdiennes": ("subarachnoïdien",),
    "subarachnoïdiens": ("subarachnoïdien",),
    "subarctique": ("subarctique",),
    "subarctiques": ("subarctique",),
    "subatomique": ("subatomique",),
    "subatomiques": ("subatomique",),
    "subaurorale": ("subauroral",),
    "subaurorales": ("subauroral",),
    "subauroral": ("subauroral",),
    "subauroraux": ("subauroral",),
    "subbétique": ("subbétique",),
    "subbétiques": ("subbétique",),
    "subbitumineuse": ("subbitumineux",),
    "subbitumineuses": ("subbitumineux",),
    "subbitumineux": ("subbitumineux",),
    "subcarpatique": ("subcarpatique",),
    "subcarpatiques": ("subcarpatique",),
    "subcaudale": ("subcaudal",),
    "subcaudales": ("subcaudal",),
    "subcaudal": ("subcaudal",),
    "subcaudaux": ("subcaudal",),
    "subcellulaire": ("subcellulaire",),
    "subcellulaires": ("subcellulaire",),
    "subchronique": ("subchronique",),
    "subchroniques": ("subchronique",),
    "subclinique": ("subclinique",),
    "subcliniques": ("subclinique",),
    "subconfusionnelle": ("subconfusionnel",),
    "subconfusionnelles": ("subconfusionnel",),
    "subconfusionnel": ("subconfusionnel",),
    "subconfusionnels": ("subconfusionnel",),
    "subcontraire": ("subcontraire",),
    "subcontraires": ("subcontraire",),
    "subcostale": ("subcostal",),
    "subcostales": ("subcostal",),
    "subcostal": ("subcostal",),
    "subcostaux": ("subcostal",),
    "subcutaneous": ("subcutaneous",),
    "subdépressif": ("subdépressif",),
    "subdépressifs": ("subdépressif",),
    "subdépressive": ("subdépressif",),
    "subdépressives": ("subdépressif",),
    "subdésertique": ("subdésertique",),
    "subdésertiques": ("subdésertique",),
    "subdistique": ("subdistique",),
    "subdistiques": ("subdistique",),
    "subdivisible": ("subdivisible",),
    "subdivisibles": ("subdivisible",),
    "subdivisionnaire": ("subdivisionnaire",),
    "subdivisionnaires": ("subdivisionnaire",),
    "subductif": ("subductif",),
    "subductifs": ("subductif",),
    "subductive": ("subductif",),
    "subductives": ("subductif",),
    "subdurale": ("subdural",),
    "subdurales": ("subdural",),
    "subdural": ("subdural",),
    "subduraux": ("subdural",),
    "subéquatoriale": ("subéquatorial",),
    "subéquatoriales": ("subéquatorial",),
    "subéquatorial": ("subéquatorial",),
    "subéquatoriaux": ("subéquatorial",),
    "subéreuse": ("subéreux",),
    "subéreuses": ("subéreux",),
    "subéreux": ("subéreux",),
    "subérique": ("subérique",),
    "subériques": ("subérique",),
    "subfébrile": ("subfébrile",),
    "subfébriles": ("subfébrile",),
    "subictérique": ("subictérique",),
    "subictériques": ("subictérique",),
    "subjectif": ("subjectif",),
    "subjectifs": ("subjectif",),
    "subjective": ("subjectif",),
    "subjectives": ("subjectif",),
    "subjectiviste": ("subjectiviste",),
    "subjectivistes": ("subjectiviste",),
    "subjonctif": ("subjonctif",),
    "subjonctifs": ("subjonctif",),
    "subjonctive": ("subjonctif",),
    "subjonctives": ("subjonctif",),
    "subjuridique": ("subjuridique",),
    "subjuridiques": ("subjuridique",),
    "subkilotonnique": ("subkilotonnique",),
    "subkilotonniques": ("subkilotonnique",),
    "sublaminale": ("sublaminal",),
    "sublaminales": ("sublaminal",),
    "sublaminal": ("sublaminal",),
    "sublaminaux": ("sublaminal",),
    "sublétale": ("sublétal",),
    "sublétales": ("sublétal",),
    "sublétal": ("sublétal",),
    "sublétaux": ("sublétal",),
    "subléthale": ("subléthal",),
    "subléthales": ("subléthal",),
    "subléthal": ("subléthal",),
    "subléthaux": ("subléthal",),
    "subleucémique": ("subleucémique",),
    "subleucémiques": ("subleucémique",),
    "subligneuse": ("subligneux",),
    "subligneuses": ("subligneux",),
    "subligneux": ("subligneux",),
    "sublimable": ("sublimable",),
    "sublimables": ("sublimable",),
    "sublimatoire": ("sublimatoire",),
    "sublimatoires": ("sublimatoire",),
    "sublimée": ("sublimé",),
    "sublimées": ("sublimé",),
    "sublimé": ("sublimé",),
    "sublime": ("sublime",),
    "sublimés": ("sublimé",),
    "sublimes": ("sublime",),
    "subliminaire": ("subliminaire",),
    "subliminaires": ("subliminaire",),
    "subliminale": ("subliminal",),
    "subliminales": ("subliminal",),
    "subliminal": ("subliminal",),
    "subliminaux": ("subliminal",),
    "sublinguale": ("sublingual",),
    "sublinguales": ("sublingual",),
    "sublingual": ("sublingual",),
    "sublinguaux": ("sublingual",),
    "sublunaire": ("sublunaire",),
    "sublunaires": ("sublunaire",),
    "sublymphémique": ("sublymphémique",),
    "sublymphémiques": ("sublymphémique",),
    "submandibulaire": ("submandibulaire",),
    "submandibulaires": ("submandibulaire",),
    "submarginale": ("submarginal",),
    "submarginales": ("submarginal",),
    "submarginal": ("submarginal",),
    "submarginaux": ("submarginal",),
    "submembraneuse": ("submembraneux",),
    "submembraneuses": ("submembraneux",),
    "submembraneux": ("submembraneux",),
    "submersible": ("submersible",),
    "submersibles": ("submersible",),
    "submicronique": ("submicronique",),
    "submicroniques": ("submicronique",),
    "submillimétrique": ("submillimétrique",),
    "submillimétriques": ("submillimétrique",),
    "submontagneuse": ("submontagneux",),
    "submontagneuses": ("submontagneux",),
    "submontagneux": ("submontagneux",),
    "subnormale": ("subnormal",),
    "subnormales": ("subnormal",),
    "subnormal": ("subnormal",),
    "subnormaux": ("subnormal",),
    "subnucléaire": ("subnucléaire",),
    "subnucléaires": ("subnucléaire",),
    "subocéanique": ("subocéanique",),
    "subocéaniques": ("subocéanique",),
    "suborbitale": ("suborbital",),
    "suborbitales": ("suborbital",),
    "suborbital": ("suborbital",),
    "suborbitaux": ("suborbital",),
    "suborneur": ("suborneur",),
    "suborneurs": ("suborneur",),
    "suborneuse": ("suborneur",),
    "suborneuses": ("suborneur",),
    "subreptice": ("subreptice",),
    "subreptices": ("subreptice",),
    "subrogateur": ("subrogateur",),
    "subrogateurs": ("subrogateur",),
    "subrogatrice": ("subrogateur",),
    "subrogatrices": ("subrogateur",),
    "subrogatif": ("subrogatif",),
    "subrogatifs": ("subrogatif",),
    "subrogative": ("subrogatif",),
    "subrogatives": ("subrogatif",),
    "subrogatoire": ("subrogatoire",),
    "subrogatoires": ("subrogatoire",),
    "subsaharien": ("subsaharien",),
    "sub-saharienne": ("sub-saharien",),
    "subsaharienne": ("subsaharien",),
    "subsahariennes": ("subsaharien",),
    "sub-sahariens": ("sub-saharien",),
    "subsahariens": ("subsaharien",),
    "subsessile": ("subsessile",),
    "subsessiles": ("subsessile",),
    "subsidiaire": ("subsidiaire",),
    "subsidiaires": ("subsidiaire",),
    "sub-sonique": ("sub-sonique",),
    "subsonique": ("subsonique",),
    "subsoniques": ("subsonique",),
    "substantialiste": ("substantialiste",),
    "substantialistes": ("substantialiste",),
    "substantielle": ("substantiel",),
    "substantielles": ("substantiel",),
    "substantiel": ("substantiel",),
    "substantiels": ("substantiel",),
    "substantif": ("substantif",),
    "substantifs": ("substantif",),
    "substantive": ("substantif",),
    "substantives": ("substantif",),
    "substantifique": ("substantifique",),
    "substantifiques": ("substantifique",),
    "substantivale": ("substantival",),
    "substantivales": ("substantival",),
    "substantival": ("substantival",),
    "substantivaux": ("substantival",),
    "substituable": ("substituable",),
    "substituables": ("substituable",),
    "substitutif": ("substitutif",),
    "substitutifs": ("substitutif",),
    "substitutive": ("substitutif",),
    "substitutives": ("substitutif",),
    "substitutionnelle": ("substitutionnel",),
    "substitutionnelles": ("substitutionnel",),
    "substitutionnel": ("substitutionnel",),
    "substitutionnels": ("substitutionnel",),
    "substructurale": ("substructural",),
    "substructurales": ("substructural",),
    "substructural": ("substructural",),
    "substructuraux": ("substructural",),
    "subterminale": ("subterminal",),
    "subterminales": ("subterminal",),
    "subterminal": ("subterminal",),
    "subterminaux": ("subterminal",),
    "subtomenteuse": ("subtomenteux",),
    "subtomenteuses": ("subtomenteux",),
    "subtomenteux": ("subtomenteux",),
    "subtotale": ("subtotal",),
    "subtotales": ("subtotal",),
    "subtotal": ("subtotal",),
    "subtotaux": ("subtotal",),
    "subtropicale": ("subtropical",),
    "subtropicales": ("subtropical",),
    "subtropical": ("subtropical",),
    "subtropicaux": ("subtropical",),
    "suburbicaire": ("suburbicaire",),
    "suburbicaires": ("suburbicaire",),
    "subventionnable": ("subventionnable",),
    "subventionnables": ("subventionnable",),
    "subventionnelle": ("subventionnel",),
    "subventionnelles": ("subventionnel",),
    "subventionnel": ("subventionnel",),
    "subventionnels": ("subventionnel",),
    "subversif": ("subversif",),
    "subversifs": ("subversif",),
    "subversive": ("subversif",),
    "subversives": ("subversif",),
    "successible": ("successible",),
    "successibles": ("successible",),
    "successif": ("successif",),
    "successifs": ("successif",),
    "successive": ("successif",),
    "successives": ("successif",),
    "successorale": ("successoral",),
    "successorales": ("successoral",),
    "successoral": ("successoral",),
    "successoraux": ("successoral",),
    "succinique": ("succinique",),
    "succiniques": ("succinique",),
    "succube": ("succube",),
    "succubes": ("succube",),
    "succursale": ("succursale",),
    "succursales": ("succursale",),
    "succursaliste": ("succursaliste",),
    "succursalistes": ("succursaliste",),
    "suceur": ("suceur",),
    "suceurs": ("suceur",),
    "suceuse": ("suceur",),
    "suceuses": ("suceur",),
    "sucrière": ("sucrier",),
    "sucrières": ("sucrier",),
    "sucrier": ("sucrier",),
    "sucriers": ("sucrier",),
    "sud-africaine": ("sud-africain",),
    "sud-africaines": ("sud-africain",),
    "sud-africain": ("sud-africain",),
    "sud-africains": ("sud-africain",),
    "sud-américaines": ("sud-américain",),
    "sud-américain": ("sud-américain",),
    "sudarabique": ("sudarabique",),
    "sudarabiques": ("sudarabique",),
    "sud": ("sud",),
    "sudatoire": ("sudatoire",),
    "sudatoires": ("sudatoire",),
    "sudète": ("sudète",),
    "sudètes": ("sudète",),
    "sudiste": ("sudiste",),
    "sudistes": ("sudiste",),
    "sudorale": ("sudoral",),
    "sudorales": ("sudoral",),
    "sudoral": ("sudoral",),
    "sudoraux": ("sudoral",),
    "sudorifère": ("sudorifère",),
    "sudorifères": ("sudorifère",),
    "sudorifique": ("sudorifique",),
    "sudorifiques": ("sudorifique",),
    "sudoripare": ("sudoripare",),
    "sudoripares": ("sudoripare",),
    "suédoise": ("suédois",),
    "suédoises": ("suédois",),
    "suédois": ("suédois",),
    "suffect": ("suffect",),
    "suffects": ("suffect",),
    "suffixale": ("suffixal",),
    "suffixales": ("suffixal",),
    "suffixal": ("suffixal",),
    "suffixaux": ("suffixal",),
    "suggestible": ("suggestible",),
    "suggestibles": ("suggestible",),
    "suggestif": ("suggestif",),
    "suggestifs": ("suggestif",),
    "suggestive": ("suggestif",),
    "suggestives": ("suggestif",),
    "suggestologique": ("suggestologique",),
    "suggestologiques": ("suggestologique",),
    "suicidaire": ("suicidaire",),
    "suicidaires": ("suicidaire",),
    "suicidogène": ("suicidogène",),
    "suicidogènes": ("suicidogène",),
    "suiffeuse": ("suiffeux",),
    "suiffeuses": ("suiffeux",),
    "suiffeux": ("suiffeux",),
    "suisse": ("suisse",),
    "suisses": ("suisse",),
    "suitée": ("suitée",),
    "suitées": ("suitée",),
    "suivable": ("suivable",),
    "suivables": ("suivable",),
    "suiveur": ("suiveur",),
    "suiveurs": ("suiveur",),
    "suiveuse": ("suiveur",),
    "suiveuses": ("suiveur",),
    "suiviste": ("suiviste",),
    "suivistes": ("suiviste",),
    "sujet": ("sujet",),
    "sujets": ("sujet",),
    "sujette": ("sujet",),
    "sujettes": ("sujet",),
    "sulciforme": ("sulciforme",),
    "sulciformes": ("sulciforme",),
    "sulfamidique": ("sulfamidique",),
    "sulfamidiques": ("sulfamidique",),
    "sulfamidobenzoïque": ("sulfamidobenzoïque",),
    "sulfamidobenzoïques": ("sulfamidobenzoïque",),
    "sulfaminique": ("sulfaminique",),
    "sulfaminiques": ("sulfaminique",),
    "sulfamique": ("sulfamique",),
    "sulfamiques": ("sulfamique",),
    "sulfanilique": ("sulfanilique",),
    "sulfaniliques": ("sulfanilique",),
    "sulfénique": ("sulfénique",),
    "sulféniques": ("sulfénique",),
    "sulfhydrique": ("sulfhydrique",),
    "sulfhydriques": ("sulfhydrique",),
    "sulfindigotique": ("sulfindigotique",),
    "sulfindigotiques": ("sulfindigotique",),
    "sulfinique": ("sulfinique",),
    "sulfiniques": ("sulfinique",),
    "sulfitique": ("sulfitique",),
    "sulfitiques": ("sulfitique",),
    "sulfoarsénique": ("sulfoarsénique",),
    "sulfoarséniques": ("sulfoarsénique",),
    "sulfocadique": ("sulfocadique",),
    "sulfocadiques": ("sulfocadique",),
    "sulfocalcique": ("sulfocalcique",),
    "sulfocalciques": ("sulfocalcique",),
    "sulfocamphorique": ("sulfocamphorique",),
    "sulfocamphoriques": ("sulfocamphorique",),
    "sulfocarbonique": ("sulfocarbonique",),
    "sulfocarboniques": ("sulfocarbonique",),
    "sulfochlorhydrique": ("sulfochlorhydrique",),
    "sulfochlorhydriques": ("sulfochlorhydrique",),
    "sulfochromique": ("sulfochromique",),
    "sulfochromiques": ("sulfochromique",),
    "sulfocyanique": ("sulfocyanique",),
    "sulfocyaniques": ("sulfocyanique",),
    "sulfomanganique": ("sulfomanganique",),
    "sulfomanganiques": ("sulfomanganique",),
    "sulfométhylique": ("sulfométhylique",),
    "sulfométhyliques": ("sulfométhylique",),
    "sulfonique": ("sulfonique",),
    "sulfoniques": ("sulfonique",),
    "sulfonitrique": ("sulfonitrique",),
    "sulfonitriques": ("sulfonitrique",),
    "sulforicinique": ("sulforicinique",),
    "sulforiciniques": ("sulforicinique",),
    "sulfovinique": ("sulfovinique",),
    "sulfoviniques": ("sulfovinique",),
    "sulfureuse": ("sulfureux",),
    "sulfureuses": ("sulfureux",),
    "sulfureux": ("sulfureux",),
    "sulfurique": ("sulfurique",),
    "sulfuriques": ("sulfurique",),
    "sulpicien": ("sulpicien",),
    "sulpicienne": ("sulpicien",),
    "sulpiciennes": ("sulpicien",),
    "sulpiciens": ("sulpicien",),
    "sultane": ("sultane",),
    "sultanes": ("sultane",),
    "sumérien": ("sumérien",),
    "sumérienne": ("sumérien",),
    "sumériennes": ("sumérien",),
    "sumériens": ("sumérien",),
    "suméro-babylonien": ("suméro-babylonien",),
    "sunnite": ("sunnite",),
    "sunnites": ("sunnite",),
    "superaérodynamique": ("superaérodynamique",),
    "superaérodynamiques": ("superaérodynamique",),
    "superantigène": ("superantigène",),
    "superantigènes": ("superantigène",),
    "super": ("super",),
    "superbe": ("superbe",),
    "superbes": ("superbe",),
    "supercarré": ("supercarré",),
    "supercarrés": ("supercarré",),
    "supercritique": ("supercritique",),
    "supercritiques": ("supercritique",),
    "supère": ("supère",),
    "supères": ("supère",),
    "superélastique": ("superélastique",),
    "superélastiques": ("superélastique",),
    "superfétatoire": ("superfétatoire",),
    "superfétatoires": ("superfétatoire",),
    "superficiaire": ("superficiaire",),
    "superficiaires": ("superficiaire",),
    "superficielle": ("superficiel",),
    "superficielles": ("superficiel",),
    "superficiel": ("superficiel",),
    "superficiels": ("superficiel",),
    "superfluide": ("superfluide",),
    "superfluides": ("superfluide",),
    "supergrande": ("supergrand",),
    "super-grandes": ("super-grand",),
    "supergrandes": ("supergrand",),
    "super-grand": ("super-grand",),
    "supergrand": ("supergrand",),
    "super-grands": ("super-grand",),
    "supergrands": ("supergrand",),
    "superhétérodyne": ("superhétérodyne",),
    "superhétérodynes": ("superhétérodyne",),
    "superlatif": ("superlatif",),
    "superlatifs": ("superlatif",),
    "superlative": ("superlatif",),
    "superlatives": ("superlatif",),
    "superluminique": ("superluminique",),
    "superluminiques": ("superluminique",),
    "superluxe": ("superluxe",),
    "superobèse": ("superobèse",),
    "superobèses": ("superobèse",),
    "superpériphérique": ("superpériphérique",),
    "superpériphériques": ("superpériphérique",),
    "superplastique": ("superplastique",),
    "superplastiques": ("superplastique",),
    "superposable": ("superposable",),
    "superposables": ("superposable",),
    "superprédateur": ("superprédateur",),
    "superprédateurs": ("superprédateur",),
    "superprédatrice": ("superprédateur",),
    "superprédatrices": ("superprédateur",),
    "supersonique": ("supersonique",),
    "supersoniques": ("supersonique",),
    "superstitieuse": ("superstitieux",),
    "superstitieuses": ("superstitieux",),
    "superstitieux": ("superstitieux",),
    "superwelter": ("superwelter",),
    "supinateur": ("supinateur",),
    "supinateurs": ("supinateur",),
    "supinatrice": ("supinateur",),
    "supinatrices": ("supinateur",),
    "supplémentaire": ("supplémentaire",),
    "supplémentaires": ("supplémentaire",),
    "supplétif": ("supplétif",),
    "supplétifs": ("supplétif",),
    "supplétive": ("supplétif",),
    "supplétives": ("supplétif",),
    "supplétoire": ("supplétoire",),
    "supplétoires": ("supplétoire",),
    "supportable": ("supportable",),
    "supportables": ("supportable",),
    "supposable": ("supposable",),
    "supposables": ("supposable",),
    "suppresseur": ("suppresseur",),
    "suppresseurs": ("suppresseur",),
    "suppresseuse": ("suppresseur",),
    "suppresseuses": ("suppresseur",),
    "suppressif": ("suppressif",),
    "suppressifs": ("suppressif",),
    "suppressive": ("suppressif",),
    "suppressives": ("suppressif",),
    "supprimable": ("supprimable",),
    "supprimables": ("supprimable",),
    "suppuratif": ("suppuratif",),
    "suppuratifs": ("suppuratif",),
    "suppurative": ("suppuratif",),
    "suppuratives": ("suppuratif",),
    "suprabranchiale": ("suprabranchial",),
    "suprabranchiales": ("suprabranchial",),
    "suprabranchial": ("suprabranchial",),
    "suprabranchiaux": ("suprabranchial",),
    "suprachiasmatique": ("suprachiasmatique",),
    "suprachiasmatiques": ("suprachiasmatique",),
    "supraconducteur": ("supraconducteur",),
    "supraconducteurs": ("supraconducteur",),
    "supra-conductrice": ("supra-conducteur",),
    "supraconductrice": ("supraconducteur",),
    "supraconductrices": ("supraconducteur",),
    "supracondylien": ("supracondylien",),
    "supracondylienne": ("supracondylien",),
    "supracondyliennes": ("supracondylien",),
    "supracondyliens": ("supracondylien",),
    "supraglottique": ("supraglottique",),
    "supraglottiques": ("supraglottique",),
    "supralapsaire": ("supralapsaire",),
    "supralapsaires": ("supralapsaire",),
    "supraliminaire": ("supraliminaire",),
    "supraliminaires": ("supraliminaire",),
    "supralittorale": ("supralittoral",),
    "supralittorales": ("supralittoral",),
    "supralittoral": ("supralittoral",),
    "supralittoraux": ("supralittoral",),
    "supralocale": ("supralocal",),
    "supralocales": ("supralocal",),
    "supralocal": ("supralocal",),
    "supralocaux": ("supralocal",),
    "supramoléculaire": ("supramoléculaire",),
    "supramoléculaires": ("supramoléculaire",),
    "supra-nationale": ("supra-national",),
    "supranationale": ("supranational",),
    "supra-nationales": ("supra-national",),
    "supranationales": ("supranational",),
    "supra-national": ("supra-national",),
    "supranational": ("supranational",),
    "supra-nationaux": ("supra-national",),
    "supranationaux": ("supranational",),
    "supranationaliste": ("supranationaliste",),
    "supranationalistes": ("supranationaliste",),
    "supranaturaliste": ("supranaturaliste",),
    "supranaturalistes": ("supranaturaliste",),
    "supranaturelle": ("supranaturel",),
    "supranaturelles": ("supranaturel",),
    "supranaturel": ("supranaturel",),
    "supranaturels": ("supranaturel",),
    "supranormale": ("supranormal",),
    "supranormales": ("supranormal",),
    "supranormal": ("supranormal",),
    "supranormaux": ("supranormal",),
    "supranucléaire": ("supranucléaire",),
    "supranucléaires": ("supranucléaire",),
    "supra-occipitales": ("supra-occipital",),
    "supra-occipital": ("supraoccipital",),
    "supra-occipitaux": ("supraoccipital",),
    "supra-optiques": ("supra-optique",),
    "suprarénale": ("suprarénal",),
    "suprarénales": ("suprarénal",),
    "suprarénal": ("suprarénal",),
    "suprarénaux": ("suprarénal",),
    "suprasegmentale": ("suprasegmental",),
    "suprasegmentales": ("suprasegmental",),
    "suprasegmental": ("suprasegmental",),
    "suprasegmentaux": ("suprasegmental",),
    "suprasellaire": ("suprasellaire",),
    "suprasellaires": ("suprasellaire",),
    "suprasensible": ("suprasensible",),
    "suprasensibles": ("suprasensible",),
    "supratemporale": ("supratemporal",),
    "supratemporales": ("supratemporal",),
    "supratemporal": ("supratemporal",),
    "supratemporaux": ("supratemporal",),
    "supraterrestre": ("supraterrestre",),
    "supra-terrestres": ("supraterrestre",),
    "supraterrestres": ("supraterrestre",),
    "supratidale": ("supratidal",),
    "supratidales": ("supratidal",),
    "supratidal": ("supratidal",),
    "supratidaux": ("supratidal",),
    "supraventriculaire": ("supraventriculaire",),
    "supraventriculaires": ("supraventriculaire",),
    "suprême": ("suprême",),
    "suprêmes": ("suprême",),
    "suraiguë": ("suraigu",),
    "suraiguës": ("suraigu",),
    "suraigu": ("suraigu",),
    "suraigus": ("suraigu",),
    "surale": ("sural",),
    "surales": ("sural",),
    "sural": ("sural",),
    "suraux": ("sural",),
    "suranale": ("suranal",),
    "suranales": ("suranal",),
    "suranal": ("suranal",),
    "suranaux": ("suranal",),
    "sure": ("sur",),
    "sûre": ("sûr",),
    "sures": ("sur",),
    "sûres": ("sûr",),
    "sur": ("sur",),
    "sûr": ("sûr",),
    "surs": ("sur",),
    "sûrs": ("sûr",),
    "surcostale": ("surcostal",),
    "surcostales": ("surcostal",),
    "surcostal": ("surcostal",),
    "surcostaux": ("surcostal",),
    "surenchérisseur": ("surenchérisseur",),
    "surenchérisseurs": ("surenchérisseur",),
    "surenchérisseuse": ("surenchérisseur",),
    "surenchérisseuses": ("surenchérisseur",),
    "surérogatoire": ("surérogatoire",),
    "surérogatoires": ("surérogatoire",),
    "suret": ("suret",),
    "surets": ("suret",),
    "surette": ("suret",),
    "surettes": ("suret",),
    "surexcitable": ("surexcitable",),
    "surexcitables": ("surexcitable",),
    "surfacique": ("surfacique",),
    "surfaciques": ("surfacique",),
    "surfacturable": ("surfacturable",),
    "surfacturables": ("surfacturable",),
    "surfusible": ("surfusible",),
    "surfusibles": ("surfusible",),
    "surgénérateur": ("surgénérateur",),
    "surgénérateurs": ("surgénérateur",),
    "surgénératrice": ("surgénérateur",),
    "surgénératrices": ("surgénérateur",),
    "surgras": ("surgras",),
    "surgrasse": ("surgras",),
    "surgrasses": ("surgras",),
    "surjalée": ("surjalée",),
    "surjalées": ("surjalée",),
    "surjectif": ("surjectif",),
    "surjectifs": ("surjectif",),
    "surjective": ("surjectif",),
    "surjectives": ("surjectif",),
    "surmoïque": ("surmoïque",),
    "surmoïques": ("surmoïque",),
    "surmontable": ("surmontable",),
    "surmontables": ("surmontable",),
    "surmultiplicateur": ("surmultiplicateur",),
    "surmultiplicateurs": ("surmultiplicateur",),
    "surmultiplicatrice": ("surmultiplicateur",),
    "surmultiplicatrices": ("surmultiplicateur",),
    "surnaturaliste": ("surnaturaliste",),
    "surnaturalistes": ("surnaturaliste",),
    "surnaturelle": ("surnaturel",),
    "surnaturelles": ("surnaturel",),
    "surnaturel": ("surnaturel",),
    "surnaturels": ("surnaturel",),
    "surnuméraire": ("surnuméraire",),
    "surnuméraires": ("surnuméraire",),
    "surosculateur": ("surosculateur",),
    "surosculateurs": ("surosculateur",),
    "surosculatrice": ("surosculateur",),
    "surosculatrices": ("surosculateur",),
    "surpassable": ("surpassable",),
    "surpassables": ("surpassable",),
    "surprise": ("surprise",),
    "surprises": ("surpris",),
    "surpris": ("surpris",),
    "surproducteur": ("surproducteur",),
    "surproducteurs": ("surproducteur",),
    "surproductrice": ("surproducteur",),
    "surproductrices": ("surproducteur",),
    "surprotecteur": ("surprotecteur",),
    "surprotecteurs": ("surprotecteur",),
    "surprotectrice": ("surprotecteur",),
    "surprotectrices": ("surprotecteur",),
    "surréaliste": ("surréaliste",),
    "surréalistes": ("surréaliste",),
    "surréelle": ("surréel",),
    "surréelles": ("surréel",),
    "surréel": ("surréel",),
    "surréels": ("surréel",),
    "surrégénérateur": ("surrégénérateur",),
    "surrégénérateurs": ("surrégénérateur",),
    "surrégénératrice": ("surrégénérateur",),
    "surrégénératrices": ("surrégénérateur",),
    "surrénale": ("surrénal",),
    "surrénales": ("surrénal",),
    "surrénal": ("surrénal",),
    "surrénaux": ("surrénal",),
    "surrénalien": ("surrénalien",),
    "surrénalienne": ("surrénalien",),
    "surrénaliennes": ("surrénalien",),
    "surrénaliens": ("surrénalien",),
    "surrénalogénitale": ("surrénalogénital",),
    "surrénalogénitales": ("surrénalogénital",),
    "surrénalogénital": ("surrénalogénital",),
    "surrénalogénitaux": ("surrénalogénital",),
    "surrénogénitale": ("surrénogénital",),
    "surrénogénitales": ("surrénogénital",),
    "surrénogénital": ("surrénogénital",),
    "surrénogénitaux": ("surrénogénital",),
    "surrénoprive": ("surrénoprive",),
    "surrénoprives": ("surrénoprive",),
    "sursitaire": ("sursitaire",),
    "sursitaires": ("sursitaire",),
    "sursolide": ("sursolide",),
    "sursolides": ("sursolide",),
    "surviable": ("surviable",),
    "surviables": ("surviable",),
    "survireur": ("survireur",),
    "survireurs": ("survireur",),
    "survireuse": ("survireur",),
    "survireuses": ("survireur",),
    "survolteur": ("survolteur",),
    "survolteurs": ("survolteur",),
    "sus-arachnoïdien": ("sus-arachnoïdien",),
    "sus-arachnoïdienne": ("sus-arachnoïdien",),
    "sus-arachnoïdiens": ("sus-arachnoïdien",),
    "sus-caudale": ("sus-caudal",),
    "susceptible": ("susceptible",),
    "susceptibles": ("susceptible",),
    "sus-claviculaire": ("sus-claviculaire",),
    "sus-épineuse": ("sus-épineux",),
    "sus-épineuses": ("sus-épineux",),
    "sus-hépatique": ("sus-hépatique",),
    "sus-hyoïdien": ("sus-hyoïdien",),
    "sus-hyoïdienne": ("sus-hyoïdien",),
    "sus-hyoïdiens": ("sus-hyoïdien",),
    "susjacente": ("susjacent",),
    "susjacentes": ("susjacent",),
    "sus-jacent": ("sus-jacent",),
    "susjacent": ("susjacent",),
    "sus-jacents": ("sus-jacent",),
    "susjacents": ("susjacent",),
    "sus-maxillaire": ("sus-maxillaire",),
    "sus-occipitales": ("sus-occipital",),
    "sus-occipital": ("sus-occipital",),
    "sus-occipitaux": ("sus-occipital",),
    "sus-optiques": ("sus-optique",),
    "sus-orbitaire": ("sus-orbitaire",),
    "suspens": ("suspens",),
    "suspenseur": ("suspenseur",),
    "suspenseurs": ("suspenseur",),
    "suspensif": ("suspensif",),
    "suspensifs": ("suspensif",),
    "suspensive": ("suspensif",),
    "suspensives": ("suspensif",),
    "suspiciens": ("suspiciens",),
    "suspicieuse": ("suspicieux",),
    "suspicieuses": ("suspicieux",),
    "suspicieux": ("suspicieux",),
    "suspirieuse": ("suspirieux",),
    "suspirieuses": ("suspirieux",),
    "suspirieux": ("suspirieux",),
    "sus-pubien": ("sus-pubien",),
    "suspubien": ("suspubien",),
    "sus-pubienne": ("sus-pubien",),
    "suspubienne": ("suspubien",),
    "suspubiennes": ("suspubien",),
    "sus-pubiens": ("sus-pubien",),
    "suspubiens": ("suspubien",),
    "sus-scapulaire": ("sus-scapulaire",),
    "sus-tensoriel": ("sus-tensoriel",),
    "sus-tensoriels": ("sus-tensoriel",),
    "sustentateur": ("sustentateur",),
    "sustentateurs": ("sustentateur",),
    "sustentatrice": ("sustentateur",),
    "sustentatrices": ("sustentateur",),
    "suturale": ("sutural",),
    "suturales": ("sutural",),
    "sutural": ("sutural",),
    "suturaux": ("sutural",),
    "svelte": ("svelte",),
    "sveltes": ("svelte",),
    "swing": ("swing",),
    "sybarite": ("sybarite",),
    "sybarites": ("sybarite",),
    "sybaritique": ("sybaritique",),
    "sybaritiques": ("sybaritique",),
    "sycotique": ("sycotique",),
    "sycotiques": ("sycotique",),
    "syénitique": ("syénitique",),
    "syénitiques": ("syénitique",),
    "syllabique": ("syllabique",),
    "syllabiques": ("syllabique",),
    "sylleptique": ("sylleptique",),
    "sylleptiques": ("sylleptique",),
    "syllogistique": ("syllogistique",),
    "syllogistiques": ("syllogistique",),
    "sylvestre": ("sylvestre",),
    "sylvestres": ("sylvestre",),
    "sylvicole": ("sylvicole",),
    "sylvicoles": ("sylvicole",),
    "sylvien": ("sylvien",),
    "sylvienne": ("sylvien",),
    "sylviennes": ("sylvien",),
    "sylviens": ("sylvien",),
    "sylvo-cynégétiques": ("sylvo-cynégétique",),
    "symbiote": ("symbiote",),
    "symbiotes": ("symbiote",),
    "symbiotique": ("symbiotique",),
    "symbiotiques": ("symbiotique",),
    "symbolique": ("symbolique",),
    "symboliques": ("symbolique",),
    "symboliste": ("symboliste",),
    "symbolistes": ("symboliste",),
    "symèle": ("symèle",),
    "symèles": ("symèle",),
    "symétrique": ("symétrique",),
    "symétriques": ("symétrique",),
    "symétrisable": ("symétrisable",),
    "symétrisables": ("symétrisable",),
    "sympa": ("sympa",),
    "sympathicogénique": ("sympathicogénique",),
    "sympathicogéniques": ("sympathicogénique",),
    "sympathicolytique": ("sympathicolytique",),
    "sympathicolytiques": ("sympathicolytique",),
    "sympathicomimétique": ("sympathicomimétique",),
    "sympathicomimétiques": ("sympathicomimétique",),
    "sympathicoplégique": ("sympathicoplégique",),
    "sympathicoplégiques": ("sympathicoplégique",),
    "sympathicotonique": ("sympathicotonique",),
    "sympathicotoniques": ("sympathicotonique",),
    "sympathique": ("sympathique",),
    "sympathiques": ("sympathique",),
    "sympathoblastique": ("sympathoblastique",),
    "sympathoblastiques": ("sympathoblastique",),
    "sympathogonique": ("sympathogonique",),
    "sympathogoniques": ("sympathogonique",),
    "sympatholytique": ("sympatholytique",),
    "sympatholytiques": ("sympatholytique",),
    "sympathomimétique": ("sympathomimétique",),
    "sympathomimétiques": ("sympathomimétique",),
    "sympathoplégique": ("sympathoplégique",),
    "sympathoplégiques": ("sympathoplégique",),
    "sympatrique": ("sympatrique",),
    "sympatriques": ("sympatrique",),
    "symphile": ("symphile",),
    "symphiles": ("symphile",),
    "symphonique": ("symphonique",),
    "symphoniques": ("symphonique",),
    "symphysaire": ("symphysaire",),
    "symphysaires": ("symphysaire",),
    "symplasmique": ("symplasmique",),
    "symplasmiques": ("symplasmique",),
    "symplectique": ("symplectique",),
    "symplectiques": ("symplectique",),
    "sympodiale": ("sympodial",),
    "sympodiales": ("sympodial",),
    "sympodial": ("sympodial",),
    "sympodiaux": ("sympodial",),
    "sympodique": ("sympodique",),
    "sympodiques": ("sympodique",),
    "symptomatique": ("symptomatique",),
    "symptomatiques": ("symptomatique",),
    "symptomatologique": ("symptomatologique",),
    "symptomatologiques": ("symptomatologique",),
    "synagogale": ("synagogal",),
    "synagogales": ("synagogal",),
    "synagogal": ("synagogal",),
    "synagogaux": ("synagogal",),
    "synallagmatique": ("synallagmatique",),
    "synallagmatiques": ("synallagmatique",),
    "synaptique": ("synaptique",),
    "synaptiques": ("synaptique",),
    "synaptolytique": ("synaptolytique",),
    "synaptolytiques": ("synaptolytique",),
    "synaptoplégique": ("synaptoplégique",),
    "synaptoplégiques": ("synaptoplégique",),
    "synaptosomiale": ("synaptosomial",),
    "synaptosomiales": ("synaptosomial",),
    "synaptosomial": ("synaptosomial",),
    "synaptosomiaux": ("synaptosomial",),
    "synarchique": ("synarchique",),
    "synarchiques": ("synarchique",),
    "synarthrodiale": ("synarthrodial",),
    "synarthrodiales": ("synarthrodial",),
    "synarthrodial": ("synarthrodial",),
    "synarthrodiaux": ("synarthrodial",),
    "syncatégorématique": ("syncatégorématique",),
    "syncatégorématiques": ("syncatégorématique",),
    "synchromiste": ("synchromiste",),
    "synchromistes": ("synchromiste",),
    "synchrone": ("synchrone",),
    "synchrones": ("synchrone",),
    "synchronique": ("synchronique",),
    "synchroniques": ("synchronique",),
    "synchrotronique": ("synchrotronique",),
    "synchrotroniques": ("synchrotronique",),
    "syncinétique": ("syncinétique",),
    "syncinétiques": ("syncinétique",),
    "syncitiale": ("syncitial",),
    "syncitiales": ("syncitial",),
    "syncitial": ("syncitial",),
    "syncitiaux": ("syncitial",),
    "synclinale": ("synclinal",),
    "synclinales": ("synclinal",),
    "synclinal": ("synclinal",),
    "synclinaux": ("synclinal",),
    "syncopale": ("syncopal",),
    "syncopales": ("syncopal",),
    "syncopal": ("syncopal",),
    "syncopaux": ("syncopal",),
    "syncrétique": ("syncrétique",),
    "syncrétiques": ("syncrétique",),
    "syncrétiste": ("syncrétiste",),
    "syncrétistes": ("syncrétiste",),
    "syncristallisable": ("syncristallisable",),
    "syncristallisables": ("syncristallisable",),
    "syncytiale": ("syncytial",),
    "syncytiales": ("syncytial",),
    "syncytial": ("syncytial",),
    "syncytiaux": ("syncytial",),
    "syndactyle": ("syndactyle",),
    "syndactyles": ("syndactyle",),
    "syndesmochoriale": ("syndesmochorial",),
    "syndesmochoriales": ("syndesmochorial",),
    "syndesmochorial": ("syndesmochorial",),
    "syndesmochoriaux": ("syndesmochorial",),
    "syndicable": ("syndicable",),
    "syndicables": ("syndicable",),
    "syndicale": ("syndical",),
    "syndicales": ("syndical",),
    "syndical": ("syndical",),
    "syndicaux": ("syndical",),
    "syndicaliste": ("syndicaliste",),
    "syndicalistes": ("syndicaliste",),
    "syndicataire": ("syndicataire",),
    "syndicataires": ("syndicataire",),
    "syndiotactique": ("syndiotactique",),
    "syndiotactiques": ("syndiotactique",),
    "synergétique": ("synergétique",),
    "synergétiques": ("synergétique",),
    "synergique": ("synergique",),
    "synergiques": ("synergique",),
    "synergiste": ("synergiste",),
    "synergistes": ("synergiste",),
    "syngamique": ("syngamique",),
    "syngamiques": ("syngamique",),
    "syngénique": ("syngénique",),
    "syngéniques": ("syngénique",),
    "synodale": ("synodal",),
    "synodales": ("synodal",),
    "synodal": ("synodal",),
    "synodaux": ("synodal",),
    "synodique": ("synodique",),
    "synodiques": ("synodique",),
    "synonyme": ("synonyme",),
    "synonymes": ("synonyme",),
    "synonymique": ("synonymique",),
    "synonymiques": ("synonymique",),
    "synoptique": ("synoptique",),
    "synoptiques": ("synoptique",),
    "synostosique": ("synostosique",),
    "synostosiques": ("synostosique",),
    "synoviale": ("synovial",),
    "synoviales": ("synovial",),
    "synovial": ("synovial",),
    "synoviaux": ("synovial",),
    "synpériplanaire": ("synpériplanaire",),
    "synpériplanaires": ("synpériplanaire",),
    "synschisteuse": ("synschisteux",),
    "synschisteuses": ("synschisteux",),
    "synschisteux": ("synschisteux",),
    "synsédimentaire": ("synsédimentaire",),
    "synsédimentaires": ("synsédimentaire",),
    "syntactique": ("syntactique",),
    "syntactiques": ("syntactique",),
    "syntagmatique": ("syntagmatique",),
    "syntagmatiques": ("syntagmatique",),
    "syntaxique": ("syntaxique",),
    "syntaxiques": ("syntaxique",),
    "syntectique": ("syntectique",),
    "syntectiques": ("syntectique",),
    "syntectonique": ("syntectonique",),
    "syntectoniques": ("syntectonique",),
    "synténique": ("synténique",),
    "synténiques": ("synténique",),
    "synthétique": ("synthétique",),
    "synthétiques": ("synthétique",),
    "synthétisable": ("synthétisable",),
    "synthétisables": ("synthétisable",),
    "synthétiseur": ("synthétiseur",),
    "synthétiseurs": ("synthétiseur",),
    "synthétiseuse": ("synthétiseur",),
    "synthétiseuses": ("synthétiseur",),
    "synthétiste": ("synthétiste",),
    "synthétistes": ("synthétiste",),
    "syntone": ("syntone",),
    "syntones": ("syntone",),
    "syphilitique": ("syphilitique",),
    "syphilitiques": ("syphilitique",),
    "syphiloïde": ("syphiloïde",),
    "syphiloïdes": ("syphiloïde",),
    "syphilophobe": ("syphilophobe",),
    "syphilophobes": ("syphilophobe",),
    "syriaque": ("syriaque",),
    "syriaques": ("syriaque",),
    "syrien": ("syrien",),
    "syrienne": ("syrien",),
    "syriennes": ("syrien",),
    "syriens": ("syrien",),
    "syringique": ("syringique",),
    "syringiques": ("syringique",),
    "syringomyélique": ("syringomyélique",),
    "syringomyéliques": ("syringomyélique",),
    "syro-libanaise": ("syro-libanais",),
    "syro-libanais": ("syro-libanais",),
    "syro-malabare": ("syro-malabare",),
    "syro-mésopotamiennes": ("syro-mésopotamien",),
    "systématique": ("systématique",),
    "systématiques": ("systématique",),
    "systématologique": ("systématologique",),
    "systématologiques": ("systématologique",),
    "systémicien": ("systémicien",),
    "systémicienne": ("systémicien",),
    "systémiciennes": ("systémicien",),
    "systémiciens": ("systémicien",),
    "systémique": ("systémique",),
    "systémiques": ("systémique",),
    "systolique": ("systolique",),
    "systoliques": ("systolique",),
    "systyle": ("systyle",),
    "systyles": ("systyle",),
    "tabac": ("tabac",),
    "tabacogène": ("tabacogène",),
    "tabacogènes": ("tabacogène",),
    "tabagique": ("tabagique",),
    "tabagiques": ("tabagique",),
    "tabellaire": ("tabellaire",),
    "tabellaires": ("tabellaire",),
    "tabétique": ("tabétique",),
    "tabétiques": ("tabétique",),
    "tabloïd": ("tabloïd",),
    "tabloïde": ("tabloïde",),
    "tabloïdes": ("tabloïde",),
    "tabulaire": ("tabulaire",),
    "tabulaires": ("tabulaire",),
    "tachéométrique": ("tachéométrique",),
    "tachéométriques": ("tachéométrique",),
    "tachiste": ("tachiste",),
    "tachistes": ("tachiste",),
    "tachistoscopique": ("tachistoscopique",),
    "tachistoscopiques": ("tachistoscopique",),
    "tachycardique": ("tachycardique",),
    "tachycardiques": ("tachycardique",),
    "tachygraphique": ("tachygraphique",),
    "tachygraphiques": ("tachygraphique",),
    "tacite": ("tacite",),
    "tacites": ("tacite",),
    "taciturne": ("taciturne",),
    "taciturnes": ("taciturne",),
    "taconique": ("taconique",),
    "taconiques": ("taconique",),
    "tactile": ("tactile",),
    "tactiles": ("tactile",),
    "tactique": ("tactique",),
    "tactiques": ("tactique",),
    "tactognosique": ("tactognosique",),
    "tactognosiques": ("tactognosique",),
    "taenicide": ("taenicide",),
    "taenicides": ("taenicide",),
    "taenifuge": ("taenifuge",),
    "taenifuges": ("taenifuge",),
    "tagmémique": ("tagmémique",),
    "tagmémiques": ("tagmémique",),
    "tahitien": ("tahitien",),
    "tahitienne": ("tahitien",),
    "tahitiennes": ("tahitien",),
    "tahitiens": ("tahitien",),
    "taillable": ("taillable",),
    "taillables": ("taillable",),
    "taiseuse": ("taiseux",),
    "taiseuses": ("taiseux",),
    "taiseux": ("taiseux",),
    "taisible": ("taisible",),
    "taisibles": ("taisible",),
    "taïwanaise": ("taïwanais",),
    "taïwanaises": ("taïwanais",),
    "taïwanais": ("taïwanais",),
    "tala": ("tala",),
    "talas": ("tala",),
    "talentueuse": ("talentueux",),
    "talentueuses": ("talentueux",),
    "talentueux": ("talentueux",),
    "talismanique": ("talismanique",),
    "talismaniques": ("talismanique",),
    "talmudique": ("talmudique",),
    "talmudiques": ("talmudique",),
    "talmudiste": ("talmudiste",),
    "talmudistes": ("talmudiste",),
    "talomucique": ("talomucique",),
    "talomuciques": ("talomucique",),
    "talonique": ("talonique",),
    "taloniques": ("talonique",),
    "talonnable": ("talonnable",),
    "talonnables": ("talonnable",),
    "talqueuse": ("talqueux",),
    "talqueuses": ("talqueux",),
    "talqueux": ("talqueux",),
    "talus": ("talus",),
    "tamponneur": ("tamponneur",),
    "tamponneurs": ("tamponneur",),
    "tamponneuse": ("tamponneur",),
    "tamponneuses": ("tamponneur",),
    "tangentielle": ("tangentiel",),
    "tangentielles": ("tangentiel",),
    "tangentiel": ("tangentiel",),
    "tangentiels": ("tangentiel",),
    "tangible": ("tangible",),
    "tangibles": ("tangible",),
    "tango": ("tango",),
    "tanneur": ("tanneur",),
    "tanneurs": ("tanneur",),
    "tanneuse": ("tanneur",),
    "tanneuses": ("tanneur",),
    "tannique": ("tannique",),
    "tanniques": ("tannique",),
    "tantalique": ("tantalique",),
    "tantaliques": ("tantalique",),
    "tantième": ("tantième",),
    "tantièmes": ("tantième",),
    "tantrique": ("tantrique",),
    "tantriques": ("tantrique",),
    "tanzanien": ("tanzanien",),
    "tanzanienne": ("tanzanien",),
    "tanzaniennes": ("tanzanien",),
    "tanzaniens": ("tanzanien",),
    "taoïque": ("taoïque",),
    "taoïques": ("taoïque",),
    "taoïste": ("taoïste",),
    "taoïstes": ("taoïste",),
    "tapageur": ("tapageur",),
    "tapageurs": ("tapageur",),
    "tapageuse": ("tapageur",),
    "tapageuses": ("tapageur",),
    "taphonomique": ("taphonomique",),
    "taphonomiques": ("taphonomique",),
    "tapissière": ("tapissier",),
    "tapissières": ("tapissier",),
    "tapissier": ("tapissier",),
    "tapissiers": ("tapissier",),
    "taraudeur": ("taraudeur",),
    "taraudeurs": ("taraudeur",),
    "taraudeuse": ("taraudeur",),
    "taraudeuses": ("taraudeur",),
    "tardenoisien": ("tardenoisien",),
    "tardenoisienne": ("tardenoisien",),
    "tardenoisiennes": ("tardenoisien",),
    "tardenoisiens": ("tardenoisien",),
    "tardif": ("tardif",),
    "tardifs": ("tardif",),
    "tardive": ("tardif",),
    "tardives": ("tardif",),
    "tardiglaciaire": ("tardiglaciaire",),
    "tardiglaciaires": ("tardiglaciaire",),
    "tardigrade": ("tardigrade",),
    "tardigrades": ("tardigrade",),
    "targuie": ("targui",),
    "targui": ("targui",),
    "touareg": ("touareg",),
    "touarègue": ("targui",),
    "targumique": ("targumique",),
    "targumiques": ("targumique",),
    "tarifaire": ("tarifaire",),
    "tarifaires": ("tarifaire",),
    "tarissable": ("tarissable",),
    "tarissables": ("tarissable",),
    "tarpéien": ("tarpéien",),
    "tarpéienne": ("tarpéien",),
    "tarpéiennes": ("tarpéien",),
    "tarpéiens": ("tarpéien",),
    "tarsale": ("tarsal",),
    "tarsales": ("tarsal",),
    "tarsal": ("tarsal",),
    "tarsaux": ("tarsal",),
    "tarse": ("tarse",),
    "tarses": ("tarse",),
    "tarsien": ("tarsien",),
    "tarsienne": ("tarsien",),
    "tarsiennes": ("tarsien",),
    "tarsiens": ("tarsien",),
    "tartare": ("tartare",),
    "tartares": ("tartare",),
    "tarte": ("tarte",),
    "tartes": ("tarte",),
    "tartignolle": ("tartignolle",),
    "tartignolles": ("tartignolle",),
    "tartinable": ("tartinable",),
    "tartinables": ("tartinable",),
    "tartineur": ("tartineur",),
    "tartineurs": ("tartineur",),
    "tartreuse": ("tartreux",),
    "tartreuses": ("tartreux",),
    "tartreux": ("tartreux",),
    "tartrique": ("tartrique",),
    "tartriques": ("tartrique",),
    "tartronique": ("tartronique",),
    "tartroniques": ("tartronique",),
    "tasmanien": ("tasmanien",),
    "tasmanienne": ("tasmanien",),
    "tasmaniennes": ("tasmanien",),
    "tasmaniens": ("tasmanien",),
    "tatillon": ("tatillon",),
    "tatillonne": ("tatillon",),
    "tatillonnes": ("tatillon",),
    "tatillons": ("tatillon",),
    "taupière": ("taupier",),
    "taupières": ("taupier",),
    "taupier": ("taupier",),
    "taupiers": ("taupier",),
    "taurobolique": ("taurobolique",),
    "tauroboliques": ("taurobolique",),
    "taurocholique": ("taurocholique",),
    "taurocholiques": ("taurocholique",),
    "tauromachique": ("tauromachique",),
    "tauromachiques": ("tauromachique",),
    "tautochrone": ("tautochrone",),
    "tautochrones": ("tautochrone",),
    "tautologique": ("tautologique",),
    "tautologiques": ("tautologique",),
    "tautomère": ("tautomère",),
    "tautomères": ("tautomère",),
    "tautomérique": ("tautomérique",),
    "tautomériques": ("tautomérique",),
    "taxable": ("taxable",),
    "taxables": ("taxable",),
    "taxateur": ("taxateur",),
    "taxateurs": ("taxateur",),
    "taxatrice": ("taxateur",),
    "taxatrices": ("taxateur",),
    "taxatif": ("taxatif",),
    "taxatifs": ("taxatif",),
    "taxative": ("taxatif",),
    "taxatives": ("taxatif",),
    "taxidermique": ("taxidermique",),
    "taxidermiques": ("taxidermique",),
    "taxinomique": ("taxinomique",),
    "taxinomiques": ("taxinomique",),
    "taxique": ("taxique",),
    "taxiques": ("taxique",),
    "taxonomique": ("taxonomique",),
    "taxonomiques": ("taxonomique",),
    "taylorien": ("taylorien",),
    "taylorienne": ("taylorien",),
    "tayloriennes": ("taylorien",),
    "tayloriens": ("taylorien",),
    "tchadien": ("tchadien",),
    "tchadienne": ("tchadien",),
    "tchadiennes": ("tchadien",),
    "tchadiens": ("tchadien",),
    "tchécoslovaque": ("tchécoslovaque",),
    "tchécoslovaques": ("tchécoslovaque",),
    "tchékiste": ("tchékiste",),
    "tchékistes": ("tchékiste",),
    "tchèque": ("tchèque",),
    "tchèques": ("tchèque",),
    "tchetchène": ("tchetchène",),
    "tchétchène": ("tchétchène",),
    "tchetchènes": ("tchetchène",),
    "tchétchènes": ("tchétchène",),
    "tchouvache": ("tchouvache",),
    "tchouvaches": ("tchouvache",),
    "technétronique": ("technétronique",),
    "technétroniques": ("technétronique",),
    "techniciste": ("techniciste",),
    "technicistes": ("techniciste",),
    "technico-commerciale": ("technico-commercial",),
    "technico-commercial": ("technico-commercial",),
    "technico-commerciaux": ("technico-commercial",),
    "technico-scientifique": ("technico-scientifique",),
    "technico-scientifiques": ("technico-scientifique",),
    "technique": ("technique",),
    "techniques": ("technique",),
    "techno": ("techno",),
    "technobureaucratique": ("technobureaucratique",),
    "technobureaucratiques": ("technobureaucratique",),
    "technocratique": ("technocratique",),
    "technocratiques": ("technocratique",),
    "techno-économique": ("technoéconomique",),
    "technoéconomique": ("technoéconomique",),
    "technoéconomiques": ("technoéconomique",),
    "technographique": ("technographique",),
    "technographiques": ("technographique",),
    "techno-industriel": ("techno-industriel",),
    "technologique": ("technologique",),
    "technologiques": ("technologique",),
    "technophile": ("technophile",),
    "technophiles": ("technophile",),
    "tecteur": ("tecteur",),
    "tecteurs": ("tecteur",),
    "tectrice": ("tectrice",),
    "tectrices": ("tectrice",),
    "tectonique": ("tectonique",),
    "tectoniques": ("tectonique",),
    "tectonométamorphique": ("tectonométamorphique",),
    "tectonométamorphiques": ("tectonométamorphique",),
    "tegmentale": ("tegmental",),
    "tegmentales": ("tegmental",),
    "tegmental": ("tegmental",),
    "tegmentaux": ("tegmental",),
    "tégumentaire": ("tégumentaire",),
    "tégumentaires": ("tégumentaire",),
    "teigneuse": ("teigneux",),
    "teigneuses": ("teigneux",),
    "teigneux": ("teigneux",),
    "teilhardien": ("teilhardien",),
    "teilhardienne": ("teilhardien",),
    "teilhardiennes": ("teilhardien",),
    "teilhardiens": ("teilhardien",),
    "télangiectasique": ("télangiectasique",),
    "télangiectasiques": ("télangiectasique",),
    "telle": ("tel",),
    "telles": ("tel",),
    "tel": ("tel",),
    "tels": ("tel",),
    "télé": ("télé",),
    "téléautographique": ("téléautographique",),
    "téléautographiques": ("téléautographique",),
    "téléceptif": ("téléceptif",),
    "téléceptifs": ("téléceptif",),
    "téléceptive": ("téléceptif",),
    "téléceptives": ("téléceptif",),
    "téléchargeable": ("téléchargeable",),
    "téléchargeables": ("téléchargeable",),
    "téléchélique": ("téléchélique",),
    "téléchéliques": ("téléchélique",),
    "télécom": ("télécom",),
    "télécommandable": ("télécommandable",),
    "télécommandables": ("télécommandable",),
    "télédiastolique": ("télédiastolique",),
    "télédiastoliques": ("télédiastolique",),
    "télédynamique": ("télédynamique",),
    "télédynamiques": ("télédynamique",),
    "téléférique": ("téléférique",),
    "téléfériques": ("téléférique",),
    "télégénique": ("télégénique",),
    "télégéniques": ("télégénique",),
    "télégraphique": ("télégraphique",),
    "télégraphiques": ("télégraphique",),
    "télégraphiste": ("télégraphiste",),
    "télégraphistes": ("télégraphiste",),
    "téléguidable": ("téléguidable",),
    "téléguidables": ("téléguidable",),
    "téléinformatique": ("téléinformatique",),
    "téléinformatiques": ("téléinformatique",),
    "télémanipulateur": ("télémanipulateur",),
    "télémanipulateurs": ("télémanipulateur",),
    "télémanipulatrice": ("télémanipulateur",),
    "télémanipulatrices": ("télémanipulateur",),
    "télématique": ("télématique",),
    "télématiques": ("télématique",),
    "télémécanique": ("télémécanique",),
    "télémécaniques": ("télémécanique",),
    "télémétrique": ("télémétrique",),
    "télémétriques": ("télémétrique",),
    "télencéphalique": ("télencéphalique",),
    "télencéphaliques": ("télencéphalique",),
    "téléologique": ("téléologique",),
    "téléologiques": ("téléologique",),
    "télépathe": ("télépathe",),
    "télépathes": ("télépathe",),
    "télépathique": ("télépathique",),
    "télépathiques": ("télépathique",),
    "téléphérique": ("téléphérique",),
    "téléphériques": ("téléphérique",),
    "téléphonique": ("téléphonique",),
    "téléphoniques": ("téléphonique",),
    "téléphotographique": ("téléphotographique",),
    "téléphotographiques": ("téléphotographique",),
    "téléportable": ("téléportable",),
    "téléportables": ("téléportable",),
    "télescopeur": ("télescopeur",),
    "téléscopeur": ("téléscopeur",),
    "télescopeurs": ("télescopeur",),
    "téléscopeurs": ("téléscopeur",),
    "télescopeuse": ("télescopeur",),
    "téléscopeuse": ("téléscopeur",),
    "télescopeuses": ("télescopeur",),
    "téléscopeuses": ("téléscopeur",),
    "télescopique": ("télescopique",),
    "télescopiques": ("télescopique",),
    "télesthésique": ("télesthésique",),
    "télesthésiques": ("télesthésique",),
    "télésystolique": ("télésystolique",),
    "télésystoliques": ("télésystolique",),
    "télétoxique": ("télétoxique",),
    "télétoxiques": ("télétoxique",),
    "télétrophique": ("télétrophique",),
    "télétrophiques": ("télétrophique",),
    "télévangéliste": ("télévangéliste",),
    "télévangélistes": ("télévangéliste",),
    "télévisuelle": ("télévisuel",),
    "télévisuelles": ("télévisuel",),
    "télévisuel": ("télévisuel",),
    "télévisuels": ("télévisuel",),
    "tellien": ("tellien",),
    "tellienne": ("tellien",),
    "telliennes": ("tellien",),
    "telliens": ("tellien",),
    "tellière": ("tellière",),
    "tellières": ("tellière",),
    "tellureuse": ("tellureux",),
    "tellureuses": ("tellureux",),
    "tellureux": ("tellureux",),
    "tellurhydrique": ("tellurhydrique",),
    "tellurhydriques": ("tellurhydrique",),
    "tellurien": ("tellurien",),
    "tellurienne": ("tellurien",),
    "telluriennes": ("tellurien",),
    "telluriens": ("tellurien",),
    "tellurique": ("tellurique",),
    "telluriques": ("tellurique",),
    "télocentrique": ("télocentrique",),
    "télocentriques": ("télocentrique",),
    "télodiastolique": ("télodiastolique",),
    "télodiastoliques": ("télodiastolique",),
    "télogène": ("télogène",),
    "télogènes": ("télogène",),
    "télolécithe": ("télolécithe",),
    "télolécithes": ("télolécithe",),
    "télolécithique": ("télolécithique",),
    "télolécithiques": ("télolécithique",),
    "télophasique": ("télophasique",),
    "télophasiques": ("télophasique",),
    "télosystolique": ("télosystolique",),
    "télosystoliques": ("télosystolique",),
    "telougou": ("telougou",),
    "telougous": ("telougou",),
    "telugu": ("telugu",),
    "telugus": ("telugu",),
    "téméraire": ("téméraire",),
    "téméraires": ("téméraire",),
    "tempéramentale": ("tempéramental",),
    "tempéramentales": ("tempéramental",),
    "tempéramental": ("tempéramental",),
    "tempéramentaux": ("tempéramental",),
    "tempétueuse": ("tempétueux",),
    "tempétueuses": ("tempétueux",),
    "tempétueux": ("tempétueux",),
    "templière": ("templier",),
    "templières": ("templier",),
    "templier": ("templier",),
    "templiers": ("templier",),
    "temporaire": ("temporaire",),
    "temporaires": ("temporaire",),
    "temporale": ("temporal",),
    "temporales": ("temporal",),
    "temporal": ("temporal",),
    "temporaux": ("temporal",),
    "temporelle": ("temporel",),
    "temporelles": ("temporel",),
    "temporel": ("temporel",),
    "temporels": ("temporel",),
    "temporisateur": ("temporisateur",),
    "temporisateurs": ("temporisateur",),
    "temporisatrice": ("temporisateur",),
    "temporisatrices": ("temporisateur",),
    "temporiseur": ("temporiseur",),
    "temporiseurs": ("temporiseur",),
    "temporiseuse": ("temporiseur",),
    "temporiseuses": ("temporiseur",),
    "temporo-buccales": ("temporo-buccal",),
    "temporo-massétérine": ("temporo-massétérin",),
    "temporo-mastoïdien": ("temporo-mastoïdien",),
    "temporo-mastoïdiens": ("temporo-mastoïdien",),
    "temporo-pariétal": ("temporo-pariétal",),
    "temporo-pariétaux": ("temporo-pariétal",),
    "temporospatiale": ("temporospatial",),
    "temporospatiales": ("temporospatial",),
    "temporospatial": ("temporospatial",),
    "temporospatiaux": ("temporospatial",),
    "tenable": ("tenable",),
    "tenables": ("tenable",),
    "tenace": ("tenace",),
    "tenaces": ("tenace",),
    "tendancielle": ("tendanciel",),
    "tendancielles": ("tendanciel",),
    "tendanciel": ("tendanciel",),
    "tendanciels": ("tendanciel",),
    "tendancieuse": ("tendancieux",),
    "tendancieuses": ("tendancieux",),
    "tendancieux": ("tendancieux",),
    "tendeur": ("tendeur",),
    "tendeurs": ("tendeur",),
    "tendeuse": ("tendeur",),
    "tendeuses": ("tendeur",),
    "tendineuse": ("tendineux",),
    "tendineuses": ("tendineux",),
    "tendineux": ("tendineux",),
    "tendre": ("tendre",),
    "tendres": ("tendre",),
    "ténébreuse": ("ténébreux",),
    "ténébreuses": ("ténébreux",),
    "ténébreux": ("ténébreux",),
    "ténébriste": ("ténébriste",),
    "ténébristes": ("ténébriste",),
    "ténicide": ("ténicide",),
    "ténicides": ("ténicide",),
    "ténifuge": ("ténifuge",),
    "ténifuges": ("ténifuge",),
    "tennistique": ("tennistique",),
    "tennistiques": ("tennistique",),
    "tenonien": ("tenonien",),
    "tenonienne": ("tenonien",),
    "tenoniennes": ("tenonien",),
    "tenoniens": ("tenonien",),
    "tenseur": ("tenseur",),
    "tenseurs": ("tenseur",),
    "tensif": ("tensif",),
    "tensifs": ("tensif",),
    "tensive": ("tensif",),
    "tensives": ("tensif",),
    "tensioactif": ("tensioactif",),
    "tensio-actif": ("tensio-actif",),
    "tensio-actifs": ("tensioactif",),
    "tensioactifs": ("tensioactif",),
    "tensio-active": ("tensio-actif",),
    "tensioactive": ("tensioactif",),
    "tensio-actives": ("tensio-actif",),
    "tensioactives": ("tensioactif",),
    "tensionnelle": ("tensionnel",),
    "tensionnelles": ("tensionnel",),
    "tensionnel": ("tensionnel",),
    "tensionnels": ("tensionnel",),
    "tensorielle": ("tensoriel",),
    "tensorielles": ("tensoriel",),
    "tensoriel": ("tensoriel",),
    "tensoriels": ("tensoriel",),
    "tentaculaire": ("tentaculaire",),
    "tentaculaires": ("tentaculaire",),
    "tentateur": ("tentateur",),
    "tentateurs": ("tentateur",),
    "tentatrice": ("tentateur",),
    "tentatrices": ("tentateur",),
    "tentorielle": ("tentoriel",),
    "tentorielles": ("tentoriel",),
    "tentoriel": ("tentoriel",),
    "tentoriels": ("tentoriel",),
    "tenue": ("tenu",),
    "ténue": ("ténu",),
    "tenues": ("tenu",),
    "ténues": ("ténu",),
    "tenu": ("tenu",),
    "ténu": ("ténu",),
    "tenus": ("tenu",),
    "ténus": ("ténu",),
    "tépide": ("tépide",),
    "tépides": ("tépide",),
    "ter": ("ter",),
    "tératogène": ("tératogène",),
    "tératogènes": ("tératogène",),
    "tératogénique": ("tératogénique",),
    "tératogéniques": ("tératogénique",),
    "tératoïde": ("tératoïde",),
    "tératoïdes": ("tératoïde",),
    "tératologique": ("tératologique",),
    "tératologiques": ("tératologique",),
    "terbique": ("terbique",),
    "terbiques": ("terbique",),
    "térébique": ("térébique",),
    "térébiques": ("térébique",),
    "téréphtalique": ("téréphtalique",),
    "téréphtaliques": ("téréphtalique",),
    "terminale": ("terminal",),
    "terminales": ("terminal",),
    "terminal": ("terminal",),
    "terminaux": ("terminal",),
    "terminatif": ("terminatif",),
    "terminatifs": ("terminatif",),
    "terminative": ("terminatif",),
    "terminatives": ("terminatif",),
    "terministe": ("terministe",),
    "terministes": ("terministe",),
    "terminologique": ("terminologique",),
    "terminologiques": ("terminologique",),
    "ternaire": ("ternaire",),
    "ternaires": ("ternaire",),
    "terne": ("terne",),
    "ternes": ("terne",),
    "terpénique": ("terpénique",),
    "terpéniques": ("terpénique",),
    "terramare": ("terramare",),
    "terramares": ("terramare",),
    "terrasseuse": ("terrasseux",),
    "terrasseuses": ("terrasseux",),
    "terrasseux": ("terrasseux",),
    "terrestre": ("terrestre",),
    "terrestres": ("terrestre",),
    "terreuse": ("terreux",),
    "terreuses": ("terreux",),
    "terreux": ("terreux",),
    "terrible": ("terrible",),
    "terribles": ("terrible",),
    "terricole": ("terricole",),
    "terricoles": ("terricole",),
    "terrien": ("terrien",),
    "terrienne": ("terrien",),
    "terriennes": ("terrien",),
    "terriens": ("terrien",),
    "terrier": ("terrier",),
    "terriers": ("terrier",),
    "terrigène": ("terrigène",),
    "terrigènes": ("terrigène",),
    "territoriale": ("territorial",),
    "territoriales": ("territorial",),
    "territorial": ("territorial",),
    "territoriaux": ("territorial",),
    "terroriseur": ("terroriseur",),
    "terroriseurs": ("terroriseur",),
    "terroriseuse": ("terroriseur",),
    "terroriseuses": ("terroriseur",),
    "terroriste": ("terroriste",),
    "terroristes": ("terroriste",),
    "tertiaire": ("tertiaire",),
    "tertiaires": ("tertiaire",),
    "tertioamylique": ("tertioamylique",),
    "tertioamyliques": ("tertioamylique",),
    "tertiobutylique": ("tertiobutylique",),
    "tertiobutyliques": ("tertiobutylique",),
    "testable": ("testable",),
    "testables": ("testable",),
    "testamentaire": ("testamentaire",),
    "testamentaires": ("testamentaire",),
    "testiculaire": ("testiculaire",),
    "testiculaires": ("testiculaire",),
    "testimoniale": ("testimonial",),
    "testimoniales": ("testimonial",),
    "testimonial": ("testimonial",),
    "testimoniaux": ("testimonial",),
    "tétaniforme": ("tétaniforme",),
    "tétaniformes": ("tétaniforme",),
    "tétanique": ("tétanique",),
    "tétaniques": ("tétanique",),
    "tétartoèdre": ("tétartoèdre",),
    "tétartoèdres": ("tétartoèdre",),
    "tétonnière": ("tétonnière",),
    "tétonnières": ("tétonnière",),
    "tétraborique": ("tétraborique",),
    "tétraboriques": ("tétraborique",),
    "tétracère": ("tétracère",),
    "tétracères": ("tétracère",),
    "tétrachorique": ("tétrachorique",),
    "tétrachoriques": ("tétrachorique",),
    "tétraconque": ("tétraconque",),
    "tétraconques": ("tétraconque",),
    "tétracorde": ("tétracorde",),
    "tétracordes": ("tétracorde",),
    "tétracosanoïque": ("tétracosanoïque",),
    "tétracosanoïques": ("tétracosanoïque",),
    "tétracyclique": ("tétracyclique",),
    "tétracycliques": ("tétracyclique",),
    "tétradactyle": ("tétradactyle",),
    "tétradactyles": ("tétradactyle",),
    "tétradyname": ("tétradyname",),
    "tétradynames": ("tétradyname",),
    "tétraèdre": ("tétraèdre",),
    "tétraèdres": ("tétraèdre",),
    "tétraédrique": ("tétraédrique",),
    "tétraédriques": ("tétraédrique",),
    "tétragonale": ("tétragonal",),
    "tétragonales": ("tétragonal",),
    "tétragonal": ("tétragonal",),
    "tétragonaux": ("tétragonal",),
    "tétragone": ("tétragone",),
    "tétragones": ("tétragone",),
    "tétrahydrofurfurylique": ("tétrahydrofurfurylique",),
    "tétrahydrofurfuryliques": ("tétrahydrofurfurylique",),
    "tétramère": ("tétramère",),
    "tétramères": ("tétramère",),
    "tétraphonique": ("tétraphonique",),
    "tétraphoniques": ("tétraphonique",),
    "tétraplégique": ("tétraplégique",),
    "tétraplégiques": ("tétraplégique",),
    "tétraploïde": ("tétraploïde",),
    "tétraploïdes": ("tétraploïde",),
    "tétrapode": ("tétrapode",),
    "tétrapodes": ("tétrapode",),
    "tétrapolaire": ("tétrapolaire",),
    "tétrapolaires": ("tétrapolaire",),
    "tétraptère": ("tétraptère",),
    "tétraptères": ("tétraptère",),
    "tétrapyrrolique": ("tétrapyrrolique",),
    "tétrapyrroliques": ("tétrapyrrolique",),
    "tétrasilicique": ("tétrasilicique",),
    "tétrasiliciques": ("tétrasilicique",),
    "tétrastique": ("tétrastique",),
    "tétrastiques": ("tétrastique",),
    "tétrastyle": ("tétrastyle",),
    "tétrastyles": ("tétrastyle",),
    "tétrasyllabe": ("tétrasyllabe",),
    "tétrasyllabes": ("tétrasyllabe",),
    "tétrasyllabique": ("tétrasyllabique",),
    "tétrasyllabiques": ("tétrasyllabique",),
    "tétrathionique": ("tétrathionique",),
    "tétrathioniques": ("tétrathionique",),
    "tétratomique": ("tétratomique",),
    "tétratomiques": ("tétratomique",),
    "tétratonique": ("tétratonique",),
    "tétratoniques": ("tétratonique",),
    "teuton": ("teuton",),
    "teutonne": ("teuton",),
    "teutonnes": ("teuton",),
    "teutons": ("teuton",),
    "teutonique": ("teutonique",),
    "teutoniques": ("teutonique",),
    "textile": ("textile",),
    "textiles": ("textile",),
    "textilique": ("textilique",),
    "textiliques": ("textilique",),
    "textuelle": ("textuel",),
    "textuelles": ("textuel",),
    "textuel": ("textuel",),
    "textuels": ("textuel",),
    "texturale": ("textural",),
    "texturales": ("textural",),
    "textural": ("textural",),
    "texturaux": ("textural",),
    "thaïlandaise": ("thaïlandais",),
    "thaïlandaises": ("thaïlandais",),
    "thaïlandais": ("thaïlandais",),
    "thalamique": ("thalamique",),
    "thalamiques": ("thalamique",),
    "thalamo-cortical": ("thalamo-cortical",),
    "thalamo-corticaux": ("thalamo-cortical",),
    "thalamo-striée": ("thalamo-strié",),
    "thalassothérapique": ("thalassothérapique",),
    "thalassothérapiques": ("thalassothérapique",),
    "thalassotoque": ("thalassotoque",),
    "thalassotoques": ("thalassotoque",),
    "thalleuse": ("thalleux",),
    "thalleuses": ("thalleux",),
    "thalleux": ("thalleux",),
    "thallique": ("thallique",),
    "thalliques": ("thallique",),
    "thanatologique": ("thanatologique",),
    "thanatologiques": ("thanatologique",),
    "thaumaturge": ("thaumaturge",),
    "thaumaturges": ("thaumaturge",),
    "thé": ("thé",),
    "théâtrale": ("théâtral",),
    "théâtrales": ("théâtral",),
    "théâtral": ("théâtral",),
    "théâtraux": ("théâtral",),
    "thébaïque": ("thébaïque",),
    "thébaïques": ("thébaïque",),
    "thécale": ("thécal",),
    "thécales": ("thécal",),
    "thécal": ("thécal",),
    "thécaux": ("thécal",),
    "thécostomate": ("thécostomate",),
    "thécostomates": ("thécostomate",),
    "théière": ("théier",),
    "théières": ("théier",),
    "théier": ("théier",),
    "théiers": ("théier",),
    "théiste": ("théiste",),
    "théistes": ("théiste",),
    "thélytoque": ("thélytoque",),
    "thélytoques": ("thélytoque",),
    "thématique": ("thématique",),
    "thématiques": ("thématique",),
    "thénarien": ("thénarien",),
    "thénarienne": ("thénarien",),
    "thénariennes": ("thénarien",),
    "thénariens": ("thénarien",),
    "thénoïque": ("thénoïque",),
    "thénoïques": ("thénoïque",),
    "théocratique": ("théocratique",),
    "théocratiques": ("théocratique",),
    "théodosien": ("théodosien",),
    "théodosienne": ("théodosien",),
    "théodosiennes": ("théodosien",),
    "théodosiens": ("théodosien",),
    "théogonique": ("théogonique",),
    "théogoniques": ("théogonique",),
    "théologale": ("théologal",),
    "théologales": ("théologal",),
    "théologal": ("théologal",),
    "théologaux": ("théologal",),
    "théologien": ("théologien",),
    "théologienne": ("théologien",),
    "théologiennes": ("théologien",),
    "théologiens": ("théologien",),
    "théologique": ("théologique",),
    "théologiques": ("théologique",),
    "théophanique": ("théophanique",),
    "théophaniques": ("théophanique",),
    "théophilanthropique": ("théophilanthropique",),
    "théophilanthropiques": ("théophilanthropique",),
    "théophore": ("théophore",),
    "théophores": ("théophore",),
    "théorématique": ("théorématique",),
    "théorématiques": ("théorématique",),
    "théorétique": ("théorétique",),
    "théorétiques": ("théorétique",),
    "théorique": ("théorique",),
    "théoriques": ("théorique",),
    "théorisable": ("théorisable",),
    "théorisables": ("théorisable",),
    "théosophique": ("théosophique",),
    "théosophiques": ("théosophique",),
    "thérapeutique": ("thérapeutique",),
    "thérapeutiques": ("thérapeutique",),
    "thériacale": ("thériacal",),
    "thériacales": ("thériacal",),
    "thériacal": ("thériacal",),
    "thériacaux": ("thériacal",),
    "thermale": ("thermal",),
    "thermales": ("thermal",),
    "thermal": ("thermal",),
    "thermaux": ("thermal",),
    "thermidorien": ("thermidorien",),
    "thermidorienne": ("thermidorien",),
    "thermidoriennes": ("thermidorien",),
    "thermidoriens": ("thermidorien",),
    "thermionique": ("thermionique",),
    "thermioniques": ("thermionique",),
    "thermique": ("thermique",),
    "thermiques": ("thermique",),
    "thermoactif": ("thermoactif",),
    "thermoactifs": ("thermoactif",),
    "thermoactive": ("thermoactif",),
    "thermoactives": ("thermoactif",),
    "thermoalgésique": ("thermoalgésique",),
    "thermo-algésiques": ("thermo-algésique",),
    "thermoalgésiques": ("thermoalgésique",),
    "thermochimique": ("thermochimique",),
    "thermochimiques": ("thermochimique",),
    "thermochrome": ("thermochrome",),
    "thermochromes": ("thermochrome",),
    "thermocinétique": ("thermocinétique",),
    "thermocinétiques": ("thermocinétique",),
    "thermoclastique": ("thermoclastique",),
    "thermoclastiques": ("thermoclastique",),
    "thermoclimatique": ("thermoclimatique",),
    "thermoclimatiques": ("thermoclimatique",),
    "thermocollable": ("thermocollable",),
    "thermocollables": ("thermocollable",),
    "thermocondensable": ("thermocondensable",),
    "thermocondensables": ("thermocondensable",),
    "thermoconvectif": ("thermoconvectif",),
    "thermoconvectifs": ("thermoconvectif",),
    "thermoconvective": ("thermoconvectif",),
    "thermoconvectives": ("thermoconvectif",),
    "thermodifférentielle": ("thermodifférentiel",),
    "thermodifférentielles": ("thermodifférentiel",),
    "thermodifférentiel": ("thermodifférentiel",),
    "thermodifférentiels": ("thermodifférentiel",),
    "thermodiffusif": ("thermodiffusif",),
    "thermodiffusifs": ("thermodiffusif",),
    "thermodiffusive": ("thermodiffusif",),
    "thermodiffusives": ("thermodiffusif",),
    "thermodurcissable": ("thermodurcissable",),
    "thermodurcissables": ("thermodurcissable",),
    "thermodynamique": ("thermodynamique",),
    "thermodynamiques": ("thermodynamique",),
    "thermoélastique": ("thermoélastique",),
    "thermoélastiques": ("thermoélastique",),
    "thermo-électrique": ("thermoélectrique",),
    "thermoélectrique": ("thermoélectrique",),
    "thermo-électriques": ("thermoélectrique",),
    "thermoélectriques": ("thermoélectrique",),
    "thermoélectronique": ("thermoélectronique",),
    "thermo-électroniques": ("thermoélectronique",),
    "thermoélectroniques": ("thermoélectronique",),
    "thermoformable": ("thermoformable",),
    "thermoformables": ("thermoformable",),
    "thermofusible": ("thermofusible",),
    "thermofusibles": ("thermofusible",),
    "thermogène": ("thermogène",),
    "thermogènes": ("thermogène",),
    "thermographique": ("thermographique",),
    "thermographiques": ("thermographique",),
    "thermogravimétrique": ("thermogravimétrique",),
    "thermogravimétriques": ("thermogravimétrique",),
    "thermoïonique": ("thermoïonique",),
    "thermoïoniques": ("thermoïonique",),
    "thermolabile": ("thermolabile",),
    "thermolabiles": ("thermolabile",),
    "thermomagnétique": ("thermomagnétique",),
    "thermomagnétiques": ("thermomagnétique",),
    "thermomasseur": ("thermomasseur",),
    "thermomasseurs": ("thermomasseur",),
    "thermomasseuse": ("thermomasseur",),
    "thermomasseuses": ("thermomasseur",),
    "thermomécanique": ("thermomécanique",),
    "thermomécaniques": ("thermomécanique",),
    "thermométrique": ("thermométrique",),
    "thermométriques": ("thermométrique",),
    "thermonucléaire": ("thermonucléaire",),
    "thermonucléaires": ("thermonucléaire",),
    "thermophile": ("thermophile",),
    "thermophiles": ("thermophile",),
    "thermophonique": ("thermophonique",),
    "thermophoniques": ("thermophonique",),
    "thermoplastique": ("thermoplastique",),
    "thermoplastiques": ("thermoplastique",),
    "thermopondérale": ("thermopondéral",),
    "thermopondérales": ("thermopondéral",),
    "thermopondéral": ("thermopondéral",),
    "thermopondéraux": ("thermopondéral",),
    "thermopropulsif": ("thermopropulsif",),
    "thermopropulsifs": ("thermopropulsif",),
    "thermopropulsive": ("thermopropulsif",),
    "thermopropulsives": ("thermopropulsif",),
    "thermoréactif": ("thermoréactif",),
    "thermoréactifs": ("thermoréactif",),
    "thermoréactive": ("thermoréactif",),
    "thermoréactives": ("thermoréactif",),
    "thermorégulateur": ("thermorégulateur",),
    "thermorégulateurs": ("thermorégulateur",),
    "thermorégulatrice": ("thermorégulateur",),
    "thermorégulatrices": ("thermorégulateur",),
    "thermorétractable": ("thermorétractable",),
    "thermorétractables": ("thermorétractable",),
    "thermoscopique": ("thermoscopique",),
    "thermoscopiques": ("thermoscopique",),
    "thermosensible": ("thermosensible",),
    "thermosensibles": ("thermosensible",),
    "thermosphérique": ("thermosphérique",),
    "thermosphériques": ("thermosphérique",),
    "thermostabile": ("thermostabile",),
    "thermostabiles": ("thermostabile",),
    "thermostable": ("thermostable",),
    "thermostables": ("thermostable",),
    "thermostatique": ("thermostatique",),
    "thermostatiques": ("thermostatique",),
    "thermotrope": ("thermotrope",),
    "thermotropes": ("thermotrope",),
    "thermotropique": ("thermotropique",),
    "thermotropiques": ("thermotropique",),
    "thermovélocimétrique": ("thermovélocimétrique",),
    "thermovélocimétriques": ("thermovélocimétrique",),
    "thésauriseur": ("thésauriseur",),
    "thésauriseurs": ("thésauriseur",),
    "thésauriseuse": ("thésauriseur",),
    "thésauriseuses": ("thésauriseur",),
    "thessalien": ("thessalien",),
    "thessalienne": ("thessalien",),
    "thessaliennes": ("thessalien",),
    "thessaliens": ("thessalien",),
    "thétique": ("thétique",),
    "thétiques": ("thétique",),
    "théurgique": ("théurgique",),
    "théurgiques": ("théurgique",),
    "thiaminique": ("thiaminique",),
    "thiaminiques": ("thiaminique",),
    "thiasote": ("thiasote",),
    "thiasotes": ("thiasote",),
    "thiazidique": ("thiazidique",),
    "thiazidiques": ("thiazidique",),
    "thiazinique": ("thiazinique",),
    "thiaziniques": ("thiazinique",),
    "thiazolique": ("thiazolique",),
    "thiazoliques": ("thiazolique",),
    "thioacétique": ("thioacétique",),
    "thioacétiques": ("thioacétique",),
    "thiobenzoïque": ("thiobenzoïque",),
    "thiobenzoïques": ("thiobenzoïque",),
    "thiocarbonique": ("thiocarbonique",),
    "thiocarboniques": ("thiocarbonique",),
    "thiocarboxylique": ("thiocarboxylique",),
    "thiocarboxyliques": ("thiocarboxylique",),
    "thiocyanique": ("thiocyanique",),
    "thiocyaniques": ("thiocyanique",),
    "thiodiglycolique": ("thiodiglycolique",),
    "thiodiglycoliques": ("thiodiglycolique",),
    "thiofénique": ("thiofénique",),
    "thioféniques": ("thiofénique",),
    "thioglycolique": ("thioglycolique",),
    "thioglycoliques": ("thioglycolique",),
    "thiolactique": ("thiolactique",),
    "thiolactiques": ("thiolactique",),
    "thionique": ("thionique",),
    "thioniques": ("thionique",),
    "thiopexique": ("thiopexique",),
    "thiopexiques": ("thiopexique",),
    "thiophénique": ("thiophénique",),
    "thiophéniques": ("thiophénique",),
    "thiosalicylique": ("thiosalicylique",),
    "thiosalicyliques": ("thiosalicylique",),
    "thiosulfurique": ("thiosulfurique",),
    "thiosulfuriques": ("thiosulfurique",),
    "thixotrope": ("thixotrope",),
    "thixotropes": ("thixotrope",),
    "thixotropique": ("thixotropique",),
    "thixotropiques": ("thixotropique",),
    "tholéiitique": ("tholéiitique",),
    "tholéiitiques": ("tholéiitique",),
    "tholéitique": ("tholéitique",),
    "tholéitiques": ("tholéitique",),
    "thomiste": ("thomiste",),
    "thomistes": ("thomiste",),
    "thonière": ("thonier",),
    "thonières": ("thonier",),
    "thonier": ("thonier",),
    "thoniers": ("thonier",),
    "thoracique": ("thoracique",),
    "thoraciques": ("thoracique",),
    "thrace": ("thrace",),
    "thraces": ("thrace",),
    "thrombinomimétique": ("thrombinomimétique",),
    "thrombinomimétiques": ("thrombinomimétique",),
    "thrombocytaire": ("thrombocytaire",),
    "thrombocytaires": ("thrombocytaire",),
    "thrombocytopénique": ("thrombocytopénique",),
    "thrombocytopéniques": ("thrombocytopénique",),
    "thromboembolique": ("thromboembolique",),
    "thromboemboliques": ("thromboembolique",),
    "thrombogène": ("thrombogène",),
    "thrombogènes": ("thrombogène",),
    "thrombolytique": ("thrombolytique",),
    "thrombolytiques": ("thrombolytique",),
    "thrombopénique": ("thrombopénique",),
    "thrombopéniques": ("thrombopénique",),
    "thrombophlébitique": ("thrombophlébitique",),
    "thrombophlébitiques": ("thrombophlébitique",),
    "thromboplastique": ("thromboplastique",),
    "thromboplastiques": ("thromboplastique",),
    "thrombopoïétique": ("thrombopoïétique",),
    "thrombopoïétiques": ("thrombopoïétique",),
    "thrombostatique": ("thrombostatique",),
    "thrombostatiques": ("thrombostatique",),
    "thrombotique": ("thrombotique",),
    "thrombotiques": ("thrombotique",),
    "thymidylique": ("thymidylique",),
    "thymidyliques": ("thymidylique",),
    "thymique": ("thymique",),
    "thymiques": ("thymique",),
    "thymoanaleptique": ("thymoanaleptique",),
    "thymoanaleptiques": ("thymoanaleptique",),
    "thymoleptique": ("thymoleptique",),
    "thymoleptiques": ("thymoleptique",),
    "thymolymphatique": ("thymolymphatique",),
    "thymolymphatiques": ("thymolymphatique",),
    "thymonucléique": ("thymonucléique",),
    "thymonucléiques": ("thymonucléique",),
    "thymoprive": ("thymoprive",),
    "thymoprives": ("thymoprive",),
    "thymorégulateur": ("thymorégulateur",),
    "thymorégulateurs": ("thymorégulateur",),
    "thymorégulatrice": ("thymorégulateur",),
    "thymorégulatrices": ("thymorégulateur",),
    "thymostabilisateur": ("thymostabilisateur",),
    "thymostabilisateurs": ("thymostabilisateur",),
    "thymostabilisatrice": ("thymostabilisateur",),
    "thymostabilisatrices": ("thymostabilisateur",),
    "thyréogène": ("thyréogène",),
    "thyréogènes": ("thyréogène",),
    "thyréoprive": ("thyréoprive",),
    "thyréoprives": ("thyréoprive",),
    "thyréotoxique": ("thyréotoxique",),
    "thyréotoxiques": ("thyréotoxique",),
    "thyréotrope": ("thyréotrope",),
    "thyréotropes": ("thyréotrope",),
    "thyro-aryténoïdienne": ("thyro-aryténoïdien",),
    "thyrofrénateur": ("thyrofrénateur",),
    "thyrofrénateurs": ("thyrofrénateur",),
    "thyrofrénatrice": ("thyrofrénateur",),
    "thyrofrénatrices": ("thyrofrénateur",),
    "thyrogène": ("thyrogène",),
    "thyrogènes": ("thyrogène",),
    "thyro-hyoïdien": ("thyro-hyoïdien",),
    "thyro-hyoïdiens": ("thyro-hyoïdien",),
    "thyroïde": ("thyroïde",),
    "thyroïdes": ("thyroïde",),
    "thyroïdien": ("thyroïdien",),
    "thyroïdienne": ("thyroïdien",),
    "thyroïdiennes": ("thyroïdien",),
    "thyroïdiens": ("thyroïdien",),
    "thyrotoxique": ("thyrotoxique",),
    "thyrotoxiques": ("thyrotoxique",),
    "thyrotrope": ("thyrotrope",),
    "thyrotropes": ("thyrotrope",),
    "thyroxinien": ("thyroxinien",),
    "thyroxinienne": ("thyroxinien",),
    "thyroxiniennes": ("thyroxinien",),
    "thyroxiniens": ("thyroxinien",),
    "tibéto-birmane": ("tibéto-birman",),
    "tibiale": ("tibial",),
    "tibiales": ("tibial",),
    "tibial": ("tibial",),
    "tibiaux": ("tibial",),
    "tibialgique": ("tibialgique",),
    "tibialgiques": ("tibialgique",),
    "tibio-péroniers": ("tibio-péronier",),
    "tibio-tarsien": ("tibio-tarsien",),
    "tibio-tarsiens": ("tibio-tarsien",),
    "tidale": ("tidal",),
    "tidales": ("tidal",),
    "tidal": ("tidal",),
    "tidaux": ("tidal",),
    "tiédasse": ("tiédasse",),
    "tiédasses": ("tiédasse",),
    "tiède": ("tiède",),
    "tièdes": ("tiède",),
    "tien": ("tien",),
    "tienne": ("tien",),
    "tiennes": ("tien",),
    "tiens": ("tien",),
    "tierce": ("tiers",),
    "tierces": ("tiers",),
    "tiers": ("tiers",),
    "tigréen": ("tigréen",),
    "tigréenne": ("tigréen",),
    "tigréennes": ("tigréen",),
    "tigréens": ("tigréen",),
    "timide": ("timide",),
    "timides": ("timide",),
    "tinctoriale": ("tinctorial",),
    "tinctoriales": ("tinctorial",),
    "tinctorial": ("tinctorial",),
    "tinctoriaux": ("tinctorial",),
    "tingitane": ("tingitane",),
    "tingitanes": ("tingitane",),
    "tiqueur": ("tiqueur",),
    "tiqueurs": ("tiqueur",),
    "tiqueuse": ("tiqueur",),
    "tiqueuses": ("tiqueur",),
    "tire-bouchonné": ("tire-bouchonné",),
    "tire-bouchonnés": ("tire-bouchonné",),
    "tisseur": ("tisseur",),
    "tisseurs": ("tisseur",),
    "tisseuse": ("tisseur",),
    "tisseuses": ("tisseur",),
    "tissulaire": ("tissulaire",),
    "tissulaires": ("tissulaire",),
    "titanesque": ("titanesque",),
    "titanesques": ("titanesque",),
    "titaneuse": ("titaneux",),
    "titaneuses": ("titaneux",),
    "titaneux": ("titaneux",),
    "titanique": ("titanique",),
    "titaniques": ("titanique",),
    "titien": ("titien",),
    "titiens": ("titien",),
    "titiste": ("titiste",),
    "titistes": ("titiste",),
    "titrable": ("titrable",),
    "titrables": ("titrable",),
    "titrimétrique": ("titrimétrique",),
    "titrimétriques": ("titrimétrique",),
    "titulaire": ("titulaire",),
    "titulaires": ("titulaire",),
    "toarcien": ("toarcien",),
    "toarcienne": ("toarcien",),
    "toarciennes": ("toarcien",),
    "toarciens": ("toarcien",),
    "toc": ("toc",),
    "tocolytique": ("tocolytique",),
    "tocolytiques": ("tocolytique",),
    "togolaise": ("togolais",),
    "togolaises": ("togolais",),
    "togolais": ("togolais",),
    "toilière": ("toilier",),
    "toilières": ("toilier",),
    "toilier": ("toilier",),
    "toiliers": ("toilier",),
    "tokharien": ("tokharien",),
    "tokharienne": ("tokharien",),
    "tokhariennes": ("tokharien",),
    "tokhariens": ("tokharien",),
    "tokyoïte": ("tokyoïte",),
    "tokyoïtes": ("tokyoïte",),
    "tolérable": ("tolérable",),
    "tolérables": ("tolérable",),
    "tolérigène": ("tolérigène",),
    "tolérigènes": ("tolérigène",),
    "tolérogène": ("tolérogène",),
    "tolérogènes": ("tolérogène",),
    "toluènesulfonique": ("toluènesulfonique",),
    "toluènesulfoniques": ("toluènesulfonique",),
    "toluique": ("toluique",),
    "toluiques": ("toluique",),
    "tombeur": ("tombeur",),
    "tombeurs": ("tombeur",),
    "tombeuse": ("tombeur",),
    "tombeuses": ("tombeur",),
    "tomenteuse": ("tomenteux",),
    "tomenteuses": ("tomenteux",),
    "tomenteux": ("tomenteux",),
    "tomodensimétrique": ("tomodensimétrique",),
    "tomodensimétriques": ("tomodensimétrique",),
    "tomodensitométrique": ("tomodensitométrique",),
    "tomodensitométriques": ("tomodensitométrique",),
    "tomographique": ("tomographique",),
    "tomographiques": ("tomographique",),
    "tondante": ("tondante",),
    "tondantes": ("tondante",),
    "tonétique": ("tonétique",),
    "tonétiques": ("tonétique",),
    "tongan": ("tongan",),
    "tongans": ("tongan",),
    "tonicardiaque": ("tonicardiaque",),
    "tonicardiaques": ("tonicardiaque",),
    "tonique": ("tonique",),
    "toniques": ("tonique",),
    "tonkinoise": ("tonkinois",),
    "tonkinoises": ("tonkinois",),
    "tonkinois": ("tonkinois",),
    "tonologique": ("tonologique",),
    "tonologiques": ("tonologique",),
    "tonométrique": ("tonométrique",),
    "tonométriques": ("tonométrique",),
    "tonotopique": ("tonotopique",),
    "tonotopiques": ("tonotopique",),
    "tonotrope": ("tonotrope",),
    "tonotropes": ("tonotrope",),
    "tonsillaire": ("tonsillaire",),
    "tonsillaires": ("tonsillaire",),
    "tontinière": ("tontinier",),
    "tontinières": ("tontinier",),
    "tontinier": ("tontinier",),
    "tontiniers": ("tontinier",),
    "tontisse": ("tontisse",),
    "tontisses": ("tontisse",),
    "topiaire": ("topiaire",),
    "topiaires": ("topiaire",),
    "topique": ("topique",),
    "topiques": ("topique",),
    "topochimique": ("topochimique",),
    "topochimiques": ("topochimique",),
    "topographique": ("topographique",),
    "topographiques": ("topographique",),
    "topologique": ("topologique",),
    "topologiques": ("topologique",),
    "topométrique": ("topométrique",),
    "topométriques": ("topométrique",),
    "toponymique": ("toponymique",),
    "toponymiques": ("toponymique",),
    "tordeur": ("tordeur",),
    "tordeurs": ("tordeur",),
    "tordeuse": ("tordeur",),
    "tordeuses": ("tordeur",),
    "torique": ("torique",),
    "toriques": ("torique",),
    "tormineuse": ("tormineux",),
    "tormineuses": ("tormineux",),
    "tormineux": ("tormineux",),
    "toroïdale": ("toroïdal",),
    "toroïdales": ("toroïdal",),
    "toroïdal": ("toroïdal",),
    "toroïdaux": ("toroïdal",),
    "torontoise": ("torontois",),
    "torontoises": ("torontois",),
    "torontois": ("torontois",),
    "torpide": ("torpide",),
    "torpides": ("torpide",),
    "torrenticole": ("torrenticole",),
    "torrenticoles": ("torrenticole",),
    "torrentielle": ("torrentiel",),
    "torrentielles": ("torrentiel",),
    "torrentiel": ("torrentiel",),
    "torrentiels": ("torrentiel",),
    "torrentueuse": ("torrentueux",),
    "torrentueuses": ("torrentueux",),
    "torrentueux": ("torrentueux",),
    "torride": ("torride",),
    "torrides": ("torride",),
    "torse": ("tors",),
    "torses": ("tors",),
    "tors": ("tors",),
    "torte": ("torte",),
    "tortes": ("torte",),
    "tortionnaire": ("tortionnaire",),
    "tortionnaires": ("tortionnaire",),
    "tortueuse": ("tortueux",),
    "tortueuses": ("tortueux",),
    "tortueux": ("tortueux",),
    "toruleuse": ("toruleux",),
    "toruleuses": ("toruleux",),
    "toruleux": ("toruleux",),
    "torve": ("torve",),
    "torves": ("torve",),
    "tory": ("tory",),
    "totale": ("total",),
    "totales": ("total",),
    "total": ("total",),
    "totaux": ("total",),
    "totalisateur": ("totalisateur",),
    "totalisateurs": ("totalisateur",),
    "totalisatrice": ("totalisateur",),
    "totalisatrices": ("totalisateur",),
    "totalitaire": ("totalitaire",),
    "totalitaires": ("totalitaire",),
    "totalitariste": ("totalitariste",),
    "totalitaristes": ("totalitariste",),
    "totémique": ("totémique",),
    "totémiques": ("totémique",),
    "totémiste": ("totémiste",),
    "totémistes": ("totémiste",),
    "touaregs": ("touareg",),
    "touchable": ("touchable",),
    "touchables": ("touchable",),
    "toueur": ("toueur",),
    "toueurs": ("toueur",),
    "toulonnaise": ("toulonnais",),
    "toulonnaises": ("toulonnais",),
    "toulonnais": ("toulonnais",),
    "toungouse": ("toungouse",),
    "toungouses": ("toungouse",),
    "toungouze": ("toungouze",),
    "toungouzes": ("toungouze",),
    "tourangeau": ("tourangeau",),
    "tourangeaux": ("tourangeau",),
    "tourangelle": ("tourangeau",),
    "tourangelles": ("tourangeau",),
    "touranien": ("touranien",),
    "touranienne": ("touranien",),
    "touraniennes": ("touranien",),
    "touraniens": ("touranien",),
    "tourbeuse": ("tourbeux",),
    "tourbeuses": ("tourbeux",),
    "tourbeux": ("tourbeux",),
    "tourbière": ("tourbier",),
    "tourbières": ("tourbier",),
    "tourbier": ("tourbier",),
    "tourbiers": ("tourbier",),
    "tourbillonnaire": ("tourbillonnaire",),
    "tourbillonnaires": ("tourbillonnaire",),
    "tourdille": ("tourdille",),
    "tourière": ("tourier",),
    "tourières": ("tourier",),
    "tourier": ("tourier",),
    "touriers": ("tourier",),
    "touristique": ("touristique",),
    "touristiques": ("touristique",),
    "tourmenteur": ("tourmenteur",),
    "tourmenteurs": ("tourmenteur",),
    "tourmenteuse": ("tourmenteur",),
    "tourmenteuses": ("tourmenteur",),
    "tourneur": ("tourneur",),
    "tourneurs": ("tourneur",),
    "tourneuse": ("tourneur",),
    "tourneuses": ("tourneur",),
    "tournois": ("tournois",),
    "toxico": ("toxico",),
    "toxicos": ("toxico",),
    "toxicologique": ("toxicologique",),
    "toxicologiques": ("toxicologique",),
    "toxicomane": ("toxicomane",),
    "toxicomanes": ("toxicomane",),
    "toxicomaniaque": ("toxicomaniaque",),
    "toxicomaniaques": ("toxicomaniaque",),
    "toxicomanogène": ("toxicomanogène",),
    "toxicomanogènes": ("toxicomanogène",),
    "toxicomanologique": ("toxicomanologique",),
    "toxicomanologiques": ("toxicomanologique",),
    "toxicophile": ("toxicophile",),
    "toxicophiles": ("toxicophile",),
    "toxicophore": ("toxicophore",),
    "toxicophores": ("toxicophore",),
    "toxigène": ("toxigène",),
    "toxigènes": ("toxigène",),
    "toxinique": ("toxinique",),
    "toxiniques": ("toxinique",),
    "toxique": ("toxique",),
    "toxiques": ("toxique",),
    "toxomimétique": ("toxomimétique",),
    "toxomimétiques": ("toxomimétique",),
    "toxophore": ("toxophore",),
    "toxophores": ("toxophore",),
    "toxoplasmique": ("toxoplasmique",),
    "toxoplasmiques": ("toxoplasmique",),
    "trabéculaire": ("trabéculaire",),
    "trabéculaires": ("trabéculaire",),
    "traçable": ("traçable",),
    "traçables": ("traçable",),
    "tracassière": ("tracassier",),
    "tracassières": ("tracassier",),
    "tracassier": ("tracassier",),
    "tracassiers": ("tracassier",),
    "traceur": ("traceur",),
    "traceurs": ("traceur",),
    "traceuse": ("traceur",),
    "traceuses": ("traceur",),
    "trachéale": ("trachéal",),
    "trachéales": ("trachéal",),
    "trachéal": ("trachéal",),
    "trachéaux": ("trachéal",),
    "trachéen": ("trachéen",),
    "trachéenne": ("trachéen",),
    "trachéennes": ("trachéen",),
    "trachéens": ("trachéen",),
    "trachéo-bronchique": ("trachéo-bronchique",),
    "trachéolaire": ("trachéolaire",),
    "trachéolaires": ("trachéolaire",),
    "trachéotomique": ("trachéotomique",),
    "trachéotomiques": ("trachéotomique",),
    "trachomateuse": ("trachomateux",),
    "trachomateuses": ("trachomateux",),
    "trachomateux": ("trachomateux",),
    "trachytique": ("trachytique",),
    "trachytiques": ("trachytique",),
    "tractable": ("tractable",),
    "tractables": ("tractable",),
    "tracteur": ("tracteur",),
    "tracteurs": ("tracteur",),
    "tractrice": ("tracteur",),
    "tractrices": ("tracteur",),
    "tractif": ("tractif",),
    "tractifs": ("tractif",),
    "tractive": ("tractif",),
    "tractives": ("tractif",),
    "tractoire": ("tractoire",),
    "tractoires": ("tractoire",),
    "traditionaliste": ("traditionaliste",),
    "traditionalistes": ("traditionaliste",),
    "traditionnaire": ("traditionnaire",),
    "traditionnaires": ("traditionnaire",),
    "traditionnelle": ("traditionnel",),
    "traditionnelles": ("traditionnel",),
    "traditionnel": ("traditionnel",),
    "traditionnels": ("traditionnel",),
    "traducteur": ("traducteur",),
    "traducteurs": ("traducteur",),
    "traductrice": ("traducteur",),
    "traductrices": ("traducteur",),
    "traductionnelle": ("traductionnel",),
    "traductionnelles": ("traductionnel",),
    "traductionnel": ("traductionnel",),
    "traductionnels": ("traductionnel",),
    "traduisible": ("traduisible",),
    "traduisibles": ("traduisible",),
    "traficoteur": ("traficoteur",),
    "traficoteurs": ("traficoteur",),
    "traficoteuse": ("traficoteur",),
    "traficoteuses": ("traficoteur",),
    "tragi-comique": ("tragi-comique",),
    "tragique": ("tragique",),
    "tragiques": ("tragique",),
    "traîneur": ("traîneur",),
    "traîneurs": ("traîneur",),
    "traîneuse": ("traîneur",),
    "traîneuses": ("traîneur",),
    "traitable": ("traitable",),
    "traitables": ("traitable",),
    "traiteur": ("traiteur",),
    "traiteurs": ("traiteur",),
    "traiteuse": ("traiteur",),
    "traiteuses": ("traiteur",),
    "traître": ("traître",),
    "traîtres": ("traître",),
    "traîtresse": ("traître",),
    "traîtresses": ("traître",),
    "trajectographique": ("trajectographique",),
    "trajectographiques": ("trajectographique",),
    "trancheur": ("trancheur",),
    "trancheurs": ("trancheur",),
    "trancheuse": ("trancheur",),
    "trancheuses": ("trancheur",),
    "tranexamique": ("tranexamique",),
    "tranexamiques": ("tranexamique",),
    "tranquille": ("tranquille",),
    "tranquilles": ("tranquille",),
    "transabdominale": ("transabdominal",),
    "transabdominales": ("transabdominal",),
    "transabdominal": ("transabdominal",),
    "transabdominaux": ("transabdominal",),
    "transactionnelle": ("transactionnel",),
    "transactionnelles": ("transactionnel",),
    "transactionnel": ("transactionnel",),
    "transactionnels": ("transactionnel",),
    "transamazonien": ("transamazonien",),
    "transamazonienne": ("transamazonien",),
    "transamazoniennes": ("transamazonien",),
    "transamazoniens": ("transamazonien",),
    "transanale": ("transanal",),
    "transanales": ("transanal",),
    "transanal": ("transanal",),
    "transanaux": ("transanal",),
    "transatlantique": ("transatlantique",),
    "transatlantiques": ("transatlantique",),
    "transatmosphérique": ("transatmosphérique",),
    "transatmosphériques": ("transatmosphérique",),
    "transbordeur": ("transbordeur",),
    "transbordeurs": ("transbordeur",),
    "transbordeuse": ("transbordeur",),
    "transbordeuses": ("transbordeur",),
    "transbronchique": ("transbronchique",),
    "transbronchiques": ("transbronchique",),
    "transcanadien": ("transcanadien",),
    "transcanadienne": ("transcanadien",),
    "transcanadiennes": ("transcanadien",),
    "transcanadiens": ("transcanadien",),
    "transcapillaire": ("transcapillaire",),
    "transcapillaires": ("transcapillaire",),
    "transcarpatique": ("transcarpatique",),
    "transcarpatiques": ("transcarpatique",),
    "transcaspien": ("transcaspien",),
    "transcaspienne": ("transcaspien",),
    "transcaspiennes": ("transcaspien",),
    "transcaspiens": ("transcaspien",),
    "transcaucasien": ("transcaucasien",),
    "transcaucasienne": ("transcaucasien",),
    "transcaucasiennes": ("transcaucasien",),
    "transcaucasiens": ("transcaucasien",),
    "transcendantale": ("transcendantal",),
    "transcendantales": ("transcendantal",),
    "transcendantal": ("transcendantal",),
    "transcendantaux": ("transcendantal",),
    "transclérale": ("transcléral",),
    "transclérales": ("transcléral",),
    "transcléral": ("transcléral",),
    "transcléraux": ("transcléral",),
    "transcontinentale": ("transcontinental",),
    "transcontinentales": ("transcontinental",),
    "transcontinental": ("transcontinental",),
    "transcontinentaux": ("transcontinental",),
    "transcorticale": ("transcortical",),
    "transcorticales": ("transcortical",),
    "transcortical": ("transcortical",),
    "transcorticaux": ("transcortical",),
    "transcripteur": ("transcripteur",),
    "transcripteurs": ("transcripteur",),
    "transcriptrice": ("transcripteur",),
    "transcriptrices": ("transcripteur",),
    "transcriptible": ("transcriptible",),
    "transcriptibles": ("transcriptible",),
    "transcriptionnelle": ("transcriptionnel",),
    "transcriptionnelles": ("transcriptionnel",),
    "transcriptionnel": ("transcriptionnel",),
    "transcriptionnels": ("transcriptionnel",),
    "transculturelle": ("transculturel",),
    "transculturelles": ("transculturel",),
    "transculturel": ("transculturel",),
    "transculturels": ("transculturel",),
    "transcystique": ("transcystique",),
    "transcystiques": ("transcystique",),
    "transdermique": ("transdermique",),
    "transdermiques": ("transdermique",),
    "transdiaphragmatique": ("transdiaphragmatique",),
    "transdiaphragmatiques": ("transdiaphragmatique",),
    "transdisciplinaire": ("transdisciplinaire",),
    "trans-disciplinaires": ("trans-disciplinaire",),
    "transdisciplinaires": ("transdisciplinaire",),
    "transductif": ("transductif",),
    "transductifs": ("transductif",),
    "transductive": ("transductif",),
    "transductives": ("transductif",),
    "transduodénale": ("transduodénal",),
    "transduodénales": ("transduodénal",),
    "transduodénal": ("transduodénal",),
    "transduodénaux": ("transduodénal",),
    "transépithéliale": ("transépithélial",),
    "transépithéliales": ("transépithélial",),
    "transépithélial": ("transépithélial",),
    "transépithéliaux": ("transépithélial",),
    "transeptale": ("transeptal",),
    "transeptales": ("transeptal",),
    "transeptal": ("transeptal",),
    "transeptaux": ("transeptal",),
    "transeuropéen": ("transeuropéen",),
    "transeuropéenne": ("transeuropéen",),
    "transeuropéennes": ("transeuropéen",),
    "transeuropéens": ("transeuropéen",),
    "transférable": ("transférable",),
    "transférables": ("transférable",),
    "transférentielle": ("transférentiel",),
    "transférentielles": ("transférentiel",),
    "transférentiel": ("transférentiel",),
    "transférentiels": ("transférentiel",),
    "transfigurateur": ("transfigurateur",),
    "transfigurateurs": ("transfigurateur",),
    "transfiguratrice": ("transfigurateur",),
    "transfiguratrices": ("transfigurateur",),
    "transfontanellaire": ("transfontanellaire",),
    "transfontanellaires": ("transfontanellaire",),
    "transformable": ("transformable",),
    "transformables": ("transformable",),
    "transformateur": ("transformateur",),
    "transformateurs": ("transformateur",),
    "transformatrice": ("transformateur",),
    "transformatrices": ("transformateur",),
    "transformatif": ("transformatif",),
    "transformatifs": ("transformatif",),
    "transformative": ("transformatif",),
    "transformatives": ("transformatif",),
    "transformationnaliste": ("transformationnaliste",),
    "transformationnalistes": ("transformationnaliste",),
    "transformationnelle": ("transformationnel",),
    "transformationnelles": ("transformationnel",),
    "transformationnel": ("transformationnel",),
    "transformationnels": ("transformationnel",),
    "transformationniste": ("transformationniste",),
    "transformationnistes": ("transformationniste",),
    "transformiste": ("transformiste",),
    "transformistes": ("transformiste",),
    "transfrontalière": ("transfrontalier",),
    "transfrontalières": ("transfrontalier",),
    "transfrontalier": ("transfrontalier",),
    "transfrontaliers": ("transfrontalier",),
    "transfrontière": ("transfrontière",),
    "transfrontières": ("transfrontière",),
    "transfusable": ("transfusable",),
    "transfusables": ("transfusable",),
    "transfusionnelle": ("transfusionnel",),
    "transfusionnelles": ("transfusionnel",),
    "transfusionnel": ("transfusionnel",),
    "transfusionnels": ("transfusionnel",),
    "transgabonaise": ("transgabonais",),
    "transgabonaises": ("transgabonais",),
    "transgabonais": ("transgabonais",),
    "transgastrique": ("transgastrique",),
    "transgastriques": ("transgastrique",),
    "transgénique": ("transgénique",),
    "transgéniques": ("transgénique",),
    "transgranulaire": ("transgranulaire",),
    "transgranulaires": ("transgranulaire",),
    "transgressif": ("transgressif",),
    "transgressifs": ("transgressif",),
    "transgressive": ("transgressif",),
    "transgressives": ("transgressif",),
    "transhorizon": ("transhorizon",),
    "transigible": ("transigible",),
    "transigibles": ("transigible",),
    "transitaire": ("transitaire",),
    "transitaires": ("transitaire",),
    "transitif": ("transitif",),
    "transitifs": ("transitif",),
    "transitive": ("transitif",),
    "transitives": ("transitif",),
    "transitionnelle": ("transitionnel",),
    "transitionnelles": ("transitionnel",),
    "transitionnel": ("transitionnel",),
    "transitionnels": ("transitionnel",),
    "transitoire": ("transitoire",),
    "transitoires": ("transitoire",),
    "translatable": ("translatable",),
    "translatables": ("translatable",),
    "translatif": ("translatif",),
    "translatifs": ("translatif",),
    "translative": ("translatif",),
    "translatives": ("translatif",),
    "translucide": ("translucide",),
    "translucides": ("translucide",),
    "transluminale": ("transluminal",),
    "transluminales": ("transluminal",),
    "transluminal": ("transluminal",),
    "transluminaux": ("transluminal",),
    "transmanche": ("transmanche",),
    "transmembranaire": ("transmembranaire",),
    "transmembranaires": ("transmembranaire",),
    "transmembranique": ("transmembranique",),
    "transmembraniques": ("transmembranique",),
    "transméridien": ("transméridien",),
    "transméridienne": ("transméridien",),
    "transméridiennes": ("transméridien",),
    "transméridiens": ("transméridien",),
    "transmésocolique": ("transmésocolique",),
    "transmésocoliques": ("transmésocolique",),
    "transmetteur": ("transmetteur",),
    "transmetteurs": ("transmetteur",),
    "transmettrice": ("transmetteur",),
    "transmettrices": ("transmetteur",),
    "transmissible": ("transmissible",),
    "transmissibles": ("transmissible",),
    "transmitrale": ("transmitral",),
    "transmitrales": ("transmitral",),
    "transmitral": ("transmitral",),
    "transmitraux": ("transmitral",),
    "transmuable": ("transmuable",),
    "transmuables": ("transmuable",),
    "transmurale": ("transmural",),
    "transmurales": ("transmural",),
    "transmural": ("transmural",),
    "transmuraux": ("transmural",),
    "transmutable": ("transmutable",),
    "transmutables": ("transmutable",),
    "transmutatoire": ("transmutatoire",),
    "transmutatoires": ("transmutatoire",),
    "transnationale": ("transnational",),
    "transnationales": ("transnational",),
    "transnational": ("transnational",),
    "transnationaux": ("transnational",),
    "transneptunien": ("transneptunien",),
    "transneptunienne": ("transneptunien",),
    "transneptuniennes": ("transneptunien",),
    "transneptuniens": ("transneptunien",),
    "transocéanien": ("transocéanien",),
    "transocéanienne": ("transocéanien",),
    "transocéaniennes": ("transocéanien",),
    "transocéaniens": ("transocéanien",),
    "transocéanique": ("transocéanique",),
    "transocéaniques": ("transocéanique",),
    "transoesophagien": ("transoesophagien",),
    "transoesophagienne": ("transoesophagien",),
    "transoesophagiennes": ("transoesophagien",),
    "transoesophagiens": ("transoesophagien",),
    "transombilicale": ("transombilical",),
    "transombilicales": ("transombilical",),
    "transombilical": ("transombilical",),
    "transombilicaux": ("transombilical",),
    "transorbitaire": ("transorbitaire",),
    "transorbitaires": ("transorbitaire",),
    "transpariétale": ("transpariétal",),
    "transpariétales": ("transpariétal",),
    "transpariétal": ("transpariétal",),
    "transpariétaux": ("transpariétal",),
    "transpéritonéale": ("transpéritonéal",),
    "transpéritonéales": ("transpéritonéal",),
    "transpéritonéal": ("transpéritonéal",),
    "transpéritonéaux": ("transpéritonéal",),
    "transphrastique": ("transphrastique",),
    "transphrastiques": ("transphrastique",),
    "transplacentaire": ("transplacentaire",),
    "transplacentaires": ("transplacentaire",),
    "transplantable": ("transplantable",),
    "transplantables": ("transplantable",),
    "transplanteur": ("transplanteur",),
    "transplanteurs": ("transplanteur",),
    "transplanteuse": ("transplanteur",),
    "transplanteuses": ("transplanteur",),
    "transplantologique": ("transplantologique",),
    "transplantologiques": ("transplantologique",),
    "transpleurale": ("transpleural",),
    "transpleurales": ("transpleural",),
    "transpleural": ("transpleural",),
    "transpleuraux": ("transpleural",),
    "transpolaire": ("transpolaire",),
    "transpolaires": ("transpolaire",),
    "transportable": ("transportable",),
    "transportables": ("transportable",),
    "transporteur": ("transporteur",),
    "transporteurs": ("transporteur",),
    "transporteuse": ("transporteur",),
    "transporteuses": ("transporteur",),
    "transposable": ("transposable",),
    "transposables": ("transposable",),
    "transposeur": ("transposeur",),
    "transposeurs": ("transposeur",),
    "transpositeur": ("transpositeur",),
    "transpositeurs": ("transpositeur",),
    "transpositrice": ("transpositeur",),
    "transpositrices": ("transpositeur",),
    "transpyrénéen": ("transpyrénéen",),
    "transpyrénéenne": ("transpyrénéen",),
    "transpyrénéennes": ("transpyrénéen",),
    "transpyrénéens": ("transpyrénéen",),
    "transsacculaire": ("transsacculaire",),
    "transsacculaires": ("transsacculaire",),
    "transsaharien": ("transsaharien",),
    "transsaharienne": ("transsaharien",),
    "transsahariennes": ("transsaharien",),
    "transsahariens": ("transsaharien",),
    "transseptale": ("transseptal",),
    "transseptales": ("transseptal",),
    "transseptal": ("transseptal",),
    "transseptaux": ("transseptal",),
    "transsexuelle": ("transsexuel",),
    "transsexuelles": ("transsexuel",),
    "transsexuel": ("transsexuel",),
    "transsexuels": ("transsexuel",),
    "transsibérien": ("transsibérien",),
    "transsibérienne": ("transsibérien",),
    "transsibériennes": ("transsibérien",),
    "transsibériens": ("transsibérien",),
    "transsonique": ("transsonique",),
    "transsoniques": ("transsonique",),
    "transsynaptique": ("transsynaptique",),
    "transsynaptiques": ("transsynaptique",),
    "transthoracique": ("transthoracique",),
    "transthoraciques": ("transthoracique",),
    "transtympanique": ("transtympanique",),
    "transtympaniques": ("transtympanique",),
    "transuranien": ("transuranien",),
    "transuranienne": ("transuranien",),
    "transuraniennes": ("transuranien",),
    "transuraniens": ("transuranien",),
    "transurétrale": ("transurétral",),
    "transurétrales": ("transurétral",),
    "transurétral": ("transurétral",),
    "transurétraux": ("transurétral",),
    "transvaginale": ("transvaginal",),
    "transvaginales": ("transvaginal",),
    "transvaginal": ("transvaginal",),
    "transvaginaux": ("transvaginal",),
    "transvatérien": ("transvatérien",),
    "transvatérienne": ("transvatérien",),
    "transvatériennes": ("transvatérien",),
    "transvatériens": ("transvatérien",),
    "transversaire": ("transversaire",),
    "transversaires": ("transversaire",),
    "transversale": ("transversal",),
    "transversales": ("transversal",),
    "transversal": ("transversal",),
    "transversaux": ("transversal",),
    "transverse": ("transverse",),
    "transverses": ("transverse",),
    "transvésicale": ("transvésical",),
    "transvésicales": ("transvésical",),
    "transvésical": ("transvésical",),
    "transvésicaux": ("transvésical",),
    "transvésiculaire": ("transvésiculaire",),
    "transvésiculaires": ("transvésiculaire",),
    "transylvanien": ("transylvanien",),
    "transylvanienne": ("transylvanien",),
    "transylvaniennes": ("transylvanien",),
    "transylvaniens": ("transylvanien",),
    "trapèze": ("trapèze",),
    "trapèzes": ("trapèze",),
    "trapézoïdale": ("trapézoïdal",),
    "trapézoïdales": ("trapézoïdal",),
    "trapézoïdal": ("trapézoïdal",),
    "trapézoïdaux": ("trapézoïdal",),
    "trapézoïde": ("trapézoïde",),
    "trapézoïdes": ("trapézoïde",),
    "traumatique": ("traumatique",),
    "traumatiques": ("traumatique",),
    "traumatologique": ("traumatologique",),
    "traumatologiques": ("traumatologique",),
    "travailleur": ("travailleur",),
    "travailleurs": ("travailleur",),
    "travailleuse": ("travailleur",),
    "travailleuses": ("travailleur",),
    "travailliste": ("travailliste",),
    "travaillistes": ("travailliste",),
    "traversable": ("traversable",),
    "traversables": ("traversable",),
    "traversière": ("traversier",),
    "traversières": ("traversier",),
    "traversier": ("traversier",),
    "traversiers": ("traversier",),
    "traversine": ("traversine",),
    "traversines": ("traversine",),
    "trayeur": ("trayeur",),
    "trayeurs": ("trayeur",),
    "trayeuse": ("trayeur",),
    "trayeuses": ("trayeur",),
    "tréfileur": ("tréfileur",),
    "tréfileurs": ("tréfileur",),
    "tréfileuse": ("tréfileur",),
    "tréfileuses": ("tréfileur",),
    "tréfoncière": ("tréfoncier",),
    "tréfoncières": ("tréfoncier",),
    "tréfoncier": ("tréfoncier",),
    "tréfonciers": ("tréfoncier",),
    "trégoroise": ("trégorois",),
    "trégoroises": ("trégorois",),
    "trégorois": ("trégorois",),
    "trégorroise": ("trégorrois",),
    "trégorroises": ("trégorrois",),
    "trégorrois": ("trégorrois",),
    "treizième": ("treizième",),
    "treizièmes": ("treizième",),
    "treiziste": ("treiziste",),
    "treizistes": ("treiziste",),
    "trématique": ("trématique",),
    "trématiques": ("trématique",),
    "trembleur": ("trembleur",),
    "trembleurs": ("trembleur",),
    "trembleuse": ("trembleur",),
    "trembleuses": ("trembleur",),
    "tremens": ("tremens",),
    "trémie": ("trémie",),
    "trémies": ("trémie",),
    "trémière": ("trémière",),
    "trémières": ("trémière",),
    "trémogène": ("trémogène",),
    "trémogènes": ("trémogène",),
    "trempeur": ("trempeur",),
    "trempeurs": ("trempeur",),
    "trempeuse": ("trempeur",),
    "trempeuses": ("trempeur",),
    "trentenaire": ("trentenaire",),
    "trentenaires": ("trentenaire",),
    "trentième": ("trentième",),
    "trentièmes": ("trentième",),
    "tréponémicide": ("tréponémicide",),
    "tréponémicides": ("tréponémicide",),
    "tréponémique": ("tréponémique",),
    "tréponémiques": ("tréponémique",),
    "triable": ("triable",),
    "triables": ("triable",),
    "triacétique": ("triacétique",),
    "triacétiques": ("triacétique",),
    "triadique": ("triadique",),
    "triadiques": ("triadique",),
    "trialiste": ("trialiste",),
    "trialistes": ("trialiste",),
    "triandre": ("triandre",),
    "triandres": ("triandre",),
    "triangulaire": ("triangulaire",),
    "triangulaires": ("triangulaire",),
    "triannuelle": ("triannuel",),
    "triannuelles": ("triannuel",),
    "triannuel": ("triannuel",),
    "triannuels": ("triannuel",),
    "triargentique": ("triargentique",),
    "triargentiques": ("triargentique",),
    "triasique": ("triasique",),
    "triasiques": ("triasique",),
    "triatomique": ("triatomique",),
    "triatomiques": ("triatomique",),
    "triaxiale": ("triaxial",),
    "triaxiales": ("triaxial",),
    "triaxial": ("triaxial",),
    "triaxiaux": ("triaxial",),
    "tribale": ("tribal",),
    "tribales": ("tribal",),
    "tribal": ("tribal",),
    "tribaux": ("tribal",),
    "tribaliste": ("tribaliste",),
    "tribalistes": ("tribaliste",),
    "tribasique": ("tribasique",),
    "tribasiques": ("tribasique",),
    "triblastique": ("triblastique",),
    "triblastiques": ("triblastique",),
    "triboélectrique": ("triboélectrique",),
    "triboélectriques": ("triboélectrique",),
    "tribunitien": ("tribunitien",),
    "tribunitienne": ("tribunitien",),
    "tribunitiennes": ("tribunitien",),
    "tribunitiens": ("tribunitien",),
    "tributaire": ("tributaire",),
    "tributaires": ("tributaire",),
    "tribute": ("tribute",),
    "tributes": ("tribute",),
    "tricalcique": ("tricalcique",),
    "tricalciques": ("tricalcique",),
    "tricarballylique": ("tricarballylique",),
    "tricarballyliques": ("tricarballylique",),
    "tricarboxylique": ("tricarboxylique",),
    "tricarboxyliques": ("tricarboxylique",),
    "tricénaire": ("tricénaire",),
    "tricénaires": ("tricénaire",),
    "tricennale": ("tricennal",),
    "tricennales": ("tricennal",),
    "tricennal": ("tricennal",),
    "tricennaux": ("tricennal",),
    "tricentenaire": ("tricentenaire",),
    "tricentenaires": ("tricentenaire",),
    "tricéphale": ("tricéphale",),
    "tricéphales": ("tricéphale",),
    "triceps": ("triceps",),
    "tricheur": ("tricheur",),
    "tricheurs": ("tricheur",),
    "tricheuse": ("tricheur",),
    "tricheuses": ("tricheur",),
    "trichinale": ("trichinal",),
    "trichinales": ("trichinal",),
    "trichinal": ("trichinal",),
    "trichinaux": ("trichinal",),
    "trichineuse": ("trichineux",),
    "trichineuses": ("trichineux",),
    "trichineux": ("trichineux",),
    "trichloracétique": ("trichloracétique",),
    "trichloracétiques": ("trichloracétique",),
    "trichlorophénoxyacétique": ("trichlorophénoxyacétique",),
    "trichlorophénoxyacétiques": ("trichlorophénoxyacétique",),
    "trichogénique": ("trichogénique",),
    "trichogéniques": ("trichogénique",),
    "trichomonacide": ("trichomonacide",),
    "trichomonacides": ("trichomonacide",),
    "trichophytique": ("trichophytique",),
    "trichophytiques": ("trichophytique",),
    "trichromate": ("trichromate",),
    "trichromates": ("trichromate",),
    "trichromatique": ("trichromatique",),
    "trichromatiques": ("trichromatique",),
    "trichrome": ("trichrome",),
    "trichromes": ("trichrome",),
    "tricipitale": ("tricipital",),
    "tricipitales": ("tricipital",),
    "tricipital": ("tricipital",),
    "tricipitaux": ("tricipital",),
    "triclinique": ("triclinique",),
    "tricliniques": ("triclinique",),
    "tricolore": ("tricolore",),
    "tricolores": ("tricolore",),
    "tricontinentale": ("tricontinental",),
    "tricontinentales": ("tricontinental",),
    "tricontinental": ("tricontinental",),
    "tricontinentaux": ("tricontinental",),
    "tricorne": ("tricorne",),
    "tricornes": ("tricorne",),
    "tricourant": ("tricourant",),
    "tricrote": ("tricrote",),
    "tricrotes": ("tricrote",),
    "tricuspide": ("tricuspide",),
    "tricuspides": ("tricuspide",),
    "tricuspidien": ("tricuspidien",),
    "tricuspidienne": ("tricuspidien",),
    "tricuspidiennes": ("tricuspidien",),
    "tricuspidiens": ("tricuspidien",),
    "tricyclique": ("tricyclique",),
    "tricycliques": ("tricyclique",),
    "tridactyle": ("tridactyle",),
    "tridactyles": ("tridactyle",),
    "tridermique": ("tridermique",),
    "tridermiques": ("tridermique",),
    "tridimensionnelle": ("tridimensionnel",),
    "tridimensionnelles": ("tridimensionnel",),
    "tridimensionnel": ("tridimensionnel",),
    "tridimensionnels": ("tridimensionnel",),
    "tridisciplinaire": ("tridisciplinaire",),
    "tridisciplinaires": ("tridisciplinaire",),
    "trièdre": ("trièdre",),
    "trièdres": ("trièdre",),
    "triennale": ("triennal",),
    "triennales": ("triennal",),
    "triennal": ("triennal",),
    "triennaux": ("triennal",),
    "trieur": ("trieur",),
    "trieurs": ("trieur",),
    "trieuse": ("trieur",),
    "trieuses": ("trieur",),
    "trifide": ("trifide",),
    "trifides": ("trifide",),
    "triflèche": ("triflèche",),
    "triflèches": ("triflèche",),
    "trigémellaire": ("trigémellaire",),
    "trigémellaires": ("trigémellaire",),
    "trigéminale": ("trigéminal",),
    "trigéminales": ("trigéminal",),
    "trigéminal": ("trigéminal",),
    "trigéminaux": ("trigéminal",),
    "trigénétique": ("trigénétique",),
    "trigénétiques": ("trigénétique",),
    "trigonale": ("trigonal",),
    "trigonales": ("trigonal",),
    "trigonal": ("trigonal",),
    "trigonaux": ("trigonal",),
    "trigonalisable": ("trigonalisable",),
    "trigonalisables": ("trigonalisable",),
    "trigone": ("trigone",),
    "trigones": ("trigone",),
    "trigonométrique": ("trigonométrique",),
    "trigonométriques": ("trigonométrique",),
    "trihebdomadaire": ("trihebdomadaire",),
    "trihebdomadaires": ("trihebdomadaire",),
    "trijumeau": ("trijumeau",),
    "trijumeaux": ("trijumeau",),
    "trijumelle": ("trijumeau",),
    "trijumelles": ("trijumeau",),
    "trilatérale": ("trilatéral",),
    "trilatérales": ("trilatéral",),
    "trilatéral": ("trilatéral",),
    "trilatéraux": ("trilatéral",),
    "trilinéaire": ("trilinéaire",),
    "trilinéaires": ("trilinéaire",),
    "trilingue": ("trilingue",),
    "trilingues": ("trilingue",),
    "trilitère": ("trilitère",),
    "trilitères": ("trilitère",),
    "trilittère": ("trilittère",),
    "trilittères": ("trilittère",),
    "triloculaire": ("triloculaire",),
    "triloculaires": ("triloculaire",),
    "trilogique": ("trilogique",),
    "trilogiques": ("trilogique",),
    "trimellitique": ("trimellitique",),
    "trimellitiques": ("trimellitique",),
    "trimère": ("trimère",),
    "trimères": ("trimère",),
    "trimésique": ("trimésique",),
    "trimésiques": ("trimésique",),
    "trimestrielle": ("trimestriel",),
    "trimestrielles": ("trimestriel",),
    "trimestriel": ("trimestriel",),
    "trimestriels": ("trimestriel",),
    "trimètre": ("trimètre",),
    "trimètres": ("trimètre",),
    "trimétrique": ("trimétrique",),
    "trimétriques": ("trimétrique",),
    "trimoteur": ("trimoteur",),
    "trinidadien": ("trinidadien",),
    "trinidadienne": ("trinidadien",),
    "trinidadiennes": ("trinidadien",),
    "trinidadiens": ("trinidadien",),
    "trinitaire": ("trinitaire",),
    "trinitaires": ("trinitaire",),
    "triode": ("triode",),
    "triodes": ("triode",),
    "triomphale": ("triomphal",),
    "triomphales": ("triomphal",),
    "triomphal": ("triomphal",),
    "triomphaux": ("triomphal",),
    "triomphaliste": ("triomphaliste",),
    "triomphalistes": ("triomphaliste",),
    "triomphateur": ("triomphateur",),
    "triomphateurs": ("triomphateur",),
    "triomphatrice": ("triomphateur",),
    "triomphatrices": ("triomphateur",),
    "tripale": ("tripale",),
    "tripales": ("tripale",),
    "tripartite": ("tripartite",),
    "tripartites": ("tripartite",),
    "triphasique": ("triphasique",),
    "triphasiques": ("triphasique",),
    "triphosphorique": ("triphosphorique",),
    "triphosphoriques": ("triphosphorique",),
    "triplace": ("triplace",),
    "triplaces": ("triplace",),
    "triple": ("triple",),
    "triples": ("triple",),
    "triplex": ("triplex",),
    "triploblastique": ("triploblastique",),
    "triploblastiques": ("triploblastique",),
    "triploïde": ("triploïde",),
    "triploïdes": ("triploïde",),
    "tripode": ("tripode",),
    "tripodes": ("tripode",),
    "tripolaire": ("tripolaire",),
    "tripolaires": ("tripolaire",),
    "tripoteur": ("tripoteur",),
    "tripoteurs": ("tripoteur",),
    "tripoteuse": ("tripoteur",),
    "tripoteuses": ("tripoteur",),
    "trirectangle": ("trirectangle",),
    "trirectangles": ("trirectangle",),
    "trisannuelle": ("trisannuel",),
    "trisannuelles": ("trisannuel",),
    "trisannuel": ("trisannuel",),
    "trisannuels": ("trisannuel",),
    "trisecteur": ("trisecteur",),
    "trisecteurs": ("trisecteur",),
    "trisectrice": ("trisecteur",),
    "trisectrices": ("trisecteur",),
    "trisilicique": ("trisilicique",),
    "trisiliciques": ("trisilicique",),
    "trismégiste": ("trismégiste",),
    "trismégistes": ("trismégiste",),
    "trisoc": ("trisoc",),
    "trisodique": ("trisodique",),
    "trisodiques": ("trisodique",),
    "trisomique": ("trisomique",),
    "trisomiques": ("trisomique",),
    "trisphérique": ("trisphérique",),
    "trisphériques": ("trisphérique",),
    "trissyllabe": ("trissyllabe",),
    "trissyllabes": ("trissyllabe",),
    "trissyllabique": ("trissyllabique",),
    "trissyllabiques": ("trissyllabique",),
    "triste": ("triste",),
    "tristes": ("triste",),
    "tristounet": ("tristounet",),
    "tristounets": ("tristounet",),
    "tristounette": ("tristounet",),
    "tristounettes": ("tristounet",),
    "trisyllabe": ("trisyllabe",),
    "trisyllabes": ("trisyllabe",),
    "trisyllabique": ("trisyllabique",),
    "trisyllabiques": ("trisyllabique",),
    "tritanope": ("tritanope",),
    "tritanopes": ("tritanope",),
    "trithionique": ("trithionique",),
    "trithioniques": ("trithionique",),
    "triturable": ("triturable",),
    "triturables": ("triturable",),
    "triumvirale": ("triumviral",),
    "triumvirales": ("triumviral",),
    "triumviral": ("triumviral",),
    "triumviraux": ("triumviral",),
    "trivalve": ("trivalve",),
    "trivalves": ("trivalve",),
    "triviale": ("trivial",),
    "triviales": ("trivial",),
    "trivial": ("trivial",),
    "triviaux": ("trivial",),
    "trobriandaise": ("trobriandais",),
    "trobriandaises": ("trobriandais",),
    "trobriandais": ("trobriandais",),
    "trochaïque": ("trochaïque",),
    "trochaïques": ("trochaïque",),
    "trochantérien": ("trochantérien",),
    "trochantérienne": ("trochantérien",),
    "trochantériennes": ("trochantérien",),
    "trochantériens": ("trochantérien",),
    "trochinien": ("trochinien",),
    "trochinienne": ("trochinien",),
    "trochiniennes": ("trochinien",),
    "trochiniens": ("trochinien",),
    "trochitérien": ("trochitérien",),
    "trochitérienne": ("trochitérien",),
    "trochitériennes": ("trochitérien",),
    "trochitériens": ("trochitérien",),
    "trochléaire": ("trochléaire",),
    "trochléaires": ("trochléaire",),
    "trochoïde": ("trochoïde",),
    "trochoïdes": ("trochoïde",),
    "trochophore": ("trochophore",),
    "trochophores": ("trochophore",),
    "troglobie": ("troglobie",),
    "troglobies": ("troglobie",),
    "troglodyte": ("troglodyte",),
    "troglodytes": ("troglodyte",),
    "troglodytique": ("troglodytique",),
    "troglodytiques": ("troglodytique",),
    "troisième": ("troisième",),
    "troisièmes": ("troisième",),
    "trojane": ("trojane",),
    "trojanes": ("trojane",),
    "trompeur": ("trompeur",),
    "trompeurs": ("trompeur",),
    "trompeuse": ("trompeur",),
    "trompeuses": ("trompeur",),
    "troncable": ("troncable",),
    "troncables": ("troncable",),
    "tronconique": ("tronconique",),
    "tronconiques": ("tronconique",),
    "tronculaire": ("tronculaire",),
    "tronculaires": ("tronculaire",),
    "tropézien": ("tropézien",),
    "tropézienne": ("tropézien",),
    "tropéziennes": ("tropézien",),
    "tropéziens": ("tropézien",),
    "trophallactique": ("trophallactique",),
    "trophallactiques": ("trophallactique",),
    "trophique": ("trophique",),
    "trophiques": ("trophique",),
    "trophoblastique": ("trophoblastique",),
    "trophoblastiques": ("trophoblastique",),
    "trophoneurotique": ("trophoneurotique",),
    "trophoneurotiques": ("trophoneurotique",),
    "trophostatique": ("trophostatique",),
    "trophostatiques": ("trophostatique",),
    "tropicale": ("tropical",),
    "tropicales": ("tropical",),
    "tropical": ("tropical",),
    "tropicaux": ("tropical",),
    "tropique": ("tropique",),
    "tropiques": ("tropique",),
    "tropologique": ("tropologique",),
    "tropologiques": ("tropologique",),
    "troposphérique": ("troposphérique",),
    "troposphériques": ("troposphérique",),
    "trotskiste": ("trotskiste",),
    "trotskistes": ("trotskiste",),
    "trotskyste": ("trotskyste",),
    "trotskystes": ("trotskyste",),
    "trotteur": ("trotteur",),
    "trotteurs": ("trotteur",),
    "trotteuse": ("trotteur",),
    "trotteuses": ("trotteur",),
    "troubadour": ("troubadour",),
    "troubadours": ("troubadour",),
    "troublée": ("troublé",),
    "troublées": ("troublé",),
    "troublé": ("troublé",),
    "trouble": ("trouble",),
    "troublés": ("troublé",),
    "troubles": ("trouble",),
    "troupier": ("troupier",),
    "troupiers": ("troupier",),
    "trouvable": ("trouvable",),
    "trouvables": ("trouvable",),
    "troyen": ("troyen",),
    "troyenne": ("troyen",),
    "troyennes": ("troyen",),
    "troyens": ("troyen",),
    "truffière": ("truffier",),
    "truffières": ("truffier",),
    "truffier": ("truffier",),
    "truffiers": ("truffier",),
    "trypanocide": ("trypanocide",),
    "trypanocides": ("trypanocide",),
    "trypanosomique": ("trypanosomique",),
    "trypanosomiques": ("trypanosomique",),
    "trypomastigote": ("trypomastigote",),
    "trypomastigotes": ("trypomastigote",),
    "tryptaminergique": ("tryptaminergique",),
    "tryptaminergiques": ("tryptaminergique",),
    "tsariste": ("tsariste",),
    "tsaristes": ("tsariste",),
    "tsigane": ("tsigane",),
    "tsiganes": ("tsigane",),
    "tuable": ("tuable",),
    "tuables": ("tuable",),
    "tubaire": ("tubaire",),
    "tubaires": ("tubaire",),
    "tubeless": ("tubeless",),
    "tuberculeuse": ("tuberculeux",),
    "tuberculeuses": ("tuberculeux",),
    "tuberculeux": ("tuberculeux",),
    "tuberculinique": ("tuberculinique",),
    "tuberculiniques": ("tuberculinique",),
    "tuberculoïde": ("tuberculoïde",),
    "tuberculoïdes": ("tuberculoïde",),
    "tuberculostatique": ("tuberculostatique",),
    "tuberculostatiques": ("tuberculostatique",),
    "tubéreuse": ("tubéreux",),
    "tubéreuses": ("tubéreux",),
    "tubéreux": ("tubéreux",),
    "tubérien": ("tubérien",),
    "tubérienne": ("tubérien",),
    "tubériennes": ("tubérien",),
    "tubériens": ("tubérien",),
    "tubériforme": ("tubériforme",),
    "tubériformes": ("tubériforme",),
    "tubérositaire": ("tubérositaire",),
    "tubérositaires": ("tubérositaire",),
    "tubicole": ("tubicole",),
    "tubicoles": ("tubicole",),
    "tubiforme": ("tubiforme",),
    "tubiformes": ("tubiforme",),
    "tubinare": ("tubinare",),
    "tubinares": ("tubinare",),
    "tubiste": ("tubiste",),
    "tubistes": ("tubiste",),
    "tubulaire": ("tubulaire",),
    "tubulaires": ("tubulaire",),
    "tubuleuse": ("tubuleux",),
    "tubuleuses": ("tubuleux",),
    "tubuleux": ("tubuleux",),
    "tubuliflore": ("tubuliflore",),
    "tubuliflores": ("tubuliflore",),
    "tudesque": ("tudesque",),
    "tudesques": ("tudesque",),
    "tueur": ("tueur",),
    "tueurs": ("tueur",),
    "tueuse": ("tueur",),
    "tueuses": ("tueur",),
    "tufière": ("tufier",),
    "tufières": ("tufier",),
    "tufier": ("tufier",),
    "tufiers": ("tufier",),
    "tuilière": ("tuilier",),
    "tuilières": ("tuilier",),
    "tuilier": ("tuilier",),
    "tuiliers": ("tuilier",),
    "tullière": ("tullier",),
    "tullières": ("tullier",),
    "tullier": ("tullier",),
    "tulliers": ("tullier",),
    "tumorale": ("tumoral",),
    "tumorales": ("tumoral",),
    "tumoral": ("tumoral",),
    "tumoraux": ("tumoral",),
    "tumorigène": ("tumorigène",),
    "tumorigènes": ("tumorigène",),
    "tumulaire": ("tumulaire",),
    "tumulaires": ("tumulaire",),
    "tumultuaire": ("tumultuaire",),
    "tumultuaires": ("tumultuaire",),
    "tumultueuse": ("tumultueux",),
    "tumultueuses": ("tumultueux",),
    "tumultueux": ("tumultueux",),
    "tungstique": ("tungstique",),
    "tungstiques": ("tungstique",),
    "tunicaire": ("tunicaire",),
    "tunicaires": ("tunicaire",),
    "tunisien": ("tunisien",),
    "tunisienne": ("tunisien",),
    "tunisiennes": ("tunisien",),
    "tunisiens": ("tunisien",),
    "tunisoise": ("tunisois",),
    "tunisoises": ("tunisois",),
    "tunisois": ("tunisois",),
    "tunnellaire": ("tunnellaire",),
    "tunnellaires": ("tunnellaire",),
    "tupi": ("tupi",),
    "tupis": ("tupi",),
    "turbide": ("turbide",),
    "turbides": ("turbide",),
    "turbidimétrique": ("turbidimétrique",),
    "turbidimétriques": ("turbidimétrique",),
    "turbiditique": ("turbiditique",),
    "turbiditiques": ("turbiditique",),
    "turbimétrique": ("turbimétrique",),
    "turbimétriques": ("turbimétrique",),
    "turbinable": ("turbinable",),
    "turbinables": ("turbinable",),
    "turbinale": ("turbinal",),
    "turbinales": ("turbinal",),
    "turbinal": ("turbinal",),
    "turbinaux": ("turbinal",),
    "turboalternateur": ("turboalternateur",),
    "turboalternateurs": ("turboalternateur",),
    "turbomoléculaire": ("turbomoléculaire",),
    "turbomoléculaires": ("turbomoléculaire",),
    "turc": ("turc",),
    "turcs": ("turc",),
    "turque": ("turc",),
    "turques": ("turc",),
    "turcique": ("turcique",),
    "turciques": ("turcique",),
    "turco-égyptienne": ("turco-égyptien",),
    "turco-mongole": ("turco-mongol",),
    "turco-mongol": ("turco-mongol",),
    "turcophone": ("turcophone",),
    "turcophones": ("turcophone",),
    "turco-tatares": ("turco-tatar",),
    "turco-tatar": ("turco-tatar",),
    "turdoïde": ("turdoïde",),
    "turdoïdes": ("turdoïde",),
    "turgide": ("turgide",),
    "turgides": ("turgide",),
    "turinoise": ("turinois",),
    "turinoises": ("turinois",),
    "turinois": ("turinois",),
    "turkmène": ("turkmène",),
    "turkmènes": ("turkmène",),
    "turonien": ("turonien",),
    "turonienne": ("turonien",),
    "turoniennes": ("turonien",),
    "turoniens": ("turonien",),
    "turpide": ("turpide",),
    "turpides": ("turpide",),
    "turquin": ("turquin",),
    "turquins": ("turquin",),
    "turquoise": ("turquoise",),
    "tussah": ("tussah",),
    "tussau": ("tussau",),
    "tussigène": ("tussigène",),
    "tussigènes": ("tussigène",),
    "tussipare": ("tussipare",),
    "tussipares": ("tussipare",),
    "tutélaire": ("tutélaire",),
    "tutélaires": ("tutélaire",),
    "tutoyeur": ("tutoyeur",),
    "tutoyeurs": ("tutoyeur",),
    "tutoyeuse": ("tutoyeur",),
    "tutoyeuses": ("tutoyeur",),
    "tylosique": ("tylosique",),
    "tylosiques": ("tylosique",),
    "tympanale": ("tympanal",),
    "tympanales": ("tympanal",),
    "tympanal": ("tympanal",),
    "tympanaux": ("tympanal",),
    "tympanique": ("tympanique",),
    "tympaniques": ("tympanique",),
    "typhique": ("typhique",),
    "typhiques": ("typhique",),
    "typhoïde": ("typhoïde",),
    "typhoïdes": ("typhoïde",),
    "typhoïdique": ("typhoïdique",),
    "typhoïdiques": ("typhoïdique",),
    "typhosique": ("typhosique",),
    "typhosiques": ("typhosique",),
    "typique": ("typique",),
    "typiques": ("typique",),
    "typographique": ("typographique",),
    "typographiques": ("typographique",),
    "typologique": ("typologique",),
    "typologiques": ("typologique",),
    "tyrannicide": ("tyrannicide",),
    "tyrannicides": ("tyrannicide",),
    "tyrannique": ("tyrannique",),
    "tyranniques": ("tyrannique",),
    "tyrien": ("tyrien",),
    "tyrienne": ("tyrien",),
    "tyriennes": ("tyrien",),
    "tyriens": ("tyrien",),
    "tyrolien": ("tyrolien",),
    "tyrolienne": ("tyrolien",),
    "tyroliennes": ("tyrolien",),
    "tyroliens": ("tyrolien",),
    "tyrrhénien": ("tyrrhénien",),
    "tyrrhénienne": ("tyrrhénien",),
    "tyrrhéniennes": ("tyrrhénien",),
    "tyrrhéniens": ("tyrrhénien",),
    "tzigane": ("tzigane",),
    "tziganes": ("tzigane",),
    "ubérale": ("ubérale",),
    "ubérales": ("ubérale",),
    "ubiquiste": ("ubiquiste",),
    "ubiquistes": ("ubiquiste",),
    "ubiquitaire": ("ubiquitaire",),
    "ubiquitaires": ("ubiquitaire",),
    "ubuesque": ("ubuesque",),
    "ubuesques": ("ubuesque",),
    "ufologique": ("ufologique",),
    "ufologiques": ("ufologique",),
    "ukrainien": ("ukrainien",),
    "ukrainienne": ("ukrainien",),
    "ukrainiennes": ("ukrainien",),
    "ukrainiens": ("ukrainien",),
    "ulcératif": ("ulcératif",),
    "ulcératifs": ("ulcératif",),
    "ulcérative": ("ulcératif",),
    "ulcératives": ("ulcératif",),
    "ulcéreuse": ("ulcéreux",),
    "ulcéreuses": ("ulcéreux",),
    "ulcéreux": ("ulcéreux",),
    "ulcérogène": ("ulcérogène",),
    "ulcérogènes": ("ulcérogène",),
    "ulcéroïde": ("ulcéroïde",),
    "ulcéroïdes": ("ulcéroïde",),
    "uliginaire": ("uliginaire",),
    "uliginaires": ("uliginaire",),
    "uligineuse": ("uligineux",),
    "uligineuses": ("uligineux",),
    "uligineux": ("uligineux",),
    "ulmique": ("ulmique",),
    "ulmiques": ("ulmique",),
    "ulnaire": ("ulnaire",),
    "ulnaires": ("ulnaire",),
    "ultième": ("ultième",),
    "ultièmes": ("ultième",),
    "ultime": ("ultime",),
    "ultimes": ("ultime",),
    "ultimobranchiale": ("ultimobranchial",),
    "ultimobranchiales": ("ultimobranchial",),
    "ultimobranchial": ("ultimobranchial",),
    "ultimobranchiaux": ("ultimobranchial",),
    "ultra": ("ultra",),
    "ultras": ("ultra",),
    "ultrabasique": ("ultrabasique",),
    "ultrabasiques": ("ultrabasique",),
    "ultrabourgeoise": ("ultrabourgeois",),
    "ultrabourgeoises": ("ultrabourgeois",),
    "ultrabourgeois": ("ultrabourgeois",),
    "ultrabref": ("ultrabref",),
    "ultrabrefs": ("ultrabref",),
    "ultrabrève": ("ultrabref",),
    "ultrabrèves": ("ultrabref",),
    "ultra-chics": ("ultra-chic",),
    "ultra-confidentielles": ("ultra-confidentiel",),
    "ultraconfortable": ("ultraconfortable",),
    "ultraconfortables": ("ultraconfortable",),
    "ultra-conservateur": ("ultra-conservateur",),
    "ultraconservateur": ("ultraconservateur",),
    "ultra-conservateurs": ("ultra-conservateur",),
    "ultraconservateurs": ("ultraconservateur",),
    "ultra-conservatrice": ("ultra-conservateur",),
    "ultraconservatrice": ("ultraconservateur",),
    "ultra-conservatrices": ("ultra-conservateur",),
    "ultraconservatrices": ("ultraconservateur",),
    "ultradien": ("ultradien",),
    "ultradienne": ("ultradien",),
    "ultradiennes": ("ultradien",),
    "ultradiens": ("ultradien",),
    "ultra-fine": ("ultra-fin",),
    "ultra-légère": ("ultraléger",),
    "ultralégère": ("ultraléger",),
    "ultra-légères": ("ultraléger",),
    "ultralégères": ("ultraléger",),
    "ultra-léger": ("ultraléger",),
    "ultraléger": ("ultraléger",),
    "ultralégers": ("ultraléger",),
    "ultralibérale": ("ultralibéral",),
    "ultra-libérales": ("ultra-libéral",),
    "ultralibérales": ("ultralibéral",),
    "ultra-libéral": ("ultra-libéral",),
    "ultralibéral": ("ultralibéral",),
    "ultralibéraux": ("ultralibéral",),
    "ultra-marine": ("ultra-marin",),
    "ultra-marines": ("ultra-marin",),
    "ultramétrique": ("ultramétrique",),
    "ultramétriques": ("ultramétrique",),
    "ultramicroscopique": ("ultramicroscopique",),
    "ultramicroscopiques": ("ultramicroscopique",),
    "ultra-mince": ("ultra-mince",),
    "ultramince": ("ultramince",),
    "ultraminces": ("ultramince",),
    "ultra-moderne": ("ultra-moderne",),
    "ultramoderne": ("ultramoderne",),
    "ultramodernes": ("ultramoderne",),
    "ultranationaliste": ("ultranationaliste",),
    "ultranationalistes": ("ultranationaliste",),
    "ultraplate": ("ultraplat",),
    "ultraplates": ("ultraplat",),
    "ultra-plat": ("ultra-plat",),
    "ultraplat": ("ultraplat",),
    "ultra-plats": ("ultra-plat",),
    "ultraplats": ("ultraplat",),
    "ultra-puissantes": ("ultra-puissant",),
    "ultra-rapide": ("ultra-rapide",),
    "ultrarapide": ("ultrarapide",),
    "ultra-rapides": ("ultra-rapide",),
    "ultrarapides": ("ultrarapide",),
    "ultra-résistant": ("ultra-résistant",),
    "ultrariche": ("ultrariche",),
    "ultrariches": ("ultrariche",),
    "ultraroyaliste": ("ultraroyaliste",),
    "ultraroyalistes": ("ultraroyaliste",),
    "ultra-secrète": ("ultra-secret",),
    "ultra-secrètes": ("ultra-secret",),
    "ultra-secrets": ("ultra-secret",),
    "ultra-sensible": ("ultra-sensible",),
    "ultrasensible": ("ultrasensible",),
    "ultra-sensibles": ("ultra-sensible",),
    "ultrasensibles": ("ultrasensible",),
    "ultrasonique": ("ultrasonique",),
    "ultrasoniques": ("ultrasonique",),
    "ultrasonographique": ("ultrasonographique",),
    "ultrasonographiques": ("ultrasonographique",),
    "ultrasonore": ("ultrasonore",),
    "ultrasonores": ("ultrasonore",),
    "ultrastructurale": ("ultrastructural",),
    "ultrastructurales": ("ultrastructural",),
    "ultrastructural": ("ultrastructural",),
    "ultrastructuraux": ("ultrastructural",),
    "ultra-violet": ("ultraviolet",),
    "ultraviolet": ("ultraviolet",),
    "ultra-violets": ("ultraviolet",),
    "ultraviolets": ("ultraviolet",),
    "ultraviolette": ("ultraviolet",),
    "ultraviolettes": ("ultraviolet",),
    "umbonale": ("umbonal",),
    "umbonales": ("umbonal",),
    "umbonal": ("umbonal",),
    "umbonaux": ("umbonal",),
    "unaire": ("unaire",),
    "unaires": ("unaire",),
    "unanime": ("unanime",),
    "unanimes": ("unanime",),
    "unanimiste": ("unanimiste",),
    "unanimistes": ("unanimiste",),
    "unciale": ("uncial",),
    "unciales": ("uncial",),
    "uncial": ("uncial",),
    "unciaux": ("uncial",),
    "unciforme": ("unciforme",),
    "unciformes": ("unciforme",),
    "uncovertébrale": ("uncovertébral",),
    "uncovertébrales": ("uncovertébral",),
    "uncovertébral": ("uncovertébral",),
    "uncovertébraux": ("uncovertébral",),
    "undécanoïque": ("undécanoïque",),
    "undécanoïques": ("undécanoïque",),
    "undécennale": ("undécennal",),
    "undécennales": ("undécennal",),
    "undécennal": ("undécennal",),
    "undécennaux": ("undécennal",),
    "undécénoïque": ("undécénoïque",),
    "undécénoïques": ("undécénoïque",),
    "undécylénique": ("undécylénique",),
    "undécyléniques": ("undécylénique",),
    "underground": ("underground",),
    "unguéale": ("unguéal",),
    "unguéales": ("unguéal",),
    "unguéal": ("unguéal",),
    "unguéaux": ("unguéal",),
    "unguifère": ("unguifère",),
    "unguifères": ("unguifère",),
    "uniangulaire": ("uniangulaire",),
    "uniangulaires": ("uniangulaire",),
    "uniate": ("uniate",),
    "uniates": ("uniate",),
    "uniaxe": ("uniaxe",),
    "uniaxes": ("uniaxe",),
    "uniaxiale": ("uniaxial",),
    "uniaxiales": ("uniaxial",),
    "uniaxial": ("uniaxial",),
    "uniaxiaux": ("uniaxial",),
    "unicaule": ("unicaule",),
    "unicaules": ("unicaule",),
    "unicellulaire": ("unicellulaire",),
    "unicellulaires": ("unicellulaire",),
    "unicolonne": ("unicolonne",),
    "unicolonnes": ("unicolonne",),
    "unicolore": ("unicolore",),
    "unicolores": ("unicolore",),
    "unicorne": ("unicorne",),
    "unicornes": ("unicorne",),
    "unicursale": ("unicursal",),
    "unicursales": ("unicursal",),
    "unicursal": ("unicursal",),
    "unicursaux": ("unicursal",),
    "unidimensionnelle": ("unidimensionnel",),
    "unidimensionnelles": ("unidimensionnel",),
    "unidimensionnel": ("unidimensionnel",),
    "unidimensionnels": ("unidimensionnel",),
    "unidirectionnelle": ("unidirectionnel",),
    "unidirectionnelles": ("unidirectionnel",),
    "unidirectionnel": ("unidirectionnel",),
    "unidirectionnels": ("unidirectionnel",),
    "unième": ("unième",),
    "unièmes": ("unième",),
    "uniface": ("uniface",),
    "unifaces": ("uniface",),
    "unifaciale": ("unifacial",),
    "unifaciales": ("unifacial",),
    "unifacial": ("unifacial",),
    "unifaciaux": ("unifacial",),
    "unifactorielle": ("unifactoriel",),
    "unifactorielles": ("unifactoriel",),
    "unifactoriel": ("unifactoriel",),
    "unifactoriels": ("unifactoriel",),
    "unificateur": ("unificateur",),
    "unificateurs": ("unificateur",),
    "unificatrice": ("unificateur",),
    "unificatrices": ("unificateur",),
    "unifilaire": ("unifilaire",),
    "unifilaires": ("unifilaire",),
    "uniflorale": ("unifloral",),
    "uniflorales": ("unifloral",),
    "unifloral": ("unifloral",),
    "unifloraux": ("unifloral",),
    "uniflore": ("uniflore",),
    "uniflores": ("uniflore",),
    "uniforme": ("uniforme",),
    "uniformes": ("uniforme",),
    "uniformisateur": ("uniformisateur",),
    "uniformisateurs": ("uniformisateur",),
    "uniformisatrice": ("uniformisateur",),
    "uniformisatrices": ("uniformisateur",),
    "unihoraire": ("unihoraire",),
    "unihoraires": ("unihoraire",),
    "unijambiste": ("unijambiste",),
    "unijambistes": ("unijambiste",),
    "unilatérale": ("unilatéral",),
    "unilatérales": ("unilatéral",),
    "unilatéral": ("unilatéral",),
    "unilatéraux": ("unilatéral",),
    "unilatère": ("unilatère",),
    "unilatères": ("unilatère",),
    "uniligne": ("uniligne",),
    "unilignes": ("uniligne",),
    "unilinéaire": ("unilinéaire",),
    "unilinéaires": ("unilinéaire",),
    "unilingue": ("unilingue",),
    "unilingues": ("unilingue",),
    "uniloculaire": ("uniloculaire",),
    "uniloculaires": ("uniloculaire",),
    "unimodale": ("unimodal",),
    "unimodales": ("unimodal",),
    "unimodal": ("unimodal",),
    "unimodaux": ("unimodal",),
    "unimodulaire": ("unimodulaire",),
    "unimodulaires": ("unimodulaire",),
    "uninominale": ("uninominal",),
    "uninominales": ("uninominal",),
    "uninominal": ("uninominal",),
    "uninominaux": ("uninominal",),
    "unioniste": ("unioniste",),
    "unionistes": ("unioniste",),
    "uniovulaire": ("uniovulaire",),
    "uniovulaires": ("uniovulaire",),
    "unipare": ("unipare",),
    "unipares": ("unipare",),
    "uniparentale": ("uniparental",),
    "uniparentales": ("uniparental",),
    "uniparental": ("uniparental",),
    "uniparentaux": ("uniparental",),
    "unipersonnelle": ("unipersonnel",),
    "unipersonnelles": ("unipersonnel",),
    "unipersonnel": ("unipersonnel",),
    "unipersonnels": ("unipersonnel",),
    "uniphasique": ("uniphasique",),
    "uniphasiques": ("uniphasique",),
    "unipolaire": ("unipolaire",),
    "unipolaires": ("unipolaire",),
    "unipulmonaire": ("unipulmonaire",),
    "unipulmonaires": ("unipulmonaire",),
    "unique": ("unique",),
    "uniques": ("unique",),
    "unisexe": ("unisexe",),
    "unisexes": ("unisexe",),
    "unisexuelle": ("unisexuel",),
    "unisexuelles": ("unisexuel",),
    "unisexuel": ("unisexuel",),
    "unisexuels": ("unisexuel",),
    "unitaire": ("unitaire",),
    "unitaires": ("unitaire",),
    "unitarien": ("unitarien",),
    "unitarienne": ("unitarien",),
    "unitariennes": ("unitarien",),
    "unitariens": ("unitarien",),
    "unitif": ("unitif",),
    "unitifs": ("unitif",),
    "unitive": ("unitif",),
    "unitives": ("unitif",),
    "unitissulaire": ("unitissulaire",),
    "unitissulaires": ("unitissulaire",),
    "unitonale": ("unitonal",),
    "unitonales": ("unitonal",),
    "unitonal": ("unitonal",),
    "unitonaux": ("unitonal",),
    "univalve": ("univalve",),
    "univalves": ("univalve",),
    "universaliste": ("universaliste",),
    "universalistes": ("universaliste",),
    "universelle": ("universel",),
    "universelles": ("universel",),
    "universel": ("universel",),
    "universels": ("universel",),
    "universitaire": ("universitaire",),
    "universitaires": ("universitaire",),
    "univoque": ("univoque",),
    "univoques": ("univoque",),
    "uracylique": ("uracylique",),
    "uracyliques": ("uracylique",),
    "uraneuse": ("uraneux",),
    "uraneuses": ("uraneux",),
    "uraneux": ("uraneux",),
    "uranifère": ("uranifère",),
    "uranifères": ("uranifère",),
    "uranique": ("uranique",),
    "uraniques": ("uranique",),
    "uratique": ("uratique",),
    "uratiques": ("uratique",),
    "urbanisable": ("urbanisable",),
    "urbanisables": ("urbanisable",),
    "urbaniste": ("urbaniste",),
    "urbanistes": ("urbaniste",),
    "urbanistique": ("urbanistique",),
    "urbanistiques": ("urbanistique",),
    "urcéolaire": ("urcéolaire",),
    "urcéolaires": ("urcéolaire",),
    "uréique": ("uréique",),
    "uréiques": ("uréique",),
    "urémigène": ("urémigène",),
    "urémigènes": ("urémigène",),
    "urémique": ("urémique",),
    "urémiques": ("urémique",),
    "uréogénique": ("uréogénique",),
    "uréogéniques": ("uréogénique",),
    "uréopoïétique": ("uréopoïétique",),
    "uréopoïétiques": ("uréopoïétique",),
    "uréosécrétoire": ("uréosécrétoire",),
    "uréosécrétoires": ("uréosécrétoire",),
    "uréotélique": ("uréotélique",),
    "uréotéliques": ("uréotélique",),
    "urétérale": ("urétéral",),
    "urétérales": ("urétéral",),
    "urétéral": ("urétéral",),
    "urétéraux": ("urétéral",),
    "urétéro-vésicale": ("urétérovésical",),
    "urétéro-vésical": ("urétéro-vésical",),
    "urétéro-vésicaux": ("urétéro-vésical",),
    "urétrale": ("urétral",),
    "urétrales": ("urétral",),
    "urétral": ("urétral",),
    "urétraux": ("urétral",),
    "urétro-périnéal": ("urétropérinéal",),
    "urétro-périnéaux": ("urétropérinéal",),
    "urétro-rectales": ("urétrorectal",),
    "urétroscopique": ("urétroscopique",),
    "urétroscopiques": ("urétroscopique",),
    "urgentissime": ("urgentissime",),
    "urgentissimes": ("urgentissime",),
    "urgonien": ("urgonien",),
    "urgonienne": ("urgonien",),
    "urgoniennes": ("urgonien",),
    "urgoniens": ("urgonien",),
    "uricoéliminateur": ("uricoéliminateur",),
    "uricoéliminateurs": ("uricoéliminateur",),
    "uricoéliminatrice": ("uricoéliminateur",),
    "uricoéliminatrices": ("uricoéliminateur",),
    "uricofrénateur": ("uricofrénateur",),
    "uricofrénateurs": ("uricofrénateur",),
    "uricofrénatrice": ("uricofrénateur",),
    "uricofrénatrices": ("uricofrénateur",),
    "urico-inhibitrice": ("urico-inhibiteur",),
    "uricolytique": ("uricolytique",),
    "uricolytiques": ("uricolytique",),
    "uricopoïétique": ("uricopoïétique",),
    "uricopoïétiques": ("uricopoïétique",),
    "uricosurique": ("uricosurique",),
    "uricosuriques": ("uricosurique",),
    "uricotélique": ("uricotélique",),
    "uricotéliques": ("uricotélique",),
    "uridylique": ("uridylique",),
    "uridyliques": ("uridylique",),
    "urinaire": ("urinaire",),
    "urinaires": ("urinaire",),
    "urineuse": ("urineux",),
    "urineuses": ("urineux",),
    "urineux": ("urineux",),
    "urinifère": ("urinifère",),
    "urinifères": ("urinifère",),
    "urique": ("urique",),
    "uriques": ("urique",),
    "urobilinurique": ("urobilinurique",),
    "urobilinuriques": ("urobilinurique",),
    "urodynamique": ("urodynamique",),
    "urodynamiques": ("urodynamique",),
    "urogénitale": ("urogénital",),
    "urogénitales": ("urogénital",),
    "urogénital": ("urogénital",),
    "urogénitaux": ("urogénital",),
    "urologique": ("urologique",),
    "urologiques": ("urologique",),
    "uronique": ("uronique",),
    "uroniques": ("uronique",),
    "uropoïétique": ("uropoïétique",),
    "uropoïétiques": ("uropoïétique",),
    "uropygiale": ("uropygial",),
    "uropygiales": ("uropygial",),
    "uropygial": ("uropygial",),
    "uropygiaux": ("uropygial",),
    "uropygien": ("uropygien",),
    "uropygienne": ("uropygien",),
    "uropygiennes": ("uropygien",),
    "uropygiens": ("uropygien",),
    "urotélique": ("urotélique",),
    "urotéliques": ("urotélique",),
    "ursodésoxycholique": ("ursodésoxycholique",),
    "ursodésoxycholiques": ("ursodésoxycholique",),
    "ursolique": ("ursolique",),
    "ursoliques": ("ursolique",),
    "urticarien": ("urticarien",),
    "urticarienne": ("urticarien",),
    "urticariennes": ("urticarien",),
    "urticariens": ("urticarien",),
    "urugayen": ("urugayen",),
    "urugayenne": ("urugayen",),
    "urugayennes": ("urugayen",),
    "urugayens": ("urugayen",),
    "uruguayen": ("uruguayen",),
    "uruguayenne": ("uruguayen",),
    "uruguayennes": ("uruguayen",),
    "uruguayens": ("uruguayen",),
    "usable": ("usable",),
    "usables": ("usable",),
    "usagère": ("usager",),
    "usagères": ("usager",),
    "usager": ("usager",),
    "usagers": ("usager",),
    "usinable": ("usinable",),
    "usinables": ("usinable",),
    "usinière": ("usinier",),
    "usinières": ("usinier",),
    "usinier": ("usinier",),
    "usiniers": ("usinier",),
    "usuelle": ("usuel",),
    "usuelles": ("usuel",),
    "usuel": ("usuel",),
    "usuels": ("usuel",),
    "usufructuaire": ("usufructuaire",),
    "usufructuaires": ("usufructuaire",),
    "usufruitière": ("usufruitier",),
    "usufruitières": ("usufruitier",),
    "usufruitier": ("usufruitier",),
    "usufruitiers": ("usufruitier",),
    "usuraire": ("usuraire",),
    "usuraires": ("usuraire",),
    "usurpateur": ("usurpateur",),
    "usurpateurs": ("usurpateur",),
    "usurpatrice": ("usurpateur",),
    "usurpatrices": ("usurpateur",),
    "usurpatoire": ("usurpatoire",),
    "usurpatoires": ("usurpatoire",),
    "utéro-ovariennes": ("utéro-ovarien",),
    "utéro-placentaires": ("utéroplacentaire",),
    "utéro-vaginale": ("utérovaginal",),
    "utile": ("utile",),
    "utiles": ("utile",),
    "utilisable": ("utilisable",),
    "utilisables": ("utilisable",),
    "utilisateur": ("utilisateur",),
    "utilisateurs": ("utilisateur",),
    "utilisatrice": ("utilisateur",),
    "utilisatrices": ("utilisateur",),
    "utilitaire": ("utilitaire",),
    "utilitaires": ("utilitaire",),
    "utilitariste": ("utilitariste",),
    "utilitaristes": ("utilitariste",),
    "uto-aztèque": ("uto-aztèque",),
    "utopique": ("utopique",),
    "utopiques": ("utopique",),
    "utopiste": ("utopiste",),
    "utopistes": ("utopiste",),
    "utriculaire": ("utriculaire",),
    "utriculaires": ("utriculaire",),
    "utriculeuse": ("utriculeux",),
    "utriculeuses": ("utriculeux",),
    "utriculeux": ("utriculeux",),
    "uvale": ("uval",),
    "uvales": ("uval",),
    "uval": ("uval",),
    "uvaux": ("uval",),
    "uvéale": ("uvéal",),
    "uvéales": ("uvéal",),
    "uvéal": ("uvéal",),
    "uvéaux": ("uvéal",),
    "uvulaire": ("uvulaire",),
    "uvulaires": ("uvulaire",),
    "uxorilocale": ("uxorilocal",),
    "uxorilocales": ("uxorilocal",),
    "uxorilocal": ("uxorilocal",),
    "uxorilocaux": ("uxorilocal",),
    "uzbek": ("uzbek",),
    "uzbeks": ("uzbek",),
    "vacancière": ("vacancier",),
    "vacancières": ("vacancier",),
    "vacancier": ("vacancier",),
    "vacanciers": ("vacancier",),
    "vacataire": ("vacataire",),
    "vacataires": ("vacataire",),
    "vaccinable": ("vaccinable",),
    "vaccinables": ("vaccinable",),
    "vaccinale": ("vaccinal",),
    "vaccinales": ("vaccinal",),
    "vaccinal": ("vaccinal",),
    "vaccinaux": ("vaccinal",),
    "vaccinateur": ("vaccinateur",),
    "vaccinateurs": ("vaccinateur",),
    "vaccinatrice": ("vaccinateur",),
    "vaccinatrices": ("vaccinateur",),
    "vaccinifère": ("vaccinifère",),
    "vaccinifères": ("vaccinifère",),
    "vacciniforme": ("vacciniforme",),
    "vacciniformes": ("vacciniforme",),
    "vaccinogène": ("vaccinogène",),
    "vaccinogènes": ("vaccinogène",),
    "vaccinoïde": ("vaccinoïde",),
    "vaccinoïdes": ("vaccinoïde",),
    "vache": ("vache",),
    "vaches": ("vache",),
    "vachère": ("vacher",),
    "vachères": ("vacher",),
    "vacher": ("vacher",),
    "vachers": ("vacher",),
    "vacuolaire": ("vacuolaire",),
    "vacuolaires": ("vacuolaire",),
    "vadrouilleur": ("vadrouilleur",),
    "vadrouilleurs": ("vadrouilleur",),
    "vadrouilleuse": ("vadrouilleur",),
    "vadrouilleuses": ("vadrouilleur",),
    "vagale": ("vagal",),
    "vagales": ("vagal",),
    "vagal": ("vagal",),
    "vagaux": ("vagal",),
    "vagile": ("vagile",),
    "vagiles": ("vagile",),
    "vaginale": ("vaginal",),
    "vaginales": ("vaginal",),
    "vaginal": ("vaginal",),
    "vaginaux": ("vaginal",),
    "vaginotrope": ("vaginotrope",),
    "vaginotropes": ("vaginotrope",),
    "vagolytique": ("vagolytique",),
    "vagolytiques": ("vagolytique",),
    "vagomimétique": ("vagomimétique",),
    "vagomimétiques": ("vagomimétique",),
    "vagoparalytique": ("vagoparalytique",),
    "vagoparalytiques": ("vagoparalytique",),
    "vagosympathique": ("vagosympathique",),
    "vagosympathiques": ("vagosympathique",),
    "vagotonique": ("vagotonique",),
    "vagotoniques": ("vagotonique",),
    "vague": ("vague",),
    "vagues": ("vague",),
    "vainqueur": ("vainqueur",),
    "vainqueurs": ("vainqueur",),
    "vairon": ("vairon",),
    "vaironne": ("vairon",),
    "vaironnes": ("vairon",),
    "vairons": ("vairon",),
    "valable": ("valable",),
    "valables": ("valable",),
    "valaisan": ("valaisan",),
    "valaisanne": ("valaisan",),
    "valaisannes": ("valaisan",),
    "valaisans": ("valaisan",),
    "valaque": ("valaque",),
    "valaques": ("valaque",),
    "valencien": ("valencien",),
    "valencienne": ("valencien",),
    "valenciennes": ("valencien",),
    "valenciens": ("valencien",),
    "valenciennoise": ("valenciennois",),
    "valenciennoises": ("valenciennois",),
    "valenciennois": ("valenciennois",),
    "valentinoise": ("valentinois",),
    "valentinoises": ("valentinois",),
    "valentinois": ("valentinois",),
    "valérianique": ("valérianique",),
    "valérianiques": ("valérianique",),
    "valérique": ("valérique",),
    "valériques": ("valérique",),
    "valétudinaire": ("valétudinaire",),
    "valétudinaires": ("valétudinaire",),
    "valeureuse": ("valeureux",),
    "valeureuses": ("valeureux",),
    "valeureux": ("valeureux",),
    "valga": ("valgus",),
    "valgus": ("valgus",),
    "validable": ("validable",),
    "validables": ("validable",),
    "valide": ("valide",),
    "valides": ("valide",),
    "vallaire": ("vallaire",),
    "vallaires": ("vallaire",),
    "vallonneuse": ("vallonneux",),
    "vallonneuses": ("vallonneux",),
    "vallonneux": ("vallonneux",),
    "valorisable": ("valorisable",),
    "valorisables": ("valorisable",),
    "valseur": ("valseur",),
    "valseurs": ("valseur",),
    "valseuse": ("valseur",),
    "valseuses": ("valseur",),
    "valvaire": ("valvaire",),
    "valvaires": ("valvaire",),
    "valvulaire": ("valvulaire",),
    "valvulaires": ("valvulaire",),
    "vampire": ("vampire",),
    "vampires": ("vampire",),
    "vampirique": ("vampirique",),
    "vampiriques": ("vampirique",),
    "vanadeuse": ("vanadeux",),
    "vanadeuses": ("vanadeux",),
    "vanadeux": ("vanadeux",),
    "vanadifère": ("vanadifère",),
    "vanadifères": ("vanadifère",),
    "vanadique": ("vanadique",),
    "vanadiques": ("vanadique",),
    "vandale": ("vandale",),
    "vandales": ("vandale",),
    "vanillique": ("vanillique",),
    "vanilliques": ("vanillique",),
    "vanillylmandélique": ("vanillylmandélique",),
    "vanillylmandéliques": ("vanillylmandélique",),
    "vaniteuse": ("vaniteux",),
    "vaniteuses": ("vaniteux",),
    "vaniteux": ("vaniteux",),
    "vanneur": ("vanneur",),
    "vanneurs": ("vanneur",),
    "vanneuse": ("vanneur",),
    "vanneuses": ("vanneur",),
    "vanylmandélique": ("vanylmandélique",),
    "vanylmandéliques": ("vanylmandélique",),
    "vaporeuse": ("vaporeux",),
    "vaporeuses": ("vaporeux",),
    "vaporeux": ("vaporeux",),
    "vara": ("varus",),
    "variable": ("variable",),
    "variables": ("variable",),
    "variantielle": ("variantiel",),
    "variantielles": ("variantiel",),
    "variantiel": ("variantiel",),
    "variantiels": ("variantiel",),
    "variationnelle": ("variationnel",),
    "variationnelles": ("variationnel",),
    "variationnel": ("variationnel",),
    "variationnels": ("variationnel",),
    "varicelleuse": ("varicelleux",),
    "varicelleuses": ("varicelleux",),
    "varicelleux": ("varicelleux",),
    "varicelliforme": ("varicelliforme",),
    "varicelliformes": ("varicelliforme",),
    "variétale": ("variétal",),
    "variétales": ("variétal",),
    "variétal": ("variétal",),
    "variétaux": ("variétal",),
    "varioleuse": ("varioleux",),
    "varioleuses": ("varioleux",),
    "varioleux": ("varioleux",),
    "varioliforme": ("varioliforme",),
    "varioliformes": ("varioliforme",),
    "variolique": ("variolique",),
    "varioliques": ("variolique",),
    "variolitique": ("variolitique",),
    "variolitiques": ("variolitique",),
    "variqueuse": ("variqueux",),
    "variqueuses": ("variqueux",),
    "variqueux": ("variqueux",),
    "varoise": ("varois",),
    "varoises": ("varois",),
    "varois": ("varois",),
    "varus": ("varus",),
    "vasculaire": ("vasculaire",),
    "vasculaires": ("vasculaire",),
    "vasculo-nerveux": ("vasculo-nerveux",),
    "vaseuse": ("vaseux",),
    "vaseuses": ("vaseux",),
    "vaseux": ("vaseux",),
    "vasoconstricteur": ("vasoconstricteur",),
    "vasoconstricteurs": ("vasoconstricteur",),
    "vasoconstrictrice": ("vasoconstricteur",),
    "vasoconstrictrices": ("vasoconstricteur",),
    "vasoconstrictif": ("vasoconstrictif",),
    "vasoconstrictifs": ("vasoconstrictif",),
    "vasoconstrictive": ("vasoconstrictif",),
    "vasoconstrictives": ("vasoconstrictif",),
    "vaso-dilatateur": ("vasodilatateur",),
    "vasodilatateur": ("vasodilatateur",),
    "vasodilatateurs": ("vasodilatateur",),
    "vaso-dilatatrice": ("vasodilatateur",),
    "vasodilatatrice": ("vasodilatateur",),
    "vasodilatatrices": ("vasodilatateur",),
    "vasogénique": ("vasogénique",),
    "vasogéniques": ("vasogénique",),
    "vasoinhibiteur": ("vasoinhibiteur",),
    "vaso-inhibiteurs": ("vaso-inhibiteur",),
    "vasoinhibiteurs": ("vasoinhibiteur",),
    "vasoinhibitrice": ("vasoinhibiteur",),
    "vasoinhibitrices": ("vasoinhibiteur",),
    "vasolabile": ("vasolabile",),
    "vasolabiles": ("vasolabile",),
    "vaso-moteur": ("vaso-moteur",),
    "vasomoteur": ("vasomoteur",),
    "vaso-moteurs": ("vasomoteur",),
    "vasomoteurs": ("vasomoteur",),
    "vasomotrice": ("vasomoteur",),
    "vaso-motrices": ("vaso-moteur",),
    "vasomotrices": ("vasomoteur",),
    "vasoparalytique": ("vasoparalytique",),
    "vasoparalytiques": ("vasoparalytique",),
    "vasoplégique": ("vasoplégique",),
    "vasoplégiques": ("vasoplégique",),
    "vasopresseur": ("vasopresseur",),
    "vasopresseurs": ("vasopresseur",),
    "vasotonique": ("vasotonique",),
    "vasotoniques": ("vasotonique",),
    "vasotrope": ("vasotrope",),
    "vasotropes": ("vasotrope",),
    "vasovagale": ("vasovagal",),
    "vasovagales": ("vasovagal",),
    "vasovagal": ("vasovagal",),
    "vasovagaux": ("vasovagal",),
    "vassale": ("vassal",),
    "vassales": ("vassal",),
    "vassal": ("vassal",),
    "vassaux": ("vassal",),
    "vassalique": ("vassalique",),
    "vassaliques": ("vassalique",),
    "vaste": ("vaste",),
    "vastes": ("vaste",),
    "vatérien": ("vatérien",),
    "vatérienne": ("vatérien",),
    "vatériennes": ("vatérien",),
    "vatériens": ("vatérien",),
    "vaticane": ("vaticane",),
    "vaticanes": ("vaticane",),
    "vaticinateur": ("vaticinateur",),
    "vaticinateurs": ("vaticinateur",),
    "vaticinatrice": ("vaticinateur",),
    "vaticinatrices": ("vaticinateur",),
    "vauclusien": ("vauclusien",),
    "vauclusienne": ("vauclusien",),
    "vauclusiennes": ("vauclusien",),
    "vauclusiens": ("vauclusien",),
    "vaudevillesque": ("vaudevillesque",),
    "vaudevillesques": ("vaudevillesque",),
    "vaudoise": ("vaudois",),
    "vaudoises": ("vaudois",),
    "vaudois": ("vaudois",),
    "vaurien": ("vaurien",),
    "vaurienne": ("vaurien",),
    "vauriennes": ("vaurien",),
    "vauriens": ("vaurien",),
    "vecteur": ("vecteur",),
    "vecteurs": ("vecteur",),
    "vectrice": ("vecteur",),
    "vectrices": ("vecteur",),
    "vectorielle": ("vectoriel",),
    "vectorielles": ("vectoriel",),
    "vectoriel": ("vectoriel",),
    "vectoriels": ("vectoriel",),
    "védantique": ("védantique",),
    "védantiques": ("védantique",),
    "védique": ("védique",),
    "védiques": ("védique",),
    "végétale": ("végétal",),
    "végétales": ("végétal",),
    "végétal": ("végétal",),
    "végétaux": ("végétal",),
    "végétalien": ("végétalien",),
    "végétalienne": ("végétalien",),
    "végétaliennes": ("végétalien",),
    "végétaliens": ("végétalien",),
    "végétaliste": ("végétaliste",),
    "végétalistes": ("végétaliste",),
    "végétarien": ("végétarien",),
    "végétarienne": ("végétarien",),
    "végétariennes": ("végétarien",),
    "végétariens": ("végétarien",),
    "végétatif": ("végétatif",),
    "végétatifs": ("végétatif",),
    "végétative": ("végétatif",),
    "végétatives": ("végétatif",),
    "véhiculaire": ("véhiculaire",),
    "véhiculaires": ("véhiculaire",),
    "vehmique": ("vehmique",),
    "vehmiques": ("vehmique",),
    "veineuse": ("veineux",),
    "veineuses": ("veineux",),
    "veineux": ("veineux",),
    "veinotonique": ("veinotonique",),
    "veinotoniques": ("veinotonique",),
    "vélaire": ("vélaire",),
    "vélaires": ("vélaire",),
    "vélamenteuse": ("vélamenteux",),
    "vélamenteuses": ("vélamenteux",),
    "vélamenteux": ("vélamenteux",),
    "velche": ("velche",),
    "velches": ("velche",),
    "véligère": ("véligère",),
    "véligères": ("véligère",),
    "vélique": ("vélique",),
    "véliques": ("vélique",),
    "vélivole": ("vélivole",),
    "vélivoles": ("vélivole",),
    "velléitaire": ("velléitaire",),
    "velléitaires": ("velléitaire",),
    "véloce": ("véloce",),
    "véloces": ("véloce",),
    "vélocimétrique": ("vélocimétrique",),
    "vélocimétriques": ("vélocimétrique",),
    "vélocipédique": ("vélocipédique",),
    "vélocipédiques": ("vélocipédique",),
    "vélopalatine": ("vélopalatin",),
    "vélo-palatines": ("vélo-palatin",),
    "vélopalatines": ("vélopalatin",),
    "vélopalatin": ("vélopalatin",),
    "vélopalatins": ("vélopalatin",),
    "velouteuse": ("velouteux",),
    "velouteuses": ("velouteux",),
    "velouteux": ("velouteux",),
    "veloutière": ("veloutier",),
    "veloutières": ("veloutier",),
    "veloutier": ("veloutier",),
    "veloutiers": ("veloutier",),
    "velvétique": ("velvétique",),
    "velvétiques": ("velvétique",),
    "vénale": ("vénal",),
    "vénales": ("vénal",),
    "vénal": ("vénal",),
    "vénaux": ("vénal",),
    "vendable": ("vendable",),
    "vendables": ("vendable",),
    "vendangeable": ("vendangeable",),
    "vendangeables": ("vendangeable",),
    "vendéen": ("vendéen",),
    "vendéenne": ("vendéen",),
    "vendéennes": ("vendéen",),
    "vendéens": ("vendéen",),
    "vénéneuse": ("vénéneux",),
    "vénéneuses": ("vénéneux",),
    "vénéneux": ("vénéneux",),
    "vénénifère": ("vénénifère",),
    "vénénifères": ("vénénifère",),
    "vénérable": ("vénérable",),
    "vénérables": ("vénérable",),
    "vénéréologique": ("vénéréologique",),
    "vénéréologiques": ("vénéréologique",),
    "vénérien": ("vénérien",),
    "vénérienne": ("vénérien",),
    "vénériennes": ("vénérien",),
    "vénériens": ("vénérien",),
    "vénérologique": ("vénérologique",),
    "vénérologiques": ("vénérologique",),
    "vénète": ("vénète",),
    "vénètes": ("vénète",),
    "vénézuélien": ("vénézuélien",),
    "vénézuélienne": ("vénézuélien",),
    "vénézuéliennes": ("vénézuélien",),
    "vénézuéliens": ("vénézuélien",),
    "vengeresse": ("vengeur",),
    "vengeresses": ("vengeur",),
    "vengeur": ("vengeur",),
    "vengeurs": ("vengeur",),
    "vénielle": ("véniel",),
    "vénielles": ("véniel",),
    "véniel": ("véniel",),
    "véniels": ("véniel",),
    "venimeuse": ("venimeux",),
    "venimeuses": ("venimeux",),
    "venimeux": ("venimeux",),
    "vénitien": ("vénitien",),
    "vénitienne": ("vénitien",),
    "vénitiennes": ("vénitien",),
    "vénitiens": ("vénitien",),
    "venteuse": ("venteux",),
    "venteuses": ("venteux",),
    "venteux": ("venteux",),
    "ventilable": ("ventilable",),
    "ventilables": ("ventilable",),
    "ventilatoire": ("ventilatoire",),
    "ventilatoires": ("ventilatoire",),
    "ventrale": ("ventral",),
    "ventrales": ("ventral",),
    "ventral": ("ventral",),
    "ventraux": ("ventral",),
    "ventriculaire": ("ventriculaire",),
    "ventriculaires": ("ventriculaire",),
    "ventriculonecteur": ("ventriculonecteur",),
    "ventriculonecteurs": ("ventriculonecteur",),
    "ventriculonectrice": ("ventriculonecteur",),
    "ventriculonectrices": ("ventriculonecteur",),
    "ventriloque": ("ventriloque",),
    "ventriloques": ("ventriloque",),
    "ventrolatérale": ("ventrolatéral",),
    "ventrolatérales": ("ventrolatéral",),
    "ventrolatéral": ("ventrolatéral",),
    "ventrolatéraux": ("ventrolatéral",),
    "vénusien": ("vénusien",),
    "vénusienne": ("vénusien",),
    "vénusiennes": ("vénusien",),
    "vénusiens": ("vénusien",),
    "vérace": ("vérace",),
    "véraces": ("vérace",),
    "verbale": ("verbal",),
    "verbales": ("verbal",),
    "verbal": ("verbal",),
    "verbaux": ("verbal",),
    "verbalisateur": ("verbalisateur",),
    "verbalisateurs": ("verbalisateur",),
    "verbalisatrice": ("verbalisateur",),
    "verbalisatrices": ("verbalisateur",),
    "verbeuse": ("verbeux",),
    "verbeuses": ("verbeux",),
    "verbeux": ("verbeux",),
    "verdâtre": ("verdâtre",),
    "verdâtres": ("verdâtre",),
    "verdelet": ("verdelet",),
    "verdelets": ("verdelet",),
    "verdelette": ("verdelet",),
    "verdelettes": ("verdelet",),
    "verdien": ("verdien",),
    "verdienne": ("verdien",),
    "verdiennes": ("verdien",),
    "verdiens": ("verdien",),
    "vérécondieuse": ("vérécondieux",),
    "vérécondieuses": ("vérécondieux",),
    "vérécondieux": ("vérécondieux",),
    "véreuse": ("véreux",),
    "véreuses": ("véreux",),
    "véreux": ("véreux",),
    "vergeur": ("vergeur",),
    "vergeurs": ("vergeur",),
    "vériconditionnelle": ("vériconditionnel",),
    "vériconditionnelles": ("vériconditionnel",),
    "vériconditionnel": ("vériconditionnel",),
    "vériconditionnels": ("vériconditionnel",),
    "véridicteur": ("véridicteur",),
    "véridicteurs": ("véridicteur",),
    "véridictrice": ("véridicteur",),
    "véridictrices": ("véridicteur",),
    "véridique": ("véridique",),
    "véridiques": ("véridique",),
    "vérifiable": ("vérifiable",),
    "vérifiables": ("vérifiable",),
    "vérificateur": ("vérificateur",),
    "vérificateurs": ("vérificateur",),
    "vérificatrice": ("vérificateur",),
    "vérificatrices": ("vérificateur",),
    "vérificatif": ("vérificatif",),
    "vérificatifs": ("vérificatif",),
    "vérificative": ("vérificatif",),
    "vérificatives": ("vérificatif",),
    "vérificationniste": ("vérificationniste",),
    "vérificationnistes": ("vérificationniste",),
    "vériste": ("vériste",),
    "véristes": ("vériste",),
    "véritable": ("véritable",),
    "véritables": ("véritable",),
    "vermeille": ("vermeil",),
    "vermeilles": ("vermeil",),
    "vermeil": ("vermeil",),
    "vermeils": ("vermeil",),
    "vermicide": ("vermicide",),
    "vermicides": ("vermicide",),
    "vermiculaire": ("vermiculaire",),
    "vermiculaires": ("vermiculaire",),
    "vermien": ("vermien",),
    "vermienne": ("vermien",),
    "vermiennes": ("vermien",),
    "vermiens": ("vermien",),
    "vermiforme": ("vermiforme",),
    "vermiformes": ("vermiforme",),
    "vermifuge": ("vermifuge",),
    "vermifuges": ("vermifuge",),
    "vermillon": ("vermillon",),
    "vermineuse": ("vermineux",),
    "vermineuses": ("vermineux",),
    "vermineux": ("vermineux",),
    "vermivore": ("vermivore",),
    "vermivores": ("vermivore",),
    "vernaculaire": ("vernaculaire",),
    "vernaculaires": ("vernaculaire",),
    "vernale": ("vernal",),
    "vernales": ("vernal",),
    "vernal": ("vernal",),
    "vernaux": ("vernal",),
    "véroleuse": ("véroleux",),
    "véroleuses": ("véroleux",),
    "véroleux": ("véroleux",),
    "véronaise": ("véronais",),
    "véronaises": ("véronais",),
    "véronais": ("véronais",),
    "verrière": ("verrier",),
    "verrières": ("verrier",),
    "verrier": ("verrier",),
    "verriers": ("verrier",),
    "verrouillable": ("verrouillable",),
    "verrouillables": ("verrouillable",),
    "verruciforme": ("verruciforme",),
    "verruciformes": ("verruciforme",),
    "verruqueuse": ("verruqueux",),
    "verruqueuses": ("verruqueux",),
    "verruqueux": ("verruqueux",),
    "versable": ("versable",),
    "versables": ("versable",),
    "versaillaise": ("versaillais",),
    "versaillaises": ("versaillais",),
    "versaillais": ("versaillais",),
    "versatile": ("versatile",),
    "versatiles": ("versatile",),
    "verseur": ("verseur",),
    "verseurs": ("verseur",),
    "verseuse": ("verseur",),
    "verseuses": ("verseur",),
    "versicolore": ("versicolore",),
    "versicolores": ("versicolore",),
    "vertébrale": ("vertébral",),
    "vertébrales": ("vertébral",),
    "vertébral": ("vertébral",),
    "vertébraux": ("vertébral",),
    "vertébro-basilaire": ("vertébro-basilaire",),
    "vertébrobasilaire": ("vertébrobasilaire",),
    "vertébrobasilaires": ("vertébrobasilaire",),
    "vertébro-vertébral": ("vertébro-vertébral",),
    "vertébro-vertébraux": ("vertébro-vertébral",),
    "verticale": ("vertical",),
    "verticales": ("vertical",),
    "vertical": ("vertical",),
    "verticaux": ("vertical",),
    "vertigineuse": ("vertigineux",),
    "vertigineuses": ("vertigineux",),
    "vertigineux": ("vertigineux",),
    "vertueuse": ("vertueux",),
    "vertueuses": ("vertueux",),
    "vertueux": ("vertueux",),
    "verveuse": ("verveux",),
    "verveuses": ("verveux",),
    "verveux": ("verveux",),
    "vésanique": ("vésanique",),
    "vésaniques": ("vésanique",),
    "vésicale": ("vésical",),
    "vésicales": ("vésical",),
    "vésical": ("vésical",),
    "vésicaux": ("vésical",),
    "vésicatoire": ("vésicatoire",),
    "vésicatoires": ("vésicatoire",),
    "vésiculaire": ("vésiculaire",),
    "vésiculaires": ("vésiculaire",),
    "vésiculeuse": ("vésiculeux",),
    "vésiculeuses": ("vésiculeux",),
    "vésiculeux": ("vésiculeux",),
    "vésiculopustuleuse": ("vésiculopustuleux",),
    "vésiculopustuleuses": ("vésiculopustuleux",),
    "vésiculopustuleux": ("vésiculopustuleux",),
    "vespérale": ("vespéral",),
    "vespérales": ("vespéral",),
    "vespéral": ("vespéral",),
    "vespéraux": ("vespéral",),
    "vespiforme": ("vespiforme",),
    "vespiformes": ("vespiforme",),
    "vestibulaire": ("vestibulaire",),
    "vestibulaires": ("vestibulaire",),
    "vestibulo-cochléaires": ("vestibulo-cochléaire",),
    "vestigiale": ("vestigial",),
    "vestigiales": ("vestigial",),
    "vestigial": ("vestigial",),
    "vestigiaux": ("vestigial",),
    "vestimentaire": ("vestimentaire",),
    "vestimentaires": ("vestimentaire",),
    "vestimentifère": ("vestimentifère",),
    "vestimentifères": ("vestimentifère",),
    "vésuvien": ("vésuvien",),
    "vésuvienne": ("vésuvien",),
    "vésuviennes": ("vésuvien",),
    "vésuviens": ("vésuvien",),
    "vétérinaire": ("vétérinaire",),
    "vétérinaires": ("vétérinaire",),
    "vétilleur": ("vétilleur",),
    "vétilleurs": ("vétilleur",),
    "vétilleuse": ("vétilleux",),
    "vétilleuses": ("vétilleux",),
    "vétilleux": ("vétilleux",),
    "vétuste": ("vétuste",),
    "vétustes": ("vétuste",),
    "veuf": ("veuf",),
    "veufs": ("veuf",),
    "veuve": ("veuf",),
    "veuves": ("veuf",),
    "veule": ("veule",),
    "veules": ("veule",),
    "vexateur": ("vexateur",),
    "vexateurs": ("vexateur",),
    "vexatrice": ("vexateur",),
    "vexatrices": ("vexateur",),
    "vexatoire": ("vexatoire",),
    "vexatoires": ("vexatoire",),
    "vexillaire": ("vexillaire",),
    "vexillaires": ("vexillaire",),
    "viable": ("viable",),
    "viables": ("viable",),
    "viagère": ("viager",),
    "viagères": ("viager",),
    "viager": ("viager",),
    "viagers": ("viager",),
    "vibratile": ("vibratile",),
    "vibratiles": ("vibratile",),
    "vibratoire": ("vibratoire",),
    "vibratoires": ("vibratoire",),
    "vibrionien": ("vibrionien",),
    "vibrionienne": ("vibrionien",),
    "vibrioniennes": ("vibrionien",),
    "vibrioniens": ("vibrionien",),
    "vicariale": ("vicarial",),
    "vicariales": ("vicarial",),
    "vicarial": ("vicarial",),
    "vicariaux": ("vicarial",),
    "vicennale": ("vicennal",),
    "vicennales": ("vicennal",),
    "vicennal": ("vicennal",),
    "vicennaux": ("vicennal",),
    "vicésimale": ("vicésimal",),
    "vicésimales": ("vicésimal",),
    "vicésimal": ("vicésimal",),
    "vicésimaux": ("vicésimal",),
    "vichyssoise": ("vichyssois",),
    "vichyssoises": ("vichyssois",),
    "vichyssois": ("vichyssois",),
    "vichyste": ("vichyste",),
    "vichystes": ("vichyste",),
    "viciable": ("viciable",),
    "viciables": ("viciable",),
    "viciateur": ("viciateur",),
    "viciateurs": ("viciateur",),
    "viciatrice": ("viciateur",),
    "viciatrices": ("viciateur",),
    "vicieuse": ("vicieux",),
    "vicieuses": ("vicieux",),
    "vicieux": ("vicieux",),
    "vicinale": ("vicinal",),
    "vicinales": ("vicinal",),
    "vicinal": ("vicinal",),
    "vicinaux": ("vicinal",),
    "vicomtale": ("vicomtal",),
    "vicomtales": ("vicomtal",),
    "vicomtal": ("vicomtal",),
    "vicomtaux": ("vicomtal",),
    "vicomtière": ("vicomtier",),
    "vicomtières": ("vicomtier",),
    "vicomtier": ("vicomtier",),
    "vicomtiers": ("vicomtier",),
    "victime": ("victime",),
    "victimes": ("victime",),
    "victorien": ("victorien",),
    "victorienne": ("victorien",),
    "victoriennes": ("victorien",),
    "victoriens": ("victorien",),
    "victorieuse": ("victorieux",),
    "victorieuses": ("victorieux",),
    "victorieux": ("victorieux",),
    "vidangeable": ("vidangeable",),
    "vidangeables": ("vidangeable",),
    "vidée": ("vidé",),
    "vidées": ("vidé",),
    "vidé": ("vidé",),
    "vide": ("vide",),
    "vidés": ("vidé",),
    "vides": ("vide",),
    "vidéo": ("vidéo",),
    "vidéographique": ("vidéographique",),
    "vidéographiques": ("vidéographique",),
    "vidien": ("vidien",),
    "vidienne": ("vidien",),
    "vidiennes": ("vidien",),
    "vidiens": ("vidien",),
    "vieille": ("vieux",),
    "vieilles": ("vieux",),
    "vieil": ("vieil",),
    "vieux": ("vieux",),
    "vieillot": ("vieillot",),
    "vieillots": ("vieillot",),
    "vieillotte": ("vieillot",),
    "vieillottes": ("vieillot",),
    "viennoise": ("viennois",),
    "viennoises": ("viennois",),
    "viennois": ("viennois",),
    "vierge": ("vierge",),
    "vierges": ("vierge",),
    "viet": ("viet",),
    "viets": ("viet",),
    "vietnamien": ("vietnamien",),
    "vietnamienne": ("vietnamien",),
    "vietnamiennes": ("vietnamien",),
    "vietnamiens": ("vietnamien",),
    "vif": ("vif",),
    "vifs": ("vif",),
    "vive": ("vif",),
    "vives": ("vif",),
    "vigésimale": ("vigésimal",),
    "vigésimales": ("vigésimal",),
    "vigésimal": ("vigésimal",),
    "vigésimaux": ("vigésimal",),
    "vigneron": ("vigneron",),
    "vigneronne": ("vigneron",),
    "vigneronnes": ("vigneron",),
    "vignerons": ("vigneron",),
    "vigoureuse": ("vigoureux",),
    "vigoureuses": ("vigoureux",),
    "vigoureux": ("vigoureux",),
    "vihueliste": ("vihueliste",),
    "vihuelistes": ("vihueliste",),
    "viking": ("viking",),
    "vikings": ("viking",),
    "vilené": ("vilené",),
    "vilenés": ("vilené",),
    "villafranchien": ("villafranchien",),
    "villafranchienne": ("villafranchien",),
    "villafranchiennes": ("villafranchien",),
    "villafranchiens": ("villafranchien",),
    "villageoise": ("villageois",),
    "villageoises": ("villageois",),
    "villageois": ("villageois",),
    "villanovien": ("villanovien",),
    "villanovienne": ("villanovien",),
    "villanoviennes": ("villanovien",),
    "villanoviens": ("villanovien",),
    "villenauxière": ("villenauxier",),
    "villenauxières": ("villenauxier",),
    "villenauxier": ("villenauxier",),
    "villenauxiers": ("villenauxier",),
    "villerière": ("villerier",),
    "villerières": ("villerier",),
    "villerier": ("villerier",),
    "villeriers": ("villerier",),
    "villeuse": ("villeux",),
    "villeuses": ("villeux",),
    "villeux": ("villeux",),
    "villositaire": ("villositaire",),
    "villositaires": ("villositaire",),
    "vinaire": ("vinaire",),
    "vinaires": ("vinaire",),
    "vindicatif": ("vindicatif",),
    "vindicatifs": ("vindicatif",),
    "vindicative": ("vindicatif",),
    "vindicatives": ("vindicatif",),
    "vineuse": ("vineux",),
    "vineuses": ("vineux",),
    "vineux": ("vineux",),
    "vingtième": ("vingtième",),
    "vingtièmes": ("vingtième",),
    "vinicole": ("vinicole",),
    "vinicoles": ("vinicole",),
    "vinifère": ("vinifère",),
    "vinifères": ("vinifère",),
    "vinique": ("vinique",),
    "viniques": ("vinique",),
    "vinylique": ("vinylique",),
    "vinyliques": ("vinylique",),
    "vinylogue": ("vinylogue",),
    "vinylogues": ("vinylogue",),
    "vioc": ("vioc",),
    "viocs": ("vioc",),
    "vioque": ("vioque",),
    "vioques": ("vioque",),
    "violable": ("violable",),
    "violables": ("violable",),
    "violat": ("violat",),
    "violats": ("violat",),
    "violateur": ("violateur",),
    "violateurs": ("violateur",),
    "violatrice": ("violateur",),
    "violatrices": ("violateur",),
    "violâtre": ("violâtre",),
    "violâtres": ("violâtre",),
    "violet": ("violet",),
    "violets": ("violet",),
    "violette": ("violet",),
    "violettes": ("violet",),
    "violine": ("violine",),
    "violines": ("violine",),
    "violurique": ("violurique",),
    "violuriques": ("violurique",),
    "virale": ("viral",),
    "virales": ("viral",),
    "viral": ("viral",),
    "viraux": ("viral",),
    "virémique": ("virémique",),
    "virémiques": ("virémique",),
    "vireur": ("vireur",),
    "vireurs": ("vireur",),
    "vireuse": ("vireux",),
    "vireuses": ("vireux",),
    "vireux": ("vireux",),
    "virginale": ("virginal",),
    "virginales": ("virginal",),
    "virginal": ("virginal",),
    "virginaux": ("virginal",),
    "virilocale": ("virilocal",),
    "virilocales": ("virilocal",),
    "virilocal": ("virilocal",),
    "virilocaux": ("virilocal",),
    "viriloïde": ("viriloïde",),
    "viriloïdes": ("viriloïde",),
    "virocide": ("virocide",),
    "virocides": ("virocide",),
    "virogène": ("virogène",),
    "virogènes": ("virogène",),
    "virologique": ("virologique",),
    "virologiques": ("virologique",),
    "virostatique": ("virostatique",),
    "virostatiques": ("virostatique",),
    "virtuelle": ("virtuel",),
    "virtuelles": ("virtuel",),
    "virtuel": ("virtuel",),
    "virtuels": ("virtuel",),
    "virucide": ("virucide",),
    "virucides": ("virucide",),
    "virulicide": ("virulicide",),
    "virulicides": ("virulicide",),
    "viscérale": ("viscéral",),
    "viscérales": ("viscéral",),
    "viscéral": ("viscéral",),
    "viscéraux": ("viscéral",),
    "viscérogène": ("viscérogène",),
    "viscérogènes": ("viscérogène",),
    "viscéromoteur": ("viscéromoteur",),
    "viscéromoteurs": ("viscéromoteur",),
    "viscéromotrice": ("viscéromoteur",),
    "viscéromotrices": ("viscéromoteur",),
    "viscérosensitif": ("viscérosensitif",),
    "viscérosensitifs": ("viscérosensitif",),
    "viscérosensitive": ("viscérosensitif",),
    "viscérosensitives": ("viscérosensitif",),
    "viscérotrope": ("viscérotrope",),
    "viscérotropes": ("viscérotrope",),
    "viscoélastique": ("viscoélastique",),
    "viscoélastiques": ("viscoélastique",),
    "viscoplastique": ("viscoplastique",),
    "viscoplastiques": ("viscoplastique",),
    "viscosimétrique": ("viscosimétrique",),
    "viscosimétriques": ("viscosimétrique",),
    "viscostatique": ("viscostatique",),
    "viscostatiques": ("viscostatique",),
    "visible": ("visible",),
    "visibles": ("visible",),
    "visigothique": ("visigothique",),
    "visigothiques": ("visigothique",),
    "visionnaire": ("visionnaire",),
    "visionnaires": ("visionnaire",),
    "visitable": ("visitable",),
    "visitables": ("visitable",),
    "visiteur": ("visiteur",),
    "visiteurs": ("visiteur",),
    "visiteuse": ("visiteur",),
    "visiteuses": ("visiteur",),
    "visqueuse": ("visqueux",),
    "visqueuses": ("visqueux",),
    "visqueux": ("visqueux",),
    "visualisable": ("visualisable",),
    "visualisables": ("visualisable",),
    "visuelle": ("visuel",),
    "visuelles": ("visuel",),
    "visuel": ("visuel",),
    "visuels": ("visuel",),
    "visuoconstructif": ("visuoconstructif",),
    "visuoconstructifs": ("visuoconstructif",),
    "visuoconstructive": ("visuoconstructif",),
    "visuoconstructives": ("visuoconstructif",),
    "visuomoteur": ("visuomoteur",),
    "visuomoteurs": ("visuomoteur",),
    "visuomotrice": ("visuomoteur",),
    "visuomotrices": ("visuomoteur",),
    "visuospatiale": ("visuospatial",),
    "visuospatiales": ("visuospatial",),
    "visuospatial": ("visuospatial",),
    "visuospatiaux": ("visuospatial",),
    "vitale": ("vital",),
    "vitales": ("vital",),
    "vital": ("vital",),
    "vitaux": ("vital",),
    "vitaliste": ("vitaliste",),
    "vitalistes": ("vitaliste",),
    "vitaminique": ("vitaminique",),
    "vitaminiques": ("vitaminique",),
    "vitaminogène": ("vitaminogène",),
    "vitaminogènes": ("vitaminogène",),
    "vitellogène": ("vitellogène",),
    "vitellogènes": ("vitellogène",),
    "viticole": ("viticole",),
    "viticoles": ("viticole",),
    "vitiligineuse": ("vitiligineux",),
    "vitiligineuses": ("vitiligineux",),
    "vitiligineux": ("vitiligineux",),
    "vitivinicole": ("vitivinicole",),
    "vitivinicoles": ("vitivinicole",),
    "vitréen": ("vitréen",),
    "vitréenne": ("vitréen",),
    "vitréennes": ("vitréen",),
    "vitréens": ("vitréen",),
    "vitrescible": ("vitrescible",),
    "vitrescibles": ("vitrescible",),
    "vitreuse": ("vitreux",),
    "vitreuses": ("vitreux",),
    "vitreux": ("vitreux",),
    "vitrifiable": ("vitrifiable",),
    "vitrifiables": ("vitrifiable",),
    "vitrificateur": ("vitrificateur",),
    "vitrificateurs": ("vitrificateur",),
    "vitrificatrice": ("vitrificateur",),
    "vitrificatrices": ("vitrificateur",),
    "vitrificatif": ("vitrificatif",),
    "vitrificatifs": ("vitrificatif",),
    "vitrificative": ("vitrificatif",),
    "vitrificatives": ("vitrificatif",),
    "vitriolique": ("vitriolique",),
    "vitrioliques": ("vitriolique",),
    "vitrocéramique": ("vitrocéramique",),
    "vitrocéramiques": ("vitrocéramique",),
    "vitrocéramisable": ("vitrocéramisable",),
    "vitrocéramisables": ("vitrocéramisable",),
    "vitulaire": ("vitulaire",),
    "vitulaires": ("vitulaire",),
    "vitupérateur": ("vitupérateur",),
    "vitupérateurs": ("vitupérateur",),
    "vitupératrice": ("vitupérateur",),
    "vitupératrices": ("vitupérateur",),
    "vivable": ("vivable",),
    "vivables": ("vivable",),
    "vivace": ("vivace",),
    "vivaces": ("vivace",),
    "vivificateur": ("vivificateur",),
    "vivificateurs": ("vivificateur",),
    "vivificatrice": ("vivificateur",),
    "vivificatrices": ("vivificateur",),
    "vivipare": ("vivipare",),
    "vivipares": ("vivipare",),
    "vivrière": ("vivrier",),
    "vivrières": ("vivrier",),
    "vivrier": ("vivrier",),
    "vivriers": ("vivrier",),
    "vocale": ("vocal",),
    "vocales": ("vocal",),
    "vocal": ("vocal",),
    "vocaux": ("vocal",),
    "vocalique": ("vocalique",),
    "vocaliques": ("vocalique",),
    "vocatif": ("vocatif",),
    "vocatifs": ("vocatif",),
    "vocative": ("vocatif",),
    "vocatives": ("vocatif",),
    "vociférateur": ("vociférateur",),
    "vociférateurs": ("vociférateur",),
    "vocifératrice": ("vociférateur",),
    "vocifératrices": ("vociférateur",),
    "vocifère": ("vocifère",),
    "vocifères": ("vocifère",),
    "vogoule": ("vogoule",),
    "vogoules": ("vogoule",),
    "volable": ("volable",),
    "volables": ("volable",),
    "volage": ("volage",),
    "volages": ("volage",),
    "volatilisable": ("volatilisable",),
    "volatilisables": ("volatilisable",),
    "volcanique": ("volcanique",),
    "volcaniques": ("volcanique",),
    "volcanologique": ("volcanologique",),
    "volcanologiques": ("volcanologique",),
    "volcanoplutonique": ("volcanoplutonique",),
    "volcanoplutoniques": ("volcanoplutonique",),
    "volémique": ("volémique",),
    "volémiques": ("volémique",),
    "voleur": ("voleur",),
    "voleurs": ("voleur",),
    "voleuse": ("voleur",),
    "voleuses": ("voleur",),
    "volgaïque": ("volgaïque",),
    "volgaïques": ("volgaïque",),
    "volitif": ("volitif",),
    "volitifs": ("volitif",),
    "volitive": ("volitif",),
    "volitives": ("volitif",),
    "volitionnelle": ("volitionnel",),
    "volitionnelles": ("volitionnel",),
    "volitionnel": ("volitionnel",),
    "volitionnels": ("volitionnel",),
    "volontaire": ("volontaire",),
    "volontaires": ("volontaire",),
    "volontariste": ("volontariste",),
    "volontaristes": ("volontariste",),
    "voltaïque": ("voltaïque",),
    "voltaïques": ("voltaïque",),
    "voltairien": ("voltairien",),
    "voltairienne": ("voltairien",),
    "voltairiennes": ("voltairien",),
    "voltairiens": ("voltairien",),
    "voltigeur": ("voltigeur",),
    "voltigeurs": ("voltigeur",),
    "voltigeuse": ("voltigeur",),
    "voltigeuses": ("voltigeur",),
    "volubile": ("volubile",),
    "volubiles": ("volubile",),
    "volumétrique": ("volumétrique",),
    "volumétriques": ("volumétrique",),
    "volumineuse": ("volumineux",),
    "volumineuses": ("volumineux",),
    "volumineux": ("volumineux",),
    "volumique": ("volumique",),
    "volumiques": ("volumique",),
    "voluptuaire": ("voluptuaire",),
    "voluptuaires": ("voluptuaire",),
    "voluptueuse": ("voluptueux",),
    "voluptueuses": ("voluptueux",),
    "voluptueux": ("voluptueux",),
    "vomérien": ("vomérien",),
    "vomérienne": ("vomérien",),
    "vomériennes": ("vomérien",),
    "vomériens": ("vomérien",),
    "voméronasale": ("voméronasal",),
    "voméronasales": ("voméronasal",),
    "voméronasal": ("voméronasal",),
    "voméronasaux": ("voméronasal",),
    "vomique": ("vomique",),
    "vomiques": ("vomique",),
    "vomisseur": ("vomisseur",),
    "vomisseurs": ("vomisseur",),
    "vomisseuse": ("vomisseur",),
    "vomisseuses": ("vomisseur",),
    "vomitif": ("vomitif",),
    "vomitifs": ("vomitif",),
    "vomitive": ("vomitif",),
    "vomitives": ("vomitif",),
    "vorace": ("vorace",),
    "voraces": ("vorace",),
    "vorticiste": ("vorticiste",),
    "vorticistes": ("vorticiste",),
    "vosgien": ("vosgien",),
    "vosgienne": ("vosgien",),
    "vosgiennes": ("vosgien",),
    "vosgiens": ("vosgien",),
    "votif": ("votif",),
    "votifs": ("votif",),
    "votive": ("votif",),
    "votives": ("votif",),
    "vôtre": ("vôtre",),
    "vôtres": ("vôtre",),
    "voyageur": ("voyageur",),
    "voyageurs": ("voyageur",),
    "voyageuse": ("voyageur",),
    "voyageuses": ("voyageur",),
    "voyer": ("voyer",),
    "voyers": ("voyer",),
    "voyeuriste": ("voyeuriste",),
    "voyeuristes": ("voyeuriste",),
    "vraisemblable": ("vraisemblable",),
    "vraisemblables": ("vraisemblable",),
    "vrillaire": ("vrillaire",),
    "vrillaires": ("vrillaire",),
    "vulcanale": ("vulcanal",),
    "vulcanales": ("vulcanal",),
    "vulcanal": ("vulcanal",),
    "vulcanaux": ("vulcanal",),
    "vulcanien": ("vulcanien",),
    "vulcanienne": ("vulcanien",),
    "vulcaniennes": ("vulcanien",),
    "vulcaniens": ("vulcanien",),
    "vulcanisable": ("vulcanisable",),
    "vulcanisables": ("vulcanisable",),
    "vulcanologique": ("vulcanologique",),
    "vulcanologiques": ("vulcanologique",),
    "vulgaire": ("vulgaire",),
    "vulgaires": ("vulgaire",),
    "vulgarisateur": ("vulgarisateur",),
    "vulgarisateurs": ("vulgarisateur",),
    "vulgarisatrice": ("vulgarisateur",),
    "vulgarisatrices": ("vulgarisateur",),
    "vulnérable": ("vulnérable",),
    "vulnérables": ("vulnérable",),
    "vulnéraire": ("vulnéraire",),
    "vulnéraires": ("vulnéraire",),
    "vultueuse": ("vultueux",),
    "vultueuses": ("vultueux",),
    "vultueux": ("vultueux",),
    "vulvaire": ("vulvaire",),
    "vulvaires": ("vulvaire",),
    "vulviforme": ("vulviforme",),
    "vulviformes": ("vulviforme",),
    "wagnérien": ("wagnérien",),
    "wagnérienne": ("wagnérien",),
    "wagnériennes": ("wagnérien",),
    "wagnériens": ("wagnérien",),
    "wahhabite": ("wahhabite",),
    "wahhabites": ("wahhabite",),
    "wallérien": ("wallérien",),
    "wallérienne": ("wallérien",),
    "wallériennes": ("wallérien",),
    "wallériens": ("wallérien",),
    "wallon": ("wallon",),
    "wallonne": ("wallon",),
    "wallonnes": ("wallon",),
    "wallons": ("wallon",),
    "waterproof": ("waterproof",),
    "welche": ("welche",),
    "welches": ("welche",),
    "welter": ("welter",),
    "welters": ("welter",),
    "whig": ("whig",),
    "whigs": ("whig",),
    "wisigothique": ("wisigothique",),
    "wisigothiques": ("wisigothique",),
    "wolffien": ("wolffien",),
    "wolffienne": ("wolffien",),
    "wolffiennes": ("wolffien",),
    "wolffiens": ("wolffien",),
    "wolof": ("wolof",),
    "wolofs": ("wolof",),
    "wormien": ("wormien",),
    "wormiens": ("wormien",),
    "wurmien": ("wurmien",),
    "würmien": ("würmien",),
    "wurmienne": ("wurmien",),
    "würmienne": ("würmien",),
    "wurmiennes": ("wurmien",),
    "würmiennes": ("würmien",),
    "wurmiens": ("wurmien",),
    "würmiens": ("würmien",),
    "wurtembergeoise": ("wurtembergeois",),
    "wurtembergeoises": ("wurtembergeois",),
    "wurtembergeois": ("wurtembergeois",),
    "wyandotte": ("wyandotte",),
    "wyandottes": ("wyandotte",),
    "xanthique": ("xanthique",),
    "xanthiques": ("xanthique",),
    "xanthochromique": ("xanthochromique",),
    "xanthochromiques": ("xanthochromique",),
    "xanthocobaltique": ("xanthocobaltique",),
    "xanthocobaltiques": ("xanthocobaltique",),
    "xanthoderme": ("xanthoderme",),
    "xanthodermes": ("xanthoderme",),
    "xanthogénique": ("xanthogénique",),
    "xanthogéniques": ("xanthogénique",),
    "xanthogranulomateuse": ("xanthogranulomateux",),
    "xanthogranulomateuses": ("xanthogranulomateux",),
    "xanthogranulomateux": ("xanthogranulomateux",),
    "xanthomateuse": ("xanthomateux",),
    "xanthomateuses": ("xanthomateux",),
    "xanthomateux": ("xanthomateux",),
    "xanthonique": ("xanthonique",),
    "xanthoniques": ("xanthonique",),
    "xénobiotique": ("xénobiotique",),
    "xénobiotiques": ("xénobiotique",),
    "xénogénique": ("xénogénique",),
    "xénogéniques": ("xénogénique",),
    "xénomorphe": ("xénomorphe",),
    "xénomorphes": ("xénomorphe",),
    "xénopathique": ("xénopathique",),
    "xénopathiques": ("xénopathique",),
    "xénophile": ("xénophile",),
    "xénophiles": ("xénophile",),
    "xénophobe": ("xénophobe",),
    "xénophobes": ("xénophobe",),
    "xénoplastique": ("xénoplastique",),
    "xénoplastiques": ("xénoplastique",),
    "xénotrope": ("xénotrope",),
    "xénotropes": ("xénotrope",),
    "xérochiménique": ("xérochiménique",),
    "xérochiméniques": ("xérochiménique",),
    "xérodermique": ("xérodermique",),
    "xérodermiques": ("xérodermique",),
    "xérographique": ("xérographique",),
    "xérographiques": ("xérographique",),
    "xérophile": ("xérophile",),
    "xérophiles": ("xérophile",),
    "xérophytique": ("xérophytique",),
    "xérophytiques": ("xérophytique",),
    "xérothérique": ("xérothérique",),
    "xérothériques": ("xérothérique",),
    "xérothermique": ("xérothermique",),
    "xérothermiques": ("xérothermique",),
    "xiphodyme": ("xiphodyme",),
    "xiphodymes": ("xiphodyme",),
    "xiphoïde": ("xiphoïde",),
    "xiphoïdes": ("xiphoïde",),
    "xiphoïdien": ("xiphoïdien",),
    "xiphoïdienne": ("xiphoïdien",),
    "xiphoïdiennes": ("xiphoïdien",),
    "xiphoïdiens": ("xiphoïdien",),
    "xiphopage": ("xiphopage",),
    "xiphopages": ("xiphopage",),
    "xyloglyptique": ("xyloglyptique",),
    "xyloglyptiques": ("xyloglyptique",),
    "xylographique": ("xylographique",),
    "xylographiques": ("xylographique",),
    "xylologique": ("xylologique",),
    "xylologiques": ("xylologique",),
    "xylonique": ("xylonique",),
    "xyloniques": ("xylonique",),
    "xylophage": ("xylophage",),
    "xylophages": ("xylophage",),
    "yankee": ("yankee",),
    "yankees": ("yankee",),
    "yddisch": ("yddisch",),
    "yddish": ("yddish",),
    "yéménite": ("yéménite",),
    "yéménites": ("yéménite",),
    "yéyé": ("yéyé",),
    "yiddish": ("yiddish",),
    "yogique": ("yogique",),
    "yogiques": ("yogique",),
    "yorkshire": ("yorkshire",),
    "yougoslave": ("yougoslave",),
    "yougoslaves": ("yougoslave",),
    "yttrifère": ("yttrifère",),
    "yttrifères": ("yttrifère",),
    "yttrique": ("yttrique",),
    "yttriques": ("yttrique",),
    "zain": ("zain",),
    "zains": ("zain",),
    "zaïroise": ("zaïrois",),
    "zaïroises": ("zaïrois",),
    "zaïrois": ("zaïrois",),
    "zalambdodonte": ("zalambdodonte",),
    "zalambdodontes": ("zalambdodonte",),
    "zambien": ("zambien",),
    "zambienne": ("zambien",),
    "zambiennes": ("zambien",),
    "zambiens": ("zambien",),
    "zéen": ("zéen",),
    "zéens": ("zéen",),
    "zélandaise": ("zélandais",),
    "zélandaises": ("zélandais",),
    "zélandais": ("zélandais",),
    "zélateur": ("zélateur",),
    "zélateurs": ("zélateur",),
    "zélatrice": ("zélateur",),
    "zélatrices": ("zélateur",),
    "zélote": ("zélote",),
    "zélotes": ("zélote",),
    "zen": ("zen",),
    "zénithale": ("zénithal",),
    "zénithales": ("zénithal",),
    "zénithal": ("zénithal",),
    "zénithaux": ("zénithal",),
    "zenkérien": ("zenkérien",),
    "zenkérienne": ("zenkérien",),
    "zenkériennes": ("zenkérien",),
    "zenkériens": ("zenkérien",),
    "zéolitique": ("zéolitique",),
    "zéolitiques": ("zéolitique",),
    "zéotropique": ("zéotropique",),
    "zéotropiques": ("zéotropique",),
    "zéphyrien": ("zéphyrien",),
    "zéphyrienne": ("zéphyrien",),
    "zéphyriennes": ("zéphyrien",),
    "zéphyriens": ("zéphyrien",),
    "zététique": ("zététique",),
    "zététiques": ("zététique",),
    "zimbabwéen": ("zimbabwéen",),
    "zimbabwéenne": ("zimbabwéen",),
    "zimbabwéennes": ("zimbabwéen",),
    "zimbabwéens": ("zimbabwéen",),
    "zincifère": ("zincifère",),
    "zincifères": ("zincifère",),
    "zingueur": ("zingueur",),
    "zingueurs": ("zingueur",),
    "zingueuse": ("zingueur",),
    "zingueuses": ("zingueur",),
    "zinzin": ("zinzin",),
    "zinzins": ("zinzin",),
    "zirconifère": ("zirconifère",),
    "zirconifères": ("zirconifère",),
    "zodiacale": ("zodiacal",),
    "zodiacales": ("zodiacal",),
    "zodiacal": ("zodiacal",),
    "zodiacaux": ("zodiacal",),
    "zoïdogame": ("zoïdogame",),
    "zoïdogames": ("zoïdogame",),
    "zonaire": ("zonaire",),
    "zonaires": ("zonaire",),
    "zonale": ("zonal",),
    "zonales": ("zonal",),
    "zonal": ("zonal",),
    "zonaux": ("zonal",),
    "zonateuse": ("zonateux",),
    "zonateuses": ("zonateux",),
    "zonateux": ("zonateux",),
    "zonière": ("zonier",),
    "zonières": ("zonier",),
    "zonier": ("zonier",),
    "zoniers": ("zonier",),
    "zonulaire": ("zonulaire",),
    "zonulaires": ("zonulaire",),
    "zoochore": ("zoochore",),
    "zoochores": ("zoochore",),
    "zoogène": ("zoogène",),
    "zoogènes": ("zoogène",),
    "zoographique": ("zoographique",),
    "zoographiques": ("zoographique",),
    "zooïde": ("zooïde",),
    "zooïdes": ("zooïde",),
    "zoolâtre": ("zoolâtre",),
    "zoolâtres": ("zoolâtre",),
    "zoologique": ("zoologique",),
    "zoologiques": ("zoologique",),
    "zoomorphe": ("zoomorphe",),
    "zoomorphes": ("zoomorphe",),
    "zoomorphique": ("zoomorphique",),
    "zoomorphiques": ("zoomorphique",),
    "zoopathique": ("zoopathique",),
    "zoopathiques": ("zoopathique",),
    "zoophage": ("zoophage",),
    "zoophages": ("zoophage",),
    "zoophile": ("zoophile",),
    "zoophiles": ("zoophile",),
    "zoophorique": ("zoophorique",),
    "zoophoriques": ("zoophorique",),
    "zoophytophage": ("zoophytophage",),
    "zoophytophages": ("zoophytophage",),
    "zooplanctonique": ("zooplanctonique",),
    "zooplanctoniques": ("zooplanctonique",),
    "zoosanitaire": ("zoosanitaire",),
    "zoosanitaires": ("zoosanitaire",),
    "zoosémiotique": ("zoosémiotique",),
    "zoosémiotiques": ("zoosémiotique",),
    "zootechnique": ("zootechnique",),
    "zootechniques": ("zootechnique",),
    "zoothérapeutique": ("zoothérapeutique",),
    "zoothérapeutiques": ("zoothérapeutique",),
    "zootrope": ("zootrope",),
    "zootropes": ("zootrope",),
    "zoroastrien": ("zoroastrien",),
    "zoroastrienne": ("zoroastrien",),
    "zoroastriennes": ("zoroastrien",),
    "zoroastriens": ("zoroastrien",),
    "zoroastrique": ("zoroastrique",),
    "zoroastriques": ("zoroastrique",),
    "zostérien": ("zostérien",),
    "zostérienne": ("zostérien",),
    "zostériennes": ("zostérien",),
    "zostériens": ("zostérien",),
    "zostériforme": ("zostériforme",),
    "zostériformes": ("zostériforme",),
    "zozoteur": ("zozoteur",),
    "zozoteurs": ("zozoteur",),
    "zozoteuse": ("zozoteur",),
    "zozoteuses": ("zozoteur",),
    "zumique": ("zumique",),
    "zumiques": ("zumique",),
    "zurichoise": ("zurichois",),
    "zurichoises": ("zurichois",),
    "zurichois": ("zurichois",),
    "zutique": ("zutique",),
    "zutiques": ("zutique",),
    "zwinglien": ("zwinglien",),
    "zwinglienne": ("zwinglien",),
    "zwingliennes": ("zwinglien",),
    "zwingliens": ("zwinglien",),
    "zygodactile": ("zygodactile",),
    "zygodactiles": ("zygodactile",),
    "zygomatique": ("zygomatique",),
    "zygomatiques": ("zygomatique",),
    "zygomorphe": ("zygomorphe",),
    "zygomorphes": ("zygomorphe",),
    "zygotique": ("zygotique",),
    "zygotiques": ("zygotique",),
    "zymogène": ("zymogène",),
    "zymogènes": ("zymogène",),
    "zymonucléique": ("zymonucléique",),
    "zymonucléiques": ("zymonucléique",),
    "zymotique": ("zymotique",),
    "zymotiques": ("zymotique",)
}